class LockSingler
{
	HANDLE hSema;
	BOOL Locked;
public:
	LockSingler(const LPTSTR lpName = NULL)
	{
		hSema = CreateSemaphore(NULL, 1, 1, lpName);
		Locked = FALSE;
	}
	~LockSingler()
	{
		CloseHandle(hSema);
	}
	BOOL IsLocked()
	{
		return Locked;
	}
	DWORD Lock( const DWORD dwTimeOut = INFINITE )
	{
		Locked = TRUE;
		return WaitForSingleObject(hSema, dwTimeOut);
	}
	BOOL Unlock()
	{
		Locked = FALSE;
		return ReleaseSemaphore(hSema, 1, NULL);
	}
};

class LockSinglerEve : public LockSingler
{
	HANDLE hSet;
	BOOL Set;
public:
	LockSinglerEve(const LPTSTR lpName = NULL, const LPTSTR lpEve = NULL) : LockSingler(lpName)
	{
		hSet = CreateSemaphore(NULL, 1, 1, lpEve);
		Set = TRUE;
	}
	~LockSinglerEve()
	{
		CloseHandle(hSet);
	}
	BOOL Lock( const DWORD dwTimeOut = INFINITE )
	{
		if(!Set){
			WaitForSingleObject(hSet, INFINITE);
			ReleaseSemaphore(hSet, 1, NULL);
		}
		return LockSingler::Lock(dwTimeOut);
	}
	BOOL IsSet()
	{
		return Set;
	}
	void SetEvent()
	{
		ReleaseSemaphore(hSet, 1, NULL);
		Set = TRUE;
	}
	void ResetEvent()
	{
		if(Set){
			WaitForSingleObject(hSet, INFINITE);
			Set = FALSE;
		}
	}
};

class AutoLocker
{
	LockSingler * sema;
public:
	AutoLocker(LockSingler * const s)
	{
		s->Lock();
		sema = s;
	}
	~AutoLocker()
	{
		sema->Unlock();
	}
};

class AutoUnLocker
{
	LockSingler * sema;
public:
	AutoUnLocker(LockSingler * const s)
	{
		sema = s;
	}
	~AutoUnLocker()
	{
		sema->Unlock();
	}
};
