template <class TYPE> class StrIdxArray
{
	template <class TYP> struct StrIdxArrayNode
	{
		TYP * Item;
		StrIdxArrayNode * Next;
		StrIdxArrayNode()
		{
			Item = NULL;
			Next = NULL;
		}
		~StrIdxArrayNode()
		{
			if(Item != NULL) delete Item;
			if(Next != NULL) delete [] Next;
		}
	};
	StrIdxArrayNode<TYPE> item[(UCHAR_MAX+1)];
	LockSingler Sema;
	void Hash(unsigned char & key, const void * const la, const int len)
	{
		int i;
		for(i = 0; i < len; i++) key ^= (key<<1) ^ ((unsigned char *)la)[i];
	}
	StrIdxArrayNode<TYPE> & AddLabel(const _TCHAR * const la)
	{
		unsigned char key, uc;
		int len;
		StrIdxArrayNode<TYPE> * next;
		key = 0;
		len = sizeof(_TCHAR)*_tcslen(la) - sizeof(_TCHAR) + 1;
		Hash(key, la, len);
		if(item[key].Item == NULL){
			item[key].Item = new TYPE(la);
			return item[key];
		}
		next = item;
		uc = 0;
		do{
			if(_tcscmp(next[key].Item->label(), la)==0) return next[key];
			if(next[key].Next == NULL) next[key].Next = new StrIdxArrayNode<TYPE>[(UCHAR_MAX+1)];
			next = next[key].Next;
			key ^= ++uc;
			Hash(key, la, len);
		}while(next[key].Item != NULL);
		next[key].Item = new TYPE(la);
		return next[key];
	}
	StrIdxArrayNode<TYPE> * Find(const _TCHAR * const la)
	{
		unsigned char key, uc;
		int len;
		StrIdxArrayNode<TYPE> * next;
		key = 0;
		len = sizeof(_TCHAR)*_tcslen(la) - sizeof(_TCHAR) + 1;
		Hash(key, la, len);
		if(item[key].Item == NULL) return NULL;
		next = item;
		uc = 0;
		do{
			if(_tcscmp(next[key].Item->label(), la)==0) return &next[key];
			if(next[key].Next == NULL) return NULL;
			next = next[key].Next;
			key ^= ++uc;
			Hash(key, la, len);
		}while(next[key].Item != NULL);
		return NULL;
	}
	TYPE * MikeL(StrIdxArrayNode<TYPE> & no)
	{
		int i;
		TYPE * tmp;
		if(no.Next == NULL) return NULL;
		for(i = 0; i < (UCHAR_MAX+1); i++){
			if(no.Next[i].Item != NULL){
				tmp = no.Next[i].Item;
				no.Next[i].Item = MikeL(no.Next[i]);
				return tmp;
			}
		}
		delete [] no.Next;
		no.Next = NULL;
		return NULL;
	}
public:
	StrIdxArray()
	{
	}
	~StrIdxArray()
	{
		Clear();
	}
	TYPE * Get(const _TCHAR * const la)
	{
		AutoLocker al(&Sema);
		StrIdxArrayNode<TYPE> * n;
		if((n=Find(la)) == NULL) return NULL;
		return n->Item;
	}
	bool Get(const _TCHAR * const la, TYPE & to)
	{
		AutoLocker al(&Sema);
		StrIdxArrayNode<TYPE> * n;
		if((n=Find(la)) == NULL) return false;
		to = *n->Item;
		return true;
	}
	bool Exist(const _TCHAR * const la)
	{
		AutoLocker al(&Sema);
		return Find(la) != NULL;
	}
	bool Delete(const _TCHAR * const la)
	{
		AutoLocker al(&Sema);
		StrIdxArrayNode<TYPE> * n;
		if((n=Find(la)) == NULL) return false;
		delete n->Item;
		n->Item = MikeL(*n);
		return true;
	}
	void Clear()
	{
		AutoLocker al(&Sema);
		int i;
		for(i = 0; i < (UCHAR_MAX+1); i++) while(item[i].Item != NULL){
			delete item[i].Item;
			item[i].Item = MikeL(item[i]);
		}
	}
	TYPE & operator[] (const _TCHAR * const la)
	{
		AutoLocker al(&Sema);
		return *AddLabel(la).Item;
	}
};

class SIAItem
{
protected:
	_TCHAR * Label;
public:
	SIAItem(const _TCHAR * const la)
	{
		Label = new _TCHAR[_tcslen(la)+1];
		_tcscpy(Label, la);
	}
	~SIAItem()
	{
		delete [] Label;
	}
	const _TCHAR * const & label()
	{
		return Label;
	}
};

template <class T> class SIAIntItem : public SIAItem
{
	T i;
public:
	SIAIntItem(const _TCHAR * const la) : SIAItem(la)
	{
		i = 0;
	}
	T get()
	{
		return i;
	}
	T set(const T & x)
	{
		return i = x;
	}
	T inc()
	{
		return ++i;
	}
	T dec()
	{
		return --i;
	}
};

class SIARFileItem : public SIAItem
{
protected:
	HANDLE file;
	LockSingler RSema;
public:
	SIARFileItem(const _TCHAR * const la) : SIAItem(la)
	{
		file = CreateFile(la,GENERIC_READ,FILE_SHARE_READ,
			NULL,OPEN_EXISTING,FILE_ATTRIBUTE_NORMAL,NULL);
	}
	~SIARFileItem()
	{
		AutoLocker al(&RSema);
		CloseHandle(file);
	}
	DWORD GetSize(DWORD & SizeHigh)
	{
		AutoLocker al(&RSema);
		return GetFileSize(file, &SizeHigh);
	}
	DWORD Read(LPVOID lpBuffer, DWORD ToRead)
	{
		AutoLocker al(&RSema);
		DWORD len;
		ReadFile(file, lpBuffer, ToRead, &len, NULL);
		return len;
	}
	DWORD ZRead(LPVOID lpBuffer, DWORD ToRead)
	{
		AutoLocker al(&RSema);
		DWORD len;
		LONG high = 0;
		SetFilePointer(file, 0, &high, FILE_BEGIN);
		ReadFile(file, lpBuffer, ToRead, &len, NULL);
		return len;
	}
	DWORD PRead(LPVOID lpBuffer, DWORD ToRead, LONG & tom, LONG & high)
	{
		AutoLocker al(&RSema);
		DWORD len;
		tom = SetFilePointer(file, tom, &high, FILE_BEGIN);
		ReadFile(file, lpBuffer, ToRead, &len, NULL);
		return len;
	}
	intptr_t AllRead(PWCArray<char> & re)
	{
		AutoLocker al(&RSema);
		DWORD size, len;
		SetFilePointer(file, 0, NULL, FILE_BEGIN);
		size = GetFileSize(file, NULL);
		re.SetLength(re.GetLength()+(intptr_t)size);
		re.SetLength(re.GetLength()-(intptr_t)size);
		ReadFile(file, re.GetData()+re.GetLength(), size, &len, NULL);
		re.SetLength(re.GetLength()+(intptr_t)len);
		return (intptr_t)len;
	}
	intptr_t AllText(PWCArray<_TCHAR> & re)
	{
		AutoLocker al(&RSema);
		DWORD size, len;
		SetFilePointer(file, 0, NULL, FILE_BEGIN);
		size = GetFileSize(file, NULL);
		len = size/sizeof(_TCHAR);
		size = sizeof(_TCHAR)*len;
		re.SetLength(re.GetLength()+(intptr_t)len);
		re.SetLength(re.GetLength()-(intptr_t)len);
		ReadFile(file, (LPVOID)(re.GetData()+re.GetLength()), size, &len, NULL);
		re.SetLength(re.GetLength()+(intptr_t)(len/=sizeof(_TCHAR)));
		return (intptr_t)len;
	}
};

class SIAWFileItem : public SIAItem
{
protected:
	HANDLE file;
	LockSingler WSema;
public:
	SIAWFileItem(const _TCHAR * const la) : SIAItem(la)
	{
		LONG high = 0;
		file = CreateFile(la,GENERIC_WRITE,0,
			NULL,OPEN_ALWAYS,FILE_ATTRIBUTE_NORMAL,NULL);
		SetFilePointer(file, 0, &high, FILE_END);
	}
	~SIAWFileItem()
	{
		AutoLocker al(&WSema);
		CloseHandle(file);
	}
	DWORD GetSize(DWORD & SizeHigh)
	{
		AutoLocker al(&WSema);
		return GetFileSize(file, &SizeHigh);
	}
	DWORD Write(LPCVOID lpBuffer, DWORD ToWrite)
	{
		AutoLocker al(&WSema);
		DWORD len;
		WriteFile(file, lpBuffer, ToWrite, &len, NULL);
		return len;
	}
	DWORD ZWrite(LPCVOID lpBuffer, DWORD ToWrite)
	{
		AutoLocker al(&WSema);
		DWORD len;
		LONG high = 0;
		SetFilePointer(file, 0, &high, FILE_BEGIN);
		WriteFile(file, lpBuffer, ToWrite, &len, NULL);
		SetEndOfFile(file);
		return len;
	}
};
