struct HeapObjHead
{
	int8_t * data;
	intptr_t datasize;
	HANDLE mutex;
	uint32_t refcount;
};
struct HeapObj
{
	HeapObjHead head;
	union{
		int8_t data[1];
		intptr_t limitsize;
	} body;
	void createmutex()
	{
		HANDLE mut;
		if(head.mutex != NULL) return;
		*(intptr_t *)&head.mutex = ~NULL;
		mut = CreateMutex(NULL, FALSE, NULL);
		if((intptr_t)head.mutex == ~NULL){
			head.mutex = mut;
		}else{
			CloseHandle(mut);
		}
	}
	void lock()
	{
		createmutex();
		WaitForSingleObject(head.mutex, INFINITE);
	}
	void unlock()
	{
		ReleaseMutex(head.mutex);
	}
	int8_t * at(intptr_t i)
	{
		i %= head.datasize;
		if(i < 0) i += head.datasize;
		return head.data + i;
	}
	void delEte()
	{
		if(head.data != body.data) sszrefdeletefunc(head.data);
		if(head.mutex != NULL) CloseHandle(head.mutex);
		sszrefdeletefunc(this);
	}
};
struct Reference
{
	HeapObj * pointer;
	intptr_t position;
	intptr_t length;
	void init()
	{
		pointer = NULL;
		position = length = 0;
	}
	bool null() const
	{
		return pointer == NULL;
	}
	HeapObj * obj() const
	{
		return (HeapObj *)((intptr_t)pointer & INTPTR_MAX);
	}
	intptr_t pos() const
	{
		return position;
	}
	intptr_t len() const
	{
		if(length < 0){
			return obj()->head.datasize;
		}
		return length;
	}
	intptr_t size() const
	{
		if(null()) return 0;
		return obj()->head.datasize;
	}
	uint32_t refcnt() const
	{
		if(null()) return 0;
		return obj()->head.refcount;
	}
	void countup()
	{
		if(null()) return;
		obj()->head.refcount++;
	}
	HeapObj * release()
	{
		HeapObj * p;
		p = obj();
		if((intptr_t)pointer < 0){
			p->head.refcount--;
		}else{
			p = NULL;
		}
		init();
		return p;
	}
	void releaseanddelete()
	{
		HeapObj * p;
		if(null()) return;
		p = release();
		if(p->head.refcount == 0) p->delEte();
	}
	HeapObj * copy(const Reference & r)
	{
		HeapObj * p;
		if(r.null()) return release();
		p = pointer;
		*this = r;
		if(obj() == (HeapObj *)((intptr_t)p & INTPTR_MAX)){
			if((intptr_t)p < 0){
				if((intptr_t)pointer >= 0){
					p = pointer;
					p->head.refcount--;
				}else{
					p = NULL;
				}
			}else{
				if((intptr_t)pointer < 0) p->head.refcount++;
				p = NULL;
			}
			return p;
		}else if((intptr_t)p < 0){
			p = (HeapObj *)((intptr_t)p & INTPTR_MAX);
			p->head.refcount--;
		}else{
			p = NULL;
		}
		if((intptr_t)pointer < 0) obj()->head.refcount++;
		return p;
	}
	HeapObj * sref(const Reference & r)
	{
		HeapObj * p;
		if(r.null()) return release();
		p = pointer;
		*this = r;
		*(intptr_t *)&pointer |= INTPTR_MIN;
		if(obj() == (HeapObj *)((intptr_t)p & INTPTR_MAX)){
			if((intptr_t)p >= 0) p->head.refcount++;
			return NULL;
		}else if((intptr_t)p < 0){
			p = (HeapObj *)((intptr_t)p & INTPTR_MAX);
			p->head.refcount--;
		}else{
			p = NULL;
		}
		obj()->head.refcount++;
		return p;
	}
	HeapObj * wref(const Reference & r)
	{
		HeapObj * p;
		if(r.null()) return release();
		p = pointer;
		*this = r;
		*(intptr_t *)&pointer &= INTPTR_MAX;
		if(pointer == (HeapObj *)((intptr_t)p & INTPTR_MAX)){
			if((intptr_t)p < 0){
				p = pointer;
				p->head.refcount--;
			}else{
				p = NULL;
			}
			return p;
		}else if((intptr_t)p < 0){
			p = (HeapObj *)((intptr_t)p & INTPTR_MAX);
			p->head.refcount--;
		}else{
			p = NULL;
		}
		return p;
	}
	void lock()
	{
		if(null()) return;
		obj()->lock();
	}
	void unlock()
	{
		if(null()) return;
		obj()->unlock();
	}
//////////////////////////////////////////////////////////////////////////////
	int8_t * atpos() const
	{
		return obj()->head.data + position;
	}
	int8_t * refat(intptr_t i)
	{
		intptr_t l;
		if(length < 0){
			l = obj()->head.datasize;
			i %= l;
			if(i < 0) i += l;
			return obj()->head.data+i;
		}
		i %= length;
		if(i < 0) i += length;
		return obj()->head.data+position+i;
	}
	int8_t * listat(const intptr_t i)
	{
		return obj()->at(i);
	}
	int8_t * listnewat(const intptr_t i, const intptr_t size)
	{
		intptr_t idx;
		if(i < 0){
			if(null()){
				listnew(-i*size);
				return obj()->head.data;
			}
			idx = addsize(-i*size);
			return obj()->head.data + idx;
		}
		if(null()){
			listnew((i+1)*size);
		}else if((i+1)*size > obj()->head.datasize){
			addsize((i+1)*size - obj()->head.datasize);
		}
		return obj()->head.data + i*size;
	}
	void refnew(const intptr_t s)
	{
		if(s < 0) return;
		pointer = (HeapObj *)sszrefnewfunc(sizeof(HeapObjHead)+s);
		pointer->head.data = pointer->body.data;
		pointer->head.datasize = length = s;
		position = 0;
		pointer->head.mutex = NULL;
		pointer->head.refcount = 1;
		*(intptr_t *)&pointer |= INTPTR_MIN;
	}
	void listnew(const intptr_t s)
	{
		if(s < 0) return;
		pointer = (HeapObj *)sszrefnewfunc(sizeof(HeapObj));
		pointer->head.data = (int8_t *)sszrefnewfunc(s);
		pointer->head.datasize = pointer->body.limitsize = s;
		position = 0;
		length = -1;
		pointer->head.mutex = NULL;
		pointer->head.refcount = 1;
		*(intptr_t *)&pointer |= INTPTR_MIN;
	}
	intptr_t addsize(const intptr_t s)
	{
		intptr_t tmps;
		int8_t * tmpd;
		if(null()){
			listnew(s);
			return 0;
		}
		tmps = obj()->head.datasize;
		if(s <= 0) return tmps;
		obj()->head.datasize += s;
		if(obj()->head.datasize > obj()->body.limitsize){
			tmpd = obj()->head.data;
			obj()->body.limitsize = obj()->head.datasize + (obj()->head.datasize >> 2);
			obj()->head.data = (int8_t *)sszrefnewfunc(obj()->body.limitsize);
			memcpy(obj()->head.data, tmpd, tmps);
			sszrefdeletefunc(tmpd);
		}
		return tmps;
	}
	void slice(const intptr_t kara, const intptr_t made, const intptr_t size)
	{
		intptr_t po, le;
		if(null()) return;
		if(len() == 0){
			init();
			return;
		}
		po = (kara*size) % len();
		if(po < 0) po += len();
		le = (made*size) % len();
		if(le < 0) le += len();
		if(po > le){
			position += le;
			length = po - le + size;
		}else{
			position += po;
			length = le - po + size;
		}
	}
};

struct Thread
{
	HANDLE handle;
	void init()
	{
		handle = NULL;
	}
	bool null() const
	{
		return handle == NULL;
	}
	void wait()
	{
		if(null()) return;
		WaitForSingleObject(handle, INFINITE);
		CloseHandle(handle);
		handle = NULL;
	}
	void create(unsigned (__stdcall * const lsr)(void *), void * const param)
	{
		wait();
		handle = (HANDLE)_beginthreadex(NULL, 0, lsr, param, 0, NULL);
	}
};
