struct OmCompiler
{
	PWCArray<wchar_t> * filename;
	int gyousuu;
	struct KuwashiiType
	{
		int32_t id;
		PWCArray<intptr_t> kwsk;
		KuwashiiType & operator = (const KuwashiiType & x)
		{
			id = x.id;
			kwsk = x.kwsk;
			return *this;
		}
	};
	class XCompi
	{
	protected:
		OmCompiler * pomc;
		void Backpatch(PWCArray<uint8_t> & bytecode, PWCArray<intptr_t> & plist)
		{
			int i;
			for(i = 0; i < plist.GetLength(); i++){
				*(intptr_t *)(bytecode.GetConst()+plist.GetConst()[i]) = bytecode.GetLength();
			}
			plist.Clear();
		}
		void KansuStackSet(const SourceTree & stree, PWCArray<uint8_t> & bytecode)
		{
			int i;
			intptr_t siz, fsi;
			fsi = 0;
			for(i = stree.tpcount; i < stree.tpcount+stree.hikisuucount; i++){
				fsi += stree.funchensuu.GetConst()[i].size;
			}
			siz = 0;
			for(i = stree.tpcount+stree.hikisuucount; i < stree.funchensuu.GetLength(); i++){
				siz += stree.funchensuu.GetConst()[i].size;
			}
			if(siz > 0){
				bytecode += HENSUUSTACKKAKUHO_MEIREI;
				AtaiCode(bytecode, siz);
			}else if(fsi > 0){
				bytecode += LOCALPUSH_MEIREI;
			}
		}
		void KansuStackClear(const SourceTree & stree, PWCArray<uint8_t> & bytecode)
		{
			intptr_t siz;
			siz = stree.GetMemberSize();
			if(siz > 0){
				if(stree.GetTypeSize(stree.rettype) > 0){
					bytecode += POPTOHENSUU_MEIREI;
					AtaiCode(bytecode, -siz);
				}
				bytecode += HENSUUSTACKKAIHOU_MEIREI;
				AtaiCode(bytecode, siz-stree.GetTypeSize(stree.rettype));
			}
		}
		int TypeAtai(PWCArray<uint8_t> & bytecode, const MeireiCode typ, const void * const xp)
		{
			switch(typ){
			case BYTETYPE_MEIREI:
			case UBYTETYPE_MEIREI:
				AtaiCode(bytecode, *(int8_t *)xp);
				return sizeof(int8_t);
			case SHORTTYPE_MEIREI:
			case USHORTTYPE_MEIREI:
				AtaiCode(bytecode, *(int16_t *)xp);
				return sizeof(int16_t);
			case INTTYPE_MEIREI:
			case UINTTYPE_MEIREI:
				AtaiCode(bytecode, *(int32_t *)xp);
				return sizeof(int32_t);
			case LONGTYPE_MEIREI:
			case ULONGTYPE_MEIREI:
				AtaiCode(bytecode, *(int64_t *)xp);
				return sizeof(int64_t);
			case FLOATTYPE_MEIREI:
				AtaiCode(bytecode, *(float *)xp);
				return sizeof(float);
			case DOUBLETYPE_MEIREI:
				AtaiCode(bytecode, *(double *)xp);
				return sizeof(double);
			case CHARTYPE_MEIREI:
				AtaiCode(bytecode, *(wchar_t *)xp);
				return sizeof(wchar_t);
			case BOOLTYPE_MEIREI:
				AtaiCode(bytecode, *(bool *)xp);
				return sizeof(bool);
			case INDEXTYPE_MEIREI:
				AtaiCode(bytecode, *(intptr_t *)xp);
				return sizeof(intptr_t);
			}
			return 0;
		}
		MeireiCode TypeIdtoMeireiT(const SourceTree & stree, const int32_t typ)
		{
			switch(typ){
			case BYTE_TYPEID:
				return BYTETYPE_MEIREI;
			case UBYTE_TYPEID:
				return UBYTETYPE_MEIREI;
			case SHORT_TYPEID:
				return SHORTTYPE_MEIREI;
			case USHORT_TYPEID:
				return USHORTTYPE_MEIREI;
			case INT_TYPEID:
				return INTTYPE_MEIREI;
			case UINT_TYPEID:
				return UINTTYPE_MEIREI;
			case LONG_TYPEID:
				return LONGTYPE_MEIREI;
			case ULONG_TYPEID:
				return ULONGTYPE_MEIREI;
			case FLOAT_TYPEID:
				return FLOATTYPE_MEIREI;
			case DOUBLE_TYPEID:
				return DOUBLETYPE_MEIREI;
			case CHAR_TYPEID:
				return CHARTYPE_MEIREI;
			case BOOL_TYPEID:
				return BOOLTYPE_MEIREI;
			case ADDRESS_TYPEID:
				return INDEXTYPE_MEIREI;
			case FUNC_TYPEID:
			case METHOD_TYPEID:
				return INDEXTYPE_MEIREI;
			case REF_TYPEID:
			case LIST_TYPEID:
				return REFTYPE_MEIREI;
			default:
				if(typ < 0) return NOP_MEIREI;
				switch(stree.funclist.Get(typ)->selftype){
				case ENUM_BLOCK:
					return INTTYPE_MEIREI;
				}
				break;
			}
			return NOP_MEIREI;
		}
		intptr_t TypeIdtoSize(const SourceTree & stree, const int32_t typ)
		{
			switch(typ){
			case BYTE_TYPEID:
				return sizeof(int8_t);
			case UBYTE_TYPEID:
				return sizeof(uint8_t);
			case SHORT_TYPEID:
				return sizeof(int16_t);
			case USHORT_TYPEID:
				return sizeof(uint16_t);
			case INT_TYPEID:
				return sizeof(int32_t);
			case UINT_TYPEID:
				return sizeof(uint32_t);
			case LONG_TYPEID:
				return sizeof(int64_t);
			case ULONG_TYPEID:
				return sizeof(uint64_t);
			case FLOAT_TYPEID:
				return sizeof(float);
			case DOUBLE_TYPEID:
				return sizeof(double);
			case CHAR_TYPEID:
				return sizeof(wchar_t);
			case BOOL_TYPEID:
				return sizeof(bool);
			case ADDRESS_TYPEID:
				return sizeof(intptr_t);
			case FUNC_TYPEID:
			case METHOD_TYPEID:
				return sizeof(intptr_t);
			case REF_TYPEID:
			case LIST_TYPEID:
				return sizeof(Reference);
			default:
				if(typ < 0){
					if(ENDTHREAD_TYPEID <= typ && typ < 0) return sizeof(Thread);
					return -1;
				}
				switch(stree.funclist.Get(typ)->selftype){
				case CLASS_BLOCK:
					return stree.funclist.Get(typ)->GetMemberSize();
				case ENUM_BLOCK:
					return sizeof(int32_t);
				}
				break;
			}
			return -1;
		}
		template<typename TYPE> int ConstCastint(const int32_t fromt, const void * const fromd, TYPE * const tod)
		{
			switch(fromt){
			case BYTE_TYPEID:
				*tod = (TYPE)*(int8_t *)fromd;
				return sizeof(int8_t);
			case SHORT_TYPEID:
				*tod = (TYPE)*(int16_t *)fromd;
				return sizeof(int16_t);
			case INT_TYPEID:
				*tod = (TYPE)*(int32_t *)fromd;
				return sizeof(int32_t);
			case LONG_TYPEID:
				*tod = (TYPE)*(int64_t *)fromd;
				return sizeof(int64_t);
			case ADDRESS_TYPEID:
				*tod = (TYPE)*(intptr_t *)fromd;
				return sizeof(intptr_t);
			}
			return -1;
		}
		template<typename TYPE> int ConstCastuint(const int32_t fromt, const void * const fromd, TYPE * const tod)
		{
			switch(fromt){
			case UBYTE_TYPEID:
				*tod = (TYPE)*(uint8_t *)fromd;
				return sizeof(uint8_t);
			case USHORT_TYPEID:
				*tod = (TYPE)*(uint16_t *)fromd;
				return sizeof(uint16_t);
			case UINT_TYPEID:
				*tod = (TYPE)*(uint32_t *)fromd;
				return sizeof(uint32_t);
			case ULONG_TYPEID:
				*tod = (TYPE)*(uint64_t *)fromd;
				return sizeof(uint64_t);
			}
			return -1;
		}
		template<typename TYPE> int ConstCastReal(const int32_t fromt, const void * const fromd, TYPE * const tod)
		{
			switch(fromt){
			case FLOAT_TYPEID:
				*tod = (TYPE)*(float *)fromd;
				return sizeof(float);
			case DOUBLE_TYPEID:
				*tod = (TYPE)*(double *)fromd;
				return sizeof(double);
			}
			return -1;
		}
		int CastConst(SourceTree & stree, const int32_t fromt, const void * const fromd, const int32_t tot, void * const tod)
		{
			switch(tot){
			case BYTE_TYPEID:
				return ConstCastint(fromt, fromd, (int8_t *)tod);
			case SHORT_TYPEID:
				return ConstCastint(fromt, fromd, (int16_t *)tod);
			case INT_TYPEID:
				return ConstCastint(fromt, fromd, (int32_t *)tod);
			case LONG_TYPEID:
				return ConstCastint(fromt, fromd, (int64_t *)tod);
			case INDEX_TOKEN:
				return ConstCastint(fromt, fromd, (intptr_t *)tod);
			case UBYTE_TYPEID:
				return ConstCastuint(fromt, fromd, (uint8_t *)tod);
			case USHORT_TYPEID:
				return ConstCastuint(fromt, fromd, (uint16_t *)tod);
			case UINT_TYPEID:
				return ConstCastuint(fromt, fromd, (uint32_t *)tod);
			case ULONG_TYPEID:
				return ConstCastuint(fromt, fromd, (uint64_t *)tod);
			case FLOAT_TYPEID:
				return ConstCastReal(fromt, fromd, (float *)tod);
			case DOUBLE_TYPEID:
				return ConstCastReal(fromt, fromd, (double *)tod);
			case BOOL_TYPEID:
				if(fromt != BOOL_TYPEID) return -1;
				*(bool *)tod = *(bool *)fromd;
				return sizeof(bool);
			case CHAR_TYPEID:
				if(fromt != CHAR_TYPEID) return -1;
				*(wchar_t *)tod = *(wchar_t *)fromd;
				return sizeof(wchar_t);
			default:
				if(fromt < 0 || fromt > ENDCLASS_TYPEID || fromt != tot || stree.funclist.Get(fromt)->selftype != ENUM_BLOCK) return -1;
				*(int32_t *)tod = *(int32_t *)fromd;
				return sizeof(int32_t);
			}
			return -1;
		}
		bool YuruiKataCheck(const PWCArray<intptr_t> & watasu, const PWCArray<intptr_t> & toru)
		{
			int wnbn, tnbn;
			wnbn = tnbn = 0;
			if(IsSoushokuToken((TokenKind)watasu.GetConst()[wnbn])) wnbn++;
			if(IsSoushokuToken((TokenKind)toru.GetConst()[tnbn])) tnbn++;
			while(wnbn < watasu.GetLength() && tnbn < toru.GetLength()){
				if(toru.GetConst()[tnbn] == REF_TOKEN){
					if(watasu.GetConst()[wnbn] == LIST_TOKEN){
						tnbn++;
						wnbn++;
					}
				}else if(toru.GetConst()[tnbn] == FUNC_TOKEN || toru.GetConst()[tnbn] == METHOD_TOKEN){
					if(toru.GetConst()[tnbn] == FUNC_TOKEN){
						if(watasu.GetConst()[wnbn] != FUNC_TOKEN){
							ErrorMessage.Add(*pomc->filename, pomc->gyousuu, L"^G[łB");
							return false;
						}
					}else{
						tnbn++;
						if(watasu.GetConst()[wnbn] == METHOD_TOKEN){
							wnbn++;
							if(watasu.GetConst()[wnbn] != toru.GetConst()[tnbn]){
								ErrorMessage.Add(*pomc->filename, pomc->gyousuu, L"^G[łB");
								return false;
							}
						}else if(watasu.GetConst()[wnbn] != FUNC_TOKEN){
							ErrorMessage.Add(*pomc->filename, pomc->gyousuu, L"^G[łB");
							return false;
						}
					}
					tnbn++;
					wnbn++;
					if(watasu.GetConst()[wnbn] == CONST_TOKEN){
						wnbn++;
						if(toru.GetConst()[tnbn] == CONST_TOKEN) tnbn++;
					}else if(watasu.GetConst()[wnbn] == PROPERTY_TOKEN){
						wnbn++;
						if(IsReadOnlyToken((TokenKind)toru.GetConst()[tnbn])) tnbn++;
					}
				}
				if(toru.GetConst()[tnbn] == CONST_TOKEN){
					tnbn++;
					if(watasu.GetConst()[wnbn] == CONST_TOKEN) wnbn++;
				}else if(toru.GetConst()[tnbn] == PROPERTY_TOKEN){
					tnbn++;
					if(IsReadOnlyToken((TokenKind)watasu.GetConst()[wnbn])) wnbn++;
				}
				if(toru.GetConst()[tnbn] == CLASS_TOKEN || toru.GetConst()[tnbn] == ENUM_TOKEN){
					if(watasu.GetConst()[wnbn] != toru.GetConst()[tnbn]){
						ErrorMessage.Add(*pomc->filename, pomc->gyousuu, L"^G[łB");
						return false;
					}
					tnbn++;
					wnbn++;
				}
				if(watasu.GetConst()[wnbn] != toru.GetConst()[tnbn]){
					ErrorMessage.Add(*pomc->filename, pomc->gyousuu, L"^G[łB");
					return false;
				}
				tnbn++;
				wnbn++;
			}
			if(tnbn != toru.GetLength()){
				ErrorMessage.Add(*pomc->filename, pomc->gyousuu, L"^G[łB");
				return false;
			}
			return true;
		}
		intptr_t Kansuu(SourceTree & stree, PWCArray<uint8_t> & bytecode, const intptr_t * const iap, int & i, PWCArray<int32_t> & tystack, KuwashiiType & ktype, SourceTree & st, const bool thrd)
		{
			int ii, jj, il;
			intptr_t bp;
			int32_t typ;
			intptr_t sizee;
			SourceTree * retcall = NULL;
			bool refari;
			PWCArray<wchar_t> name;
			if(!st.kakutei) return -1;
			refari = false;
			ii = 0;
			while(iap[i] != SHOUKAKKOCLOSE_TOKEN){
				if(ii >= st.hikisuucount) return -1;
				do{
					if(!MainSwitch(stree, bytecode, iap, i, tystack, ktype, retcall)) return -1;
					i++;
				}while(iap[i] != SHOUKAKKOCLOSE_TOKEN && iap[i] != COMMA_TOKEN);
				if((typ = TokenTtoTypeId(st.funchensuu.GetConst()[st.tpcount+ii].type.GetConst(), il=0)) == UNKNOWN_TYPEID) return -1;
				if(st.funchensuu.GetConst()[st.tpcount+ii].type.GetConst()[st.funchensuu.GetConst()[st.tpcount+ii].type.GetLength()-1] == ~DAINYUU_TOKEN){
					if(thrd || tystack.GetConst()[tystack.GetLength()-1] != UNKNOWN_TYPEID || ktype.id != typ) return -1;
					if(ktype.id == REF_TYPEID || ktype.id == LIST_TYPEID || ktype.id == FUNC_TYPEID || ktype.id == METHOD_TYPEID){
						il = 0;
						if(IsSoushokuToken((TokenKind)ktype.kwsk.GetConst()[il])) il++;
						if(st.funchensuu.GetConst()[st.tpcount+ii].type.GetLength()-1 > ktype.kwsk.GetLength()-il) return -1;
						for(jj = 0; jj < st.funchensuu.GetConst()[st.tpcount+ii].type.GetLength()-1; jj++){
							if(st.funchensuu.GetConst()[st.tpcount+ii].type.GetConst()[jj] != ktype.kwsk.GetConst()[jj+il]) return -1;
						}
					}
					ktype.id = VOID_TYPEID;
					i++;
				}else{
					if(tystack.GetData()[tystack.GetLength()-1] == UNKNOWN_TYPEID) return -1;
					if(tystack.GetData()[tystack.GetLength()-1] == BOOL_TYPEID && ktype.id != BOOL_TYPEID){
						bytecode += BOOLTYPE_MEIREI;
						ktype.id = BOOL_TYPEID;
					}
					if(ktype.id == REF_TYPEID || ktype.id == LIST_TYPEID){
						if(!YuruiKataCheck(ktype.kwsk, st.funchensuu.GetConst()[st.tpcount+ii].type)) return -1;
						if(thrd){
							bytecode += REFUP_MEIREI;
							refari = true;
						}
					}else if(ktype.id == FUNC_TYPEID || ktype.id == METHOD_TYPEID){
						if(!YuruiKataCheck(ktype.kwsk, st.funchensuu.GetConst()[st.tpcount+ii].type)) return -1;
					}else if(0 <= ktype.id && ktype.id <= ENDCLASS_TYPEID){
						if(!JidouCast(stree, bytecode, tystack, typ, ktype.id)) return -1;
						il = 0;
						if(stree.funclist.Get(ktype.id)->selftype == CLASS_BLOCK){
							if(thrd){
								name = L"break";
								if(stree.funclist.Get(ktype.id)->GetFuncId(name, false) >= 0) return -1;
							}
							bytecode += LOADSANSHOUKARASANSHOUSAKI_MEIREI;
							AtaiCode(bytecode, stree.funclist.Get(ktype.id)->GetMemberSize());
						}
					}else{
						if(!JidouCast(stree, bytecode, tystack, typ, ktype.id)) return -1;
						ktype.id = typ;
					}
				}
				if(iap[i] == COMMA_TOKEN){
					i++;
					if(iap[i] == SHOUKAKKOCLOSE_TOKEN) return -1;
				}
				ii++;
			}
			tystack.SetLength(tystack.GetLength()-ii);
			if(ii != st.hikisuucount) return -1;
			sizee = 0;
			for(jj = st.tpcount; jj < st.tpcount+st.hikisuucount; jj++){
				if(st.funchensuu.GetConst()[jj].type.GetConst()[st.funchensuu.GetConst()[jj].type.GetLength()-1] == ~DAINYUU_TOKEN){
					sizee += sizeof(intptr_t);
				}else{
					sizee += stree.GetTypeSize(st.funchensuu.GetConst()[jj].type);
				}
			}
			if(thrd){
				if(ktype.id != ADDRESS_TYPEID) bytecode += INDEXTYPE_MEIREI;
				bytecode += PUSHTEISUU_MEIREI;
				AtaiCode(bytecode, sizee);
				bytecode += PUSHTEISUU_MEIREI;
				if(st.byteadress == 0){
					st.backpatch += bytecode.GetLength();
				}
				AtaiCode(bytecode, st.byteadress);
				if(refari){
					if(st.golbalgetahoka == 0){
						bytecode += JUMP_MEIREI;
						bp = bytecode.GetLength();
						AtaiCode(bytecode, (intptr_t)0);
						st.golbalgetahoka = bytecode.GetLength();
						ktype.id = VOID_TYPEID;
						sizee = 0;
						for(jj = st.tpcount+st.hikisuucount-1; jj >= st.tpcount; jj--){
							if(st.funchensuu.GetConst()[jj].type.GetConst()[st.funchensuu.GetConst()[jj].type.GetLength()-1] == ~DAINYUU_TOKEN){
								sizee += sizeof(intptr_t);
							}else{
								sizee += stree.GetTypeSize(st.funchensuu.GetConst()[jj].type);
							}
							if(st.funchensuu.GetConst()[jj].type.GetConst()[0]==REF_TOKEN || st.funchensuu.GetConst()[jj].type.GetConst()[0]==LIST_TOKEN){
								bytecode += MEMBERKARASANSHOU_MEIREI;
								AtaiCode(bytecode, -sizee);
								if(!RefCountDown(stree, bytecode, ktype, SANSHOUREFDOWNNZJUMP_MEIREI, st.funchensuu.GetConst()[jj].type, true)) return false;
							}
						}
						bytecode += RETURN_MEIREI;
						*(intptr_t *)(bytecode.GetConst()+bp) = bytecode.GetLength();
					}
					bytecode += PUSHTEISUU_MEIREI;
					AtaiCode(bytecode, st.golbalgetahoka);
				}else{
					bytecode += PUSHTEISUU_MEIREI;
					AtaiCode(bytecode, (intptr_t)0);
				}
				ktype.id = ADDRESS_TYPEID;
			}
			return sizee;
		}
		bool KansuuKata(const SourceTree * const pstree, const PWCArray<intptr_t> & katmari, PWCArrayQuad< PWCArray<intptr_t> > & waketa)
		{
			int i, j;
			i = 0;
			if(IsSoushokuToken((TokenKind)katmari.GetConst()[i])) i++;
			if(katmari.GetConst()[i] != FUNC_TOKEN){
				if(katmari.GetConst()[i] != METHOD_TOKEN) return false;
				i++;
				if(pstree == NULL || (int32_t)katmari.GetConst()[i] != pstree->funcid) return false;
			}
			i++;
			waketa.Clear();
			waketa[0].Clear();
			if(IsReadOnlyToken((TokenKind)katmari.GetConst()[i])){
				waketa.GetData()[0] += katmari.GetConst()[i];
				i++;
			}
			switch(katmari.GetConst()[i]){
			case BOOL_TOKEN:
			case CHAR_TOKEN:
			case DOUBLE_TOKEN:
			case FLOAT_TOKEN:
			case BYTE_TOKEN:
			case INT_TOKEN:
			case LONG_TOKEN:
			case SHORT_TOKEN:
			case UBYTE_TOKEN:
			case UINT_TOKEN:
			case ULONG_TOKEN:
			case USHORT_TOKEN:
			case INDEX_TOKEN:
			case VOID_TOKEN:
				waketa.GetData()[0] += katmari.GetConst()[i++];
				break;
			case ENUM_TOKEN:
				waketa.GetData()[0] += katmari.GetConst()[i++];
				waketa.GetData()[0] += katmari.GetConst()[i++];
				break;
			case FUNC_TOKEN:
				if(!FuncType(waketa.GetData()[0], katmari.GetConst(), i)) return false;
				break;
			default:
				return false;
			}
			if(katmari.GetConst()[i] != KAKKOCOLOOPEN_TOKEN) return false;
			if(katmari.GetConst()[i+1] == KAKKOCOLOCLOSE_TOKEN) return true;
			j = 0;
			while(true){
				i++;
				j++;
				waketa[j].Clear();
				do{
					waketa.GetData()[j] += katmari.GetConst()[i++];
					if(katmari.GetConst()[i-1] == FUNC_TOKEN){
						FuncType(waketa.GetData()[j], katmari.GetConst(), i);
					}else if(katmari.GetConst()[i-1] == CLASS_TOKEN || katmari.GetConst()[i-1] == ENUM_TOKEN){
						waketa.GetData()[j] += katmari.GetConst()[i++];
					}
					if(katmari.GetConst()[i] == KAKKOCOLOCLOSE_TOKEN) return true;
				}while(katmari.GetConst()[i] != COMMA_TOKEN);
			}
			return true;
		}
		intptr_t KansuuPointer(SourceTree & stree, PWCArray<uint8_t> & bytecode, const intptr_t * const iap, int & i, PWCArray<int32_t> & tystack, KuwashiiType & ktype, const SourceTree * const  pmbrstree, PWCArrayQuad< PWCArray<intptr_t> > & waketa)
		{
			int ii, jj, il;
			int32_t typ;
			intptr_t sizee;
			SourceTree * retcall = NULL;
			if((ktype.id != FUNC_TYPEID && ktype.id != METHOD_TYPEID) || !KansuuKata(pmbrstree, ktype.kwsk, waketa)) return -1;
			ii = 0;
			while(iap[i] != KAKKOCOLOCLOSE_TOKEN){
				if(ii+1 >= waketa.GetLength()) return -1;
				do{
					if(!MainSwitch(stree, bytecode, iap, i, tystack, ktype, retcall)) return -1;
					i++;
				}while(iap[i] != KAKKOCOLOCLOSE_TOKEN && iap[i] != COMMA_TOKEN);
				if((typ = TokenTtoTypeId(waketa.GetConst()[ii+1].GetConst(), il=0)) == UNKNOWN_TYPEID) return -1;
				if(waketa.GetConst()[ii+1].GetConst()[waketa.GetConst()[ii+1].GetLength()-1] == ~DAINYUU_TOKEN){
					if(tystack.GetConst()[tystack.GetLength()-1] != UNKNOWN_TYPEID || ktype.id != typ) return -1;
					if(ktype.id == REF_TYPEID || ktype.id == LIST_TYPEID || ktype.id == FUNC_TYPEID || ktype.id == METHOD_TYPEID){
						il = 0;
						if(IsSoushokuToken((TokenKind)ktype.kwsk.GetConst()[il])) il++;
						if(waketa.GetConst()[ii+1].GetLength()-1 > ktype.kwsk.GetLength()-il) return -1;
						for(jj = 0; jj < waketa.GetConst()[ii+1].GetLength()-1; jj++){
							if(waketa.GetConst()[ii+1].GetConst()[jj] != ktype.kwsk.GetConst()[jj+il]) return -1;
						}
					}
					ktype.id = VOID_TYPEID;
					i++;
				}else{
					if(tystack.GetData()[tystack.GetLength()-1] == UNKNOWN_TYPEID) return -1;
					if(tystack.GetData()[tystack.GetLength()-1] == BOOL_TYPEID && ktype.id != BOOL_TYPEID){
						bytecode += BOOLTYPE_MEIREI;
						ktype.id = BOOL_TYPEID;
					}
					if(ktype.id == REF_TYPEID || ktype.id == LIST_TYPEID || ktype.id == FUNC_TYPEID || ktype.id == METHOD_TYPEID){
						if(!YuruiKataCheck(ktype.kwsk, waketa.GetConst()[ii+1])) return -1;
					}else if(0 <= ktype.id && ktype.id <= ENDCLASS_TYPEID){
						if(!JidouCast(stree, bytecode, tystack, typ, ktype.id)) return -1;
						il = 0;
						if(stree.funclist.Get(ktype.id)->selftype == CLASS_BLOCK){
							bytecode += LOADSANSHOUKARASANSHOUSAKI_MEIREI;
							AtaiCode(bytecode, stree.funclist.Get(ktype.id)->GetMemberSize());
						}
					}else{
						if(!JidouCast(stree, bytecode, tystack, typ, ktype.id)) return -1;
						ktype.id = typ;
					}
				}
				if(iap[i] == COMMA_TOKEN){
					i++;
					if(iap[i] == KAKKOCOLOCLOSE_TOKEN) return -1;
				}
				ii++;
			}
			tystack.SetLength(tystack.GetLength()-ii);
			if(ii+1 != waketa.GetLength()) return -1;
			sizee = 0;
			for(jj = 1; jj < waketa.GetLength(); jj++){
				if(waketa.GetConst()[jj].GetConst()[waketa.GetConst()[jj].GetLength()-1] == ~DAINYUU_TOKEN){
					sizee += sizeof(intptr_t);
				}else{
					sizee += stree.GetTypeSize(waketa.GetConst()[jj]);
				}
			}
			return sizee;
		}
		bool RefCountDown(SourceTree & stree, PWCArray<uint8_t> & bytecode, KuwashiiType & ktype, const MeireiCode shurui, const PWCArray<intptr_t> & hes, const bool popsuru)
		{
			SourceTree * pst;
			int32_t fi;
			PWCArray<intptr_t> type;
			PWCArray<wchar_t> name;
			intptr_t bkp, bp1, bp2, bp3;
			int il;
			il = 0;
			if(IsSoushokuToken((TokenKind)hes.GetConst()[il])) il++;
			if(hes.GetConst()[il] != REF_TOKEN && hes.GetConst()[il] != LIST_TOKEN) return false;
			il++;
			if(hes.GetConst()[il] == CONST_TOKEN) il++;
			if(hes.GetConst()[il] == CLASS_TOKEN){
				pst = stree.funclist.Get((int32_t)hes.GetConst()[il+1]);
			}else{
				pst = NULL;
			}
			switch(shurui){
			case SANSHOUREFDOWNNZJUMP_MEIREI:
			case SANSHOUREFCOPYNZJUMP_MEIREI:
			case SANSHOUREFSREFNZJUMP_MEIREI:
			case SANSHOUREFWREFNZJUMP_MEIREI:
				bytecode += shurui;
				break;
			default:
				return false;
			}
			bkp = bytecode.GetLength();
			AtaiCode(bytecode, (intptr_t)0);
			if( hes.GetConst()[il] == REF_TOKEN || hes.GetConst()[il] == LIST_TOKEN
				|| (pst != NULL && (name = L"break", fi = pst->GetFuncId(name, false)) >= 0) )
			{
				bytecode += LOCALPUSH_MEIREI;
				if(ktype.id != ADDRESS_TYPEID){
					bytecode += INDEXTYPE_MEIREI;
					ktype.id = ADDRESS_TYPEID;
				}
				bytecode += PUSHTEISUU_MEIREI;
				AtaiCode(bytecode, (intptr_t)0);
				switch(shurui){
				case SANSHOUREFDOWNNZJUMP_MEIREI:
					bytecode += PUSHHENSUU_MEIREI;
					AtaiCode(bytecode, -(intptr_t)sizeof(intptr_t));
					bytecode += REFTYPE_MEIREI;
					bytecode += SANSHOUKARASANSHOUSAKI_MEIREI;
					break;
				case SANSHOUREFCOPYNZJUMP_MEIREI:
				case SANSHOUREFSREFNZJUMP_MEIREI:
				case SANSHOUREFWREFNZJUMP_MEIREI:
					bytecode += REFTYPE_MEIREI;
					bytecode += PUSHHENSUU_MEIREI;
					AtaiCode(bytecode, -(intptr_t)sizeof(Reference));
					break;
				default:
					return false;
				}
				bytecode += REFSIZE_MEIREI;
				//
				switch(shurui){
				case SANSHOUREFDOWNNZJUMP_MEIREI:
					bytecode += INDEXTYPE_MEIREI;
					bytecode += PUSHHENSUU_MEIREI;
					AtaiCode(bytecode, -(intptr_t)sizeof(intptr_t));
					bytecode += REFTYPE_MEIREI;
					bytecode += SANSHOUKARASANSHOUSAKI_MEIREI;
					break;
				case SANSHOUREFCOPYNZJUMP_MEIREI:
				case SANSHOUREFSREFNZJUMP_MEIREI:
				case SANSHOUREFWREFNZJUMP_MEIREI:
					bytecode += PUSHHENSUU_MEIREI;
					AtaiCode(bytecode, -(intptr_t)sizeof(Reference));
					break;
				default:
					return false;
				}
				bytecode += INDEXTYPE_MEIREI;
				bytecode += PUSHTEISUU_MEIREI;
				AtaiCode(bytecode, (intptr_t)0);
				bytecode += LISTIDXSANSHOU_MEIREI;
				//
				bp1 = bytecode.GetLength();
				//
				bytecode += PUSHHENSUU_MEIREI;
				AtaiCode(bytecode, (intptr_t)0);
				bytecode += PUSHHENSUU_MEIREI;
				AtaiCode(bytecode, (intptr_t)sizeof(intptr_t));
				bytecode += SHOU_MEIREI;
				//
				bytecode += POPNFALSEJUMP_MEIREI;
				bp2 = bytecode.GetLength();
				AtaiCode(bytecode, (intptr_t)0);
				//
				if(hes.GetConst()[il] == CLASS_TOKEN){
					bytecode += PUSHTEISUU_MEIREI;
					AtaiCode(bytecode, (intptr_t)pst->GetMemberSize());
					bytecode += TASU_MEIREI;
					//
					bytecode += MEMBERPUSHSTACK_MEIREI;
					bytecode += CALL_MEIREI;
					if(stree.funclist.Get(fi)->byteadress == 0){
						stree.funclist.Get(fi)->backpatch += bytecode.GetLength();
					}
					AtaiCode(bytecode, stree.funclist.Get(fi)->byteadress);
					bytecode += MEMBERPOP_MEIREI;
					//
					bytecode += INDEXTYPE_MEIREI;
					//
					bytecode += PUSHHENSUU_MEIREI;
					AtaiCode(bytecode, (intptr_t)0);
					bytecode += PUSHTEISUU_MEIREI;
					AtaiCode(bytecode, (intptr_t)pst->GetMemberSize());
					bytecode += TASU_MEIREI;
				}else if(hes.GetConst()[il] == THREAD_TOKEN){
					bytecode += PUSHSTACK_MEIREI;
					bytecode += SANSHOUTHREADSETNULL_MEIREI;
					bytecode += PUSHTEISUU_MEIREI;
					AtaiCode(bytecode, (intptr_t)sizeof(Thread));
					bytecode += TASU_MEIREI;
					bytecode += PUSHHENSUU_MEIREI;
					AtaiCode(bytecode, (intptr_t)0);
					bytecode += PUSHTEISUU_MEIREI;
					AtaiCode(bytecode, (intptr_t)sizeof(Thread));
					bytecode += TASU_MEIREI;
				}else{
					type.Clear();
					type.AddTail(hes.GetConst()+il, hes.GetLength()-il);
					RefCountDown(stree, bytecode, ktype, SANSHOUREFDOWNNZJUMP_MEIREI, type, false);
					bytecode += PUSHTEISUU_MEIREI;
					AtaiCode(bytecode, (intptr_t)sizeof(Reference));
					bytecode += TASU_MEIREI;
					bytecode += PUSHHENSUU_MEIREI;
					AtaiCode(bytecode, (intptr_t)0);
					bytecode += PUSHTEISUU_MEIREI;
					AtaiCode(bytecode, (intptr_t)sizeof(Reference));
					bytecode += TASU_MEIREI;
				}
				bytecode += POPTOHENSUU_MEIREI;
				AtaiCode(bytecode, (intptr_t)0);
				//
				bytecode += JUMP_MEIREI;
				AtaiCode(bytecode, bp1);
				//
				*(intptr_t *)(bytecode.GetConst()+bp2) = bytecode.GetLength();
				switch(shurui){
				case SANSHOUREFDOWNNZJUMP_MEIREI:
					if(!popsuru){
						bytecode += PUSHHENSUU_MEIREI;
						AtaiCode(bytecode, -(intptr_t)sizeof(intptr_t));
						bytecode += POPTOHENSUU_MEIREI;
						AtaiCode(bytecode, (intptr_t)0);
						bytecode += HENSUUSTACKKAIHOU_MEIREI;
						AtaiCode(bytecode, (intptr_t)sizeof(intptr_t)*2);
						break;
					}
				case SANSHOUREFCOPYNZJUMP_MEIREI:
				case SANSHOUREFSREFNZJUMP_MEIREI:
				case SANSHOUREFWREFNZJUMP_MEIREI:
					bytecode += HENSUUSTACKKAIHOU_MEIREI;
					AtaiCode(bytecode, (intptr_t)sizeof(intptr_t)*3);
					break;
				default:
					return false;
				}
			}else if(!popsuru && shurui == SANSHOUREFDOWNNZJUMP_MEIREI){
				bytecode += PUSHSTACK_MEIREI;
			}
			switch(shurui){
			case SANSHOUREFDOWNNZJUMP_MEIREI:
				bytecode += SANSHOUREFDELETE_MEIREI;
				if(popsuru){
					bytecode += JUMP_MEIREI;
					bp3 = bytecode.GetLength();
					AtaiCode(bytecode, (intptr_t)0);
				}
				break;
			case SANSHOUREFCOPYNZJUMP_MEIREI:
			case SANSHOUREFSREFNZJUMP_MEIREI:
			case SANSHOUREFWREFNZJUMP_MEIREI:
				bytecode += LOCALPUSH_MEIREI;
				bytecode += HENSUUKARASANSHOU_MEIREI;
				AtaiCode(bytecode, -(intptr_t)sizeof(Reference));
				bytecode += SANSHOUREFDELETE_MEIREI;
				if(popsuru){
					bytecode += HENSUUSTACKKAIHOU_MEIREI;
					AtaiCode(bytecode, (intptr_t)(sizeof(intptr_t)+sizeof(Reference)));
				}else{
					bytecode += HENSUUSTACKKAIHOU_MEIREI;
					AtaiCode(bytecode, (intptr_t)sizeof(Reference));
				}
				bytecode += JUMP_MEIREI;
				bp3 = bytecode.GetLength();
				AtaiCode(bytecode, (intptr_t)0);
				break;
			default:
				return false;
			}
			*(intptr_t *)(bytecode.GetConst()+bkp) = bytecode.GetLength();
			switch(shurui){
			case SANSHOUREFDOWNNZJUMP_MEIREI:
				if(popsuru){
					bytecode += POPADDRESS_MEIREI;
					*(intptr_t *)(bytecode.GetConst()+bp3) = bytecode.GetLength();
				}
				break;
			case SANSHOUREFCOPYNZJUMP_MEIREI:
			case SANSHOUREFSREFNZJUMP_MEIREI:
			case SANSHOUREFWREFNZJUMP_MEIREI:
				bytecode += REFTYPE_MEIREI;
				ktype.id = VOID_TYPEID;
				bytecode += POP_MEIREI;
				if(popsuru) bytecode += POPADDRESS_MEIREI;
				*(intptr_t *)(bytecode.GetConst()+bp3) = bytecode.GetLength();
				break;
			default:
				return false;
			}
			return true;
		}
		bool RefNew(SourceTree & stree, PWCArray<uint8_t> & bytecode, const intptr_t * const iap, int & i, PWCArray<int32_t> & tystack, KuwashiiType & ktype, const MeireiCode shurui, const PWCArray<intptr_t> & hes)
		{
			SourceTree * pst;
			SourceTree * retcall = NULL;
			int32_t fi;
			intptr_t bp1, bp2, bp3, bp4;
			PWCArray<intptr_t> type;
			PWCArray<wchar_t> name;
			int il;
			il = 0;
			if(IsSoushokuToken((TokenKind)hes.GetConst()[il])) il++;
			if(hes.GetConst()[il] != REF_TOKEN && hes.GetConst()[il] != LIST_TOKEN) return false;
			il++;
			if(hes.GetConst()[il] == CONST_TOKEN) il++;
			if(hes.GetConst()[il] == CLASS_TOKEN){
				pst = stree.funclist.Get((int32_t)hes.GetConst()[il+1]);
			}else{
				pst = NULL;
			}
			do{
				if(!MainSwitch(stree, bytecode, iap, i, tystack, ktype, retcall)) return false;
				i++;
			}while(iap[i] != SHOUKAKKOCLOSE_TOKEN);
			if(!JidouCast(stree, bytecode, tystack, ADDRESS_TYPEID, ktype.id)) return false;
			ktype.id = ADDRESS_TYPEID;
			bytecode += PUSHTEISUU_MEIREI;
			if(hes.GetConst()[il] == CLASS_TOKEN){
				AtaiCode(bytecode, (intptr_t)pst->GetMemberSize());
			}else{
				type.Clear();
				type.AddTail(hes.GetConst()+il, hes.GetLength()-il);
				AtaiCode(bytecode, (intptr_t)stree.GetTypeSize(type));
			}
			bytecode += KAKERU_MEIREI;
			switch(shurui){
			case SANSHOUREFNEW_MEIREI:
			case SANSHOULISTNEW_MEIREI:
				bytecode += shurui;
				break;
			default:
				return false;
			}
			if(
				hes.GetConst()[il] == REF_TOKEN || hes.GetConst()[il] == LIST_TOKEN || hes.GetConst()[il] == THREAD_TOKEN
				|| (pst != NULL && (name = L"default", fi = pst->GetFuncId(name, false)) >= 0))
			{
				bytecode += PUSHTEISUU_MEIREI;
				AtaiCode(bytecode, (intptr_t)0);
				bytecode += LOCALPUSH_MEIREI;
				//
				bytecode += PUSHHENSUU_MEIREI;
				AtaiCode(bytecode, -(intptr_t)sizeof(intptr_t)*3);
				//
				bytecode += PUSHHENSUU_MEIREI;
				AtaiCode(bytecode, -(intptr_t)sizeof(intptr_t));
				bytecode += PUSHHENSUU_MEIREI;
				AtaiCode(bytecode, -(intptr_t)sizeof(intptr_t)*2);
				bytecode += SHOU_MEIREI;
				//
				bytecode += POPNFALSEJUMP_MEIREI;
				bp4 = bytecode.GetLength();
				AtaiCode(bytecode, (intptr_t)0);
				//
				bytecode += REFTYPE_MEIREI;
				bytecode += SANSHOUKARASANSHOUSAKI_MEIREI;
				bytecode += REFPOSSANSHOU_MEIREI;
				bytecode += INDEXTYPE_MEIREI;
				//
				bytecode += JUMP_MEIREI;
				bp3 = bytecode.GetLength();
				AtaiCode(bytecode, (intptr_t)0);
				//
				bp1 = bytecode.GetLength();
				//
				bytecode += PUSHHENSUU_MEIREI;
				AtaiCode(bytecode, -(intptr_t)sizeof(intptr_t));
				bytecode += PUSHHENSUU_MEIREI;
				AtaiCode(bytecode, -(intptr_t)sizeof(intptr_t)*2);
				bytecode += SHOU_MEIREI;
				//
				bytecode += POPNFALSEJUMP_MEIREI;
				bp2 = bytecode.GetLength();
				AtaiCode(bytecode, (intptr_t)0);
				//
				*(intptr_t *)(bytecode.GetConst()+bp3) = bytecode.GetLength();
				//
				if(hes.GetConst()[il] == CLASS_TOKEN){
					bytecode += PUSHTEISUU_MEIREI;
					AtaiCode(bytecode, (intptr_t)pst->GetMemberSize());
					bytecode += TASU_MEIREI;
					//
					bytecode += MEMBERPUSHSTACK_MEIREI;
					bytecode += CALL_MEIREI;
					if(stree.funclist.Get(fi)->byteadress == 0){
						stree.funclist.Get(fi)->backpatch += bytecode.GetLength();
					}
					AtaiCode(bytecode, stree.funclist.Get(fi)->byteadress);
					bytecode += MEMBERPOP_MEIREI;
					//
					bytecode += INDEXTYPE_MEIREI;
					//
					bytecode += PUSHHENSUU_MEIREI;
					AtaiCode(bytecode, -(intptr_t)sizeof(intptr_t));
					bytecode += PUSHTEISUU_MEIREI;
					AtaiCode(bytecode, (intptr_t)pst->GetMemberSize());
					bytecode += TASU_MEIREI;
				}else{
					bytecode += PUSHSTACK_MEIREI;
					if(hes.GetConst()[il] == THREAD_TOKEN){
						bytecode += SANSHOUTHREADSETNULL_MEIREI;
						bytecode += PUSHTEISUU_MEIREI;
						AtaiCode(bytecode, (intptr_t)sizeof(Thread));
						bytecode += TASU_MEIREI;
						bytecode += PUSHHENSUU_MEIREI;
						AtaiCode(bytecode, -(intptr_t)sizeof(intptr_t));
						bytecode += PUSHTEISUU_MEIREI;
						AtaiCode(bytecode, (intptr_t)sizeof(Thread));
						bytecode += TASU_MEIREI;
					}else{
						bytecode += SANSHOUREFSETNULL_MEIREI;
						bytecode += PUSHTEISUU_MEIREI;
						AtaiCode(bytecode, (intptr_t)sizeof(Reference));
						bytecode += TASU_MEIREI;
						bytecode += PUSHHENSUU_MEIREI;
						AtaiCode(bytecode, -(intptr_t)sizeof(intptr_t));
						bytecode += PUSHTEISUU_MEIREI;
						AtaiCode(bytecode, (intptr_t)sizeof(Reference));
						bytecode += TASU_MEIREI;
					}
				}
				bytecode += POPTOHENSUU_MEIREI;
				AtaiCode(bytecode, -(intptr_t)sizeof(intptr_t));
				//
				bytecode += JUMP_MEIREI;
				AtaiCode(bytecode, bp1);
				//
				*(intptr_t *)(bytecode.GetConst()+bp2) = bytecode.GetLength();
				*(intptr_t *)(bytecode.GetConst()+bp4) = bytecode.GetLength();
				//
				bytecode += HENSUUSTACKKAIHOU_MEIREI;
				AtaiCode(bytecode, (intptr_t)sizeof(intptr_t)*4);
			}else{
				bytecode += POP_MEIREI;
				bytecode += POP_MEIREI;
			}
			ktype.id = VOID_TYPEID;
			tystack += ktype.id;
			return true;
		}
		bool RefIdxNew(SourceTree & stree, PWCArray<uint8_t> & bytecode, const intptr_t * const iap, int & i, PWCArray<int32_t> & tystack, KuwashiiType & ktype, const PWCArray<intptr_t> & hes)
		{
			SourceTree * pst;
			SourceTree * retcall = NULL;
			int32_t fi;
			intptr_t bp1, bp2;
			PWCArray<intptr_t> type;
			PWCArray<wchar_t> name;
			int il;
			il = 0;
			if(IsSoushokuToken((TokenKind)hes.GetConst()[il])) il++;
			if(hes.GetConst()[il] != REF_TOKEN && hes.GetConst()[il] != LIST_TOKEN) return false;
			il++;
			if(hes.GetConst()[il] == CONST_TOKEN) il++;
			if(hes.GetConst()[il] == CLASS_TOKEN){
				pst = stree.funclist.Get((int32_t)hes.GetConst()[il+1]);
			}else{
				pst = NULL;
			}
			do{
				if(!MainSwitch(stree, bytecode, iap, i, tystack, ktype, retcall)) return false;
				i++;
			}while(iap[i] != DAIKAKKOCLOSE_TOKEN);
			if(!JidouCast(stree, bytecode, tystack, ADDRESS_TYPEID, ktype.id)) return false;
			ktype.id = ADDRESS_TYPEID;
			bytecode += PUSHTEISUU_MEIREI;
			if(hes.GetConst()[il] == CLASS_TOKEN){
				AtaiCode(bytecode, (intptr_t)pst->GetMemberSize());
			}else{
				type.Clear();
				type.AddTail(hes.GetConst()+il, hes.GetLength()-il);
				AtaiCode(bytecode, (intptr_t)stree.GetTypeSize(type));
			}
			bytecode += SANSHOULISTIDXNEW_MEIREI;
			if(
				hes.GetConst()[il] == REF_TOKEN || hes.GetConst()[il] == LIST_TOKEN || hes.GetConst()[il] == THREAD_TOKEN
				|| (pst != NULL && (name = L"default", fi = pst->GetFuncId(name, false)) >= 0))
			{
				bytecode += PUSHTEISUU_MEIREI;
				AtaiCode(bytecode, (intptr_t)0);
				bytecode += LOCALPUSH_MEIREI;
				//
				bytecode += PUSHHENSUU_MEIREI;
				AtaiCode(bytecode, -(intptr_t)sizeof(intptr_t)*3);
				//
				bp1 = bytecode.GetLength();
				//
				bytecode += INCLKARAMAENOATAI_MEIREI;
				AtaiCode(bytecode, -(intptr_t)sizeof(intptr_t));
				bytecode += PUSHHENSUU_MEIREI;
				AtaiCode(bytecode, -(intptr_t)sizeof(intptr_t)*2);
				bytecode += SHOU_MEIREI;
				//
				bytecode += POPNFALSEJUMP_MEIREI;
				bp2 = bytecode.GetLength();
				AtaiCode(bytecode, (intptr_t)0);
				//
				if(hes.GetConst()[il] == CLASS_TOKEN){
					bytecode += PUSHTEISUU_MEIREI;
					AtaiCode(bytecode, (intptr_t)pst->GetMemberSize());
					bytecode += TASU_MEIREI;
					//
					bytecode += MEMBERPUSHSTACK_MEIREI;
					bytecode += CALL_MEIREI;
					if(stree.funclist.Get(fi)->byteadress == 0){
						stree.funclist.Get(fi)->backpatch += bytecode.GetLength();
					}
					AtaiCode(bytecode, stree.funclist.Get(fi)->byteadress);
					bytecode += MEMBERPOP_MEIREI;
					//
					bytecode += INDEXTYPE_MEIREI;
				}else{
					bytecode += PUSHSTACK_MEIREI;
					if(hes.GetConst()[il] == THREAD_TOKEN){
						bytecode += SANSHOUTHREADSETNULL_MEIREI;
						bytecode += PUSHTEISUU_MEIREI;
						AtaiCode(bytecode, (intptr_t)sizeof(Thread));
						bytecode += TASU_MEIREI;
					}else{
						bytecode += SANSHOUREFSETNULL_MEIREI;
						bytecode += PUSHTEISUU_MEIREI;
						AtaiCode(bytecode, (intptr_t)sizeof(Reference));
						bytecode += TASU_MEIREI;
					}
				}
				//
				bytecode += JUMP_MEIREI;
				AtaiCode(bytecode, bp1);
				//
				*(intptr_t *)(bytecode.GetConst()+bp2) = bytecode.GetLength();
				//
				bytecode += HENSUUSTACKKAIHOU_MEIREI;
				AtaiCode(bytecode, (intptr_t)sizeof(intptr_t)*4);
			}else{
				bytecode += POP_MEIREI;
				bytecode += POP_MEIREI;
			}
			return true;
		}
		bool Sanshou(SourceTree & stree, PWCArray<uint8_t> & bytecode, const intptr_t * const iap, int & i, PWCArray<int32_t> & tystack, KuwashiiType & ktype, const PWCArray<intptr_t> & otype, const bool dicnstf)
		{
			SourceTree * pst;
			SourceTree * retcall = NULL;
			MeireiCode deco;
			int32_t tyki;
			KuwashiiType typ;
			intptr_t ig, tmpip;
			PWCArray<intptr_t> typer, type;
			int indt, il;
			bool tmpb, cnstf, tendeta;
			PWCArrayQuad< PWCArray<intptr_t> > waketa;
			ig = 0;
			typer = otype;
			cnstf = dicnstf || IsReadOnlyToken((TokenKind)typer.GetConst()[0]);
			tendeta = false;
			while(iap[i+1] == POINT_TOKEN){
				tendeta = true;
				il = 0;
				if(IsSoushokuToken((TokenKind)typer.GetConst()[il])) il++;
				if(typer.GetConst()[il] != CLASS_TOKEN && typer.GetConst()[il] != ENUM_TOKEN) return false;
				il++;
				tyki = (int32_t)typer.GetConst()[il];
				i += 2;
				pst = stree.funclist.Get(tyki);
				ig += pst->GetMemberSize();
				if(iap[i] == SHOUKAKKOOPEN_TOKEN){
					i++;
					if(iap[i] < 0){
						pst = stree.funclist.Get(~iap[i]);
						i++;
						if(!pst->kakutei && (pst = pst->GetIjousaki(ig)) == NULL) return false;
						if(stree.rettype.GetConst()[0] == CONST_TOKEN && pst->rettype.GetConst()[0] != CONST_TOKEN) return false;
						if(cnstf && !IsReadOnlyToken((TokenKind)pst->rettype.GetConst()[0])) return false;
						if(Kansuu(stree, bytecode, iap, i, tystack, ktype, *pst, false) < 0) return false;
						tmpip = -(intptr_t)sizeof(intptr_t);
						for(il = pst->tpcount; il < pst->hikisuucount; il++){
							tmpip -= pst->funchensuu.GetConst()[il].size;
						}
						bytecode += LOCALPUSH_MEIREI;
						if(ktype.id != ADDRESS_TYPEID){
							bytecode += INDEXTYPE_MEIREI;
							ktype.id = ADDRESS_TYPEID;
						}
						bytecode += PUSHHENSUU_MEIREI;
						AtaiCode(bytecode, tmpip);
						if(ig != 0){
							bytecode += PUSHTEISUU_MEIREI;
							AtaiCode(bytecode, ig);
							bytecode += TASU_MEIREI;
						}
						bytecode += POPTOMEMBERSTACK_MEIREI;
						bytecode += CALL_MEIREI;
						if(pst->byteadress == 0){
							pst->backpatch += bytecode.GetLength();
						}
						AtaiCode(bytecode, pst->byteadress);
						if((ktype.id = TokenTtoTypeId(pst->rettype.GetConst(), il=0)) == UNKNOWN_TYPEID) return false;
						ktype.kwsk = pst->rettype;
						tystack += ktype.id;
						if(ktype.id != VOID_TYPEID){
							bytecode += POPTOHENSUU_MEIREI;
							AtaiCode(bytecode, tmpip);
						}
						bytecode += HENSUUSTACKKAIHOU_MEIREI;
						AtaiCode(bytecode, (intptr_t)sizeof(intptr_t)-stree.GetTypeSize(pst->rettype));
						bytecode += MEMBERPOP_MEIREI;
					}else{
						return false;
					}
					break;
				}
				if(iap[i] >= 0) return false;
				indt = ~iap[i];
				for(il = pst->funchensuu.GetLength()-1; il >= indt; il--) ig -= pst->funchensuu.GetConst()[il].size;
				typer = pst->funchensuu.GetConst()[indt].type;
				cnstf = cnstf || IsReadOnlyToken((TokenKind)typer.GetConst()[0]);
			}
			if(iap[i] >= 0 && iap[i] != DIA_TOKEN && iap[i] != DAIKAKKOCLOSE_TOKEN) return true;
			if(tendeta && typer.GetConst()[0] == CONST_TOKEN){
				bytecode += POP_MEIREI;
			}else if(ig != 0){
				bytecode += PUSHTEISUU_MEIREI;
				AtaiCode(bytecode, ig);
				bytecode += TASU_MEIREI;
			}
			il = 0;
			if(IsSoushokuToken((TokenKind)typer.GetConst()[il])) il++;
			if(iap[i+1] == VOID_TOKEN){
				i++;
				if(typer.GetConst()[il] == THREAD_TOKEN){
					bytecode += SANSHOUTHREADSETNULL_MEIREI;
				}else{
					bytecode += SANSHOUREFSETNULL_MEIREI;
				}
				i++;
				if(iap[i] != SEMICOLON_TOKEN) return false;
				return true;
			}
			if(iap[i+1] == DELETE_TOKEN || iap[i+1] == NEW_TOKEN){
				if(cnstf) return false;
				i++;
				if(typer.GetConst()[il] == THREAD_TOKEN){
					bytecode += SANSHOUTHREADWAIT_MEIREI;
				}else if(iap[i] != NEW_TOKEN || iap[i+1] != DAIKAKKOOPEN_TOKEN){
					if(!RefCountDown(stree, bytecode, ktype, SANSHOUREFDOWNNZJUMP_MEIREI, typer, iap[i]==DELETE_TOKEN)) return false;
				}
				if(iap[i] == NEW_TOKEN){
					i++;
					if(typer.GetConst()[il+1] == CONST_TOKEN) return false;
					if(iap[i] == SHOUKAKKOOPEN_TOKEN){
						i++;
						if(typer.GetConst()[il] == REF_TOKEN){
							if(!RefNew(stree, bytecode, iap, i, tystack, ktype, SANSHOUREFNEW_MEIREI, typer)) return false;
						}else{
							if(!RefNew(stree, bytecode, iap, i, tystack, ktype, SANSHOULISTNEW_MEIREI, typer)) return false;
						}
					}else if(iap[i] == DAIKAKKOOPEN_TOKEN){
						i++;
						if(typer.GetConst()[il] != LIST_TOKEN) return false;
						if(!RefIdxNew(stree, bytecode, iap, i, tystack, ktype, typer)) return false;
						il++;
						type.Clear();
						type.AddTail(typer.GetConst()+il, typer.GetLength()-il);
						if(!Sanshou(stree, bytecode, iap, i, tystack, ktype, type, false)) return false;
					}else{
						return false;
					}
				}else{
					i++;
					if(iap[i] != SEMICOLON_TOKEN) return false;
				}
				return true;
			}
			if(iap[i+1] == SHOUKAKKOOPEN_TOKEN && iap[i+2] == TENTEN_TOKEN){
				if(cnstf) return false;
				i += 3;
				if(typer.GetConst()[il] != THREAD_TOKEN) return false;
				il++;
				if(Kansuu(stree, bytecode, iap, i, tystack, ktype, *stree.funclist.Get((int32_t)typer.GetConst()[il]), true) < 0) return false;
				bytecode += SANSHOUTHREADRUN_MEIREI;
				ktype.id = VOID_TYPEID;
				return true;
			}
			tmpb = typer.GetConst()[il] == CLASS_TOKEN;
			if((typ.id = TokenTtoTypeId(typer.GetConst(), il=0)) == UNKNOWN_TYPEID) return false;
			typ.kwsk = typer;
			if(iap[i+1] == NULL_TOKEN && iap[i+2] == TENDAINYUU_TOKEN){
				if(cnstf) return false;
				i += 2;
				if(!Append(stree, bytecode, iap, i, tystack, ktype, typ)) return false;
				return true;
			}
			if(iap[i+1] == NULL_TOKEN && (DAINYUU_TOKEN <= iap[i+2] && iap[i+2] <= SHIROYAJIRUSHI_TOKEN)){
				if(cnstf) return false;
				i += 2;
				if(!Dainyuu(stree, bytecode, iap, i, tystack, ktype, typ, ig, PUSHSTACKSANSHOU_MEIREI, tmpb, false)) return false;
				return true;
			}
			if(
				(iap[i+1] == NULL_TOKEN && (iap[i+2] == PLSPLS_TOKEN || iap[i+2] == MNSMNS_TOKEN))
				|| iap[i+1] == PLSPLS_TOKEN || iap[i+1] == MNSMNS_TOKEN)
			{
				if(cnstf) return false;
				i++;
				if(!IncDec(stree, bytecode, iap, i, tystack, ktype, typ)) return false;
				return true;
			}
			ktype.kwsk = typ.kwsk;
			if(typ.id != ktype.id){
				if(typ.id == VOID_TYPEID) return false;
				ktype.id = typ.id;
				if(!tmpb && !(ENDTHREAD_TYPEID <= ktype.id && ktype.id < 0)){
					if((deco = TypeIdtoMeireiT(stree, ktype.id)) == NOP_MEIREI) return false;
					bytecode += deco;
				}
			}
			if(cnstf && ENDTHREAD_TYPEID <= ktype.id && ktype.id < 0) return false;
			if(ktype.id != VOID_TYPEID){
				if(tendeta && typer.GetConst()[0] == CONST_TOKEN){
					if(ktype.id == FUNC_TYPEID){
						bytecode += PUSHTEISUU_MEIREI;
						if(typer.GetConst()[typer.GetLength()-1] < 0){
							AtaiCode(bytecode, typer.GetConst()[typer.GetLength()-1]);
						}else{
							if(!stree.funclist.Get((int32_t)typer.GetConst()[typer.GetLength()-1])->kakutei) return false;
							if(stree.funclist.Get((int32_t)typer.GetConst()[typer.GetLength()-1])->byteadress == 0){
								stree.funclist.Get((int32_t)typer.GetConst()[typer.GetLength()-1])->backpatch += bytecode.GetLength();
							}
							AtaiCode(bytecode, stree.funclist.Get((int32_t)typer.GetConst()[typer.GetLength()-1])->byteadress);
						}
					}else if(ktype.id == REF_TYPEID){
						bytecode += PUSHGLOBALHENSUU_MEIREI;
						AtaiCode(bytecode, typer.GetConst()[typer.GetLength()-1]);
					}else{
						if((deco = TypeIdtoMeireiT(stree, ktype.id)) == NOP_MEIREI) return false;
						bytecode += PUSHTEISUU_MEIREI;
						TypeAtai(bytecode, deco, typer.GetConst()+il);
					}
				}else{
					if(ktype.id == METHOD_TYPEID && iap[i+1] == KAKKOCOLOOPEN_TOKEN){
						i += 2;
						ig = 0;
						for(il = indt; il < pst->funchensuu.GetLength(); il++) ig += pst->funchensuu.GetConst()[il].size;
						if((tmpip = KansuuPointer(stree, bytecode, iap, i, tystack, ktype, pst, waketa)) < 0) return false;
						if(stree.rettype.GetConst()[0] == CONST_TOKEN && waketa.GetConst()[0].GetConst()[0] != CONST_TOKEN) return false;
						if(cnstf && !IsReadOnlyToken((TokenKind)waketa.GetConst()[0].GetConst()[0])) return false;
						bytecode += INDEXTYPE_MEIREI;
						if(tmpip > 0){
							bytecode += LOCALPUSH_MEIREI;
							bytecode += PUSHHENSUU_MEIREI;
							AtaiCode(bytecode, -(intptr_t)(tmpip+sizeof(intptr_t)));
						}else{
							bytecode += PUSHSTACK_MEIREI;
						}
						if(ig != 0){
							bytecode += PUSHTEISUU_MEIREI;
							AtaiCode(bytecode, ig);
							bytecode += TASU_MEIREI;
						}
						bytecode += POPTOMEMBERSTACK_MEIREI;
						if(tmpip > 0){
							bytecode += PUSHHENSUU_MEIREI;
							AtaiCode(bytecode, -(intptr_t)(tmpip+sizeof(intptr_t)));
						}
						bytecode += SANSHOUKARASANSHOUSAKI_MEIREI;
						bytecode += STACKCALL_MEIREI;
						if((ktype.id = TokenTtoTypeId(waketa.GetConst()[0].GetConst(), il=0)) == UNKNOWN_TYPEID) return false;
						ktype.kwsk = waketa.GetConst()[0];
						if(tmpip > 0){
							if(ktype.id != VOID_TYPEID){
								bytecode += POPTOHENSUU_MEIREI;
								AtaiCode(bytecode, -(intptr_t)(tmpip+sizeof(intptr_t)));
							}
							bytecode += HENSUUSTACKKAIHOU_MEIREI;
							AtaiCode(bytecode, (intptr_t)sizeof(intptr_t)-stree.GetTypeSize(waketa.GetConst()[0]));
						}
						bytecode += MEMBERPOP_MEIREI;
					}else{
						if(!tmpb && !(ENDTHREAD_TYPEID <= ktype.id && ktype.id < 0)) bytecode += SANSHOUKARASANSHOUSAKI_MEIREI;
					}
				}
			}
			tystack += ktype.id;
			return true;
		}
		bool FuncType(PWCArray<intptr_t> & type, const intptr_t * const iap, int & i)
		{
			if(IsReadOnlyToken((TokenKind)iap[i])){
				type += iap[i];
				i++;
			}
			switch(iap[i]){
			case BOOL_TOKEN:
			case CHAR_TOKEN:
			case DOUBLE_TOKEN:
			case FLOAT_TOKEN:
			case BYTE_TOKEN:
			case INT_TOKEN:
			case LONG_TOKEN:
			case SHORT_TOKEN:
			case UBYTE_TOKEN:
			case UINT_TOKEN:
			case ULONG_TOKEN:
			case USHORT_TOKEN:
			case INDEX_TOKEN:
			case VOID_TOKEN:
				type += iap[i++];
				break;
			case ENUM_TOKEN:
				type += iap[i++];
				type += iap[i++];
				break;
			case FUNC_TOKEN:
				type += FUNC_TOKEN;
				if(!FuncType(type, iap, i)) return false;
				break;
			default:
				return false;
			}
			if(iap[i] != KAKKOCOLOOPEN_TOKEN) return false;
			type += iap[i++];
			while(iap[i] != KAKKOCOLOCLOSE_TOKEN){
				type += iap[i++];
				if(iap[i-1] == FUNC_TOKEN){
					FuncType(type, iap, i);
				}else if(iap[i-1] == CLASS_TOKEN || iap[i-1] == ENUM_TOKEN){
					type += iap[i++];
				}
			}
			type += iap[i++];
			return true;
		}
		bool RefType(PWCArray<intptr_t> & type, const intptr_t * const iap, int & i)
		{
			if(iap[i] == CONST_TOKEN){
				type += CONST_TOKEN;
				i++;
			}
			switch(iap[i]){
			case BOOL_TOKEN:
			case CHAR_TOKEN:
			case DOUBLE_TOKEN:
			case FLOAT_TOKEN:
			case BYTE_TOKEN:
			case INT_TOKEN:
			case LONG_TOKEN:
			case SHORT_TOKEN:
			case UBYTE_TOKEN:
			case UINT_TOKEN:
			case ULONG_TOKEN:
			case USHORT_TOKEN:
			case INDEX_TOKEN:
			case VOID_TOKEN:
				type += iap[i++];
				break;
			case CLASS_TOKEN:
			case ENUM_TOKEN:
				type += iap[i++];
				type += iap[i++];
				break;
			case REF_TOKEN:
			case LIST_TOKEN:
				type += iap[i++];
				RefType(type, iap, i);
				break;
			default:
				return false;
			}
			return true;
		}
		bool MainSwitch(SourceTree & stree, PWCArray<uint8_t> & bytecode, const intptr_t * const iap, int & i, PWCArray<int32_t> & tystack, KuwashiiType & ktype, SourceTree * & retcall)
		{
			static intptr_t glbbp;
			SourceTree * pst;
			MeireiCode deco;
			intptr_t ig, bp1, bp2, tmpip;
			int32_t tyki;
			KuwashiiType typ;
			TokenKind tmptk;
			int indt, il;
			PWCArray<intptr_t> type;
			const PWCArray<intptr_t> * pty;
			bool tmpb, cnstf;
			PWCArrayQuad< PWCArray<intptr_t> > waketa;
			switch(iap[i]){
			case CONST_TOKEN:
				i++;
				if((typ.id = TokenTtoTypeId(iap, i)) == UNKNOWN_TYPEID) return false;
				if(typ.id != ktype.id){
					ktype = typ;
					if((deco = TypeIdtoMeireiT(stree, ktype.id)) == NOP_MEIREI) return false;
					bytecode += deco;
				}
				if(ktype.id == REF_TYPEID){
					ktype.kwsk = REF_TOKEN;
					if(!RefType(ktype.kwsk, iap, i)) return false;
					bytecode += PUSHGLOBALHENSUU_MEIREI;
					AtaiCode(bytecode, iap[i]);
				}else if(ktype.id == FUNC_TYPEID || ktype.id == METHOD_TYPEID){
					ktype.kwsk = (ktype.id == FUNC_TYPEID ? FUNC_TOKEN : METHOD_TOKEN);
					if(ktype.id == METHOD_TYPEID) ktype.kwsk += iap[i++];
					if(!FuncType(ktype.kwsk, iap, i)) return false;
					bytecode += PUSHTEISUU_MEIREI;
					if(iap[i] < 0){
						AtaiCode(bytecode, iap[i]);
					}else{
						if(!stree.funclist.Get((int32_t)iap[i])->kakutei) return false;
						if(stree.funclist.Get((int32_t)iap[i])->byteadress == 0){
							stree.funclist.Get((int32_t)iap[i])->backpatch += bytecode.GetLength();
						}
						AtaiCode(bytecode, stree.funclist.Get((int32_t)iap[i])->byteadress);
					}
				}else{
					bytecode += PUSHTEISUU_MEIREI;
					if((deco = TypeIdtoMeireiT(stree, ktype.id)) == NOP_MEIREI) return false;
					i += (TypeAtai(bytecode, deco, iap+i)+sizeof(intptr_t)-1)/sizeof(intptr_t) - 1;
				}
				tystack += ktype.id;
				break;
			case PULUS_TOKEN:
				ktype.id = tystack.GetConst()[tystack.GetLength()-2];
				if(ktype.id == BOOL_TYPEID || ktype.id <= ENDCLASS_TYPEID) return false;
				if(!JidouCast(stree, bytecode, tystack, ktype.id, tystack.GetConst()[tystack.GetLength()-1])) return false;
				bytecode += TASU_MEIREI;
				tystack.SetLength(tystack.GetLength()-1);
				break;
			case MINUS_TOKEN:
				ktype.id = tystack.GetConst()[tystack.GetLength()-2];
				if(ktype.id == BOOL_TYPEID || ktype.id <= ENDCLASS_TYPEID) return false;
				if(!JidouCast(stree, bytecode, tystack, ktype.id, tystack.GetConst()[tystack.GetLength()-1])) return false;
				bytecode += HIKU_MEIREI;
				tystack.SetLength(tystack.GetLength()-1);
				break;
			case KAKERU_TOKEN:
				ktype.id = tystack.GetConst()[tystack.GetLength()-2];
				if(ktype.id == BOOL_TYPEID || ktype.id <= ENDCLASS_TYPEID) return false;
				if(!JidouCast(stree, bytecode, tystack, ktype.id, tystack.GetConst()[tystack.GetLength()-1])) return false;
				bytecode += KAKERU_MEIREI;
				tystack.SetLength(tystack.GetLength()-1);
				break;
			case WARU_TOKEN:
				ktype.id = tystack.GetConst()[tystack.GetLength()-2];
				if(ktype.id == BOOL_TYPEID || ktype.id <= ENDCLASS_TYPEID) return false;
				if(!JidouCast(stree, bytecode, tystack, ktype.id, tystack.GetConst()[tystack.GetLength()-1])) return false;
				bytecode += WARU_MEIREI;
				tystack.SetLength(tystack.GetLength()-1);
				break;
			case AMARI_TOKEN:
				ktype.id = tystack.GetConst()[tystack.GetLength()-2];
				if(ktype.id == BOOL_TYPEID || ktype.id == FLOAT_TYPEID || ktype.id == DOUBLE_TYPEID || ktype.id <= ENDCLASS_TYPEID) return false;
				if(!JidouCast(stree, bytecode, tystack, ktype.id, tystack.GetConst()[tystack.GetLength()-1])) return false;
				bytecode += AMARI_MEIREI;
				tystack.SetLength(tystack.GetLength()-1);
				break;
			case AND_TOKEN:
				ktype.id = tystack.GetConst()[tystack.GetLength()-2];
				if(ktype.id == FLOAT_TYPEID || ktype.id == DOUBLE_TYPEID || ktype.id <= ENDCLASS_TYPEID) return false;
				if(!JidouCast(stree, bytecode, tystack, ktype.id, tystack.GetConst()[tystack.GetLength()-1])) return false;
				bytecode += AND_MEIREI;
				tystack.SetLength(tystack.GetLength()-1);
				break;
			case XOR_TOKEN:
				ktype.id = tystack.GetConst()[tystack.GetLength()-2];
				if(ktype.id == FLOAT_TYPEID || ktype.id == DOUBLE_TYPEID || ktype.id <= ENDCLASS_TYPEID) return false;
				if(!JidouCast(stree, bytecode, tystack, ktype.id, tystack.GetConst()[tystack.GetLength()-1])) return false;
				bytecode += XOR_MEIREI;
				tystack.SetLength(tystack.GetLength()-1);
				break;
			case OR_TOKEN:
				ktype.id = tystack.GetConst()[tystack.GetLength()-2];
				if(ktype.id == FLOAT_TYPEID || ktype.id == DOUBLE_TYPEID || ktype.id <= ENDCLASS_TYPEID) return false;
				if(!JidouCast(stree, bytecode, tystack, ktype.id, tystack.GetConst()[tystack.GetLength()-1])) return false;
				bytecode += OR_MEIREI;
				tystack.SetLength(tystack.GetLength()-1);
				break;
			case LSHIFT_TOKEN:
				ktype.id = tystack.GetConst()[tystack.GetLength()-2];
				if(ktype.id == BOOL_TYPEID || ktype.id == FLOAT_TYPEID || ktype.id == DOUBLE_TYPEID || ktype.id <= ENDCLASS_TYPEID) return false;
				if(!JidouCast(stree, bytecode, tystack, ktype.id, tystack.GetConst()[tystack.GetLength()-1])) return false;
				bytecode += LSHIFT_MEIREI;
				tystack.SetLength(tystack.GetLength()-1);
				break;
			case RSHIFT_TOKEN:
				ktype.id = tystack.GetConst()[tystack.GetLength()-2];
				if(ktype.id == BOOL_TYPEID || ktype.id == FLOAT_TYPEID || ktype.id == DOUBLE_TYPEID || ktype.id <= ENDCLASS_TYPEID) return false;
				if(!JidouCast(stree, bytecode, tystack, ktype.id, tystack.GetConst()[tystack.GetLength()-1])) return false;
				bytecode += RSHIFT_MEIREI;
				tystack.SetLength(tystack.GetLength()-1);
				break;
			case EQUAL_TOKEN:
				ktype.id = tystack.GetConst()[tystack.GetLength()-2];
				if(ktype.id <= ENDCLASS_TYPEID){
					if(ktype.id < 0){
						if((ktype.id != FUNC_TYPEID && ktype.id != METHOD_TYPEID)) return false;
					}else{
						if(stree.funclist.Get(ktype.id)->selftype != ENUM_BLOCK) return false;
					}
				}
				if(!JidouCast(stree, bytecode, tystack, ktype.id, tystack.GetConst()[tystack.GetLength()-1])) return false;
				bytecode += EQUAL_MEIREI;
				tystack.SetLength(tystack.GetLength()-1);
				tystack.GetData()[tystack.GetLength()-1] = BOOL_TYPEID;
				break;
			case NOTEQUAL_TOKEN:
				ktype.id = tystack.GetConst()[tystack.GetLength()-2];
				if(ktype.id <= ENDCLASS_TYPEID){
					if(ktype.id < 0){
						if((ktype.id != FUNC_TYPEID && ktype.id != METHOD_TYPEID)) return false;
					}else{
						if(stree.funclist.Get(ktype.id)->selftype != ENUM_BLOCK) return false;
					}
				}
				if(!JidouCast(stree, bytecode, tystack, ktype.id, tystack.GetConst()[tystack.GetLength()-1])) return false;
				bytecode += NOTEQUAL_MEIREI;
				tystack.SetLength(tystack.GetLength()-1);
				tystack.GetData()[tystack.GetLength()-1] = BOOL_TYPEID;
				break;
			case SHOU_TOKEN:
				ktype.id = tystack.GetConst()[tystack.GetLength()-2];
				if(ktype.id == BOOL_TYPEID) return false;
				if(ktype.id <= ENDCLASS_TYPEID){
					if(ktype.id < 0) return false;
					if(stree.funclist.Get(ktype.id)->selftype != ENUM_BLOCK) return false;
				}
				if(!JidouCast(stree, bytecode, tystack, ktype.id, tystack.GetConst()[tystack.GetLength()-1])) return false;
				bytecode += SHOU_MEIREI;
				tystack.SetLength(tystack.GetLength()-1);
				tystack.GetData()[tystack.GetLength()-1] = BOOL_TYPEID;
				break;
			case SHOUOREQUAL_TOKEN:
				ktype.id = tystack.GetConst()[tystack.GetLength()-2];
				if(ktype.id == BOOL_TYPEID) return false;
				if(ktype.id <= ENDCLASS_TYPEID){
					if(ktype.id < 0) return false;
					if(stree.funclist.Get(ktype.id)->selftype != ENUM_BLOCK) return false;
				}
				if(!JidouCast(stree, bytecode, tystack, ktype.id, tystack.GetConst()[tystack.GetLength()-1])) return false;
				bytecode += SHOUOREQUAL_MEIREI;
				tystack.SetLength(tystack.GetLength()-1);
				tystack.GetData()[tystack.GetLength()-1] = BOOL_TYPEID;
				break;
			case DAI_TOKEN:
				ktype.id = tystack.GetConst()[tystack.GetLength()-2];
				if(ktype.id == BOOL_TYPEID) return false;
				if(ktype.id <= ENDCLASS_TYPEID){
					if(ktype.id < 0) return false;
					if(stree.funclist.Get(ktype.id)->selftype != ENUM_BLOCK) return false;
				}
				if(!JidouCast(stree, bytecode, tystack, ktype.id, tystack.GetConst()[tystack.GetLength()-1])) return false;
				bytecode += DAI_MEIREI;
				tystack.SetLength(tystack.GetLength()-1);
				tystack.GetData()[tystack.GetLength()-1] = BOOL_TYPEID;
				break;
			case DAIOREQUAL_TOKEN:
				ktype.id = tystack.GetConst()[tystack.GetLength()-2];
				if(ktype.id == BOOL_TYPEID) return false;
				if(ktype.id <= ENDCLASS_TYPEID){
					if(ktype.id < 0) return false;
					if(stree.funclist.Get(ktype.id)->selftype != ENUM_BLOCK) return false;
				}
				if(!JidouCast(stree, bytecode, tystack, ktype.id, tystack.GetConst()[tystack.GetLength()-1])) return false;
				bytecode += DAIOREQUAL_MEIREI;
				tystack.SetLength(tystack.GetLength()-1);
				tystack.GetData()[tystack.GetLength()-1] = BOOL_TYPEID;
				break;
			case EXCLAMATION_TOKEN:
				if(ktype.id == FLOAT_TYPEID || ktype.id == DOUBLE_TYPEID || ktype.id <= ENDCLASS_TYPEID) return false;
				if(tystack.GetData()[tystack.GetLength()-1] == UNKNOWN_TYPEID) return false;
				if(tystack.GetData()[tystack.GetLength()-1] == BOOL_TYPEID && ktype.id != BOOL_TYPEID){
					bytecode += BOOLTYPE_MEIREI;
					ktype.id = BOOL_TYPEID;
				}
				bytecode += NOT_MEIREI;
				break;
			case DIA_TOKEN:
				if(ktype.id != REF_TYPEID && ktype.id != LIST_TYPEID) return false;
				il = 0;
				if(IsSoushokuToken((TokenKind)ktype.kwsk.GetConst()[il])) il++;
				if(ktype.kwsk.GetConst()[il] != REF_TOKEN && ktype.kwsk.GetConst()[il] != LIST_TOKEN) return false;
				il++;
				type.Clear();
				type.AddTail(ktype.kwsk.GetConst()+il, ktype.kwsk.GetLength()-il);
				bytecode += REFPOSSANSHOU_MEIREI;
				bytecode += INDEXTYPE_MEIREI;
				ktype.id = ADDRESS_TYPEID;
				tystack.SetLength(tystack.GetLength()-1);
				if(!Sanshou(stree, bytecode, iap, i, tystack, ktype, type, false)) return false;
				break;
			case DAIKAKKOOPEN_TOKEN:
				if(ktype.id == REF_TYPEID){
					deco = REFIDXSANSHOU_MEIREI;
				}else if(ktype.id == LIST_TYPEID){
					deco = LISTIDXSANSHOU_MEIREI;
				}else{
					return false;
				}
				il = 0;
				if(IsSoushokuToken((TokenKind)ktype.kwsk.GetConst()[il])) il++;
				if(ktype.kwsk.GetConst()[il] != REF_TOKEN && ktype.kwsk.GetConst()[il] != LIST_TOKEN) return false;
				il++;
				type.Clear();
				type.AddTail(ktype.kwsk.GetConst()+il, ktype.kwsk.GetLength()-il);
				i++;
				do{
					if(!MainSwitch(stree, bytecode, iap, i, tystack, ktype, retcall)) return false;
					i++;
				}while(iap[i] != DAIKAKKOCLOSE_TOKEN && iap[i] != TENTEN_TOKEN);
				if(!JidouCast(stree, bytecode, tystack, ADDRESS_TYPEID, ktype.id)) return false;
				ktype.id = ADDRESS_TYPEID;
				bytecode += PUSHTEISUU_MEIREI;
				AtaiCode(bytecode, (intptr_t)stree.GetTypeSize(type));
				if(iap[i] == TENTEN_TOKEN){
					i++;
					if(iap[i] != DAIKAKKOCLOSE_TOKEN) return false;
					bytecode += REFTYPE_MEIREI;
					bytecode += SLICE_MEIREI;
					ktype.id = REF_TYPEID;
					ktype.kwsk = REF_TOKEN;
					ktype.kwsk += type;
					tystack.SetLength(tystack.GetLength()-2);
					tystack.GetData()[tystack.GetLength()-1] = ktype.id;
				}else{
					bytecode += KAKERU_MEIREI;
					bytecode += deco;
					tystack.SetLength(tystack.GetLength()-2);
					if(!Sanshou(stree, bytecode, iap, i, tystack, ktype, type, false)) return false;
				}
				break;
			case NULL_TOKEN:
				i++;
				switch(iap[i]){
				case PULUS_TOKEN:
					if(ktype.id == BOOL_TYPEID || ktype.id <= ENDCLASS_TYPEID) return false;
					if(tystack.GetData()[tystack.GetLength()-1] == UNKNOWN_TYPEID) return false;
					if(tystack.GetData()[tystack.GetLength()-1] == BOOL_TYPEID) return false;
					break;
				case MINUS_TOKEN:
					if(ktype.id == BOOL_TYPEID || ktype.id <= ENDCLASS_TYPEID) return false;
					if(tystack.GetData()[tystack.GetLength()-1] == UNKNOWN_TYPEID) return false;
					if(tystack.GetData()[tystack.GetLength()-1] == BOOL_TYPEID) return false;
					bytecode += MINUS_MEIREI;
					break;
				case ANDAND_TOKEN:
				case OROR_TOKEN:
					if(!AAOO(stree, bytecode, iap, i, tystack, ktype)) return false;
					break;
				case QUESTION_TOKEN:
					if(!Sankou(stree, bytecode, iap, i, tystack, ktype)) return false;
					break;
				case MBR_TOKEN:
					if(ktype.id != ADDRESS_TYPEID) bytecode += INDEXTYPE_MEIREI;
					ktype.id = ADDRESS_TYPEID;
					bytecode += MEMBERKARASANSHOU_MEIREI;
					AtaiCode(bytecode, -stree.frp->parent->GetMemberSize());
					tystack += ADDRESS_TYPEID;
					if(iap[i+1] == NULL_TOKEN && iap[i+2] == DAINYUU_TOKEN){
						if(IsReadOnlyToken((TokenKind)stree.rettype.GetConst()[0])) return false;
						i += 2;
						typ.id = stree.frp->parent->funcid;
						if(!Dainyuu(stree, bytecode, iap, i, tystack, ktype, typ, 0, PUSHSTACKSANSHOU_MEIREI, true, false)) return false;
					}else{
						ktype.id = stree.frp->parent->funcid;
						tystack.GetData()[tystack.GetLength()-1] = ktype.id;
					}
					break;
				case TENTEN_TOKEN:
					if(!JidouCast(stree, bytecode, tystack, ADDRESS_TYPEID, ktype.id)) return false;
					ktype.id = ADDRESS_TYPEID;
					break;
				case RETURN_TOKEN:
					if((typ.id = TokenTtoTypeId(stree.frp->rettype.GetConst(), il=0)) == UNKNOWN_TYPEID) return false;
					if(!JidouCast(stree, bytecode, tystack, typ.id, ktype.id)) return false;
					ktype.id = typ.id;
					if(tystack.GetLength() > 0){//if͋󕶑΍
						if(ktype.id == VOID_TYPEID) return false;
						tystack.SetLength(tystack.GetLength()-1);
					}
					if(stree.frp == stree.root){
						bytecode += GBLDELPUSH_MEIREI;
						AtaiCode(bytecode, bytecode.GetLength()+1+sizeof(intptr_t)*2);
						bytecode += JUMP_MEIREI;
						glbbp = bytecode.GetLength();
						AtaiCode(bytecode, (intptr_t)0);
					}
					break;
				default:
					return false;
				}
				break;
			case RETURN_TOKEN:
				if(stree.frp == stree.root){
					if(retcall == NULL) *(intptr_t *)(bytecode.GetData()+glbbp) = bytecode.GetLength();
				}else{
					KansuStackClear(stree, bytecode);
				}
				typ.id = TokenTtoTypeId(stree.frp->rettype.GetConst(), il=0);
				if(stree.frp != stree.root && typ.id != VOID_TYPEID &&
					TypeIdtoMeireiT(stree, ktype.id) != TypeIdtoMeireiT(stree, typ.id)){
					bytecode += TypeIdtoMeireiT(stree, typ.id);
				}
				ktype.id = typ.id;
				if(retcall == NULL){
					bytecode += RETURN_MEIREI;
				}else{
					bytecode += JUMP_MEIREI;
					if(retcall->byteadress == 0){
						retcall->backpatch += bytecode.GetLength();
					}
					AtaiCode(bytecode, retcall->byteadress);
				}
				break;
			case SHARP_TOKEN:
			case SEMICOLON_TOKEN:
				if(ktype.id != VOID_TYPEID){
					if(tystack.GetData()[tystack.GetLength()-1] == UNKNOWN_TYPEID) return false;
					if(tystack.GetData()[tystack.GetLength()-1] == BOOL_TYPEID && ktype.id != BOOL_TYPEID) bytecode += BOOLTYPE_MEIREI;
					bytecode += POP_MEIREI;
					ktype.id = VOID_TYPEID;
				}
				tystack.SetLength(tystack.GetLength()-1);
				break;
			case LEN_TOKEN:
				i++;
				if(iap[i] != SHOUKAKKOOPEN_TOKEN) return false;
				i++;
				do{
					if(!MainSwitch(stree, bytecode, iap, i, tystack, ktype, retcall)) return false;
					i++;
				}while(iap[i] != SHOUKAKKOCLOSE_TOKEN);
				if(
					tystack.GetData()[tystack.GetLength()-1] == UNKNOWN_TYPEID
					|| tystack.GetData()[tystack.GetLength()-1] == BOOL_TYPEID
					|| (ktype.id != REF_TYPEID && ktype.id != LIST_TYPEID))
				{
					return false;
				}
				bytecode += REFLEN_MEIREI;
				il = 0;
				if(IsSoushokuToken((TokenKind)ktype.kwsk.GetConst()[il])) il++;
				if(ktype.kwsk.GetConst()[il] != REF_TOKEN && ktype.kwsk.GetConst()[il] != LIST_TOKEN) return false;
				il++;
				if((typ.id = TokenTtoTypeId(ktype.kwsk.GetConst(), il)) == UNKNOWN_TYPEID) return false;
				bytecode += INDEXTYPE_MEIREI;
				bytecode += PUSHTEISUU_MEIREI;
				AtaiCode(bytecode, TypeIdtoSize(stree, typ.id));
				bytecode += WARU_MEIREI;
				ktype.id = ADDRESS_TYPEID;
				tystack.GetData()[tystack.GetLength()-1] = ktype.id;
				break;
			case WAIT_TOKEN:
				i++;
				if(iap[i] != SHOUKAKKOOPEN_TOKEN) return false;
				do{
					i++;
					do{
						if(!MainSwitch(stree, bytecode, iap, i, tystack, ktype, retcall)) return false;
						i++;
					}while(iap[i] != SHOUKAKKOCLOSE_TOKEN && iap[i] != COMMA_TOKEN);
					if(
						tystack.GetData()[tystack.GetLength()-1] == UNKNOWN_TYPEID
						|| tystack.GetData()[tystack.GetLength()-1] == BOOL_TYPEID)
					{
						return false;
					}
					if(ktype.id == REF_TYPEID || ktype.id == LIST_TYPEID){
						bytecode += LOCK_MEIREI;
						bytecode += UNLOCK_MEIREI;
						bytecode += POP_MEIREI;
					}else if(ENDTHREAD_TYPEID <= ktype.id && ktype.id < 0){
						bytecode += SANSHOUTHREADWAIT_MEIREI;
					}else{
						return false;
					}
					tystack.SetLength(tystack.GetLength()-1);
				}while(iap[i] != SHOUKAKKOCLOSE_TOKEN);
				ktype.id = VOID_TYPEID;
				break;
			case CHUUKAKKOOPEN_TOKEN:
				i++;
				pst = stree.children.GetConst()[iap[i]];
				switch(pst->selftype){
				case NORMAL_BLOCK:
					if(!pomc->ncom.FuncTreeCompile(*pst, bytecode)) return false;
					break;
				case BRANCH_BLOCK:
					if(!pomc->brcom.FuncTreeCompile(*pst, bytecode)) return false;
					break;
				case LOOP_BLOCK:
					if(!pomc->lpcom.FuncTreeCompile(*pst, bytecode)) return false;
					break;
				case LOCK_BLOCK:
					i++;
					if(iap[i] != SHOUKAKKOOPEN_TOKEN) return false;
					indt = 0;
					do{
						i++;
						do{
							if(!MainSwitch(stree, bytecode, iap, i, tystack, ktype, retcall)) return false;
							i++;
						}while(iap[i] != SHOUKAKKOCLOSE_TOKEN && iap[i] != COMMA_TOKEN);
						if(
							tystack.GetData()[tystack.GetLength()-1] == UNKNOWN_TYPEID
							|| tystack.GetData()[tystack.GetLength()-1] == BOOL_TYPEID
							|| (ktype.id != REF_TYPEID && ktype.id != LIST_TYPEID))
						{
							return false;
						}
						bytecode += LOCK_MEIREI;
						bytecode += REFUP_MEIREI;
						bytecode += INDEXTYPE_MEIREI;
						bytecode += PUSHTEISUU_MEIREI;
						bp1 = bytecode.GetLength();
						AtaiCode(bytecode, (intptr_t)0);
						bytecode += JUMP_MEIREI;
						bp2 = bytecode.GetLength();
						AtaiCode(bytecode, (intptr_t)0);
						//
						*(intptr_t *)(bytecode.GetConst()+bp1) = bytecode.GetLength();
						//
						bytecode += UNLOCK_MEIREI;
						bytecode += LOCALPUSH_MEIREI;
						bytecode += HENSUUKARASANSHOU_MEIREI;
						AtaiCode(bytecode, -(intptr_t)sizeof(Reference));
						typ = ktype;
						ktype.id = VOID_TYPEID;
						if(!RefCountDown(stree, bytecode, ktype, SANSHOUREFDOWNNZJUMP_MEIREI, typ.kwsk, false)) return false;
						bytecode += HENSUUSTACKKAIHOU_MEIREI;
						AtaiCode(bytecode, (intptr_t)(sizeof(Reference)+sizeof(intptr_t)));
						bytecode += RETURN_MEIREI;
						//
						*(intptr_t *)(bytecode.GetConst()+bp2) = bytecode.GetLength();
						ktype.id = ADDRESS_TYPEID;
						//
						indt++;
					}while(iap[i] != SHOUKAKKOCLOSE_TOKEN);
					pst->hikisuucount = indt;
					if(!pomc->lkcom.FuncTreeCompile(*pst, bytecode)) return false;
					break;
				case SWITCH_BLOCK:
					i++;
					if(iap[i] != SHOUKAKKOOPEN_TOKEN) return false;
					i++;
					do{
						if(!MainSwitch(stree, bytecode, iap, i, tystack, ktype, retcall)) return false;
						i++;
					}while(iap[i] != SHOUKAKKOCLOSE_TOKEN);
					if(ktype.id == VOID_TYPEID) return false;
					ktype.id = tystack.GetData()[tystack.GetLength()-1];
					if(ktype.id < 0 || (ktype.id <= ENDCLASS_TYPEID && stree.funclist.Get(ktype.id)->selftype != ENUM_BLOCK)) return false;
					pst->extswitch->swtype = ktype.id;
					if(!pomc->swcom.FuncTreeCompile(*pst, bytecode)) return false;
					break;
				default:
					return false;
				}
				i++;
				if(iap[i] != CHUUKAKKOCLOSE_TOKEN) return false;
				break;
			case SHOUKAKKOOPEN_TOKEN:
				i++;
				if(iap[i] < 0){
					pst = stree.funclist.Get(~iap[i]);
					i++;
					if(Kansuu(stree, bytecode, iap, i, tystack, ktype, *pst, false) < 0) return false;
					if(!IsReadOnlyToken((TokenKind)pst->rettype.GetConst()[0]) && stree.frp->parent != NULL && !stree.frp->touka) bytecode += MEMBERPUSH_MEIREI;
					bytecode += CALL_MEIREI;
					if((ktype.id = TokenTtoTypeId(pst->rettype.GetConst(), il=0)) == UNKNOWN_TYPEID) return false;
					ktype.kwsk = pst->rettype;
					tystack += ktype.id;
					if(pst->byteadress == 0){
						pst->backpatch += bytecode.GetLength();
					}
					AtaiCode(bytecode, pst->byteadress);
					if(!IsReadOnlyToken((TokenKind)pst->rettype.GetConst()[0]) && stree.frp->parent != NULL && !stree.frp->touka) bytecode += MEMBERPOP_MEIREI;
				}else{
					if((typ.id = TokenTtoTypeId(iap, i)) == UNKNOWN_TYPEID) return false;
					if(!MeijiCast(stree, bytecode, tystack, typ.id, ktype.id)) return false;
					ktype = typ;
					tystack.GetData()[tystack.GetLength()-1] = ktype.id;
				}
				break;
			case KAKKOCOLOOPEN_TOKEN:
				i++;
				if((tmpip = KansuuPointer(stree, bytecode, iap, i, tystack, ktype, stree.frp->parent, waketa)) < 0) return false;
				if(tmpip > 0){
					bytecode += INDEXTYPE_MEIREI;
					bytecode += LOCALPUSH_MEIREI;
					bytecode += PUSHHENSUU_MEIREI;
					AtaiCode(bytecode, -(intptr_t)(tmpip+sizeof(intptr_t)));
				}
				bytecode += STACKCALL_MEIREI;
				if((ktype.id = TokenTtoTypeId(waketa.GetConst()[0].GetConst(), il=0)) == UNKNOWN_TYPEID) return false;
				ktype.kwsk = waketa.GetConst()[0];
				tystack.GetData()[tystack.GetLength()-1] = ktype.id;
				if(tmpip > 0){
					if(ktype.id != VOID_TYPEID){
						bytecode += TypeIdtoMeireiT(stree, ktype.id);
						bytecode += POPTOHENSUU_MEIREI;
						AtaiCode(bytecode, -(intptr_t)(tmpip+sizeof(intptr_t)));
					}
					bytecode += HENSUUSTACKKAIHOU_MEIREI;
					AtaiCode(bytecode, (intptr_t)sizeof(intptr_t)-stree.GetTypeSize(waketa.GetConst()[0]));
				}
				break;
			case LIB_TOKEN:
			case GBL_TOKEN:
				tmptk = (TokenKind)iap[i];
				i++;
				if(tmptk == LIB_TOKEN) i += 2;
				if(iap[i] == SHOUKAKKOOPEN_TOKEN){
					i++;
					if(iap[i] < 0){
						pst = stree.funclist.Get(~iap[i]);
						i++;
						if(stree.glbconstant && pst->rettype.GetConst()[0] != CONST_TOKEN) return false;
						if((typ.id = TokenTtoTypeId(pst->rettype.GetConst(), il=0)) == UNKNOWN_TYPEID) return false;
						typ.kwsk = pst->rettype;
						tystack += typ.id;
						if(typ.id == VOID_TYPEID && iap[i] == SHOUKAKKOCLOSE_TOKEN && iap[i+1] == NULL_TOKEN && iap[i+2] == RETURN_TOKEN){
							if(TokenTtoTypeId(stree.frp->rettype.GetConst(), il=0) != VOID_TYPEID) return false;
							tystack.SetLength(tystack.GetLength()-1);
							retcall = pst;
						}else{
							if(Kansuu(stree, bytecode, iap, i, tystack, ktype, *pst, false) < 0) return false;
							bytecode += CALL_MEIREI;
							if(pst->byteadress == 0){
								pst->backpatch += bytecode.GetLength();
							}
							AtaiCode(bytecode, pst->byteadress);
						}
						ktype = typ;
					}else{
						return false;
					}
				}else{
					if(iap[i] >= 0) return MainSwitch(stree, bytecode, iap, i, tystack, ktype, retcall);
					indt = ~iap[i];
					pst = (tmptk == LIB_TOKEN ? (SourceTree *)iap[i-2] : stree.root);
					cnstf = stree.glbconstant;
					ig = pst->golbalgetahoka;
					indt = ~iap[i];
					while(true){
						for(il=0; il < indt; il++) ig += pst->funchensuu.GetConst()[il].size;
						if(iap[i+1] != POINT_TOKEN) break;
						i += 2;
						if(iap[i] == SHOUKAKKOOPEN_TOKEN){
							ig += pst->funchensuu.GetConst()[indt].size;
							i++;
							if(iap[i] < 0){
								pst = stree.funclist.Get(~iap[i]);
								i++;
								if(!pst->kakutei && (pst = pst->GetIjousaki(ig)) == NULL) return false;
								if(stree.rettype.GetConst()[0] == CONST_TOKEN && pst->rettype.GetConst()[0] != CONST_TOKEN) return false;
								if(cnstf && !IsReadOnlyToken((TokenKind)pst->rettype.GetConst()[0])) return false;
								if(Kansuu(stree, bytecode, iap, i, tystack, ktype, *pst, false) < 0) return false;
								bytecode += MEMBERPUSHGLOBAL_MEIREI;
								AtaiCode(bytecode, ig);
								bytecode += CALL_MEIREI;
								if(pst->byteadress == 0){
									pst->backpatch += bytecode.GetLength();
								}
								AtaiCode(bytecode, pst->byteadress);
								if((ktype.id = TokenTtoTypeId(pst->rettype.GetConst(), il=0)) == UNKNOWN_TYPEID) return false;
								ktype.kwsk = pst->rettype;
								tystack += ktype.id;
								bytecode += MEMBERPOP_MEIREI;
							}else{
								return false;
							}
							break;
						}
						if(iap[i] >= 0) return false;
						il = 0;
						if(IsSoushokuToken((TokenKind)pst->funchensuu.GetConst()[indt].type.GetConst()[il])) il++;
						if(pst->funchensuu.GetConst()[indt].type.GetConst()[il] != CLASS_TOKEN) return false;
						il++;
						tyki = (int32_t)pst->funchensuu.GetConst()[indt].type.GetConst()[il];
						pst = stree.funclist.Get(tyki);
						indt = ~iap[i];
						cnstf = cnstf || IsReadOnlyToken((TokenKind)pst->funchensuu.GetConst()[indt].type.GetConst()[0]);
					}
					if(iap[i] >= 0) break;
					pty = &pst->funchensuu.GetConst()[indt].type;
					il = 0;
					if(IsSoushokuToken((TokenKind)pty->GetConst()[il])) il++;
					if(iap[i+1] == VOID_TOKEN){
						i++;
						if(pty->GetConst()[il] == THREAD_TOKEN){
							bytecode += GLOBALTHREADSETNULL_MEIREI;
							AtaiCode(bytecode, ig);
						}else{
							bytecode += GLOBALREFSETNULL_MEIREI;
							AtaiCode(bytecode, ig);
						}
						i++;
						if(iap[i] != SEMICOLON_TOKEN) return false;
						break;
					}
					if(iap[i+1] == DELETE_TOKEN || iap[i+1] == NEW_TOKEN){
						if(cnstf) return false;
						i++;
						bytecode += GLOBALKARASANSHOU_MEIREI;
						AtaiCode(bytecode, ig);
						if(pty->GetConst()[il] == THREAD_TOKEN){
							bytecode += SANSHOUTHREADWAIT_MEIREI;
						}else if(iap[i] != NEW_TOKEN || iap[i+1] != DAIKAKKOOPEN_TOKEN){
							if(!RefCountDown(stree, bytecode, ktype, SANSHOUREFDOWNNZJUMP_MEIREI, *pty, iap[i]==DELETE_TOKEN)) return false;
						}
						if(iap[i] == NEW_TOKEN){
							i++;
							if(pty->GetConst()[il+1] == CONST_TOKEN) return false;
							if(iap[i] == SHOUKAKKOOPEN_TOKEN){
								i++;
								if(pty->GetConst()[il] == REF_TOKEN){
									if(!RefNew(stree, bytecode, iap, i, tystack, ktype, SANSHOUREFNEW_MEIREI, *pty)) return false;
								}else{
									if(!RefNew(stree, bytecode, iap, i, tystack, ktype, SANSHOULISTNEW_MEIREI, *pty)) return false;
								}
							}else if(iap[i] == DAIKAKKOOPEN_TOKEN){
								i++;
								if(pty->GetConst()[il] != LIST_TOKEN) return false;
								if(!RefIdxNew(stree, bytecode, iap, i, tystack, ktype, *pty)) return false;
								il++;
								type.Clear();
								type.AddTail(pty->GetConst()+il, pty->GetLength()-il);
								if(!Sanshou(stree, bytecode, iap, i, tystack, ktype, type, false)) return false;
							}else{
								return false;
							}
						}else{
							i++;
							if(iap[i] != SEMICOLON_TOKEN) return false;
						}
						break;
					}
					if(iap[i+1] == SHOUKAKKOOPEN_TOKEN && iap[i+2] == TENTEN_TOKEN){
						if(cnstf) return false;
						i += 3;
						bytecode += GLOBALKARASANSHOU_MEIREI;
						AtaiCode(bytecode, ig);
						if(pty->GetConst()[il] != THREAD_TOKEN) return false;
						il++;
						if(Kansuu(stree, bytecode, iap, i, tystack, ktype, *stree.funclist.Get((int32_t)pty->GetConst()[il]), true) < 0) return false;
						bytecode += SANSHOUTHREADRUN_MEIREI;
						ktype.id = VOID_TYPEID;
						break;
					}
					tmpb = pty->GetConst()[il] == CLASS_TOKEN;
					if((typ.id = TokenTtoTypeId(pty->GetConst(), il=0)) == UNKNOWN_TYPEID) return false;
					typ.kwsk = pst->funchensuu.GetConst()[indt].type;
					if(iap[i+1] == NULL_TOKEN && iap[i+2] == TENDAINYUU_TOKEN){
						if(cnstf) return false;
						i += 2;
						bytecode += GLOBALKARASANSHOU_MEIREI;
						AtaiCode(bytecode, ig);
						if(!Append(stree, bytecode, iap, i, tystack, ktype, typ)) return false;
						return true;
					}
					if(iap[i+1] == NULL_TOKEN && (DAINYUU_TOKEN <= iap[i+2] && iap[i+2] <= SHIROYAJIRUSHI_TOKEN)){
						if(cnstf) return false;
						i += 2;
						if(!Dainyuu(stree, bytecode, iap, i, tystack, ktype, typ, ig, PUSHGLOBALHENSUU_MEIREI, tmpb , false)) return false;
						break;
					}
					if(
						(iap[i+1] == NULL_TOKEN && (iap[i+2] == PLSPLS_TOKEN || iap[i+2] == MNSMNS_TOKEN))
						|| iap[i+1] == PLSPLS_TOKEN || iap[i+1] == MNSMNS_TOKEN)
					{
						if(cnstf) return false;
						i++;
						bytecode += GLOBALKARASANSHOU_MEIREI;
						AtaiCode(bytecode, ig);
						if(!IncDec(stree, bytecode, iap, i, tystack, ktype, typ)) return false;
						break;
					}
					ktype.kwsk = typ.kwsk;
					if(typ.id != ktype.id){
						if(typ.id == VOID_TYPEID) return false;
						ktype.id = typ.id;
						if(!tmpb && !(ENDTHREAD_TYPEID <= ktype.id && ktype.id < 0)){
							if((deco = TypeIdtoMeireiT(stree, ktype.id)) == NOP_MEIREI) return false;
							bytecode += deco;
						}
					}
					if(cnstf && ENDTHREAD_TYPEID <= ktype.id && ktype.id < 0) return false;
					if(ktype.id != VOID_TYPEID){
						if(pty->GetConst()[0] == CONST_TOKEN){
							if(ktype.id == FUNC_TYPEID){
								bytecode += PUSHTEISUU_MEIREI;
								if(pty->GetConst()[pty->GetLength()-1] < 0){
									AtaiCode(bytecode, pty->GetConst()[pty->GetLength()-1]);
								}else{
									if(!stree.funclist.Get((int32_t)pty->GetConst()[pty->GetLength()-1])->kakutei) return false;
									if(stree.funclist.Get((int32_t)pty->GetConst()[pty->GetLength()-1])->byteadress == 0){
										stree.funclist.Get((int32_t)pty->GetConst()[pty->GetLength()-1])->backpatch += bytecode.GetLength();
									}
									AtaiCode(bytecode, stree.funclist.Get((int32_t)pty->GetConst()[pty->GetLength()-1])->byteadress);
								}
							}else if(ktype.id == REF_TYPEID){
								bytecode += PUSHGLOBALHENSUU_MEIREI;
								AtaiCode(bytecode, pty->GetConst()[pty->GetLength()-1]);
							}else{
								if((deco = TypeIdtoMeireiT(stree, ktype.id)) == NOP_MEIREI) return false;
								bytecode += PUSHTEISUU_MEIREI;
								TypeAtai(bytecode, deco, pty->GetConst()+il);
							}
						}else{
							if(tmpb || (ENDTHREAD_TYPEID <= ktype.id && ktype.id < 0)){
								bytecode += GLOBALKARASANSHOU_MEIREI;
							}else{
								bytecode += PUSHGLOBALHENSUU_MEIREI;
							}
							AtaiCode(bytecode, ig);
						}
						if(ktype.id == METHOD_TYPEID && iap[i+1] == KAKKOCOLOOPEN_TOKEN){
							i += 2;
							for(il = indt; il < pst->funchensuu.GetLength(); il++) ig += pst->funchensuu.GetConst()[il].size;
							if((tmpip = KansuuPointer(stree, bytecode, iap, i, tystack, ktype, pst, waketa)) < 0) return false;
							if(stree.rettype.GetConst()[0] == CONST_TOKEN && waketa.GetConst()[0].GetConst()[0] != CONST_TOKEN) return false;
							if(cnstf && !IsReadOnlyToken((TokenKind)waketa.GetConst()[0].GetConst()[0])) return false;
							bytecode += MEMBERPUSHGLOBAL_MEIREI;
							AtaiCode(bytecode, ig);
							if(tmpip > 0){
								bytecode += INDEXTYPE_MEIREI;
								bytecode += LOCALPUSH_MEIREI;
								bytecode += PUSHHENSUU_MEIREI;
								AtaiCode(bytecode, -(intptr_t)(tmpip+sizeof(intptr_t)));
							}
							bytecode += STACKCALL_MEIREI;
							if((ktype.id = TokenTtoTypeId(waketa.GetConst()[0].GetConst(), il=0)) == UNKNOWN_TYPEID) return false;
							ktype.kwsk = waketa.GetConst()[0];
							if(tmpip > 0){
								if(ktype.id != VOID_TYPEID){
									bytecode += POPTOHENSUU_MEIREI;
									AtaiCode(bytecode, -(intptr_t)(tmpip+sizeof(intptr_t)));
								}
								bytecode += HENSUUSTACKKAIHOU_MEIREI;
								AtaiCode(bytecode, (intptr_t)sizeof(intptr_t)-stree.GetTypeSize(waketa.GetConst()[0]));
							}
							bytecode += MEMBERPOP_MEIREI;
						}
					}
					tystack += ktype.id;
				}
				break;
			case MBR_TOKEN:
				i++;
				if(iap[i] == SHOUKAKKOOPEN_TOKEN){
					i++;
					if(iap[i] < 0){
						pst = stree.funclist.Get(~iap[i]);
						i++;
						if(stree.rettype.GetConst()[0] == CONST_TOKEN && pst->rettype.GetConst()[0] != CONST_TOKEN) return false;
						if(stree.rettype.GetConst()[0] == PROPERTY_TOKEN && !IsReadOnlyToken((TokenKind)pst->rettype.GetConst()[0])) return false;
						if((typ.id = TokenTtoTypeId(pst->rettype.GetConst(), il=0)) == UNKNOWN_TYPEID) return false;
						typ.kwsk = pst->rettype;
						tystack += typ.id;
						if(typ.id == VOID_TYPEID && iap[i] == SHOUKAKKOCLOSE_TOKEN && iap[i+1] == NULL_TOKEN && iap[i+2] == RETURN_TOKEN){
							if(TokenTtoTypeId(stree.frp->rettype.GetConst(), il=0) != VOID_TYPEID) return false;
							tystack.SetLength(tystack.GetLength()-1);
							retcall = pst;
						}else{
							if(Kansuu(stree, bytecode, iap, i, tystack, ktype, *pst, false) < 0) return false;
							bytecode += CALL_MEIREI;
							if(pst->byteadress == 0){
								pst->backpatch += bytecode.GetLength();
							}
							AtaiCode(bytecode, pst->byteadress);
						}
						ktype = typ;
					}else{
						return false;
					}
				}else{
					if(iap[i] >= 0) return MainSwitch(stree, bytecode, iap, i, tystack, ktype, retcall);
					indt = ~iap[i];
					pst = stree.frp->parent;
					cnstf = stree.rettype.GetConst()[0] == CONST_TOKEN;
					if(pst->tpcount <= indt && indt < pst->tpcount+pst->hikisuucount
						&& pst->funchensuu.GetConst()[indt].type.GetConst()[pst->funchensuu.GetConst()[indt].type.GetLength()-1] == ~DAINYUU_TOKEN)
					{
						ig = 0;
						for(il = pst->funchensuu.GetLength()-1; il >= indt; il--) ig -= pst->funchensuu.GetConst()[il].size;
						if(ktype.id != ADDRESS_TYPEID) bytecode += INDEXTYPE_MEIREI;
						ktype.id = ADDRESS_TYPEID;
						bytecode += PUSHMEMBERHENSUU_MEIREI;
						AtaiCode(bytecode, ig);
						type = pst->funchensuu.GetConst()[indt].type;
						type.SetLength(type.GetLength()-1);
						if(!Sanshou(stree, bytecode, iap, i, tystack, ktype, type, cnstf)) return false;
					}else{
						cnstf = cnstf || indt < pst->tpcount+pst->hikisuucount;
						ig = 0;
						indt = ~iap[i];
						while(true){
							for(il = pst->funchensuu.GetLength()-1; il >= indt; il--) ig -= pst->funchensuu.GetConst()[il].size;
							if(iap[i+1] != POINT_TOKEN) break;
							i += 2;
							ig += pst->funchensuu.GetConst()[indt].size;
							if(iap[i] == SHOUKAKKOOPEN_TOKEN){
								i++;
								if(iap[i] < 0){
									pst = stree.funclist.Get(~iap[i]);
									i++;
									if(!pst->kakutei && (pst = pst->GetIjousaki(ig)) == NULL) return false;
									if(stree.rettype.GetConst()[0] == CONST_TOKEN && pst->rettype.GetConst()[0] != CONST_TOKEN) return false;
									if(cnstf && !IsReadOnlyToken((TokenKind)pst->rettype.GetConst()[0])) return false;
									if(Kansuu(stree, bytecode, iap, i, tystack, ktype, *pst, false) < 0) return false;
									bytecode += MEMBERPUSHMEMBER_MEIREI;
									AtaiCode(bytecode, ig);
									bytecode += CALL_MEIREI;
									if((ktype.id = TokenTtoTypeId(pst->rettype.GetConst(), il=0)) == UNKNOWN_TYPEID) return false;
									ktype.kwsk = pst->rettype;
									tystack += ktype.id;
									if(pst->byteadress == 0){
										pst->backpatch += bytecode.GetLength();
									}
									AtaiCode(bytecode, pst->byteadress);
									bytecode += MEMBERPOP_MEIREI;
								}else{
									return false;
								}
								break;
							}
							if(iap[i] >= 0) return false;
							il = 0;
							if(IsSoushokuToken((TokenKind)pst->funchensuu.GetConst()[indt].type.GetConst()[il])) il++;
							if(pst->funchensuu.GetConst()[indt].type.GetConst()[il] != CLASS_TOKEN) return false;
							il++;
							tyki = (int32_t)pst->funchensuu.GetConst()[indt].type.GetConst()[il];
							pst = stree.funclist.Get(tyki);
							indt = ~iap[i];
							cnstf = cnstf || IsReadOnlyToken((TokenKind)pst->funchensuu.GetConst()[indt].type.GetConst()[0]);
						}
						if(iap[i] >= 0) break;
						pty = &pst->funchensuu.GetConst()[indt].type;
						il = 0;
						if(IsSoushokuToken((TokenKind)pty->GetConst()[il])) il++;
						if(iap[i+1] == VOID_TOKEN){
							i++;
							if(pty->GetConst()[il] == THREAD_TOKEN){
								bytecode += MEMBERTHREADSETNULL_MEIREI;
								AtaiCode(bytecode, ig);
							}else{
								bytecode += MEMBERREFSETNULL_MEIREI;
								AtaiCode(bytecode, ig);
							}
							i++;
							if(iap[i] != SEMICOLON_TOKEN) return false;
							break;
						}
						if(iap[i+1] == DELETE_TOKEN || iap[i+1] == NEW_TOKEN){
							if(cnstf) return false;
							i++;
							bytecode += MEMBERKARASANSHOU_MEIREI;
							AtaiCode(bytecode, ig);
							if(pty->GetConst()[il] == THREAD_TOKEN){
								bytecode += SANSHOUTHREADWAIT_MEIREI;
							}else if(iap[i] != NEW_TOKEN || iap[i+1] != DAIKAKKOOPEN_TOKEN){
								if(!RefCountDown(stree, bytecode, ktype, SANSHOUREFDOWNNZJUMP_MEIREI, *pty, iap[i]==DELETE_TOKEN)) return false;
							}
							if(iap[i] == NEW_TOKEN){
								i++;
								if(pty->GetConst()[il+1] == CONST_TOKEN) return false;
								if(iap[i] == SHOUKAKKOOPEN_TOKEN){
									i++;
									if(pty->GetConst()[il] == REF_TOKEN){
										if(!RefNew(stree, bytecode, iap, i, tystack, ktype, SANSHOUREFNEW_MEIREI, *pty)) return false;
									}else{
										if(!RefNew(stree, bytecode, iap, i, tystack, ktype, SANSHOULISTNEW_MEIREI, *pty)) return false;
									}
								}else if(iap[i] == DAIKAKKOOPEN_TOKEN){
									i++;
									if(pty->GetConst()[il] != LIST_TOKEN) return false;
									if(!RefIdxNew(stree, bytecode, iap, i, tystack, ktype, *pty)) return false;
									il++;
									type.Clear();
									type.AddTail(pty->GetConst()+il, pty->GetLength()-il);
									if(!Sanshou(stree, bytecode, iap, i, tystack, ktype, type, false)) return false;
								}else{
									return false;
								}
							}else{
								i++;
								if(iap[i] != SEMICOLON_TOKEN) return false;
							}
							break;
						}
						if(iap[i+1] == SHOUKAKKOOPEN_TOKEN && iap[i+2] == TENTEN_TOKEN){
							if(cnstf) return false;
							i += 3;
							bytecode += MEMBERKARASANSHOU_MEIREI;
							AtaiCode(bytecode, ig);
							if(pty->GetConst()[il] != THREAD_TOKEN) return false;
							il++;
							if(Kansuu(stree, bytecode, iap, i, tystack, ktype, *stree.funclist.Get((int32_t)pty->GetConst()[il]), true) < 0) return false;
							bytecode += SANSHOUTHREADRUN_MEIREI;
							ktype.id = VOID_TYPEID;
							break;
						}
						tmpb = pst->funchensuu.GetConst()[indt].type.GetConst()[il] == CLASS_TOKEN;
						if((typ.id = TokenTtoTypeId(pty->GetConst(), il=0)) == UNKNOWN_TYPEID) return false;
						typ.kwsk = pst->funchensuu.GetConst()[indt].type;
						if(iap[i+1] == NULL_TOKEN && iap[i+2] == TENDAINYUU_TOKEN){
							if(cnstf) return false;
							i += 2;
							bytecode += MEMBERKARASANSHOU_MEIREI;
							AtaiCode(bytecode, ig);
							if(!Append(stree, bytecode, iap, i, tystack, ktype, typ)) return false;
							return true;
						}
						if(iap[i+1] == NULL_TOKEN && (DAINYUU_TOKEN <= iap[i+2] && iap[i+2] <= SHIROYAJIRUSHI_TOKEN)){
							if(cnstf) return false;
							i += 2;
							if(!Dainyuu(stree, bytecode, iap, i, tystack, ktype, typ, ig, PUSHMEMBERHENSUU_MEIREI, tmpb, false)) return false;
							break;
						}
						if(
							(iap[i+1] == NULL_TOKEN && (iap[i+2] == PLSPLS_TOKEN || iap[i+2] == MNSMNS_TOKEN))
							|| iap[i+1] == PLSPLS_TOKEN || iap[i+1] == MNSMNS_TOKEN)
						{
							if(cnstf) return false;
							i++;
							bytecode += MEMBERKARASANSHOU_MEIREI;
							AtaiCode(bytecode, ig);
							if(!IncDec(stree, bytecode, iap, i, tystack, ktype, typ)) return false;
							break;
						}
						ktype.kwsk = typ.kwsk;
						if(typ.id != ktype.id){
							if(typ.id == VOID_TYPEID) return false;
							ktype.id = typ.id;
							if(!tmpb && !(ENDTHREAD_TYPEID <= ktype.id && ktype.id < 0)){
								if((deco = TypeIdtoMeireiT(stree, ktype.id)) == NOP_MEIREI) return false;
								bytecode += deco;
							}
						}
						if(cnstf && ENDTHREAD_TYPEID <= ktype.id && ktype.id < 0) return false;
						if(ktype.id != VOID_TYPEID){
							if(pty->GetConst()[0] == CONST_TOKEN){
								bytecode += PUSHTEISUU_MEIREI;
								if(ktype.id == FUNC_TYPEID){
									if(pty->GetConst()[pty->GetLength()-1] < 0){
										AtaiCode(bytecode, pty->GetConst()[pty->GetLength()-1]);
									}else{
										if(!stree.funclist.Get((int32_t)pty->GetConst()[pty->GetLength()-1])->kakutei) return false;
										if(stree.funclist.Get((int32_t)pty->GetConst()[pty->GetLength()-1])->byteadress == 0){
											stree.funclist.Get((int32_t)pty->GetConst()[pty->GetLength()-1])->backpatch += bytecode.GetLength();
										}
										AtaiCode(bytecode, stree.funclist.Get((int32_t)pty->GetConst()[pty->GetLength()-1])->byteadress);
									}
								}else if(ktype.id == REF_TYPEID){
									bytecode += PUSHGLOBALHENSUU_MEIREI;
									AtaiCode(bytecode, pty->GetConst()[pty->GetLength()-1]);
								}else{
									if((deco = TypeIdtoMeireiT(stree, ktype.id)) == NOP_MEIREI) return false;
									TypeAtai(bytecode, deco, pty->GetConst()+il);
								}
							}else{
								if(tmpb || (ENDTHREAD_TYPEID <= ktype.id && ktype.id < 0)){
									bytecode += MEMBERKARASANSHOU_MEIREI;
								}else{
									bytecode += PUSHMEMBERHENSUU_MEIREI;
								}
								AtaiCode(bytecode, ig);
							}
							if(ktype.id == METHOD_TYPEID && iap[i+1] == KAKKOCOLOOPEN_TOKEN){
								i += 2;
								for(il = indt; il < pst->funchensuu.GetLength(); il++) ig += pst->funchensuu.GetConst()[il].size;
								if((tmpip = KansuuPointer(stree, bytecode, iap, i, tystack, ktype, pst, waketa)) < 0) return false;
								if(stree.rettype.GetConst()[0] == CONST_TOKEN && waketa.GetConst()[0].GetConst()[0] != CONST_TOKEN) return false;
								if(cnstf && !IsReadOnlyToken((TokenKind)waketa.GetConst()[0].GetConst()[0])) return false;
								bytecode += MEMBERPUSHMEMBER_MEIREI;
								AtaiCode(bytecode, ig);
								if(tmpip > 0){
									bytecode += INDEXTYPE_MEIREI;
									bytecode += LOCALPUSH_MEIREI;
									bytecode += PUSHHENSUU_MEIREI;
									AtaiCode(bytecode, -(intptr_t)(tmpip+sizeof(intptr_t)));
								}
								bytecode += STACKCALL_MEIREI;
								if((ktype.id = TokenTtoTypeId(waketa.GetConst()[0].GetConst(), il=0)) == UNKNOWN_TYPEID) return false;
								ktype.kwsk = waketa.GetConst()[0];
								if(tmpip > 0){
									if(ktype.id != VOID_TYPEID){
										bytecode += POPTOHENSUU_MEIREI;
										AtaiCode(bytecode, -(intptr_t)(tmpip+sizeof(intptr_t)));
									}
									bytecode += HENSUUSTACKKAIHOU_MEIREI;
									AtaiCode(bytecode, (intptr_t)sizeof(intptr_t)-stree.GetTypeSize(waketa.GetConst()[0]));
								}
								bytecode += MEMBERPOP_MEIREI;
							}
						}
						tystack += ktype.id;
					}
				}
				break;
			default:
				if(iap[i] >= 0) return false;
				indt = ~iap[i];
				pst = stree.frp;
				cnstf = false;
				if(pst->tpcount <= indt && indt < pst->tpcount+pst->hikisuucount
					&& pst->funchensuu.GetConst()[indt].type.GetConst()[pst->funchensuu.GetConst()[indt].type.GetLength()-1] == ~DAINYUU_TOKEN)
				{
					ig = 0;
					for(il = pst->funchensuu.GetLength()-1; il >= indt; il--) ig -= pst->funchensuu.GetConst()[il].size;
					if(ktype.id != ADDRESS_TYPEID) bytecode += INDEXTYPE_MEIREI;
					ktype.id = ADDRESS_TYPEID;
					bytecode += PUSHHENSUU_MEIREI;
					AtaiCode(bytecode, ig);
					type = pst->funchensuu.GetConst()[indt].type;
					type.SetLength(type.GetLength()-1);
					if(!Sanshou(stree, bytecode, iap, i, tystack, ktype, type, cnstf)) return false;
				}else{
					cnstf = cnstf || indt < pst->tpcount+pst->hikisuucount;
					ig = 0;
					indt = ~iap[i];
					while(true){
						for(il = pst->funchensuu.GetLength()-1; il >= indt; il--) ig -= pst->funchensuu.GetConst()[il].size;
						if(iap[i+1] != POINT_TOKEN) break;
						i += 2;
						ig += pst->funchensuu.GetConst()[indt].size;
						if(iap[i] == SHOUKAKKOOPEN_TOKEN){
							i++;
							if(iap[i] < 0){
								pst = stree.funclist.Get(~iap[i]);
								i++;
								if(!pst->kakutei && (pst = pst->GetIjousaki(ig)) == NULL) return false;
								if(stree.rettype.GetConst()[0] == CONST_TOKEN && pst->rettype.GetConst()[0] != CONST_TOKEN) return false;
								if(cnstf && !IsReadOnlyToken((TokenKind)pst->rettype.GetConst()[0])) return false;
								if(Kansuu(stree, bytecode, iap, i, tystack, ktype, *pst, false) < 0) return false;
								bytecode += MEMBERPUSHHENSUU_MEIREI;
								AtaiCode(bytecode, ig);
								bytecode += CALL_MEIREI;
								if(pst->byteadress == 0){
									pst->backpatch += bytecode.GetLength();
								}
								AtaiCode(bytecode, pst->byteadress);
								if((ktype.id = TokenTtoTypeId(pst->rettype.GetConst(), il=0)) == UNKNOWN_TYPEID) return false;
								ktype.kwsk = pst->rettype;
								tystack += ktype.id;
								bytecode += MEMBERPOP_MEIREI;
							}else{
								return false;
							}
							break;
						}
						if(iap[i] >= 0) return false;
						il = 0;
						if(IsSoushokuToken((TokenKind)pst->funchensuu.GetConst()[indt].type.GetConst()[il])) il++;
						if(pst->funchensuu.GetConst()[indt].type.GetConst()[il] != CLASS_TOKEN && pst->funchensuu.GetConst()[indt].type.GetConst()[il] != ENUM_TOKEN) return false;
						il++;
						tyki = (int32_t)pst->funchensuu.GetConst()[indt].type.GetConst()[il];
						pst = stree.funclist.Get(tyki);
						indt = ~iap[i];
						cnstf = cnstf || IsReadOnlyToken((TokenKind)pst->funchensuu.GetConst()[indt].type.GetConst()[0]);
					}
					if(iap[i] >= 0) break;
					pty = &pst->funchensuu.GetConst()[indt].type;
					il = 0;
					if(IsSoushokuToken((TokenKind)pty->GetConst()[il])) il++;
					if(iap[i+1] == VOID_TOKEN){
						i++;
						if(pty->GetConst()[il] == THREAD_TOKEN){
							bytecode += HENSUUTHREADSETNULL_MEIREI;
							AtaiCode(bytecode, ig);
						}else{
							bytecode += HENSUUREFSETNULL_MEIREI;
							AtaiCode(bytecode, ig);
						}
						i++;
						if(iap[i] != SEMICOLON_TOKEN) return false;
						break;
					}
					if(iap[i+1] == DELETE_TOKEN || iap[i+1] == NEW_TOKEN){
						if(cnstf) return false;
						i++;
						bytecode += HENSUUKARASANSHOU_MEIREI;
						AtaiCode(bytecode, ig);
						if(pty->GetConst()[il] == THREAD_TOKEN){
							bytecode += SANSHOUTHREADWAIT_MEIREI;
						}else if(iap[i] != NEW_TOKEN || iap[i+1] != DAIKAKKOOPEN_TOKEN){
							if(!RefCountDown(stree, bytecode, ktype, SANSHOUREFDOWNNZJUMP_MEIREI, *pty, iap[i]==DELETE_TOKEN)) return false;
						}
						if(iap[i] == NEW_TOKEN){
							i++;
							if(pty->GetConst()[il+1] == CONST_TOKEN) return false;
							if(iap[i] == SHOUKAKKOOPEN_TOKEN){
								i++;
								if(pty->GetConst()[il] == REF_TOKEN){
									if(!RefNew(stree, bytecode, iap, i, tystack, ktype, SANSHOUREFNEW_MEIREI, *pty)) return false;
								}else{
									if(!RefNew(stree, bytecode, iap, i, tystack, ktype, SANSHOULISTNEW_MEIREI, *pty)) return false;
								}
							}else if(iap[i] == DAIKAKKOOPEN_TOKEN){
								i++;
								if(pty->GetConst()[il] != LIST_TOKEN) return false;
								if(!RefIdxNew(stree, bytecode, iap, i, tystack, ktype, *pty)) return false;
								il++;
								type.Clear();
								type.AddTail(pty->GetConst()+il, pty->GetLength()-il);
								if(!Sanshou(stree, bytecode, iap, i, tystack, ktype, type, false)) return false;
							}else{
								return false;
							}
						}else{
							i++;
							if(iap[i] != SEMICOLON_TOKEN) return false;
						}
						break;
					}
					if(iap[i+1] == SHOUKAKKOOPEN_TOKEN && iap[i+2] == TENTEN_TOKEN){
						if(cnstf) return false;
						i += 3;
						bytecode += HENSUUKARASANSHOU_MEIREI;
						AtaiCode(bytecode, ig);
						if(pty->GetConst()[il] != THREAD_TOKEN) return false;
						il++;
						if(Kansuu(stree, bytecode, iap, i, tystack, ktype, *stree.funclist.Get((int32_t)pty->GetConst()[il]), true) < 0) return false;
						bytecode += SANSHOUTHREADRUN_MEIREI;
						ktype.id = VOID_TYPEID;
						break;
					}
					tmpb = pst->funchensuu.GetConst()[indt].type.GetConst()[il] == CLASS_TOKEN;
					if((typ.id = TokenTtoTypeId(pty->GetConst(), il=0)) == UNKNOWN_TYPEID) return false;
					typ.kwsk = pst->funchensuu.GetConst()[indt].type;
					if(iap[i+1] == NULL_TOKEN && iap[i+2] == TENDAINYUU_TOKEN){
						if(cnstf) return false;
						i += 2;
						bytecode += HENSUUKARASANSHOU_MEIREI;
						AtaiCode(bytecode, ig);
						if(!Append(stree, bytecode, iap, i, tystack, ktype, typ)) return false;
						return true;
					}
					if(iap[i+1] == NULL_TOKEN && (DAINYUU_TOKEN <= iap[i+2] && iap[i+2] <= SHIROYAJIRUSHI_TOKEN)){
						if(cnstf) return false;
						i += 2;
						if(!Dainyuu(stree, bytecode, iap, i, tystack, ktype, typ, ig, PUSHHENSUU_MEIREI, tmpb , false)) return false;
						break;
					}
					if(
						(iap[i+1] == NULL_TOKEN && (iap[i+2] == PLSPLS_TOKEN || iap[i+2] == MNSMNS_TOKEN))
						|| iap[i+1] == PLSPLS_TOKEN || iap[i+1] == MNSMNS_TOKEN)
					{
						if(cnstf) return false;
						i++;
						bytecode += HENSUUKARASANSHOU_MEIREI;
						AtaiCode(bytecode, ig);
						if(!IncDec(stree, bytecode, iap, i, tystack, ktype, typ)) return false;
						break;
					}
					ktype.kwsk = typ.kwsk;
					if(typ.id != ktype.id){
						if(typ.id == VOID_TYPEID) return false;
						ktype.id = typ.id;
						if(!tmpb && !(ENDTHREAD_TYPEID <= ktype.id && ktype.id < 0)){
							if((deco = TypeIdtoMeireiT(stree, ktype.id)) == NOP_MEIREI) return false;
							bytecode += deco;
						}
					}
					if(cnstf && ENDTHREAD_TYPEID <= ktype.id && ktype.id < 0) return false;
					if(ktype.id != VOID_TYPEID){
						if(pty->GetConst()[0] == CONST_TOKEN){
							bytecode += PUSHTEISUU_MEIREI;
							if(ktype.id == FUNC_TYPEID){
								if(pty->GetConst()[pty->GetLength()-1] < 0){
									AtaiCode(bytecode, pty->GetConst()[pty->GetLength()-1]);
								}else{
									if(!stree.funclist.Get((int32_t)pty->GetConst()[pty->GetLength()-1])->kakutei) return false;
									if(stree.funclist.Get((int32_t)pty->GetConst()[pty->GetLength()-1])->byteadress == 0){
										stree.funclist.Get((int32_t)pty->GetConst()[pty->GetLength()-1])->backpatch += bytecode.GetLength();
									}
									AtaiCode(bytecode, stree.funclist.Get((int32_t)pty->GetConst()[pty->GetLength()-1])->byteadress);
								}
							}else if(ktype.id == REF_TYPEID){
								bytecode += PUSHGLOBALHENSUU_MEIREI;
								AtaiCode(bytecode, pty->GetConst()[pty->GetLength()-1]);
							}else{
								if((deco = TypeIdtoMeireiT(stree, ktype.id)) == NOP_MEIREI) return false;
								TypeAtai(bytecode, deco, pty->GetConst()+il);
							}
						}else{
							if(tmpb || (ENDTHREAD_TYPEID <= ktype.id && ktype.id < 0)){
								bytecode += HENSUUKARASANSHOU_MEIREI;
							}else{
								bytecode += PUSHHENSUU_MEIREI;
							}
							AtaiCode(bytecode, ig);
						}
						if(ktype.id == METHOD_TYPEID && iap[i+1] == KAKKOCOLOOPEN_TOKEN){
							i += 2;
							for(il = indt; il < pst->funchensuu.GetLength(); il++) ig += pst->funchensuu.GetConst()[il].size;
							if((tmpip = KansuuPointer(stree, bytecode, iap, i, tystack, ktype, pst, waketa)) < 0) return false;
							if(stree.rettype.GetConst()[0] == CONST_TOKEN && waketa.GetConst()[0].GetConst()[0] != CONST_TOKEN) return false;
							if(cnstf && !IsReadOnlyToken((TokenKind)waketa.GetConst()[0].GetConst()[0])) return false;
							bytecode += MEMBERPUSHHENSUU_MEIREI;
							AtaiCode(bytecode, ig);
							if(tmpip > 0){
								bytecode += INDEXTYPE_MEIREI;
								bytecode += LOCALPUSH_MEIREI;
								bytecode += PUSHHENSUU_MEIREI;
								AtaiCode(bytecode, -(intptr_t)(tmpip+sizeof(intptr_t)));
							}
							bytecode += STACKCALL_MEIREI;
							if((ktype.id = TokenTtoTypeId(waketa.GetConst()[0].GetConst(), il=0)) == UNKNOWN_TYPEID) return false;
							ktype.kwsk = waketa.GetConst()[0];
							if(tmpip > 0){
								if(ktype.id != VOID_TYPEID){
									bytecode += POPTOHENSUU_MEIREI;
									AtaiCode(bytecode, -(intptr_t)(tmpip+sizeof(intptr_t)));
								}
								bytecode += HENSUUSTACKKAIHOU_MEIREI;
								AtaiCode(bytecode, (intptr_t)sizeof(intptr_t)-stree.GetTypeSize(waketa.GetConst()[0]));
							}
							bytecode += MEMBERPOP_MEIREI;
						}
					}
					tystack += ktype.id;
				}
				break;
			}
			return true;
		}
		bool Sankou(SourceTree & stree, PWCArray<uint8_t> & bytecode, const intptr_t * const iap, int & i, PWCArray<int32_t> & tystack, KuwashiiType & ktype)
		{
			intptr_t bp1, bp2;
			KuwashiiType typ;
			SourceTree * retcall = NULL;
			if(tystack.GetData()[tystack.GetLength()-1] != BOOL_TYPEID) return false;
			bytecode += POPNFALSEJUMP_MEIREI;
			bp1 = bytecode.GetLength();
			AtaiCode(bytecode, (intptr_t)0);
			tystack.SetLength(tystack.GetLength()-1);
			ktype.id = VOID_TYPEID;
			for(i++; !(iap[i] == QUESTION_TOKEN || iap[i] == COLON_TOKEN); i++){
				if(!MainSwitch(stree, bytecode, iap, i, tystack, ktype, retcall)) return false;
			}
			if(iap[i] == QUESTION_TOKEN) return false;
			typ = ktype;
			bytecode += JUMP_MEIREI;
			bp2 = bytecode.GetLength();
			AtaiCode(bytecode, (intptr_t)0);
			tystack.SetLength(tystack.GetLength()-1);
			*(intptr_t *)(bytecode.GetConst()+bp1) = bytecode.GetLength();
			ktype.id = VOID_TYPEID;
			for(i++; !(iap[i] == QUESTION_TOKEN || iap[i] == COLON_TOKEN); i++){
				if(!MainSwitch(stree, bytecode, iap, i, tystack, ktype, retcall)) return false;
			}
			if(iap[i] == COLON_TOKEN) return false;
			if(typ.id == REF_TYPEID || typ.id == LIST_TYPEID){
				if((ktype.id != REF_TYPEID && ktype.id != LIST_TYPEID) || !YuruiKataCheck(ktype.kwsk, typ.kwsk)) return false;
			}else if(typ.id == FUNC_TYPEID || typ.id == METHOD_TYPEID){
				if(ktype.id != typ.id || !YuruiKataCheck(ktype.kwsk, typ.kwsk)) return false;
			}else{
				if(!JidouCast(stree, bytecode, tystack, typ.id, ktype.id)) return false;
			}
			ktype = typ;
			*(intptr_t *)(bytecode.GetConst()+bp2) = bytecode.GetLength();
			return true;
		}
		bool AAOO(SourceTree & stree, PWCArray<uint8_t> & bytecode, const intptr_t * const iap, int & i, PWCArray<int32_t> & tystack, KuwashiiType & ktype)
		{
			intptr_t bp;
			SourceTree * retcall = NULL;
			if(tystack.GetData()[tystack.GetLength()-1] != BOOL_TYPEID) return false;
			switch(iap[i]){
			case ANDAND_TOKEN:
				bytecode += FALSEJUMP_MEIREI;
				break;
			case OROR_TOKEN:
				bytecode += TRUEJUMP_MEIREI;
				break;
			default:
				return false;
			}
			bp = bytecode.GetLength();
			AtaiCode(bytecode, (intptr_t)0);
			if(ktype.id != BOOL_TYPEID){
				bytecode += BOOLTYPE_MEIREI;
				ktype.id = BOOL_TYPEID;
			}
			bytecode += POP_MEIREI;
			tystack.SetLength(tystack.GetLength()-1);
			for(i++; !(iap[i] == ANDAND_TOKEN || iap[i] == OROR_TOKEN); i++){
				if(!MainSwitch(stree, bytecode, iap, i, tystack, ktype, retcall)) return false;
			}
			if(tystack.GetData()[tystack.GetLength()-1] != BOOL_TYPEID) return false;
			*(intptr_t *)(bytecode.GetConst()+bp) = bytecode.GetLength();
			return true;
		}
		bool IncDecSub(SourceTree & stree, PWCArray<uint8_t> & bytecode, const intptr_t * const iap, int & i, PWCArray<int32_t> & tystack, KuwashiiType & ktype, const KuwashiiType & oktype, const MeireiCode deco)
		{
			if(iap[i+1] == SEMICOLON_TOKEN || iap[i+1] == SHARP_TOKEN){
				switch(deco){
				case INCLKARAATAI_MEIREI:
				case INCLKARAMAENOATAI_MEIREI:
					bytecode += INCL_MEIREI;
					break;
				case DECLKARAATAI_MEIREI:
				case DECLKARAMAENOATAI_MEIREI:
					bytecode += DECL_MEIREI;
					break;
				default:
					return false;
				}
				ktype.id = VOID_TYPEID;
				i += 1;
			}else if(iap[i+1] == NULL_TOKEN && (DAINYUU_TOKEN <= iap[i+2] && iap[i+2] <= RSHIFTDAINYUU_TOKEN)){
				switch(deco){
				case INCLKARAATAI_MEIREI:
				case INCLKARAMAENOATAI_MEIREI:
					bytecode += INCLKARASANSHOU_MEIREI;
					break;
				case DECLKARAATAI_MEIREI:
				case DECLKARAMAENOATAI_MEIREI:
					bytecode += DECLKARASANSHOU_MEIREI;
					break;
				default:
					return false;
				}
				i += 2;
				if(!Dainyuu(stree, bytecode, iap, i, tystack, ktype, oktype, 0, PUSHSTACKSANSHOU_MEIREI, false, true)) return false;
			}else if(
				(iap[i+1] == NULL_TOKEN && (iap[i+2] == PLSPLS_TOKEN || iap[i+2] == MNSMNS_TOKEN))
				|| iap[i+1] == PLSPLS_TOKEN || iap[i+1] == MNSMNS_TOKEN)
			{
				switch(deco){
				case INCLKARAATAI_MEIREI:
				case INCLKARAMAENOATAI_MEIREI:
					bytecode += INCLKARASANSHOU_MEIREI;
					break;
				case DECLKARAATAI_MEIREI:
				case DECLKARAMAENOATAI_MEIREI:
					bytecode += DECLKARASANSHOU_MEIREI;
					break;
				default:
					return false;
				}
				i++;
				if(!IncDec(stree, bytecode, iap, i, tystack, ktype, oktype)) return false;
			}else{
				bytecode += deco;
				ktype = oktype;
				tystack += ktype.id;
			}
			return true;
		}
		bool IncDec(SourceTree & stree, PWCArray<uint8_t> & bytecode, const intptr_t * const iap, int & i, PWCArray<int32_t> & tystack, KuwashiiType & ktype, const KuwashiiType & oktype)
		{
			if(oktype.id < ADDRESS_TYPEID || BYTE_TYPEID < oktype.id) return false;
			if(ktype.id != oktype.id){
				bytecode += TypeIdtoMeireiT(stree, oktype.id);
				ktype = oktype;
			}
			if(iap[i] == NULL_TOKEN){
				i++;
				switch(iap[i]){
				case PLSPLS_TOKEN:
					if(!IncDecSub(stree, bytecode, iap, i, tystack, ktype, oktype, INCLKARAMAENOATAI_MEIREI)) return false;
					break;
				case MNSMNS_TOKEN:
					if(!IncDecSub(stree, bytecode, iap, i, tystack, ktype, oktype, DECLKARAMAENOATAI_MEIREI)) return false;
					break;
				default:
					return false;
				}
			}else{
				switch(iap[i]){
				case PLSPLS_TOKEN:
					if(!IncDecSub(stree, bytecode, iap, i, tystack, ktype, oktype, INCLKARAATAI_MEIREI)) return false;
					break;
				case MNSMNS_TOKEN:
					if(!IncDecSub(stree, bytecode, iap, i, tystack, ktype, oktype, DECLKARAATAI_MEIREI)) return false;
					break;
				default:
					return false;
				}
			}
			return true;
		}
		bool AppendSub(SourceTree & stree, PWCArray<uint8_t> & bytecode, const intptr_t * const iap, int & i, PWCArray<int32_t> & tystack, KuwashiiType & ktype, const KuwashiiType & oktype, const MeireiCode deco, const int32_t typ)
		{
			if(iap[i+1] == SEMICOLON_TOKEN || iap[i+1] == SHARP_TOKEN){
				bytecode += deco;
				if(deco == LOADAPPEND_MEIREI) AtaiCode(bytecode, stree.funclist.Get(typ)->GetMemberSize());
				tystack.SetLength(tystack.GetLength()-1);
				ktype.id = VOID_TYPEID;
				i += 1;
			}else if(iap[i+1] == NULL_TOKEN && iap[i+2] == TENDAINYUU_TOKEN){
				switch(deco){
				case APPEND_MEIREI:
					bytecode += APPENDKARASANSHOU_MEIREI;
					break;
				case LOADAPPEND_MEIREI:
					bytecode += LOADAPPENDKARASANSHOU_MEIREI;
					AtaiCode(bytecode, stree.funclist.Get(typ)->GetMemberSize());
					break;
				default:
					return false;
				}
				tystack.SetLength(tystack.GetLength()-1);
				i += 2;
				if(!Append(stree, bytecode, iap, i, tystack, ktype, oktype)) return false;
			}else if(iap[i+1] == NULL_TOKEN && (iap[i+2] == DAINYUU_TOKEN || iap[i+2] == YAJIRUSHI_TOKEN || iap[i+2] == SHIROYAJIRUSHI_TOKEN)){
				switch(deco){
				case APPEND_MEIREI:
					bytecode += APPENDKARASANSHOU_MEIREI;
					break;
				case LOADAPPEND_MEIREI:
					bytecode += LOADAPPENDKARASANSHOU_MEIREI;
					AtaiCode(bytecode, stree.funclist.Get(typ)->GetMemberSize());
					break;
				default:
					return false;
				}
				tystack.SetLength(tystack.GetLength()-1);
				i += 2;
				if(!Dainyuu(stree, bytecode, iap, i, tystack, ktype, oktype, 0, PUSHSTACKSANSHOU_MEIREI, false, true)) return false;
			}else{
				switch(deco){
				case APPEND_MEIREI:
					bytecode += APPENDKARASANSHOU_MEIREI;
					break;
				case LOADAPPEND_MEIREI:
					bytecode += LOADAPPENDKARASANSHOU_MEIREI;
					AtaiCode(bytecode, stree.funclist.Get(typ)->GetMemberSize());
					break;
				default:
					return false;
				}
				if(ktype.id != REF_TYPEID && ktype.id != LIST_TYPEID) bytecode += REFTYPE_MEIREI;
				bytecode += SANSHOUKARASANSHOUSAKI_MEIREI;
				ktype = oktype;
				tystack.GetData()[tystack.GetLength()-1] = ktype.id;
			}
			return true;
		}
		bool Append(SourceTree & stree, PWCArray<uint8_t> & bytecode, const intptr_t * const iap, int & i, PWCArray<int32_t> & tystack, KuwashiiType & ktype, const KuwashiiType & oktype)
		{
			int32_t typ;
			int il;
			SourceTree * retcall = NULL;
			if(oktype.id != LIST_TYPEID) return false;
			for(i++; iap[i] != TENDAINYUU_TOKEN; i++){
				if(!MainSwitch(stree, bytecode, iap, i, tystack, ktype, retcall)) return false;
			}
			il = 0;
			if(IsSoushokuToken((TokenKind)oktype.kwsk.GetConst()[il])) il++;
			if(oktype.kwsk.GetConst()[il] != LIST_TOKEN) return false;
			il++;
			if((typ = TokenTtoTypeId(oktype.kwsk.GetConst(), il)) == UNKNOWN_TYPEID) return false;
			if(
				typ < 0
				|| (typ <= ENDCLASS_TYPEID && stree.funclist.Get(typ)->selftype == CLASS_BLOCK && !stree.funclist.Get(typ)->IsOpen()))
			{
				return false;
			}
			if((ktype.id == REF_TYPEID || ktype.id == LIST_TYPEID)){
				if(!YuruiKataCheck(oktype.kwsk, ktype.kwsk)) return false;
				if(!AppendSub(stree, bytecode, iap, i, tystack, ktype, oktype, APPEND_MEIREI, typ)) return false;
			}else{
				if(!JidouCast(stree, bytecode, tystack, typ, ktype.id)) return false;
				ktype.id = typ;
				if(typ <= ENDCLASS_TYPEID && stree.funclist.Get(typ)->selftype == CLASS_BLOCK){
					if(!AppendSub(stree, bytecode, iap, i, tystack, ktype, oktype, LOADAPPEND_MEIREI, typ)) return false;
				}else{
					if(!AppendSub(stree, bytecode, iap, i, tystack, ktype, oktype, APPEND_MEIREI, typ)) return false;
				}
			}
			return true;
		}
		bool Dainyuu(SourceTree & stree, PWCArray<uint8_t> & bytecode, const intptr_t * const iap, int & i, PWCArray<int32_t> & tystack, KuwashiiType & ktype, const KuwashiiType & oktype, const intptr_t ig, const MeireiCode deco, const bool classke, const bool mata)
		{
			MeireiCode dekyo;
			SourceTree * retcall = NULL;
			if(
				iap[i] == DAINYUU_TOKEN ? oktype.id == VOID_TYPEID : (
					oktype.id <= ENDCLASS_TYPEID ? (
						iap[i] == YAJIRUSHI_TOKEN || iap[i] == SHIROYAJIRUSHI_TOKEN ?
						oktype.id != REF_TYPEID && oktype.id != LIST_TYPEID : true
					) : (
						ANDDAINYUU_TOKEN <= iap[i] && iap[i] <= ORDAINYUU_TOKEN ?
						oktype.id == FLOAT_TYPEID || oktype.id == DOUBLE_TYPEID : oktype.id == BOOL_TYPEID || (
							iap[i] == LSHIFTDAINYUU_TOKEN || iap[i] == RSHIFTDAINYUU_TOKEN ?
							oktype.id == FLOAT_TYPEID || oktype.id == DOUBLE_TYPEID : false
						)
					)
				))
			{
				return false;
			}
			if(mata){
				if(iap[i] == DAINYUU_TOKEN && iap[i+1] == COMMA_TOKEN){
					tystack.GetData()[tystack.GetLength()-1] = UNKNOWN_TYPEID;
					return true;
				}
				if(iap[i] != DAINYUU_TOKEN) bytecode += PUSHSTACKSANSHOU_MEIREI;
			}else{
				switch(deco){
				case PUSHHENSUU_MEIREI:
					bytecode += HENSUUKARASANSHOU_MEIREI;
					AtaiCode(bytecode, ig);
					break;
				case PUSHMEMBERHENSUU_MEIREI:
					bytecode += MEMBERKARASANSHOU_MEIREI;
					AtaiCode(bytecode, ig);
					break;
				case PUSHGLOBALHENSUU_MEIREI:
					bytecode += GLOBALKARASANSHOU_MEIREI;
					AtaiCode(bytecode, ig);
					break;
				case PUSHSTACKSANSHOU_MEIREI:
					break;
				default:
					return false;
				}
				if(iap[i] == DAINYUU_TOKEN && iap[i+1] == COMMA_TOKEN){
					tystack += UNKNOWN_TYPEID;
					ktype = oktype;
					return true;
				}
				if(iap[i] != DAINYUU_TOKEN && iap[i] != YAJIRUSHI_TOKEN && iap[i] != SHIROYAJIRUSHI_TOKEN){
					if(oktype.id <= ENDCLASS_TYPEID) return false;
					if(ktype.id != oktype.id){
						if((dekyo = TypeIdtoMeireiT(stree, oktype.id)) == NOP_MEIREI) return false;
						bytecode += dekyo;
						ktype = oktype;
					}
					bytecode += deco;
					if(deco != PUSHSTACKSANSHOU_MEIREI) AtaiCode(bytecode, ig);
					tystack += ktype.id;
				}
			}
			for(i++; !(DAINYUU_TOKEN <= iap[i] && iap[i] <= SHIROYAJIRUSHI_TOKEN); i++){
				if(!MainSwitch(stree, bytecode, iap, i, tystack, ktype, retcall)) return false;
			}
			if(oktype.id == REF_TYPEID || oktype.id == LIST_TYPEID){
				if((ktype.id != REF_TYPEID && ktype.id != LIST_TYPEID) || !YuruiKataCheck(ktype.kwsk, oktype.kwsk)) return false;
			}else if(oktype.id == FUNC_TYPEID || oktype.id == METHOD_TYPEID){
				if(ktype.id != oktype.id || !YuruiKataCheck(ktype.kwsk, oktype.kwsk)) return false;
			}else{
				if(!JidouCast(stree, bytecode, tystack, oktype.id, ktype.id)) return false;
			}
			ktype = oktype;
			switch(iap[i]){
			case PULUSDAINYUU_TOKEN:
			case MINUSDAINYUU_TOKEN:
			case KAKERUDAINYUU_TOKEN:
			case WARUDAINYUU_TOKEN:
			case AMARIDAINYUU_TOKEN:
			case ANDDAINYUU_TOKEN:
			case XORDAINYUU_TOKEN:
			case ORDAINYUU_TOKEN:
			case LSHIFTDAINYUU_TOKEN:
			case RSHIFTDAINYUU_TOKEN:
				switch(iap[i]){
				case PULUSDAINYUU_TOKEN:
					bytecode += TASU_MEIREI;
					break;
				case MINUSDAINYUU_TOKEN:
					bytecode += HIKU_MEIREI;
					break;
				case KAKERUDAINYUU_TOKEN:
					bytecode += KAKERU_MEIREI;
					break;
				case WARUDAINYUU_TOKEN:
					bytecode += WARU_MEIREI;
					break;
				case AMARIDAINYUU_TOKEN:
					bytecode += AMARI_MEIREI;
					break;
				case ANDDAINYUU_TOKEN:
					bytecode += AND_MEIREI;
					break;
				case XORDAINYUU_TOKEN:
					bytecode += XOR_MEIREI;
					break;
				case ORDAINYUU_TOKEN:
					bytecode += OR_MEIREI;
					break;
				case LSHIFTDAINYUU_TOKEN:
					bytecode += LSHIFT_MEIREI;
					break;
				case RSHIFTDAINYUU_TOKEN:
					bytecode += RSHIFT_MEIREI;
					break;
				}
				tystack.SetLength(tystack.GetLength()-1);
			case DAINYUU_TOKEN:
				if(classke && !stree.funclist.Get(oktype.id)->IsOpen()) return false;
				if(iap[i+1] == SEMICOLON_TOKEN || iap[i+1] == SHARP_TOKEN){
					if(classke){
						bytecode += LOAD_MEIREI;
						AtaiCode(bytecode, stree.funclist.Get(oktype.id)->GetMemberSize());
					}else if(ktype.id == REF_TYPEID || ktype.id == LIST_TYPEID){
						if(!RefCountDown(stree, bytecode, ktype, SANSHOUREFCOPYNZJUMP_MEIREI, ktype.kwsk, true)) return false;
					}else{
						bytecode += DAINYUU_MEIREI;
					}
					tystack.SetLength(tystack.GetLength()-1);
					ktype.id = VOID_TYPEID;
					i++;
				}else if(iap[i+1] == NULL_TOKEN && iap[i+2] == TENDAINYUU_TOKEN){
					if(ktype.id != REF_TYPEID && ktype.id != LIST_TYPEID) return false;
					if(!RefCountDown(stree, bytecode, ktype, SANSHOUREFCOPYNZJUMP_MEIREI, ktype.kwsk, false)) return false;
					tystack.SetLength(tystack.GetLength()-1);
					i += 2;
					if(!Append(stree, bytecode, iap, i, tystack, ktype, oktype)) return false;
				}else if(iap[i+1] == NULL_TOKEN && (DAINYUU_TOKEN <= iap[i+2] && iap[i+2] <= SHIROYAJIRUSHI_TOKEN)){
					if(classke){
						bytecode += LOADKARASANSHOU_MEIREI;
						AtaiCode(bytecode, stree.funclist.Get(oktype.id)->GetMemberSize());
					}else if(ktype.id == REF_TYPEID || ktype.id == LIST_TYPEID){
						if(!RefCountDown(stree, bytecode, ktype, SANSHOUREFCOPYNZJUMP_MEIREI, ktype.kwsk, false)) return false;
					}else{
						bytecode += DAINYUUKARASANSHOU_MEIREI;
					}
					tystack.SetLength(tystack.GetLength()-1);
					i += 2;
					if(!Dainyuu(stree, bytecode, iap, i, tystack, ktype, oktype, 0, PUSHSTACKSANSHOU_MEIREI, false, true)) return false;
				}else if(
					(iap[i+1] == NULL_TOKEN && (iap[i+2] == PLSPLS_TOKEN || iap[i+2] == MNSMNS_TOKEN))
					|| iap[i+1] == PLSPLS_TOKEN || iap[i+1] == MNSMNS_TOKEN)
				{
					bytecode += DAINYUUKARASANSHOU_MEIREI;
					tystack.SetLength(tystack.GetLength()-1);
					i++;
					if(!IncDec(stree, bytecode, iap, i, tystack, ktype, oktype)) return false;
				}else{
					if(classke){
						bytecode += LOADKARASANSHOU_MEIREI;
						AtaiCode(bytecode, stree.funclist.Get(oktype.id)->GetMemberSize());
					}else if(ktype.id == REF_TYPEID || ktype.id == LIST_TYPEID){
						if(!RefCountDown(stree, bytecode, ktype, SANSHOUREFCOPYNZJUMP_MEIREI, ktype.kwsk, false)) return false;
						bytecode += REFTYPE_MEIREI;
						bytecode += SANSHOUKARASANSHOUSAKI_MEIREI;
						ktype = oktype;
					}else{
						bytecode += DAINYUUKARASANSHOU_MEIREI;
						bytecode += SANSHOUKARASANSHOUSAKI_MEIREI;
					}
					tystack.GetData()[tystack.GetLength()-1] = ktype.id;
				}
				break;
			case YAJIRUSHI_TOKEN:
				if(ktype.id != REF_TYPEID && ktype.id != LIST_TYPEID) return false;
				if(iap[i+1] == SEMICOLON_TOKEN || iap[i+1] == SHARP_TOKEN){
					if(!RefCountDown(stree, bytecode, ktype, SANSHOUREFWREFNZJUMP_MEIREI, ktype.kwsk, true)) return false;
					tystack.SetLength(tystack.GetLength()-1);
					ktype.id = VOID_TYPEID;
					i += 1;
				}else if(iap[i+1] == NULL_TOKEN && iap[i+2] == TENDAINYUU_TOKEN){
					if(!RefCountDown(stree, bytecode, ktype, SANSHOUREFWREFNZJUMP_MEIREI, ktype.kwsk, false)) return false;
					tystack.SetLength(tystack.GetLength()-1);
					i += 2;
					if(!Append(stree, bytecode, iap, i, tystack, ktype, oktype)) return false;
				}else if(iap[i+1] == NULL_TOKEN && (iap[i+2] == DAINYUU_TOKEN || iap[i+2] == YAJIRUSHI_TOKEN || iap[i+2] == SHIROYAJIRUSHI_TOKEN)){
					if(!RefCountDown(stree, bytecode, ktype, SANSHOUREFWREFNZJUMP_MEIREI, ktype.kwsk, false)) return false;
					tystack.SetLength(tystack.GetLength()-1);
					i += 2;
					if(!Dainyuu(stree, bytecode, iap, i, tystack, ktype, oktype, 0, PUSHSTACKSANSHOU_MEIREI, false, true)) return false;
				}else{
					if(!RefCountDown(stree, bytecode, ktype, SANSHOUREFWREFNZJUMP_MEIREI, ktype.kwsk, false)) return false;
					bytecode += REFTYPE_MEIREI;
					bytecode += SANSHOUKARASANSHOUSAKI_MEIREI;
					ktype = oktype;
					tystack.GetData()[tystack.GetLength()-1] = ktype.id;
				}
				break;
			case SHIROYAJIRUSHI_TOKEN:
				if(ktype.id != REF_TYPEID && ktype.id != LIST_TYPEID) return false;
				if(iap[i+1] == SEMICOLON_TOKEN || iap[i+1] == SHARP_TOKEN){
					if(!RefCountDown(stree, bytecode, ktype, SANSHOUREFSREFNZJUMP_MEIREI, ktype.kwsk, true)) return false;
					tystack.SetLength(tystack.GetLength()-1);
					ktype.id = VOID_TYPEID;
					i += 1;
				}else if(iap[i+1] == NULL_TOKEN && iap[i+2] == TENDAINYUU_TOKEN){
					if(!RefCountDown(stree, bytecode, ktype, SANSHOUREFSREFNZJUMP_MEIREI, ktype.kwsk, false)) return false;
					tystack.SetLength(tystack.GetLength()-1);
					i += 2;
					if(!Append(stree, bytecode, iap, i, tystack, ktype, oktype)) return false;
				}else if(iap[i+1] == NULL_TOKEN && (iap[i+2] == DAINYUU_TOKEN || iap[i+2] == YAJIRUSHI_TOKEN || iap[i+2] == SHIROYAJIRUSHI_TOKEN)){
					if(!RefCountDown(stree, bytecode, ktype, SANSHOUREFSREFNZJUMP_MEIREI, ktype.kwsk, false)) return false;
					tystack.SetLength(tystack.GetLength()-1);
					i += 2;
					if(!Dainyuu(stree, bytecode, iap, i, tystack, ktype, oktype, 0, PUSHSTACKSANSHOU_MEIREI, false, true)) return false;
				}else{
					if(!RefCountDown(stree, bytecode, ktype, SANSHOUREFSREFNZJUMP_MEIREI, ktype.kwsk, false)) return false;
					bytecode += REFTYPE_MEIREI;
					bytecode += SANSHOUKARASANSHOUSAKI_MEIREI;
					ktype = oktype;
					tystack.GetData()[tystack.GetLength()-1] = ktype.id;
				}
				break;
			default:
				return false;
			}
			return true;
		}
		bool MeijiCast(SourceTree & stree, PWCArray<uint8_t> & bytecode, PWCArray<int32_t> & tystack, const int32_t dtype, int32_t typ)
		{
			if(tystack.GetData()[tystack.GetLength()-1] == UNKNOWN_TYPEID){
				ErrorMessage.Add(*pomc->filename, pomc->gyousuu, L"sȃLXgłB");
				return false;
			}
			if(tystack.GetData()[tystack.GetLength()-1] == BOOL_TYPEID && typ != BOOL_TYPEID){
				bytecode += BOOLTYPE_MEIREI;
				typ = BOOL_TYPEID;
			}
			if(typ == dtype) return true;
			if(dtype == BOOL_TYPEID || dtype <= ENDCLASS_TYPEID || typ < 0){
				ErrorMessage.Add(*pomc->filename, pomc->gyousuu, L"sȃLXgłB");
				return false;
			}
			if(typ <= ENDCLASS_TYPEID){
				if(stree.funclist.Get(typ)->selftype != ENUM_BLOCK){
					ErrorMessage.Add(*pomc->filename, pomc->gyousuu, L"sȃLXgłB");
					return false;
				}
				if(dtype == INT_TYPEID) return true;
			}
			bytecode += TypeIdtoMeireiT(stree, dtype) + CASTBYTETYPE_MEIREI - BYTETYPE_MEIREI;
			tystack.GetData()[tystack.GetLength()-1] = dtype;
			return true;
		}
		bool JidouCast(SourceTree & stree, PWCArray<uint8_t> & bytecode, PWCArray<int32_t> & tystack, const int32_t dtype, int32_t typ)
		{
			if(tystack.GetData()[tystack.GetLength()-1] == UNKNOWN_TYPEID){
				ErrorMessage.Add(*pomc->filename, pomc->gyousuu, L"^G[łB");
				return false;
			}
			if(tystack.GetData()[tystack.GetLength()-1] == BOOL_TYPEID && typ != BOOL_TYPEID){
				bytecode += BOOLTYPE_MEIREI;
				typ = BOOL_TYPEID;
			}
			if(typ == dtype) return true;
			if( (
				(dtype == ADDRESS_TYPEID || BYTE_TYPEID >= dtype && dtype >= LONG_TYPEID)
				&& (typ == ADDRESS_TYPEID || BYTE_TYPEID >= typ && typ >= LONG_TYPEID)
				)
				|| (UBYTE_TYPEID >= dtype && dtype >= ULONG_TYPEID && UBYTE_TYPEID >= typ && typ >= ULONG_TYPEID)
				|| ((dtype == FLOAT_TYPEID || dtype == DOUBLE_TYPEID) && (typ == FLOAT_TYPEID || typ == DOUBLE_TYPEID)))
			{
				bytecode += TypeIdtoMeireiT(stree, dtype) + CASTBYTETYPE_MEIREI - BYTETYPE_MEIREI;
				tystack.GetData()[tystack.GetLength()-1] = dtype;
				return true;
			}
			ErrorMessage.Add(*pomc->filename, pomc->gyousuu, L"^G[łB");
			return false;
		}
		bool If(SourceTree & stree, PWCArray<uint8_t> & bytecode, int & j)
		{
			intptr_t len, bp1;
			int i;
			const intptr_t * iap;
			KuwashiiType ktype;
			PWCArray<int32_t> tystack;
			SourceTree * retcall = NULL;
			tystack.Clear();
			iap = stree.token.GetConst()[j].GetConst();
			pomc->gyousuu = stree.gyo.GetConst()[j];
			ktype.id = VOID_TYPEID;
			i = 1;
			if(iap[i] != SHOUKAKKOOPEN_TOKEN) return false;
			i++;
			do{
				if(!MainSwitch(stree, bytecode, iap, i, tystack, ktype, retcall)) return false;
				i++;
			}while(iap[i] != SHOUKAKKOCLOSE_TOKEN);
			if(tystack.GetLength() <= 0 || tystack.GetData()[tystack.GetLength()-1] != BOOL_TYPEID) return false;
			bytecode += POPNFALSEJUMP_MEIREI;
			bp1 = bytecode.GetLength();
			AtaiCode(bytecode, (intptr_t)0);
			tystack.SetLength(tystack.GetLength()-1);
			j++;
			iap = stree.token.GetConst()[j].GetConst();
			len = stree.token.GetConst()[j].GetLength();
			pomc->gyousuu = stree.gyo.GetConst()[j];
			ktype.id = VOID_TYPEID;
			if(!KoubunSwitch(stree, bytecode, iap, len, j)) return false;
			*(intptr_t *)(bytecode.GetConst()+bp1) = bytecode.GetLength();
			return true;
		}
		bool MainLoop(SourceTree & stree, PWCArray<uint8_t> & bytecode, const intptr_t * const iap, const intptr_t len, int & i, SourceTree * & retcall)
		{
			KuwashiiType ktype;
			PWCArray<int32_t> tystack;
			tystack.Clear();
			ktype.id = VOID_TYPEID;
			for(; i < len; i++){
				if(!MainSwitch(stree, bytecode, iap, i, tystack, ktype, retcall)) return false;
			}
			return true;
		}
		bool MainLoopBase(SourceTree & stree, PWCArray<uint8_t> & bytecode, const intptr_t * const iap, const intptr_t len, int & i, SourceTree * & retcall)
		{
			switch(stree.selftype){
			case FUNC_BLOCK:
				if(!pomc->fcom.MainLoop(stree, bytecode, iap, len, i, retcall)) return false;
				return true;
			case NORMAL_BLOCK:
				if(!pomc->ncom.MainLoop(stree, bytecode, iap, len, i, retcall)) return false;
				return true;
			case LOCK_BLOCK:
				if(!pomc->lkcom.MainLoop(stree, bytecode, iap, len, i, retcall)) return false;
				return true;
			case SWITCH_BLOCK:
				if(!pomc->swcom.MainLoop(stree, bytecode, iap, len, i, retcall)) return false;
				return true;
			case BRANCH_BLOCK:
				if(!pomc->brcom.MainLoop(stree, bytecode, iap, len, i, retcall)) return false;
				return true;
			case LOOP_BLOCK:
				if(!pomc->lpcom.MainLoop(stree, bytecode, iap, len, i, retcall)) return false;
				return true;
			}
			return false;
		}
		bool DefDel(SourceTree & stree, PWCArray<uint8_t> & bytecode)
		{
			int i;
			KuwashiiType ktype;
			PWCArray<int32_t> tystack;
			SourceTree * retcall = NULL;
			ktype.id = VOID_TYPEID;
			for(i = 0; i < stree.defdel.GetLength(); i++){
				if(!MainSwitch(stree, bytecode, stree.defdel.GetConst(), i, tystack, ktype, retcall)) return false;
			}
			return true;
		}
		bool DefDelBase(SourceTree & stree, PWCArray<uint8_t> & bytecode)
		{
			switch(stree.selftype){
			case FUNC_BLOCK:
				if(!pomc->fcom.DefDel(stree, bytecode)) return false;
				return true;
			case NORMAL_BLOCK:
				if(!pomc->ncom.DefDel(stree, bytecode)) return false;
				return true;
			case LOCK_BLOCK:
				if(!pomc->lkcom.DefDel(stree, bytecode)) return false;
				return true;
			case SWITCH_BLOCK:
				if(!pomc->swcom.DefDel(stree, bytecode)) return false;
				return true;
			case BRANCH_BLOCK:
				if(!pomc->brcom.DefDel(stree, bytecode)) return false;
				return true;
			case LOOP_BLOCK:
				if(!pomc->lpcom.DefDel(stree, bytecode)) return false;
				return true;
			}
			return false;
		}
		bool KoubunSwitch(SourceTree & stree, PWCArray<uint8_t> & bytecode, const intptr_t * const iap, const intptr_t len, int & j)
		{
			int i;
			SourceTree * retcall = NULL;
			if(iap[0] == IF_TOKEN){
				if(!If(stree, bytecode, j)) return false;
			}else{
				i = 0;
				if(!MainLoopBase(stree, bytecode, iap, len, i, retcall)) return false;
			}
			return true;
		}
		bool KoubunSwitchBase(SourceTree & stree, PWCArray<uint8_t> & bytecode, const intptr_t * const iap, const intptr_t len, int & j)
		{
			switch(stree.selftype){
			case FUNC_BLOCK:
				if(!pomc->fcom.KoubunSwitch(stree, bytecode, iap, len, j)) return false;
				return true;
			case NORMAL_BLOCK:
				if(!pomc->ncom.KoubunSwitch(stree, bytecode, iap, len, j)) return false;
				return true;
			case LOCK_BLOCK:
				if(!pomc->lkcom.KoubunSwitch(stree, bytecode, iap, len, j)) return false;
				return true;
			case SWITCH_BLOCK:
				if(!pomc->swcom.KoubunSwitch(stree, bytecode, iap, len, j)) return false;
				return true;
			case BRANCH_BLOCK:
				if(!pomc->brcom.KoubunSwitch(stree, bytecode, iap, len, j)) return false;
				return true;
			case LOOP_BLOCK:
				if(!pomc->lpcom.KoubunSwitch(stree, bytecode, iap, len, j)) return false;
				return true;
			}
			return false;
		}
	public:
		template<typename T> void AtaiCode(PWCArray<uint8_t> & bytecode, const T x)
		{
			bytecode.SetLength(bytecode.GetLength()+sizeof(T));
			*(T *)(bytecode.GetConst()+bytecode.GetLength()-sizeof(T)) = x;
		}
		void SetOmc(OmCompiler * const po)
		{
			pomc = po;
		}
	};
	class FuncCompi : public XCompi
	{
	public:
		bool FuncTreeCompile(SourceTree & stree, PWCArray<uint8_t> & bytecode)
		{
			int i, j;
			KuwashiiType ktype;
			PWCArray<int32_t> tystack;
			const intptr_t * iap;
			intptr_t len, glbbp;
			if(!stree.kakutei){
				if(stree.GetIjousaki(len) != NULL){
					for(i = 0; i < stree.subfunc.GetLength(); i++){
						if(!FuncTreeCompile(*stree.subfunc.GetConst()[i], bytecode)) return false;
					}
					return true;
				}
				ErrorMessage.Add(stree.srce->filename, stree.topsrcgyo, L"`łB");
				return false;
			}
			if(stree.selftype == ENUM_BLOCK) return true;
			if(stree.selftype == CLASS_BLOCK || (stree.tpcount > 0 && stree.funchensuu.GetConst()[stree.tpcount-1].type.GetLength() <= 1)){
				for(i = 0; i < stree.subfunc.GetLength(); i++){
					if(!FuncTreeCompile(*stree.subfunc.GetConst()[i], bytecode)) return false;
				}
				return true;
			}
			if(!stree.touka && stree.root != &stree && stree.parent->selftype != CLASS_BLOCK && stree.gblhani == INT_MAX) return true;
			pomc->filename = &stree.srce->filename;
			stree.byteadress = bytecode.GetLength();
			Backpatch(bytecode, stree.backpatch);
			if(stree.root != stree.frp) KansuStackSet(stree, bytecode);
			for(j = 0; j < stree.token.GetLength(); j++){
				iap = stree.token.GetConst()[j].GetConst();
				len = stree.token.GetConst()[j].GetLength();
				pomc->gyousuu = stree.gyo.GetConst()[j];
				if(!KoubunSwitchBase(stree, bytecode, iap, len, j)){
					if(ErrorMessage.mes.GetLength() == 1) ErrorMessage.Add(*pomc->filename, pomc->gyousuu, L"RpCG[łB");
					return false;
				}
			}
			if(stree.selftype == FUNC_BLOCK && stree.rettype.GetConst()[stree.rettype.GetLength()-1] != VOID_TOKEN){
				if(stree.token.GetLength() <= 0 || stree.token.GetConst()[j-1].GetConst()[len-1] != RETURN_TOKEN
					|| (stree.token.GetLength() >= 2 && stree.token.GetConst()[j-2].GetConst()[0] == IF_TOKEN))
				{
					ErrorMessage.Add(*pomc->filename, pomc->gyousuu, L"return܂B");
					return false;
				}
			}else if(stree.selftype == FUNC_BLOCK){
				ktype.id = VOID_TYPEID;
				if(stree.frp == stree.root){
					bytecode += GBLDELPUSH_MEIREI;
					AtaiCode(bytecode, bytecode.GetLength()+1+sizeof(intptr_t)*2);
					bytecode += JUMP_MEIREI;
					glbbp = bytecode.GetLength();
					AtaiCode(bytecode, (intptr_t)0);
				}
				if(!DefDelBase(stree, bytecode)){
					ErrorMessage.Add(*pomc->filename, pomc->gyousuu, L"RpCG[B");
					return false;
				}
				if(stree.root == stree.frp){
					*(intptr_t *)(bytecode.GetData()+glbbp) = bytecode.GetLength();
				}else{
					KansuStackClear(stree, bytecode);
				}
				bytecode += RETURN_MEIREI;
			}
			for(i = 0; i < stree.subfunc.GetLength(); i++){
				if(!FuncTreeCompile(*stree.subfunc.GetConst()[i], bytecode)) return false;
			}
			return true;
		}
	};
	class NormalCompi : public XCompi
	{
	protected:
		bool Break(SourceTree & stree, PWCArray<uint8_t> & bytecode, const intptr_t * const iap, const intptr_t len, int & i, PWCArray<int32_t> & tystack, KuwashiiType & ktype, SourceTree * & retcall)
		{
			i++;
			if(stree.breakin){
				bytecode += CALL_MEIREI;
				stree.breakpatch += bytecode.GetLength();
				AtaiCode(bytecode, (intptr_t)0);
			}
			while(iap[i] < 0 || iap[i] == GBL_TOKEN || iap[i] == MBR_TOKEN){
				for(; ; i++){
					if(!MainSwitch(stree, bytecode, iap, i, tystack, ktype, retcall)) return false;
					if(iap[i] == SEMICOLON_TOKEN) break;
				}
				i++;
			}
			if(iap[i] == COMMA_TOKEN){
				i++;
				if(!MainLoopBase(*stree.parent, bytecode, iap, len, i, retcall)) return false;
			}else{
				if(iap[i] != SEMICOLON_TOKEN) return false;
				i++;
			}
			bytecode += JUMP_MEIREI;
			stree.backpatch += bytecode.GetLength();
			AtaiCode(bytecode, (intptr_t)0);
			return true;
		}
	public:
		bool MainLoop(SourceTree & stree, PWCArray<uint8_t> & bytecode, const intptr_t * const iap, const intptr_t len, int & i, SourceTree * & retcall)
		{
			KuwashiiType ktype;
			PWCArray<int32_t> tystack;
			tystack.Clear();
			ktype.id = VOID_TYPEID;
			for(; i < len; i++){
				if(iap[i] == BREAK_TOKEN){
					if(!Break(stree, bytecode, iap, len, i, tystack, ktype, retcall)) return false;
				}else{
					if(!MainSwitch(stree, bytecode, iap, i, tystack, ktype, retcall)) return false;
				}
			}
			return true;
		}
		bool KoubunSwitch(SourceTree & stree, PWCArray<uint8_t> & bytecode, const intptr_t * const iap, const intptr_t len, int & j)
		{
			SourceTree * retcall = NULL;
			if(iap[0] == BREAK_TOKEN && iap[1] == COLON_TOKEN){
				bytecode += CALL_MEIREI;
				stree.breakpatch += bytecode.GetLength();
				AtaiCode(bytecode, (intptr_t)0);
				if(!DefDelBase(stree, bytecode)) return false;
				bytecode += JUMP_MEIREI;
				stree.backpatch += bytecode.GetLength();
				AtaiCode(bytecode, (intptr_t)0);
				Backpatch(bytecode, stree.breakpatch);
			}else{
				if(!XCompi::KoubunSwitch(stree, bytecode, iap, len, j)) return false;
			}
			return true;
		}
		bool FuncTreeCompile(SourceTree & stree, PWCArray<uint8_t> & bytecode)
		{
			int j;
			intptr_t len;
			PWCArray<int32_t> tystack;
			const intptr_t * iap;
			stree.byteadress = bytecode.GetLength();
			for(j = 0; j < stree.token.GetLength(); j++){
				iap = stree.token.GetConst()[j].GetConst();
				len = stree.token.GetConst()[j].GetLength();
				pomc->gyousuu = stree.gyo.GetConst()[j];
				if(!KoubunSwitchBase(stree, bytecode, iap, len, j)) return false;
			}
			if(stree.breakin){
				bytecode += RETURN_MEIREI;
			}else{
				if(!DefDelBase(stree, bytecode)) return false;
			}
			Backpatch(bytecode, stree.backpatch);
			return true;
		}
	};
	class LockCompi : public NormalCompi
	{
	public:
		bool DefDel(SourceTree & stree, PWCArray<uint8_t> & bytecode)
		{
			int i;
			if(!NormalCompi::DefDel(stree, bytecode)) return false;
			for(i = 0; i < stree.hikisuucount; i++) bytecode += STACKCALL_MEIREI;
			return true;
		}
		bool MainLoop(SourceTree & stree, PWCArray<uint8_t> & bytecode, const intptr_t * const iap, const intptr_t len, int & i, SourceTree * & retcall)
		{
			KuwashiiType ktype;
			PWCArray<int32_t> tystack;
			tystack.Clear();
			ktype.id = VOID_TYPEID;
			int j;
			for(; i < len; i++){
				if(iap[i] == BREAK_TOKEN){
					i++;
					if(stree.breakin){
						bytecode += CALL_MEIREI;
						stree.breakpatch += bytecode.GetLength();
						AtaiCode(bytecode, (intptr_t)0);
					}
					while(iap[i] < 0 || iap[i] == GBL_TOKEN || iap[i] == MBR_TOKEN){
						for(; ; i++){
							if(!MainSwitch(stree, bytecode, iap, i, tystack, ktype, retcall)) return false;
							if(iap[i] == SEMICOLON_TOKEN) break;
						}
						i++;
					}
					for(j = 0; j < stree.hikisuucount; j++) bytecode += STACKCALL_MEIREI;
					if(iap[i] == COMMA_TOKEN){
						i++;
						if(!MainLoopBase(*stree.parent, bytecode, iap, len, i, retcall)) return false;
					}else{
						if(iap[i] != SEMICOLON_TOKEN) return false;
						i++;
					}
					bytecode += JUMP_MEIREI;
					stree.backpatch += bytecode.GetLength();
					AtaiCode(bytecode, (intptr_t)0);
				}else{
					if(!MainSwitch(stree, bytecode, iap, i, tystack, ktype, retcall)) return false;
				}
			}
			return true;
		}
	};
	class SwitchCompi : public NormalCompi
	{
		void CaseTable(PWCArray<uint8_t> & bytecode, SwitchExtStruct & ses, PWCArray<bool> & uetikb, PWCArray<intptr_t> & shnnkn, const int size, const uint8_t ichi, const MeireiCode mtype)
		{
			int i;
			intptr_t tbli;
			PWCArrayQuad< PWCArray<int> > numbn;
			bytecode += SWITCHJUMP_MEIREI;
			bytecode += ichi;
			tbli = bytecode.GetLength();
			bytecode.SetLength(bytecode.GetLength() + sizeof(intptr_t)*16);
			numbn.SetLength(16);
			for(i = 0; i < uetikb.GetLength(); i++){
				if(uetikb.GetConst()[i]) continue;
				numbn.GetData()[(*((uint8_t *)(ses.atai.GetConst()+i)+size-1-(ichi>>1)) & (0x0f<<(ichi&0x01)*4)) >> (ichi&0x01)*4] += i;
			}
			for(i = 0; i < 16; i++){
				if(numbn.GetConst()[i].GetLength() <= 0){
					shnnkn += tbli + sizeof(intptr_t)*i;
				}else if(numbn.GetConst()[i].GetLength() == 1){
					*(intptr_t *)(bytecode.GetConst()+tbli+sizeof(intptr_t)*i) = bytecode.GetLength();
					bytecode += PUSHTEISUU_MEIREI;
					TypeAtai(bytecode, mtype, &ses.atai.GetConst()[numbn.GetConst()[i].GetConst()[0]]);
					bytecode += EQUAL_MEIREI;
					bytecode += POPNTRUEJUMP_MEIREI;
					ses.ataibp[numbn.GetConst()[i].GetConst()[0]] = bytecode.GetLength();
					AtaiCode(bytecode, (intptr_t)0);
					bytecode += JUMP_MEIREI;
					ses.defbp += bytecode.GetLength();
					AtaiCode(bytecode, (intptr_t)0);
					uetikb.GetData()[numbn.GetConst()[i].GetConst()[0]] = true;
				}
			}
			for(i = 0; i < 16; i++){
				if(numbn.GetConst()[i].GetLength() < 2) continue;
				*(intptr_t *)(bytecode.GetConst()+tbli+sizeof(intptr_t)*i) = bytecode.GetLength();
				CaseTable(bytecode, ses, uetikb, shnnkn, size, ichi-1, mtype);
			}
		}
	public:
		bool MainLoop(SourceTree & stree, PWCArray<uint8_t> & bytecode, const intptr_t * const iap, const intptr_t len, int & i, SourceTree * & retcall)
		{
			KuwashiiType ktype;
			PWCArray<int32_t> tystack;
			tystack.Clear();
			ktype.id = VOID_TYPEID;
			for(; i < len; i++){
				switch(iap[i]){
				case DEFAULT_TOKEN:
					i++;
					bytecode += JUMP_MEIREI;
					if(stree.extswitch->def == 0) stree.extswitch->defbp += bytecode.GetLength();
					AtaiCode(bytecode, stree.extswitch->def);
					break;
				case BREAK_TOKEN:
					if(!Break(stree, bytecode, iap, len, i, tystack, ktype, retcall)) return false;
					break;
				default:
					if(!MainSwitch(stree, bytecode, iap, i, tystack, ktype, retcall)) return false;
					break;
				}
			}
			return true;
		}
		bool KoubunSwitch(SourceTree & stree, PWCArray<uint8_t> & bytecode, const intptr_t * const iap, const intptr_t len, int & j)
		{
			int i, ii, iii, sz;
			MeireiCode deco;
			int32_t typ;
			int64_t t64;
			if(iap[0] == CASE_TOKEN || (iap[0] == DEFAULT_TOKEN && (iap[1] == COLON_TOKEN || iap[1] == COLOYAJIRUSHI_TOKEN))){
				if(!stree.extswitch->teeburutukutta){
					PWCArray<bool> tikb;
					PWCArray<intptr_t> popbp;
					for(i = 0; i < stree.token.GetLength(); i++){
						ii = 0;
						if(stree.token.GetConst()[i].GetConst()[ii] != CASE_TOKEN) continue;
						do{
							ii++;
							if((typ = TokenTtoTypeId(stree.token.GetConst()[i].GetConst(), ii)) < 0) return false;
							stree.extswitch->atai[stree.extswitch->atai.GetLength()] = 0;
							sz = CastConst(stree, typ, stree.token.GetConst()[i].GetConst()+ii,
								stree.extswitch->swtype, &stree.extswitch->atai.GetData()[stree.extswitch->atai.GetLength()-1]);
							if(sz < 0) return false;
							ii += (sz + sizeof(intptr_t)-1) / sizeof(intptr_t);
							for(iii = 0; iii < stree.extswitch->atai.GetLength()-1; iii++){
								if(stree.extswitch->atai.GetConst()[iii] == stree.extswitch->atai.GetConst()[stree.extswitch->atai.GetLength()-1]) return false;
							}
						}while(stree.token.GetConst()[i].GetConst()[ii] == COMMA_TOKEN);
					}
					popbp.Clear();
					tikb.SetLength(stree.extswitch->atai.GetLength());
					for(ii = 0; ii < tikb.GetLength(); ii++) tikb.GetData()[ii] = false;
					sz = TypeIdtoSize(stree, stree.extswitch->swtype);
					deco = TypeIdtoMeireiT(stree, stree.extswitch->swtype);
					bytecode += deco;
					CaseTable(bytecode, *stree.extswitch, tikb, popbp, sz, (uint8_t)(sz*2 - 1), deco);
					Backpatch(bytecode, popbp);
					bytecode += POP_MEIREI;
					bytecode += JUMP_MEIREI;
					stree.extswitch->defbp += bytecode.GetLength();
					AtaiCode(bytecode, (intptr_t)0);
					stree.extswitch->teeburutukutta = true;
				}
				if(iap[len-1] == COLOYAJIRUSHI_TOKEN){
					Backpatch(bytecode, stree.extswitch->tgnsuruusakibp);
				}else{
					bytecode += JUMP_MEIREI;
					stree.extswitch->tgnsuruusakibp += bytecode.GetLength();
					AtaiCode(bytecode, (intptr_t)0);
				}
				if(iap[0] == DEFAULT_TOKEN){
					if(stree.extswitch->def != 0) return false;
					stree.extswitch->def = bytecode.GetLength();
					Backpatch(bytecode, stree.extswitch->defbp);
				}else{
					ii = 0;
					do{
						ii++;
						if((typ = TokenTtoTypeId(iap, ii)) < 0) return false;
						t64 = 0;
						sz = CastConst(stree, typ, iap+ii, stree.extswitch->swtype, &t64);
						if(sz < 0) return false;
						ii += (sz + sizeof(intptr_t)-1) / sizeof(intptr_t);
						for(iii = 0; iii < stree.extswitch->atai.GetLength(); iii++){
							if(stree.extswitch->atai.GetConst()[iii] == t64){
								*(intptr_t *)(bytecode.GetConst()+stree.extswitch->ataibp.GetConst()[iii]) = bytecode.GetLength();
								break;
							}
						}
					}while(iap[ii] == COMMA_TOKEN);
				}
			}else{
				if(iap[0] == BREAK_TOKEN && iap[1] == COLON_TOKEN){
					Backpatch(bytecode, stree.extswitch->tgnsuruusakibp);
					if(stree.extswitch->def == 0) Backpatch(bytecode, stree.extswitch->defbp);
				}
				if(!NormalCompi::KoubunSwitch(stree, bytecode, iap, len, j)) return false;
			}
			return true;
		}
		bool DefDel(SourceTree & stree, PWCArray<uint8_t> & bytecode)
		{
			if(!stree.breakin){
				Backpatch(bytecode, stree.extswitch->tgnsuruusakibp);
				if(stree.extswitch->def == 0) Backpatch(bytecode, stree.extswitch->defbp);
			}
			if(!NormalCompi::DefDel(stree, bytecode)) return false;
			return true;
		}
		bool FuncTreeCompile(SourceTree & stree, PWCArray<uint8_t> & bytecode)
		{
			if(!NormalCompi::FuncTreeCompile(stree, bytecode)) return false;
			if(!stree.extswitch->teeburutukutta){
				bytecode += TypeIdtoMeireiT(stree, stree.extswitch->swtype);
				bytecode += POP_MEIREI;
			}
			return true;
		}
	};
	class BranchCompi : public NormalCompi
	{
		void CondTable(PWCArray<uint8_t> & bytecode, BranchExtStruct & bes, PWCArray<bool> & uetikb, const uint8_t ichi)
		{
			int32_t i;
			intptr_t tbli;
			PWCArrayQuad< PWCArray<int32_t> > numbn;
			bytecode += SWITCHJUMP_MEIREI;
			bytecode += ichi;
			tbli = bytecode.GetLength();
			bytecode.SetLength(bytecode.GetLength() + sizeof(intptr_t)*16);
			numbn.SetLength(16);
			for(i = 0; i < uetikb.GetLength(); i++){
				if(uetikb.GetConst()[i]) continue;
				numbn.GetData()[(*((uint8_t *)(&i)+sizeof(int32_t)-1-(ichi>>1)) & (0x0f<<(ichi&0x01)*4)) >> (ichi&0x01)*4] += i;
			}
			for(i = 0; i < 16; i++){
				if(numbn.GetConst()[i].GetLength() <= 0){
					bes.tgnelsesakibp += tbli + sizeof(intptr_t)*i;
				}else if(numbn.GetConst()[i].GetLength() == 1){
					*(intptr_t *)(bytecode.GetConst()+tbli+sizeof(intptr_t)*i) = bytecode.GetLength();
					bytecode += PUSHSTACK_MEIREI;
					bytecode += PUSHTEISUU_MEIREI;
					AtaiCode(bytecode, numbn.GetConst()[i].GetConst()[0]);
					bytecode += EQUAL_MEIREI;
					bytecode += POPNTRUEJUMP_MEIREI;
					bes.labelbp.GetData()[numbn.GetConst()[i].GetConst()[0]] = bytecode.GetLength();
					AtaiCode(bytecode, (intptr_t)0);
					bytecode += JUMP_MEIREI;
					bes.tgnelsesakibp += bytecode.GetLength();
					AtaiCode(bytecode, (intptr_t)0);
					uetikb.GetData()[i] = true;
				}
			}
			for(i = 0; i < 16; i++){
				if(numbn.GetConst()[i].GetLength() < 2) continue;
				*(intptr_t *)(bytecode.GetConst()+tbli+sizeof(intptr_t)*i) = bytecode.GetLength();
				CondTable(bytecode, bes, uetikb, ichi-1);
			}
		}
		void MakeTable(PWCArray<uint8_t> & bytecode, BranchExtStruct & bes)
		{
			int ii;
			PWCArray<bool> tikb;
			bes.labelbp.SetLength(bes.label.GetLength());
			bes.labelbpflg.SetLength(bes.label.GetLength());
			for(ii = 0; ii < bes.labelbpflg.GetLength(); ii++) bes.labelbpflg.GetData()[ii] = true;
			tikb.SetLength(bes.label.GetLength());
			for(ii = 0; ii < tikb.GetLength(); ii++) tikb.GetData()[ii] = false;
			bytecode += INTTYPE_MEIREI;
			CondTable(bytecode, bes, tikb, (uint8_t)(sizeof(int32_t)*2 - 1));
		}
		void LabelBP(PWCArray<uint8_t> & bytecode, BranchExtStruct & bes)
		{
			int i;
			for(i = 0; i < bes.labelbpflg.GetLength(); i++){
				if(bes.labelbpflg.GetConst()[i]){
					*(intptr_t *)(bytecode.GetConst()+bes.labelbp.GetConst()[i]) = bytecode.GetLength();
				}
			}
		}
	public:
		bool MainLoop(SourceTree & stree, PWCArray<uint8_t> & bytecode, const intptr_t * const iap, const intptr_t len, int & i, SourceTree * & retcall)
		{
			KuwashiiType ktype;
			PWCArray<int32_t> tystack;
			tystack.Clear();
			ktype.id = VOID_TYPEID;
			for(; i < len; i++){
				switch(iap[i]){
				case ELSE_TOKEN:
					i++;
					bytecode += JUMP_MEIREI;
					stree.extbranch->tgnelsesakibp += bytecode.GetLength();
					AtaiCode(bytecode, (intptr_t)0);
					break;
				case BREAK_TOKEN:
					if(!Break(stree, bytecode, iap, len, i, tystack, ktype, retcall)) return false;
					break;
				default:
					if(!MainSwitch(stree, bytecode, iap, i, tystack, ktype, retcall)) return false;
					break;
				}
			}
			return true;
		}
		bool KoubunSwitch(SourceTree & stree, PWCArray<uint8_t> & bytecode, const intptr_t * const iap, const intptr_t len, int & j)
		{
			KuwashiiType ktype;
			PWCArray<int32_t> tystack;
			SourceTree * retcall = NULL;
			int i;
			if(iap[0] == COND_TOKEN){
				if(stree.extbranch->nextcond != 0){
					bytecode += JUMP_MEIREI;
					stree.extbranch->tgncommsakibp += bytecode.GetLength();
					AtaiCode(bytecode, (intptr_t)0);
					*(intptr_t *)(bytecode.GetConst()+stree.extbranch->nextcond) = bytecode.GetLength();
					stree.extbranch->nextcond = 0;
				}
				if(stree.extbranch->mode < 0){
					bytecode += INTTYPE_MEIREI;
					bytecode += PUSHTEISUU_MEIREI;
					AtaiCode(bytecode, (int32_t)iap[1]);
					i = 2;
				}else{
					i = 1;
				}
				ktype.id = VOID_TYPEID;
				do{
					if(!MainSwitch(stree, bytecode, iap, i, tystack, ktype, retcall)) return false;
					i++;
				}while(iap[i] != COLON_TOKEN);
				if(tystack.GetLength() <= 0 || tystack.GetData()[tystack.GetLength()-1] != BOOL_TYPEID) return false;
				bytecode += POPNFALSEJUMP_MEIREI;
				stree.extbranch->nextcond = bytecode.GetLength();
				AtaiCode(bytecode, (intptr_t)0);
			}else if(iap[0] == ELSE_TOKEN && iap[1] == COLON_TOKEN){
				if(stree.extbranch->commnai){
					MakeTable(bytecode, *stree.extbranch);
					stree.extbranch->commnai = false;
				}
				bytecode += JUMP_MEIREI;
				stree.extbranch->tgncommsakibp += bytecode.GetLength();
				AtaiCode(bytecode, (intptr_t)0);
				if(stree.extbranch->nextcond != 0){
					*(intptr_t *)(bytecode.GetConst()+stree.extbranch->nextcond) = bytecode.GetLength();
					stree.extbranch->nextcond = 0;
					if(stree.extbranch->mode < 0){
						bytecode += INTTYPE_MEIREI;
						bytecode += PUSHTEISUU_MEIREI;
						AtaiCode(bytecode, (int32_t)-1);
					}
				}
				Backpatch(bytecode, stree.extbranch->tgnelsesakibp);
			}else if(iap[0] == COMM_TOKEN && iap[1] == COLON_TOKEN){
				LabelBP(bytecode, *stree.extbranch);
				if(stree.extbranch->nextcond != 0){
					*(intptr_t *)(bytecode.GetConst()+stree.extbranch->nextcond) = bytecode.GetLength();
					stree.extbranch->nextcond = 0;
					if(stree.extbranch->mode < 0){
						bytecode += INTTYPE_MEIREI;
						bytecode += PUSHTEISUU_MEIREI;
						AtaiCode(bytecode, (int32_t)-1);
					}
				}
				Backpatch(bytecode, stree.extbranch->tgnelsesakibp);
				Backpatch(bytecode, stree.extbranch->tgncommsakibp);
				stree.extbranch->commnai = true;
			}else if(iap[0] == DIFF_TOKEN && iap[2] == COLON_TOKEN){
				if(stree.extbranch->commnai){
					MakeTable(bytecode, *stree.extbranch);
					stree.extbranch->commnai = false;
				}
				bytecode += JUMP_MEIREI;
				stree.extbranch->tgncommsakibp += bytecode.GetLength();
				AtaiCode(bytecode, (intptr_t)0);
				*(intptr_t *)(bytecode.GetConst()+stree.extbranch->labelbp.GetConst()[iap[1]]) = bytecode.GetLength();
				stree.extbranch->labelbpflg.GetData()[iap[1]] = false;
			}else{
				if(iap[0] == BREAK_TOKEN && iap[1] == COLON_TOKEN){
					LabelBP(bytecode, *stree.extbranch);
					if(stree.extbranch->nextcond != 0){
						*(intptr_t *)(bytecode.GetConst()+stree.extbranch->nextcond) = bytecode.GetLength();
						stree.extbranch->nextcond = 0;
					}
					Backpatch(bytecode, stree.extbranch->tgnelsesakibp);
					Backpatch(bytecode, stree.extbranch->tgncommsakibp);
				}
				if(!NormalCompi::KoubunSwitch(stree, bytecode, iap, len, j)) return false;
			}
			return true;
		}
		bool DefDel(SourceTree & stree, PWCArray<uint8_t> & bytecode)
		{
			if(!stree.breakin){
				LabelBP(bytecode, *stree.extbranch);
				if(stree.extbranch->nextcond != 0){
					*(intptr_t *)(bytecode.GetConst()+stree.extbranch->nextcond) = bytecode.GetLength();
					stree.extbranch->nextcond = 0;
				}
				Backpatch(bytecode, stree.extbranch->tgnelsesakibp);
				Backpatch(bytecode, stree.extbranch->tgncommsakibp);
			}
			if(!NormalCompi::DefDel(stree, bytecode)) return false;
			return true;
		}
		bool FuncTreeCompile(SourceTree & stree, PWCArray<uint8_t> & bytecode)
		{
			if(!NormalCompi::FuncTreeCompile(stree, bytecode)) return false;
			if(stree.extbranch->mode < 0){
				bytecode += INTTYPE_MEIREI;
				bytecode += POP_MEIREI;
			}
			return true;
		}
	};
	class LoopCompi : public NormalCompi
	{
	public:
		bool MainLoop(SourceTree & stree, PWCArray<uint8_t> & bytecode, const intptr_t * const iap, const intptr_t len, int & i, SourceTree * & retcall)
		{
			KuwashiiType ktype;
			PWCArray<int32_t> tystack;
			tystack.Clear();
			ktype.id = VOID_TYPEID;
			for(; i < len; i++){
				switch(iap[i]){
				case DO_TOKEN:
					i++;
					bytecode += JUMP_MEIREI;
					if(stree.extloop->doad == 0) stree.extloop->doadbp += bytecode.GetLength();
					AtaiCode(bytecode, stree.extloop->doad);
					break;
				case CONTINUE_TOKEN:
					i++;
					bytecode += JUMP_MEIREI;
					if(stree.extloop->contad == 0) stree.extloop->contadbp += bytecode.GetLength();
					AtaiCode(bytecode, stree.extloop->contad);
					break;
				case WHILE_TOKEN:
					i++;
					bytecode += JUMP_MEIREI;
					if(stree.extloop->nextad == 0) stree.extloop->nextadbp += bytecode.GetLength();
					AtaiCode(bytecode, stree.extloop->nextad);
					break;
				case BREAK_TOKEN:
					if(!Break(stree, bytecode, iap, len, i, tystack, ktype, retcall)) return false;
					break;
				default:
					if(!MainSwitch(stree, bytecode, iap, i, tystack, ktype, retcall)) return false;
					break;
				}
			}
			return true;
		}
		bool KoubunSwitch(SourceTree & stree, PWCArray<uint8_t> & bytecode, const intptr_t * const iap, const intptr_t len, int & j)
		{
			KuwashiiType ktype;
			PWCArray<int32_t> tystack;
			SourceTree * retcall = NULL;
			int i;
			if(iap[0] == DO_TOKEN && iap[1] == COLON_TOKEN){
				stree.extloop->doad = bytecode.GetLength();
				Backpatch(bytecode, stree.extloop->doadbp);
			}else if(iap[0] == CONTINUE_TOKEN && iap[1] == COLON_TOKEN){
				stree.extloop->contad = bytecode.GetLength();
				Backpatch(bytecode, stree.extloop->contadbp);
			}else if(iap[0] == WHILE_TOKEN && iap[1] != SEMICOLON_TOKEN){
				stree.extloop->nextad = bytecode.GetLength();
				Backpatch(bytecode, stree.extloop->contadbp);
				Backpatch(bytecode, stree.extloop->nextadbp);
				i = 1;
				ktype.id = VOID_TYPEID;
				do{
					if(!MainSwitch(stree, bytecode, iap, i, tystack, ktype, retcall)) return false;
					i++;
				}while(iap[i] != COLON_TOKEN);
				if(tystack.GetLength() <= 0 || tystack.GetData()[tystack.GetLength()-1] != BOOL_TYPEID) return false;
				bytecode += POPNTRUEJUMP_MEIREI;
				AtaiCode(bytecode, stree.extloop->doad);
			}else{
				if(iap[0] == BREAK_TOKEN && iap[1] == COLON_TOKEN){
					Backpatch(bytecode, stree.extloop->doadbp);
					Backpatch(bytecode, stree.extloop->contadbp);
					Backpatch(bytecode, stree.extloop->nextadbp);
				}
				if(!NormalCompi::KoubunSwitch(stree, bytecode, iap, len, j)) return false;
			}
			return true;
		}
		bool DefDel(SourceTree & stree, PWCArray<uint8_t> & bytecode)
		{
			if(!stree.breakin){
				Backpatch(bytecode, stree.extloop->doadbp);
				Backpatch(bytecode, stree.extloop->contadbp);
				Backpatch(bytecode, stree.extloop->nextadbp);
			}
			if(!NormalCompi::DefDel(stree, bytecode)) return false;
			return true;
		}
	};
	FuncCompi fcom;
	NormalCompi ncom;
	LockCompi lkcom;
	SwitchCompi swcom;
	BranchCompi brcom;
	LoopCompi lpcom;
	OmCompiler()
	{
		fcom.SetOmc(this);
		ncom.SetOmc(this);
		lkcom.SetOmc(this);
		swcom.SetOmc(this);
		brcom.SetOmc(this);
		lpcom.SetOmc(this);
	}
	bool Compile(SourceTree & sourceroot, PWCArray<uint8_t> & bytecode, PWCArray<int8_t> & globalres)
	{
		int i;
		SourceTree * pst;
		intptr_t ttl, bp;
		if(sourceroot.parent != NULL){
			ErrorMessage.Add(sourceroot.srce->filename, sourceroot.topsrcgyo, L"^̍łȂłB");
			return false;
		}
		ttl = sourceroot.literaltotal;
		bytecode.Clear();
		pst = &sourceroot;
		while(pst->subsrc != NULL) pst = pst->subsrc;
		while(pst->parent != NULL){
			if(pst->token.GetLength() > 0){
				bytecode += CALL_MEIREI;
				pst->backpatch += bytecode.GetLength();
				fcom.AtaiCode(bytecode, pst->byteadress);
			}
			bytecode += JUMP_MEIREI;
			bp = bytecode.GetLength();
			fcom.AtaiCode(bytecode, (intptr_t)0);
			pst->golbalgetahoka = ttl;
			if(!fcom.FuncTreeCompile(*pst, bytecode)) return false;
			*(intptr_t *)(bytecode.GetData()+bp) = bytecode.GetLength();
			ttl += pst->GetMemberSize();
			pst = pst->parent;
		}
		bytecode += CALL_MEIREI;
		sourceroot.backpatch += bytecode.GetLength();
		fcom.AtaiCode(bytecode, sourceroot.byteadress);
		bytecode += RETURN_MEIREI;
		sourceroot.golbalgetahoka = ttl;
		if(!fcom.FuncTreeCompile(sourceroot, bytecode)) return false;
		ttl += sourceroot.GetMemberSize();
		globalres.SetLength(ttl);
		ttl = 0;
		for(i = 0; i < sourceroot.literallist.GetLength(); i++){
			memcpy(globalres.GetData()+ttl, sourceroot.literallist.GetConst()[i].GetConst(), sourceroot.literallist.GetConst()[i].GetLength());
			((Reference *)(globalres.GetData()+ttl))->pointer = (HeapObj *)(globalres.GetData()+ttl+sizeof(Reference));
			((HeapObjHead *)(globalres.GetData()+ttl+sizeof(Reference)))->data = (int8_t *)(globalres.GetData()+ttl+sizeof(Reference)+sizeof(HeapObjHead));
			ttl += sourceroot.literallist.GetConst()[i].GetLength();
		}
		return true;
	}
};
