enum SrcMojicode
{
	MJCODE_UNICODE,
	MJCODE_ANSI,
	MJCODE_UTF_8
};

struct Source
{
	PWCArray<wchar_t> filename;
	PWCArray<wchar_t> source;
	int idx, gyousuu;
	SrcMojicode charset;
	Source & operator = (const Source & x)
	{
		filename = x.filename;
		source = x.source;
		gyousuu = x.gyousuu;
		return *this;
	}
	void Clear()
	{
		filename.Clear();
		source.Clear();
		idx = 0;
		gyousuu = 1;
		charset = (SrcMojicode)-1;
	}
	bool Load(const wchar_t * const fn)
	{
		StrIdxArray<SIARFileItem> inFile;
		wchar_t * pwc;
		char ch;
		DWORD sh;
		PWCArray<char> tmp;
		int i;
		Clear();
		pwc = _wfullpath(NULL, fn, 0);
		if(pwc == NULL){
			filename = fn;
			ErrorMessage.Add(filename, -1, L"΃pXւ̕ϊɎsB");
			return false;
		}
		filename = pwc;
		free(pwc);
		for(i = 0; i < filename.GetLength(); i++) filename.GetData()[i] = tolower(filename.GetData()[i]);
		if(inFile[fn].ZRead(&ch, 1) <= 0){
			ErrorMessage.Add(filename, -1, L"t@C̓ǂݍ݂ɎsB");
			return false;
		}
		charset = MJCODE_ANSI;
		if(ch == '\xFF'){
			inFile[fn].Read(&ch, 1);
			if(ch == '\xFE'){
				charset = MJCODE_UNICODE;
			}
		}else if(ch == '\xEF'){
			inFile[fn].Read(&ch, 1);
			if(ch == '\xBB'){
				inFile[fn].Read(&ch, 1);
				if(ch == '\xBF'){
					charset = MJCODE_UTF_8;
				}
			}
		}
		switch(charset){
		case MJCODE_UNICODE:
			source.SetLength((inFile[fn].GetSize(sh)-2)/sizeof(wchar_t));
			inFile[fn].Read((char *)source.GetConst(), source.GetLength()*sizeof(wchar_t));
			break;
		case MJCODE_UTF_8:
			tmp.SetLength(inFile[fn].GetSize(sh)-3);
			inFile[fn].Read(tmp.GetData(), tmp.GetLength());
			source.SetLength(MultiByteToWideChar(CP_UTF8, 0, tmp.GetConst(), tmp.GetLength(), NULL, 0));
			MultiByteToWideChar(CP_UTF8, 0, tmp.GetConst(), tmp.GetLength(), source.GetData(), source.GetLength());
			break;
		case MJCODE_ANSI:
			inFile[fn].AllRead(tmp);
			source.SetLength(MultiByteToWideChar(CP_ACP, 0, tmp.GetConst(), tmp.GetLength(), NULL, 0));
			MultiByteToWideChar(CP_ACP, 0, tmp.GetConst(), tmp.GetLength(), source.GetData(), source.GetLength());
			break;
		}
		return true;
	}
	bool IsTSChar(const wchar_t wc)
	{
		return (L'0' <= wc && wc <= L'9') || (L'A' <= wc && wc <= L'Z') || (L'a' <= wc && wc <= L'z') || wc == L'_' || wc >= 0xC0;
	}
	bool GetTString()
	{
		bool ret = false;
		for(; idx < source.GetLength(); idx++){
			if(!IsTSChar(source.GetConst()[idx])){
				if(source.GetConst()[idx] != L'_') break;
			}
			ret = true;
		}
		return ret;
	}
	bool GetNumString()
	{
		bool ret = false;
		for(; idx < source.GetLength(); idx++){
			if(source.GetConst()[idx] < L'0' || L'9' < source.GetConst()[idx]) break;
			ret = true;
		}
		return ret;
	}
	void SkipSpace()
	{
		while(true){
			for(; idx < source.GetLength(); idx++){
				if(source.GetConst()[idx] == L'\r'){
					gyousuu++;
					if(idx+1 < source.GetLength() && source.GetConst()[idx+1] == L'\n') idx++;
				}else if(source.GetConst()[idx] == L'\n'){
					gyousuu++;
				}else if(source.GetConst()[idx] != L' ' && source.GetConst()[idx] != L'\t'){
					break;
				}
			}
			if(idx+1 >= source.GetLength() || source.GetConst()[idx] != L'/') break;
			if(source.GetConst()[idx+1] == L'/'){
				for(idx += 2; idx < source.GetLength(); idx++){
					if(source.GetConst()[idx] == L'\r'){
						gyousuu++;
						if(++idx >= source.GetLength()) break;
						if(source.GetConst()[idx] == L'\n') idx++;
						break;
					}else if(source.GetConst()[idx] == L'\n'){
						gyousuu++;
						idx++;
						break;
					}
				}
			}else if(source.GetConst()[idx+1] == L'*'){
				if((idx += 2) >= source.GetLength()) break;
				for(idx++; idx < source.GetLength(); idx++){
					if(source.GetConst()[idx-1] == L'*' && source.GetConst()[idx] == L'/'){
						idx++;
						break;
					}else if(source.GetConst()[idx-1] == L'\r'){
						gyousuu++;
						if(source.GetConst()[idx] == L'\n') if(++idx >= source.GetLength()) break;
					}else if(source.GetConst()[idx-1] == L'\n') gyousuu++;
				}
			}else{
				break;
			}
		}
	}
	void Find(const wchar_t md, int & t)
	{
		t = idx;
		for(; idx < source.GetLength(); idx++){
			if(source.GetConst()[idx] == L'\r'){
				gyousuu++;
				if(idx+1 < source.GetLength() && source.GetConst()[idx+1] == L'\n') idx++;
			}else if(source.GetConst()[idx] == L'\n'){
				gyousuu++;
			}else if(source.GetConst()[idx] == md){
				break;
			}
		}
	}
	wchar_t GetChar()
	{
		if(idx >= source.GetLength()) return L'\0';
		if(source.GetConst()[idx] == L'\r'){
			gyousuu++;
			if(idx+1 < source.GetLength() && source.GetConst()[idx+1] == L'\n') idx++;
		}else if(source.GetConst()[idx] == L'\n'){
			gyousuu++;
		}
		return source.GetConst()[idx++];
	}
	TokenKind GetToken(int & t)
	{
		SkipSpace();
		t = idx;
		if(idx >= source.GetLength()) return NULL_TOKEN;
		switch(source.GetConst()[idx]){
		case L'+':
			if(++idx < source.GetLength()){
				if(source.GetConst()[idx] == L'='){
					idx++;
					return PULUSDAINYUU_TOKEN;
				}else if(source.GetConst()[idx] == L'+'){
					idx++;
					return PLSPLS_TOKEN;
				}
			}
			return PULUS_TOKEN;
		case L'-':
			if(++idx < source.GetLength()){
				if(source.GetConst()[idx] == L'='){
					idx++;
					return MINUSDAINYUU_TOKEN;
				}else if(source.GetConst()[idx] == L'>'){
					idx++;
					return YAJIRUSHI_TOKEN;
				}else if(source.GetConst()[idx] == L'-'){
					idx++;
					return MNSMNS_TOKEN;
				}
			}
			return MINUS_TOKEN;
		case L'*':
			if(++idx < source.GetLength() && source.GetConst()[idx] == L'='){
				idx++;
				return KAKERUDAINYUU_TOKEN;
			}
			return KAKERU_TOKEN;
		case L'/':
			if(++idx < source.GetLength() && source.GetConst()[idx] == L'='){
				idx++;
				return WARUDAINYUU_TOKEN;
			}
			return WARU_TOKEN;
		case L'%':
			if(++idx < source.GetLength() && source.GetConst()[idx] == L'='){
				idx++;
				return AMARIDAINYUU_TOKEN;
			}
			return AMARI_TOKEN;
		case L'&':
			if(++idx < source.GetLength()){
				if(source.GetConst()[idx] == L'='){
					idx++;
					return ANDDAINYUU_TOKEN;
				}else if(source.GetConst()[idx] == L'&'){
					idx++;
					return ANDAND_TOKEN;
				}
			}
			return AND_TOKEN;
		case L'^':
			if(++idx < source.GetLength() && source.GetConst()[idx] == L'='){
				idx++;
				return XORDAINYUU_TOKEN;
			}
			return XOR_TOKEN;
		case L'|':
			if(++idx < source.GetLength()){
				if(source.GetConst()[idx] == L'='){
					idx++;
					return ORDAINYUU_TOKEN;
				}else if(source.GetConst()[idx] == L'|'){
					idx++;
					return OROR_TOKEN;
				}
			}
			return OR_TOKEN;
		case L'<':
			if(++idx < source.GetLength()){
				if(source.GetConst()[idx] == L'='){
					idx++;
					return SHOUOREQUAL_TOKEN;
				}else if(source.GetConst()[idx] == L'<'){
					if(++idx < source.GetLength() && source.GetConst()[idx] == L'='){
						idx++;
						return LSHIFTDAINYUU_TOKEN;
					}
					return LSHIFT_TOKEN;
				}else if(source.GetConst()[idx] == L'>'){
					idx++;
					return DIA_TOKEN;
				}else if(source.GetConst()[idx] == L':'){
					idx++;
					return BRACOLOOPEN_TOKEN;
				}
			}
			return SHOU_TOKEN;
		case L'>':
			if(++idx < source.GetLength()){
				if(source.GetConst()[idx] == L'='){
					idx++;
					return DAIOREQUAL_TOKEN;
				}else if(source.GetConst()[idx] == L'>'){
					if(++idx < source.GetLength() && source.GetConst()[idx] == L'='){
						idx++;
						return RSHIFTDAINYUU_TOKEN;
					}
					return RSHIFT_TOKEN;
				}
			}
			return DAI_TOKEN;
		case L'!':
			if(++idx < source.GetLength() && source.GetConst()[idx] == L'='){
				idx++;
				return NOTEQUAL_TOKEN;
			}
			return EXCLAMATION_TOKEN;
		case L'=':
			if(++idx < source.GetLength()){
				if(source.GetConst()[idx] == L'='){
					idx++;
					return EQUAL_TOKEN;
				}else if(source.GetConst()[idx] == L'>'){
					idx++;
					return SHIROYAJIRUSHI_TOKEN;
				}
			}
			return DAINYUU_TOKEN;
		case L'?':
			idx++;
			return QUESTION_TOKEN;
		case L'(':
			if(++idx < source.GetLength() && source.GetConst()[idx] == L':'){
				idx++;
				return KAKKOCOLOOPEN_TOKEN;
			}
			return SHOUKAKKOOPEN_TOKEN;
		case L')':
			idx++;
			return SHOUKAKKOCLOSE_TOKEN;
		case L'{':
			idx++;
			return CHUUKAKKOOPEN_TOKEN;
		case L'}':
			idx++;
			return CHUUKAKKOCLOSE_TOKEN;
		case L'[':
			idx++;
			return DAIKAKKOOPEN_TOKEN;
		case L']':
			idx++;
			return DAIKAKKOCLOSE_TOKEN;
		case L'#':
			idx++;
			return SHARP_TOKEN;
		case L'\\':
			idx++;
			return BACKSLA_TOKEN;
		case L'\'':
			idx++;
			return SQUOT_TOKEN;
		case L'"':
			idx++;
			return DQUOT_TOKEN;
		case L',':
			idx++;
			return COMMA_TOKEN;
		case L';':
			idx++;
			return SEMICOLON_TOKEN;
		case L'.':
			if(++idx < source.GetLength()){
				if(source.GetConst()[idx] == L'.'){
					idx++;
					return TENTEN_TOKEN;
				}else if(source.GetConst()[idx] == L'='){
					idx++;
					return TENDAINYUU_TOKEN;
				}
			}
			return POINT_TOKEN;
		case L':':
			if(++idx < source.GetLength()){
				if(source.GetConst()[idx] == L':'){
					idx++;
					return COLOCOLO_TOKEN;
				}else if(source.GetConst()[idx] == L'>'){
					idx++;
					return BRACOLOCLOSE_TOKEN;
				}else if(source.GetConst()[idx] == L')'){
					idx++;
					return KAKKOCOLOCLOSE_TOKEN;
				}else if(source.GetConst()[idx] == L'-' && idx+1 < source.GetLength() && source.GetConst()[idx+1] == L'>'){
					idx += 2;
					return COLOYAJIRUSHI_TOKEN;
				}
			}
			return COLON_TOKEN;
		default:
			if(GetTString()){
				return MojiretsuToken(source.GetConst()+t, idx-t);
			}
			break;
		}
		return NULL_TOKEN;
	}
	TokenKind MojiretsuToken(const wchar_t * const tstr, const int tlen)
	{
		if(tlen > 0) switch(tstr[0]){
///////////////////////////////////////////////////////////////////////////////
		case L'b': if(tlen > 1) switch(tstr[1]){
			case L'o': if(tlen > 2) switch(tstr[2]){
				case L'o': if(tlen > 3) switch(tstr[3]){
					case L'l': if(tlen > 4){
						}else{
							return BOOL_TOKEN;
						}break;
					}break;
				}break;
			case L'r': if(tlen > 2) switch(tstr[2]){
				case L'a': if(tlen > 3) switch(tstr[3]){
					case L'n': if(tlen > 4) switch(tstr[4]){
						case L'c': if(tlen > 5) switch(tstr[5]){
							case L'h': if(tlen > 6){
								}else{
									return BRANCH_TOKEN;
								}break;
							}break;
						}break;
					}break;
				case L'e': if(tlen > 3) switch(tstr[3]){
					case L'a': if(tlen > 4) switch(tstr[4]){
						case L'k': if(tlen > 5){
							}else{
								return BREAK_TOKEN;
							}break;
						}break;
					}break;
				}break;
			case L'y': if(tlen > 2) switch(tstr[2]){
				case L't': if(tlen > 3) switch(tstr[3]){
					case L'e': if(tlen > 4){
						}else{
							return BYTE_TOKEN;
						}break;
					}break;
				}break;
			}break;
///////////////////////////////////////////////////////////////////////////////
		case L'c': if(tlen > 1) switch(tstr[1]){
			case L'a': if(tlen > 2) switch(tstr[2]){
				case L's': if(tlen > 3) switch(tstr[3]){
					case L'e': if(tlen > 4){
						}else{
							return CASE_TOKEN;
						}break;
					}break;
				}break;
			case L'h': if(tlen > 2) switch(tstr[2]){
				case L'a': if(tlen > 3) switch(tstr[3]){
					case L'r': if(tlen > 4){
						}else{
							return CHAR_TOKEN;
						}break;
					}break;
				}break;
			case L'l': if(tlen > 2) switch(tstr[2]){
				case L'a': if(tlen > 3) switch(tstr[3]){
					case L's': if(tlen > 4) switch(tstr[4]){
						case L's': if(tlen > 5){
							}else{
								return CLASS_TOKEN;
							}break;
						}break;
					}break;
				}break;
			case L'o': if(tlen > 2) switch(tstr[2]){
				case L'm': if(tlen > 3) switch(tstr[3]){
					case L'm': if(tlen > 4){
						}else{
							return COMM_TOKEN;
						}break;
					}break;
				case L'n': if(tlen > 3) switch(tstr[3]){
					case L'd': if(tlen > 4){
						}else{
							return COND_TOKEN;
						}break;
					case L's': if(tlen > 4) switch(tstr[4]){
						case L't': if(tlen > 5){
							}else{
								return CONST_TOKEN;
							}break;
						}break;
					case L't': if(tlen > 4) switch(tstr[4]){
						case L'i': if(tlen > 5) switch(tstr[5]){
							case L'n': if(tlen > 6) switch(tstr[6]){
								case L'u': if(tlen > 7) switch(tstr[7]){
									case L'e': if(tlen > 8){
										}else{
											return CONTINUE_TOKEN;
										}break;
									}break;
								}break;
							}break;
						}break;
					}break;
				case L'r': if(tlen > 3) switch(tstr[3]){
					case L'e': if(tlen > 4){
						}else{
							return CORE_TOKEN;
						}break;
					}break;
				}break;
			}break;
///////////////////////////////////////////////////////////////////////////////
		case L'd': if(tlen > 1) switch(tstr[1]){
			case L'e': if(tlen > 2) switch(tstr[2]){
				case L'f': if(tlen > 3) switch(tstr[3]){
					case L'a': if(tlen > 4) switch(tstr[4]){
						case L'u': if(tlen > 5) switch(tstr[5]){
							case L'l': if(tlen > 6) switch(tstr[6]){
								case L't': if(tlen > 7){
									}else{
										return DEFAULT_TOKEN;
									}break;
								}break;
							}break;
						}break;
					}break;
				case L'l': if(tlen > 3) switch(tstr[3]){
					case L'e': if(tlen > 4) switch(tstr[4]){
						case L't': if(tlen > 5) switch(tstr[5]){
							case L'e': if(tlen > 6){
								}else{
									return DELETE_TOKEN;
								}break;
							}break;
						}break;
					}break;
				}break;
			case L'i': if(tlen > 2) switch(tstr[2]){
				case L'f': if(tlen > 3) switch(tstr[3]){
					case L'f': if(tlen > 4){
						}else{
							return DIFF_TOKEN;
						}break;
					}break;
				}break;
			case L'o': if(tlen > 2) switch(tstr[2]){
				case L'u': if(tlen > 3) switch(tstr[3]){
					case L'b': if(tlen > 4) switch(tstr[4]){
						case L'l': if(tlen > 5) switch(tstr[5]){
							case L'e': if(tlen > 6){
								}else{
									return DOUBLE_TOKEN;
								}break;
							}break;
						}break;
					}break;
				}else{
					return DO_TOKEN;
				}break;
			}break;
///////////////////////////////////////////////////////////////////////////////
		case L'e': if(tlen > 1) switch(tstr[1]){
			case L'l': if(tlen > 2) switch(tstr[2]){
				case L's': if(tlen > 3) switch(tstr[3]){
					case L'e': if(tlen > 4){
						}else{
							return ELSE_TOKEN;
						}break;
					}break;
				}break;
			case L'n': if(tlen > 2) switch(tstr[2]){
				case L'u': if(tlen > 3) switch(tstr[3]){
					case L'm': if(tlen > 4){
						}else{
							return ENUM_TOKEN;
						}break;
					}break;
				}break;
			}break;
///////////////////////////////////////////////////////////////////////////////
		case L'f': if(tlen > 1) switch(tstr[1]){
			case L'a': if(tlen > 2) switch(tstr[2]){
				case L'l': if(tlen > 3) switch(tstr[3]){
					case L's': if(tlen > 4) switch(tstr[4]){
						case L'e': if(tlen > 5){
							}else{
								return FALSE_TOKEN;
							}break;
						}break;
					}break;
				}break;
			case L'l': if(tlen > 2) switch(tstr[2]){
				case L'o': if(tlen > 3) switch(tstr[3]){
					case L'a': if(tlen > 4) switch(tstr[4]){
						case L't': if(tlen > 5){
							}else{
								return FLOAT_TOKEN;
							}break;
						}break;
					}break;
				}break;
			case L'u': if(tlen > 2) switch(tstr[2]){
				case L'n': if(tlen > 3) switch(tstr[3]){
					case L'c': if(tlen > 4){
						}else{
							return FUNC_TOKEN;
						}break;
					}break;
				}break;
			}break;
///////////////////////////////////////////////////////////////////////////////
		case L'g': if(tlen > 1) switch(tstr[1]){
			case L'b': if(tlen > 2) switch(tstr[2]){
				case L'l': if(tlen > 3){
					}else{
						return GBL_TOKEN;
					}break;
				}break;
			}break;
///////////////////////////////////////////////////////////////////////////////
		case L'i': if(tlen > 1) switch(tstr[1]){
			case L'f': if(tlen > 2){
				}else{
					return IF_TOKEN;
				}break;
			case L'n': if(tlen > 2) switch(tstr[2]){
				case L'd': if(tlen > 3) switch(tstr[3]){
					case L'e': if(tlen > 4) switch(tstr[4]){
						case L'x': if(tlen > 5){
							}else{
								return INDEX_TOKEN;
							}break;
						}break;
					}break;
				case L't': if(tlen > 3){
					}else{
						return INT_TOKEN;
					}break;
				}break;
			}break;
///////////////////////////////////////////////////////////////////////////////
		case L'l': if(tlen > 1) switch(tstr[1]){
			case L'e': if(tlen > 2) switch(tstr[2]){
				case L'n': if(tlen > 3){
					}else{
						return LEN_TOKEN;
					}break;
				}break;
			case L'i': if(tlen > 2) switch(tstr[2]){
				case L'b': if(tlen > 3){
					}else{
						return LIB_TOKEN;
					}break;
				case L's': if(tlen > 3) switch(tstr[3]){
					case L't': if(tlen > 4){
						}else{
							return LIST_TOKEN;
						}break;
					}break;
				}break;
			case L'o': if(tlen > 2) switch(tstr[2]){
				case L'c': if(tlen > 3) switch(tstr[3]){
					case L'k': if(tlen > 4){
						}else{
							return LOCK_TOKEN;
						}break;
					}break;
				case L'n': if(tlen > 3) switch(tstr[3]){
					case L'g': if(tlen > 4){
						}else{
							return LONG_TOKEN;
						}break;
					}break;
				case L'o': if(tlen > 3) switch(tstr[3]){
					case L'p': if(tlen > 4){
						}else{
							return LOOP_TOKEN;
						}break;
					}break;
				}break;
			}break;
///////////////////////////////////////////////////////////////////////////////
		case L'm': if(tlen > 1) switch(tstr[1]){
			case L'b': if(tlen > 2) switch(tstr[2]){
				case L'r': if(tlen > 3){
					}else{
						return MBR_TOKEN;
					}break;
				}break;
			case L'e': if(tlen > 2) switch(tstr[2]){
				case L't': if(tlen > 3) switch(tstr[3]){
					case L'h': if(tlen > 4) switch(tstr[4]){
						case L'o': if(tlen > 5) switch(tstr[5]){
							case L'd': if(tlen > 6){
								}else{
									return METHOD_TOKEN;
								}break;
							}break;
						}break;
					}break;
				}break;
			}break;
///////////////////////////////////////////////////////////////////////////////
		case L'n': if(tlen > 1) switch(tstr[1]){
			case L'e': if(tlen > 2) switch(tstr[2]){
				case L'w': if(tlen > 3){
					}else{
						return NEW_TOKEN;
					}break;
				}break;
			}break;
///////////////////////////////////////////////////////////////////////////////
		case L'p': if(tlen > 1) switch(tstr[1]){
			case L'l': if(tlen > 2) switch(tstr[2]){
				case L'u': if(tlen > 3) switch(tstr[3]){
					case L'g': if(tlen > 4) switch(tstr[4]){
						case L'i': if(tlen > 5) switch(tstr[5]){
							case L'n': if(tlen > 6){
								}else{
									return PLUGIN_TOKEN;
								}break;
							}break;
						}break;
					}break;
				}break;
			case L'r': if(tlen > 2) switch(tstr[2]){
				case L'o': if(tlen > 3) switch(tstr[3]){
					case L'p': if(tlen > 4) switch(tstr[4]){
						case L'e': if(tlen > 5) switch(tstr[5]){
							case L'r': if(tlen > 6) switch(tstr[6]){
								case L't': if(tlen > 7) switch(tstr[7]){
									case L'y': if(tlen > 8){
										}else{
											return PROPERTY_TOKEN;
										}break;
									}break;
								}break;
							}break;
						}break;
					}break;
				}break;
			case L'u': if(tlen > 2) switch(tstr[2]){
				case L'b': if(tlen > 3) switch(tstr[3]){
					case L'l': if(tlen > 4) switch(tstr[4]){
						case L'i': if(tlen > 5) switch(tstr[5]){
							case L'c': if(tlen > 6){
								}else{
									return PUBLIC_TOKEN;
								}break;
							}break;
						}break;
					}break;
				}break;
			}break;
///////////////////////////////////////////////////////////////////////////////
		case L'r': if(tlen > 1) switch(tstr[1]){
			case L'e': if(tlen > 2) switch(tstr[2]){
				case L'f': if(tlen > 3){
					}else{
						return REF_TOKEN;
					}break;
				case L't': if(tlen > 3) switch(tstr[3]){
					case L'u': if(tlen > 4) switch(tstr[4]){
						case L'r': if(tlen > 5) switch(tstr[5]){
							case L'n': if(tlen > 6){
								}else{
									return RETURN_TOKEN;
								}break;
							}break;
						}break;
					}break;
				}break;
			}break;
///////////////////////////////////////////////////////////////////////////////
		case L's': if(tlen > 1) switch(tstr[1]){
			case L'e': if(tlen > 2) switch(tstr[2]){
				case L'l': if(tlen > 3) switch(tstr[3]){
					case L'f': if(tlen > 4){
						}else{
							return SELF_TOKEN;
						}break;
					}break;
				}break;
			case L'h': if(tlen > 2) switch(tstr[2]){
				case L'o': if(tlen > 3) switch(tstr[3]){
					case L'r': if(tlen > 4) switch(tstr[4]){
						case L't': if(tlen > 5){
							}else{
								return SHORT_TOKEN;
							}break;
						}break;
					}break;
				}break;
			case L'i': if(tlen > 2) switch(tstr[2]){
				case L'z': if(tlen > 3) switch(tstr[3]){
					case L'e': if(tlen > 4) switch(tstr[4]){
						case L'o': if(tlen > 5) switch(tstr[5]){
							case L'f': if(tlen > 6){
								}else{
									return SIZEOF_TOKEN;
								}break;
							}break;
						}break;
					}break;
				}break;
			case L'w': if(tlen > 2) switch(tstr[2]){
				case L'i': if(tlen > 3) switch(tstr[3]){
					case L't': if(tlen > 4) switch(tstr[4]){
						case L'c': if(tlen > 5) switch(tstr[5]){
							case L'h': if(tlen > 6){
								}else{
									return SWITCH_TOKEN;
								}break;
							}break;
						}break;
					}break;
				}break;
			}break;
///////////////////////////////////////////////////////////////////////////////
		case L't': if(tlen > 1) switch(tstr[1]){
			case L'h': if(tlen > 2) switch(tstr[2]){
				case L'r': if(tlen > 3) switch(tstr[3]){
					case L'e': if(tlen > 4) switch(tstr[4]){
						case L'a': if(tlen > 5) switch(tstr[5]){
							case L'd': if(tlen > 6){
								}else{
									return THREAD_TOKEN;
								}break;
							}break;
						}break;
					}break;
				}break;
			case L'r': if(tlen > 2) switch(tstr[2]){
				case L'u': if(tlen > 3) switch(tstr[3]){
					case L'e': if(tlen > 4){
						}else{
							return TRUE_TOKEN;
						}break;
					}break;
				}break;
			case L'y': if(tlen > 2) switch(tstr[2]){
				case L'p': if(tlen > 3) switch(tstr[3]){
					case L'e': if(tlen > 4) switch(tstr[4]){
						case L'i': if(tlen > 5) switch(tstr[5]){
							case L'd': if(tlen > 6) switch(tstr[6]){
								case L'o': if(tlen > 7) switch(tstr[7]){
									case L'f': if(tlen > 8){
										}else{
											return TYPEIDOF_TOKEN;
										}break;
									}break;
								}break;
							}break;
						}else{
							return TYPE_TOKEN;
						}break;
					}break;
				}break;
			}break;
///////////////////////////////////////////////////////////////////////////////
		case L'u': if(tlen > 1) switch(tstr[1]){
			case L'b': if(tlen > 2) switch(tstr[2]){
				case L'y': if(tlen > 3) switch(tstr[3]){
					case L't': if(tlen > 4) switch(tstr[4]){
						case L'e': if(tlen > 5){
							}else{
								return UBYTE_TOKEN;
							}break;
						}break;
					}break;
				}break;
			case L'i': if(tlen > 2) switch(tstr[2]){
				case L'n': if(tlen > 3) switch(tstr[3]){
					case L't': if(tlen > 4){
						}else{
							return UINT_TOKEN;
						}break;
					}break;
				}break;
			case L'l': if(tlen > 2) switch(tstr[2]){
				case L'o': if(tlen > 3) switch(tstr[3]){
					case L'n': if(tlen > 4) switch(tstr[4]){
						case L'g': if(tlen > 5){
							}else{
								return ULONG_TOKEN;
							}break;
						}break;
					}break;
				}break;
			case L's': if(tlen > 2) switch(tstr[2]){
				case L'h': if(tlen > 3) switch(tstr[3]){
					case L'o': if(tlen > 4) switch(tstr[4]){
						case L'r': if(tlen > 5) switch(tstr[5]){
							case L't': if(tlen > 6){
								}else{
									return USHORT_TOKEN;
								}break;
							}break;
						}break;
					}break;
				}break;
			}break;
///////////////////////////////////////////////////////////////////////////////
		case L'v': if(tlen > 1) switch(tstr[1]){
			case L'o': if(tlen > 2) switch(tstr[2]){
				case L'i': if(tlen > 3) switch(tstr[3]){
					case L'd': if(tlen > 4){
						}else{
							return VOID_TOKEN;
						}break;
					}break;
				}break;
			}break;
///////////////////////////////////////////////////////////////////////////////
		case L'w': if(tlen > 1) switch(tstr[1]){
			case L'a': if(tlen > 2) switch(tstr[2]){
				case L'i': if(tlen > 3) switch(tstr[3]){
					case L't': if(tlen > 4){
						}else{
							return WAIT_TOKEN;
						}break;
					}break;
				}break;
			case L'h': if(tlen > 2) switch(tstr[2]){
				case L'i': if(tlen > 3) switch(tstr[3]){
					case L'l': if(tlen > 4) switch(tstr[4]){
						case L'e': if(tlen > 5){
							}else{
								return WHILE_TOKEN;
							}break;
						}break;
					}break;
				}break;
			}break;
		}
		return OTHERKIND_TOKEN;
	}
};
