enum BlockType
{
	UNKNOWN_BLOCK=0, FUNC_BLOCK, CLASS_BLOCK, ENUM_BLOCK, NORMAL_BLOCK, LOOP_BLOCK, SWITCH_BLOCK, BRANCH_BLOCK, LOCK_BLOCK
};

template<typename TREE> class SIASTreeNodeItem : public SIAItem
{
	TREE * pt;
public:
	SIASTreeNodeItem(const _TCHAR * const la) : SIAItem(la)
	{
		pt = NULL;
	}
	TREE * get()
	{
		return pt;
	}
	TREE * set(TREE * const & x)
	{
		return pt = x;
	}
};

class SIASDLLItem : public SIAItem
{
	HINSTANCE hin;
public:
	SIASDLLItem(const _TCHAR * const la) : SIAItem(la)
	{
		hin = LoadLibrary(la);
	}
	~SIASDLLItem()
	{
		FreeLibrary(hin);
	}
	FARPROC getfunc(const _TCHAR * const fn)
	{
		int i, l;
		char * s;
		FARPROC fpro;
		l = lstrlen(fn);
		s = new char[l+1];
		for(i = 0; i < l; i++) s[i] = (char)fn[i];
		s[i] = '\0';
		fpro = GetProcAddress(hin, s);
		delete [] s;
		return fpro;
	}
};

struct SwitchExtStruct
{
	int32_t swtype;
	bool teeburutukutta;
	intptr_t def;
	PWCArray<intptr_t> defbp;
	PWCArray<int64_t> atai;
	PWCArray<intptr_t> ataibp;
	PWCArray<intptr_t> tgnsuruusakibp;
	SwitchExtStruct()
	{
		teeburutukutta = false;
		def = 0;
	}
};

struct BranchExtStruct
{
	int mode;
	bool commnai;
	intptr_t nextcond;
	int32_t dino;
	PWCArrayQuad< PWCArray<wchar_t> > label;
	PWCArray<intptr_t> labelbp;
	PWCArray<bool> labelbpflg;
	PWCArray<intptr_t> tgnelsesakibp;
	PWCArray<intptr_t> tgncommsakibp;
	BranchExtStruct()
	{
		mode = 0;
		nextcond = 0;
		dino = 0;
		commnai = false;
	}
	bool addlabel(const wchar_t * const str, const int len)
	{
		int i;
		label[label.GetLength()].Clear();
		label.GetData()[label.GetLength()-1].AddTail(str, len);
		for(i = 0; i < label.GetLength()-1; i++){
			if(label.GetConst()[label.GetLength()-1] == label.GetConst()[i]){
				label.SetLength(label.GetLength()-1);
				return false;
			}
		}
		return true;
	}
	int32_t findlabel(const wchar_t * const str, const int len)
	{
		int32_t i;
		PWCArray<wchar_t> tmp;
		tmp.AddTail(str, len);
		for(i = 0; i < label.GetLength(); i++){
			if(tmp == label.GetConst()[i]) return i;
		}
		return -1;
	}
};

struct LoopExtStruct
{
	int mode;
	intptr_t doad;
	PWCArray<intptr_t> doadbp;
	intptr_t contad;
	PWCArray<intptr_t> contadbp;
	intptr_t nextad;
	PWCArray<intptr_t> nextadbp;
	LoopExtStruct()
	{
		mode = 0;
		doad = contad = nextad = 0;
	}
};

template<typename FTree> class Functions
{
	int32_t totalid;
	PWCArray<FTree *> functree;
public:
	Functions()
	{
		totalid = 0;
	}
	void Clear()
	{
		totalid = 0;
	}
	int32_t Add(FTree * const tree)
	{
		int32_t id;
		functree.SetLength(totalid);
		functree += tree;
		id = totalid++;
		return id;
	}
	FTree * Get(const int32_t id)
	{
		return functree.GetConst()[id];
	}
};

template<typename FTree> struct Hensuu
{
	PWCArray<intptr_t> type;
	intptr_t size;
	FTree * tree;
	int no;
	Hensuu & operator = (const Hensuu & x)
	{
		type = x.type;
		size = x.size;
		tree = x.tree;
		no = x.no;
		return *this;
	}
};

struct SourceTree
{
	static Functions<SourceTree> funclist;
	static StrIdxArray< SIASTreeNodeItem<SourceTree> > srclist;
	static StrIdxArray<SIASDLLItem> dlllist;
	static PWCArrayQuad< PWCArray<int8_t> > literallist;
	static intptr_t literaltotal;
	static bool tokubetuerr;
	PWCArray<wchar_t> myname;
	Source * srce;
	SourceTree * subsrc;
	SourceTree * root;
	int32_t funcid;
	bool kakutei;
	BlockType selftype;
	bool glbconstant;
	bool touka;
	SourceTree * parent;
	SourceTree * frp;
	PWCArray<intptr_t> rettype;
	int hikisuucount;
	int tpcount;
	int topsrcidx;
	int topsrcgyo;
	int gblhani;
	int mbrhani;
	PWCArray< Hensuu<SourceTree> > funchensuu;
	PWCArrayQuad< PWCArray<wchar_t> > hensuname;
	PWCArray<int> hensuidx;
	int breaknaihani;
	PWCArray<SourceTree *> children;
	PWCArray<SourceTree *> subfunc;
	PWCArrayQuad< PWCArray<intptr_t> > token;
	PWCArray<intptr_t> gyo;
	PWCArray<intptr_t> defdel;
	intptr_t golbalgetahoka;
	intptr_t byteadress;
	PWCArray<intptr_t> backpatch;
	PWCArray<intptr_t> breakpatch;
	bool returnshita;
	bool teigikinshi;
	bool breakin;
	bool breakinnest;
	SwitchExtStruct * extswitch;
	BranchExtStruct * extbranch;
	LoopExtStruct * extloop;
	SourceTree(const PWCArray<wchar_t> * const name = NULL, SourceTree * const p = NULL, const bool fukakutei = false)
	{
		FlgReset();
		parent = p;
		subsrc = NULL;
		extswitch = NULL;
		extbranch = NULL;
		extloop = NULL;
		if(parent != NULL){////////////////////////////////////////////////////
			selftype = UNKNOWN_BLOCK;
			root = parent->root;
			glbconstant = parent->glbconstant;
			if(name != NULL){
				breakinnest = false;
				kakutei = !fukakutei;
				funcid = funclist.Add(this);
				frp = this;
				myname = *name;
				parent->frp->subfunc += this;
			}else{
				breakinnest = parent->breakinnest;
				kakutei = true;
				frp = parent->frp;
			}
		}else{
			selftype = FUNC_BLOCK;
			root = this;
			glbconstant = false;
			breakinnest = false;
			kakutei = true;
			funcid = funclist.Add(this);
			frp = this;
			rettype = VOID_TOKEN;
		}
		if(root == this){
			srce = new Source;
		}else{
			srce = root->srce;
		}
	}
	~SourceTree()
	{
		if(root == this) delete srce;
		Del();
	}
	void Del()
	{
		int i;
		delete subsrc;
		subsrc = NULL;
		for(i=0; i < children.GetLength(); i++) delete children.GetConst()[i];
		children.Clear();
		delete extswitch;
		extswitch = NULL;
		delete extbranch;
		extbranch = NULL;
		delete extloop;
		extloop = NULL;
	}
	bool AruNashi(const PWCArray<wchar_t> & name)
	{
		int i;
		for(i=0; i < hensuname.GetLength(); i++){
			if(name == hensuname.GetConst()[i]) return true;
		}
		for(i=0; i < frp->subfunc.GetLength(); i++){
			if(name == frp->subfunc.GetConst()[i]->myname) return true;
		}
		return false;
	}
	bool AddHensuu(const PWCArray<intptr_t> & type, const PWCArray<wchar_t> & name, const intptr_t size)
	{
		if(L'0' <= name.GetConst()[0] && name.GetConst()[0] <= L'9') return false;
		if(name.GetLength() >= 2 && name.GetConst()[name.GetLength()-2] == L'_' && name.GetConst()[name.GetLength()-1] == L't'){
			if(type.GetConst()[0] != TYPE_TOKEN) return false;
		}else{
			if(type.GetConst()[0] == TYPE_TOKEN) return false;
		}
		if(AruNashi(name)) return false;
		frp->funchensuu[frp->funchensuu.GetLength()].tree = this;
		frp->funchensuu.GetData()[frp->funchensuu.GetLength()-1].type = type;
		frp->funchensuu.GetData()[frp->funchensuu.GetLength()-1].size = size;
		frp->funchensuu.GetData()[frp->funchensuu.GetLength()-1].no = hensuname.GetLength();
		hensuname += name;
		hensuidx += frp->funchensuu.GetLength()-1;
		return true;
	}
	SourceTree * AddChild(const PWCArray<wchar_t> * const name, const bool fukakutei)
	{
		int i;
		if(name != NULL){
			if(L'0' <= name->GetConst()[0] && name->GetConst()[0] <= L'9') return false;
			if(name->GetLength() >= 2 && name->GetConst()[name->GetLength()-2] == L'_' && name->GetConst()[name->GetLength()-1] == L't') return false;
			if(fukakutei){
				for(i=0; i < hensuname.GetLength(); i++){
					if(*name == hensuname.GetConst()[i]) return NULL;
				}
				for(i=0; i < frp->subfunc.GetLength(); i++){
					if(*name == frp->subfunc.GetConst()[i]->myname) return frp->subfunc.GetConst()[i];
				}
			}else{
				if(AruNashi(*name)) return NULL;
			}
		}
		children += new SourceTree(name, this, fukakutei);
		return children.GetConst()[children.GetLength()-1];
	}
	bool ZeroHajimari(uint64_t & ui64, const wchar_t * const tstr, const int tlen)
	{
		int i;
		if(tlen <= 1) return false;
		ui64 = 0;
		switch(tstr[0]){
		case L'b':
			for(i = 1; i < tlen; i++){
				if(tstr[i] == L'0' || tstr[i] == L'1'){
					ui64 *= 2;
					ui64 += tstr[i] - L'0';
				}else{
					return false;
				}
			}
			break;
		case L'd':
			for(i = 1; i < tlen; i++){
				if(L'0' <= tstr[i] && tstr[i] <= L'9'){
					ui64 *= 10;
					ui64 += tstr[i] - L'0';
				}else{
					return false;
				}
			}
			break;
		case L'o':
			for(i = 1; i < tlen; i++){
				if(L'0' <= tstr[i] && tstr[i] <= L'7'){
					ui64 *= 8;
					ui64 += tstr[i] - L'0';
				}else{
					return false;
				}
			}
			break;
		case L'x':
			for(i = 1; i < tlen; i++){
				if(L'0' <= tstr[i] && tstr[i] <= L'9'){
					ui64 *= 16;
					ui64 += tstr[i] - L'0';
				}else if(L'A' <= tstr[i] && tstr[i] <= L'F'){
					ui64 *= 16;
					ui64 += tstr[i] - L'A' + 10;
				}else if(L'a' <= tstr[i] && tstr[i] <= L'f'){
					ui64 *= 16;
					ui64 += tstr[i] - L'a' + 10;
				}else{
					return false;
				}
			}
			break;
		default:
			return false;
		}
		return true;
	}
	bool Suuji(PWCArray<intptr_t> & tk, Source & src, const int t)
	{
		int j, k;
		uint64_t ui64;
		double baisei;
		ui64 = 0;
		if(src.source.GetConst()[t] == L'0'){
			if(src.idx - t == 1){
			}else if(ZeroHajimari(ui64, src.source.GetConst()+t+1, src.idx-t-1)){
				tk += CONST_TOKEN;
				tk += ULONG_TOKEN;
				tk.SetLength(tk.GetLength()+(sizeof(uint64_t)+sizeof(intptr_t)-1)/sizeof(intptr_t));
				*(uint64_t *)(tk.GetConst()+tk.GetLength()-(sizeof(uint64_t)+sizeof(intptr_t)-1)/sizeof(intptr_t)) = ui64;
				return true;
			}else{
				ErrorMessage.Add(src.filename, src.gyousuu, L"Ŏn܂鎯ʎq͎g܂B");
				return false;
			}
		}else{
			for(j = t; j < src.idx; j++){
				if(L'0' <= src.source.GetConst()[j] && src.source.GetConst()[j] <= L'9'){
					ui64 *= 10;
					ui64 += src.source.GetConst()[j] - L'0';
				}else{
					ErrorMessage.Add(src.filename, src.gyousuu, L"Ŏn܂鎯ʎq͎g܂B");
					return false;
				}
			}
		}
		if(
			src.idx >= src.source.GetLength() || src.source.GetConst()[src.idx] != L'.'
			|| (src.idx+1 < src.source.GetLength() && src.source.GetConst()[src.idx+1] == L'.'))
		{
			tk += CONST_TOKEN;
			tk += LONG_TOKEN;
			tk.SetLength(tk.GetLength()+(sizeof(int64_t)+sizeof(intptr_t)-1)/sizeof(intptr_t));
			*(int64_t *)(tk.GetConst()+tk.GetLength()-(sizeof(int64_t)+sizeof(intptr_t)-1)/sizeof(intptr_t)) = (int64_t)ui64;
			return true;
		}
		src.idx++;
		j = src.idx;
		if(!src.GetNumString()){
			ErrorMessage.Add(src.filename, src.gyousuu, L"_̌ '0' KvłB");
			return false;
		}
		baisei = 0.0;
		for(k = 1; k <= src.idx-j; k++){
			baisei += (double)(src.source.GetConst()[src.idx-k] - L'0');
			baisei /= 10.0;
		}
		baisei += (double)ui64;
		if(src.idx >= src.source.GetLength() || (src.source.GetConst()[src.idx] != L'E' && src.source.GetConst()[src.idx] != L'e')){
			if(src.IsTSChar(src.source.GetConst()[src.idx])){
				ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
				return false;
			}
			tk += CONST_TOKEN;
			tk += DOUBLE_TOKEN;
			tk.SetLength(tk.GetLength()+(sizeof(double)+sizeof(intptr_t)-1)/sizeof(intptr_t));
			*(double *)(tk.GetConst()+tk.GetLength()-(sizeof(double)+sizeof(intptr_t)-1)/sizeof(intptr_t)) = baisei;
			return true;
		}
		src.idx++;
		if(src.idx >= src.source.GetLength()){
			ErrorMessage.Add(src.filename, src.gyousuu, L"sȈʒuŃt@CI[ɒB܂B");
			return false;
		}
		if(src.source.GetConst()[src.idx] == L'-'){
			src.idx++;
			j = src.idx;
			if(!src.GetTString()){
				ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
				return false;
			}
			k = 0;
			for(; j < src.idx; j++){
				if(L'0' <= src.source.GetConst()[j] && src.source.GetConst()[j] <= L'9'){
					k *= 10;
					k += src.source.GetConst()[j] - L'0';
				}else{
					ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
					return false;
				}
			}
			baisei *= pow(10.0, -(double)k);
		}else{
			if(src.source.GetConst()[src.idx] == L'+') src.idx++;
			j = src.idx;
			if(!src.GetTString()){
				ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
				return false;
			}
			k = 0;
			for(; j < src.idx; j++){
				if(L'0' <= src.source.GetConst()[j] && src.source.GetConst()[j] <= L'9'){
					k *= 10;
					k += src.source.GetConst()[j] - L'0';
				}else{
					ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
					return false;
				}
			}
			baisei *= pow(10.0, (double)k);
		}
		tk += CONST_TOKEN;
		tk += DOUBLE_TOKEN;
		tk.SetLength(tk.GetLength()+(sizeof(double)+sizeof(intptr_t)-1)/sizeof(intptr_t));
		*(double *)(tk.GetConst()+tk.GetLength()-(sizeof(double)+sizeof(intptr_t)-1)/sizeof(intptr_t)) = baisei;
		return true;
	}
	SourceTree * BlockOpen(const PWCArray<wchar_t> * const name, const BlockType type)
	{
		SourceTree * pst;
		if(type != FUNC_BLOCK && type != CLASS_BLOCK){
			if((pst = AddChild(name, false)) == NULL) return NULL;
			pst->selftype = type;
			return pst;
		}
		if((pst = AddChild(name, true)) == NULL) return NULL;
		pst->selftype = type;
		return pst;
	}
	bool IsOpen()
	{
		int ii;
		for(ii=0; ii < funchensuu.GetLength(); ii++){
			if(funchensuu.GetConst()[ii].size > 0){
				if(funchensuu.GetConst()[ii].type.GetConst()[0] != PUBLIC_TOKEN) return false;
				if(funchensuu.GetConst()[ii].type.GetConst()[1] == REF_TOKEN) return false;
				if(funchensuu.GetConst()[ii].type.GetConst()[1] == LIST_TOKEN) return false;
				if(funchensuu.GetConst()[ii].type.GetConst()[1] == THREAD_TOKEN) return false;
				if(funchensuu.GetConst()[ii].type.GetConst()[1] == CLASS_TOKEN){
					if(!funclist.Get(funchensuu.GetConst()[ii].type.GetConst()[2])->IsOpen()) return false;
				}
			}
		}
		return true;
	}
	int32_t GetFuncId(const PWCArray<wchar_t> & name, const bool create)
	{
		SourceTree * pst;
		int i;
		for(i=0; i < frp->subfunc.GetLength(); i++){
			if(name == frp->subfunc.GetConst()[i]->myname){
				return frp->subfunc.GetConst()[i]->funcid;
			}
		}
		if(create && (pst = frp->AddChild(&name, true)) != NULL){
			return pst->funcid;
		}
		return -1;
	}
	intptr_t GetMemberSize() const
	{
		int ii;
		intptr_t size;
		size = 0;
		for(ii=0; ii < funchensuu.GetLength(); ii++){
			size += funchensuu.GetConst()[ii].size;
		}
		return size;
	}
	SourceTree *  IjouTansaku(const PWCArray<wchar_t> & name, intptr_t & memberichi)
	{
		SourceTree * pst;
		intptr_t sa;
		int32_t fi;
		int i;
		pst = NULL;
		sa = 0;
		fi = GetFuncId(name, false);
		if(fi >= 0){
			pst = funclist.Get(fi);
			if(pst->selftype != FUNC_BLOCK) return NULL;
			if(!pst->kakutei) pst = NULL;
		}
		if(pst == NULL) for(i = funchensuu.GetLength()-1; i >= 0 ; i--){
			if(funchensuu.GetConst()[i].type.GetConst()[0] == CORE_TOKEN){
				if(pst != NULL) return NULL;
				pst = funclist.Get((int32_t)funchensuu.GetConst()[i].type.GetConst()[2])->IjouTansaku(name, memberichi);
				if(pst != NULL) memberichi -= sa;
			}
			sa += funchensuu.GetConst()[i].size;
		}
		return pst;
	}
	SourceTree * GetIjousaki(intptr_t & memberichi)
	{
		if(parent == NULL || parent->selftype != CLASS_BLOCK || frp != this) return NULL;
		return parent->IjouTansaku(myname, memberichi);
	}
	intptr_t GetTypeSize(const PWCArray<intptr_t> & type) const
	{
		int jj;
		jj = 0;
		if(IsSoushokuToken((TokenKind)type.GetConst()[jj])) jj++;
		switch(type.GetConst()[jj]){
		case BOOL_TOKEN:
			return sizeof(bool);
		case CHAR_TOKEN:
			return sizeof(wchar_t);
		case DOUBLE_TOKEN:
			return sizeof(double);
		case FLOAT_TOKEN:
			return sizeof(float);
		case BYTE_TOKEN:
		case UBYTE_TOKEN:
			return sizeof(int8_t);
		case INT_TOKEN:
		case UINT_TOKEN:
			return sizeof(int32_t);
		case LONG_TOKEN:
		case ULONG_TOKEN:
			return sizeof(int64_t);
		case SHORT_TOKEN:
		case USHORT_TOKEN:
			return sizeof(int16_t);
		case INDEX_TOKEN:
			return sizeof(intptr_t);
		case VOID_TOKEN:
			return 0;
		case REF_TOKEN:
		case LIST_TOKEN:
			return sizeof(Reference);
		case THREAD_TOKEN:
			return sizeof(Thread);
		case ENUM_TOKEN:
			return sizeof(int32_t);
		case FUNC_TOKEN:
		case METHOD_TOKEN:
			return sizeof(intptr_t);
		case CLASS_TOKEN:
			if(!funclist.Get(type.GetConst()[jj+1])->kakutei) return -1;
			return funclist.Get(type.GetConst()[jj+1])->GetMemberSize();
		}
		return -1;
	}
	int32_t GetTypeId(const PWCArray<intptr_t> & type) const
	{
		int i;
		if(type.GetConst()[0] == NULL){
			return (int32_t)type.GetConst()[1];
		}
		return TokenTtoTypeId(type.GetConst(), i=0);
	}
	void GblhaniSet(const SourceTree & hkishiki)
	{
		if(gblhani == INT_MAX){
			if(root != hkishiki.root){
				gblhani = INT_MAX-1;
			}else if(hkishiki.gblhani != INT_MAX){
				gblhani = hkishiki.gblhani;
			}else{
				gblhani = root->hensuidx.GetLength();
			}
		}
	}
	void FuncTypeGet(PWCArray<intptr_t> & type, bool cont, const SourceTree & hkishiki)
	{
		int ii;
		GblhaniSet(hkishiki);
		if(mbrhani == INT_MAX) mbrhani = parent->hensuidx.GetLength();
		ii = 0;
		if(rettype[ii] == PUBLIC_TOKEN) ii++;
		type.AddTail(rettype.GetConst()+ii, rettype.GetLength()-ii);
		type += KAKKOCOLOOPEN_TOKEN;
		if(hikisuucount > 0){
			for(ii = tpcount; ii < tpcount+hikisuucount; ii++){
				type += funchensuu.GetConst()[ii].type;
				type += COMMA_TOKEN;
			}
			type.GetData()[type.GetLength()-1] = KAKKOCOLOCLOSE_TOKEN;
		}else{
			type += KAKKOCOLOCLOSE_TOKEN;
		}
		if(cont) type += funcid;
	}
	template<typename TYPE> void TankouConst(const TokenKind to, TYPE & x)
	{
		switch(to){
		case PULUS_TOKEN:
			break;
		case MINUS_TOKEN:
			x *= -1;
			break;
		case EXCLAMATION_TOKEN:
			x = ~x;
			break;
		}
	}
	template<typename TYPE> void TankouConstReal(const TokenKind to, TYPE & x)
	{
		switch(to){
		case PULUS_TOKEN:
			break;
		case MINUS_TOKEN:
			x *= -1;
			break;
		}
	}
	template<typename TYPE> bool ConstCast(PWCArray<intptr_t> & last, TYPE & x)
	{
		int tmpi;
		tmpi = 0;
		if(last.GetConst()[tmpi] != CONST_TOKEN) return false;
		tmpi++;
		switch(last.GetConst()[tmpi++]){
		case BYTE_TOKEN:
			x = (TYPE)*(int8_t *)(last.GetConst()+tmpi);
			break;
		case SHORT_TOKEN:
			x = (TYPE)*(int16_t *)(last.GetConst()+tmpi);
			break;
		case INT_TOKEN:
			x = (TYPE)*(int32_t *)(last.GetConst()+tmpi);
			break;
		case LONG_TOKEN:
			x = (TYPE)*(int64_t *)(last.GetConst()+tmpi);
			break;
		case UBYTE_TOKEN:
			x = (TYPE)*(uint8_t *)(last.GetConst()+tmpi);
			break;
		case USHORT_TOKEN:
			x = (TYPE)*(uint16_t *)(last.GetConst()+tmpi);
			break;
		case UINT_TOKEN:
			x = (TYPE)*(uint32_t *)(last.GetConst()+tmpi);
			break;
		case ULONG_TOKEN:
			x = (TYPE)*(uint64_t *)(last.GetConst()+tmpi);
			break;
		case INDEX_TOKEN:
			x = (TYPE)*(intptr_t *)(last.GetConst()+tmpi);
			break;
		case FLOAT_TOKEN:
			x = (TYPE)*(float *)(last.GetConst()+tmpi);
			break;
		case DOUBLE_TOKEN:
			x = (TYPE)*(double *)(last.GetConst()+tmpi);
			break;
		case CHAR_TOKEN:
			x = (TYPE)*(wchar_t *)(last.GetConst()+tmpi);
			break;
		case BOOL_TOKEN:
			x = (TYPE)*(bool *)(last.GetConst()+tmpi);
			break;
		case ENUM_TOKEN:
			x = (TYPE)*(int32_t *)(last.GetConst()+tmpi+1);
			break;
		default:
			return false;
		}
		return true;
	}
	bool ConstCaster(PWCArray<intptr_t> & last, const PWCArray<intptr_t> & type)
	{
		int tmpi, tmpii;
		intptr_t pmpip;
		union{
			int8_t _byte; int16_t _short; int32_t _int; int64_t _long;
			uint8_t _ubyte; uint16_t _ushort; uint32_t _uint; uint64_t _ulong;
			float _float; double _double;
			intptr_t _index;
			wchar_t _char;
			bool _bool;
		} x;
		tmpi = 0;
		if(type.GetConst()[tmpi] != CONST_TOKEN) return false;
		tmpi++;
		switch(type.GetConst()[tmpi++]){
		case BYTE_TOKEN:
			if(!ConstCast(last, x._byte)) return false;
			last = type;
			last.SetLength(tmpi+(sizeof(int8_t)+sizeof(intptr_t)-1)/sizeof(intptr_t));
			*(int8_t *)(last.GetConst()+last.GetLength()-(sizeof(int8_t)+sizeof(intptr_t)-1)/sizeof(intptr_t)) = x._byte;
			break;
		case SHORT_TOKEN:
			if(!ConstCast(last, x._short)) return false;
			last = type;
			last.SetLength(tmpi+(sizeof(int16_t)+sizeof(intptr_t)-1)/sizeof(intptr_t));
			*(int16_t *)(last.GetConst()+last.GetLength()-(sizeof(int16_t)+sizeof(intptr_t)-1)/sizeof(intptr_t)) = x._short;
			break;
		case INT_TOKEN:
			if(!ConstCast(last, x._int)) return false;
			last = type;
			last.SetLength(tmpi+(sizeof(int32_t)+sizeof(intptr_t)-1)/sizeof(intptr_t));
			*(int32_t *)(last.GetConst()+last.GetLength()-(sizeof(int32_t)+sizeof(intptr_t)-1)/sizeof(intptr_t)) = x._int;
			break;
		case LONG_TOKEN:
			if(!ConstCast(last, x._long)) return false;
			last = type;
			last.SetLength(tmpi+(sizeof(int64_t)+sizeof(intptr_t)-1)/sizeof(intptr_t));
			*(int64_t *)(last.GetConst()+last.GetLength()-(sizeof(int64_t)+sizeof(intptr_t)-1)/sizeof(intptr_t)) = x._long;
			break;
		case UBYTE_TOKEN:
			if(!ConstCast(last, x._ubyte)) return false;
			last = type;
			last.SetLength(tmpi+(sizeof(uint8_t)+sizeof(intptr_t)-1)/sizeof(intptr_t));
			*(uint8_t *)(last.GetConst()+last.GetLength()-(sizeof(uint8_t)+sizeof(intptr_t)-1)/sizeof(intptr_t)) = x._ubyte;
			break;
		case USHORT_TOKEN:
			if(!ConstCast(last, x._ushort)) return false;
			last = type;
			last.SetLength(tmpi+(sizeof(uint16_t)+sizeof(intptr_t)-1)/sizeof(intptr_t));
			*(uint16_t *)(last.GetConst()+last.GetLength()-(sizeof(uint16_t)+sizeof(intptr_t)-1)/sizeof(intptr_t)) = x._ushort;
			break;
		case UINT_TOKEN:
			if(!ConstCast(last, x._uint)) return false;
			last = type;
			last.SetLength(tmpi+(sizeof(uint32_t)+sizeof(intptr_t)-1)/sizeof(intptr_t));
			*(uint32_t *)(last.GetConst()+last.GetLength()-(sizeof(uint32_t)+sizeof(intptr_t)-1)/sizeof(intptr_t)) = x._uint;
			break;
		case ULONG_TOKEN:
			if(!ConstCast(last, x._ulong)) return false;
			last = type;
			last.SetLength(tmpi+(sizeof(uint64_t)+sizeof(intptr_t)-1)/sizeof(intptr_t));
			*(uint64_t *)(last.GetConst()+last.GetLength()-(sizeof(uint64_t)+sizeof(intptr_t)-1)/sizeof(intptr_t)) = x._ulong;
			break;
		case INDEX_TOKEN:
			if(!ConstCast(last, x._index)) return false;
			last = type;
			last.SetLength(tmpi+(sizeof(intptr_t)+sizeof(intptr_t)-1)/sizeof(intptr_t));
			*(intptr_t *)(last.GetConst()+last.GetLength()-(sizeof(intptr_t)+sizeof(intptr_t)-1)/sizeof(intptr_t)) = x._index;
			break;
		case FLOAT_TOKEN:
			if(!ConstCast(last, x._float)) return false;
			last = type;
			last.SetLength(tmpi+(sizeof(float)+sizeof(intptr_t)-1)/sizeof(intptr_t));
			*(float *)(last.GetConst()+last.GetLength()-(sizeof(float)+sizeof(intptr_t)-1)/sizeof(intptr_t)) = x._float;
			break;
		case DOUBLE_TOKEN:
			if(!ConstCast(last, x._double)) return false;
			last = type;
			last.SetLength(tmpi+(sizeof(double)+sizeof(intptr_t)-1)/sizeof(intptr_t));
			*(double *)(last.GetConst()+last.GetLength()-(sizeof(double)+sizeof(intptr_t)-1)/sizeof(intptr_t)) = x._double;
			break;
		case CHAR_TOKEN:
			if(!ConstCast(last, x._char)) return false;
			last = type;
			last.SetLength(tmpi+(sizeof(wchar_t)+sizeof(intptr_t)-1)/sizeof(intptr_t));
			*(wchar_t *)(last.GetConst()+last.GetLength()-(sizeof(wchar_t)+sizeof(intptr_t)-1)/sizeof(intptr_t)) = x._char;
			break;
		case BOOL_TOKEN:
		case ENUM_TOKEN:
		case REF_TOKEN:
			if(last.GetLength()-1 > type.GetLength()) return false;
			for(tmpi = 0; tmpi < last.GetLength()-1; tmpi++){
				if(last.GetConst()[tmpi] != type.GetConst()[tmpi]) return false;
			}
			break;
		case METHOD_TOKEN:
			if(last.GetConst()[tmpi] != type.GetConst()[tmpi]) return false;
			tmpi++;
		case FUNC_TOKEN:
			if(type.GetConst()[tmpi] == CONST_TOKEN){
				if(last.GetConst()[tmpi] != CONST_TOKEN) return false;
				tmpi++;
			}else if(type.GetConst()[tmpi] == PROPERTY_TOKEN){
				if(!IsReadOnlyToken((TokenKind)last.GetConst()[tmpi])) return false;
				tmpi++;
			}
			if(IsReadOnlyToken((TokenKind)last.GetConst()[tmpi])){
				tmpii = 1;
			}else{
				tmpii = 0;
			}
			if(last.GetLength()-tmpii-1 > type.GetLength()) return false;
			for(tmpi += tmpii; tmpi < last.GetLength()-1; tmpi++){
				if(last.GetConst()[tmpi] != type.GetConst()[tmpi-tmpii]) return false;
			}
			if(tmpii > 0){
				pmpip = last.GetConst()[last.GetLength()-1];
				last.Clear();
				last.AddTail(type.GetConst(), tmpi-tmpii);
				last += pmpip;
			}
			break;
		default:
			return false;
		}
		return true;
	}
	bool ConstNanikaPath(Source & src, PWCArray<intptr_t> & last, SourceTree & hkishiki)
	{
		int32_t tyki;
		PWCArray<wchar_t> name,tmp;
		Hensuu<SourceTree> * phs;
		int t, ii;
		if((tyki = PathtoClassID(src, FUNC_BLOCK, true, false, hkishiki)) < 0) return false;
		switch(funclist.Get(tyki)->selftype){
		case FUNC_BLOCK:
			if(funclist.Get(tyki) != funclist.Get(tyki)->root){
				if(!funclist.Get(tyki)->kakutei){
					ErrorMessage.Add(src.filename, src.gyousuu, L"m肵ĂȂ̂Ŋ֐|C^ł܂B");
					return false;
				}
				if(funclist.Get(tyki)->parent == funclist.Get(tyki)->root){
					last = CONST_TOKEN;
					last += FUNC_TOKEN;
					funclist.Get(tyki)->FuncTypeGet(last, true, hkishiki);
				}else if(funclist.Get(tyki)->parent->selftype == CLASS_BLOCK){
					last = CONST_TOKEN;
					last += METHOD_TOKEN;
					last += funclist.Get(tyki)->parent->funcid;
					funclist.Get(tyki)->FuncTypeGet(last, true, hkishiki);
				}else{
					ErrorMessage.Add(src.filename, src.gyousuu, L"֐֐͊֐|C^ł܂B");
					return false;
				}
				break;
			}
		case CLASS_BLOCK:
			src.GetToken(t);
			src.GetToken(t);
			name.Clear();
			name.AddTail(src.source.GetConst()+t, src.idx-t);
			if((phs = funclist.Get(tyki)->GetHensuu(name, ii, true)) == NULL){
				tmp = L'\'';
				tmp += name;
				tmp += L"' o萔Ɍ܂B";
				tmp += L'\0';
				ErrorMessage.Add(src.filename, src.gyousuu, tmp.GetConst());
				return false;
			}
			last = phs->type;
			break;
		case ENUM_BLOCK:
			src.GetToken(t);
			if(src.GetToken(t) != OTHERKIND_TOKEN){
				ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
				return false;
			}
			name.Clear();
			name.AddTail(src.source.GetConst()+t, src.idx-t);
			if((phs = funclist.Get(tyki)->GetHensuu(name, ii, true)) == NULL){
				tmp = L'\'';
				tmp += name;
				tmp += L"' ܂B";
				tmp += L'\0';
				ErrorMessage.Add(src.filename, src.gyousuu, tmp.GetConst());
				return false;
			}
			last = phs->type;
			break;
		default:
			ErrorMessage.Add(src.filename, src.gyousuu, L"G[łB");
			return false;
		}
		return true;
	}
	bool Literal(Source & src, const PWCArray<intptr_t> & type, PWCArray<intptr_t> & tk, SourceTree & hkishiki)
	{
		int t;
		PWCArray<int8_t> * plit;
		PWCArray<intptr_t> last;
		TokenKind kin;
		plit = &literallist[literallist.GetLength()];
		plit->SetLength(sizeof(Reference)+sizeof(HeapObjHead));
		kin = src.GetToken(t);
		while(true){
			hkishiki.ConstShiki(src, t, NULL_TOKEN, kin, last, DAIKAKKOCLOSE_TOKEN, hkishiki);
			if(!ConstCaster(last, type)){
				ErrorMessage.Add(src.filename, src.gyousuu, L"^G[łB");
				return false;
			}
			plit->AddTail((int8_t *)(last.GetData()+2), GetTypeSize(last));
			if(src.source.GetConst()[t] == L','){
				kin = src.GetToken(t);
			}else{
				break;
			}
		}
		((Reference *)plit->GetData())->position = 0;
		((Reference *)plit->GetData())->length = plit->GetLength() - (sizeof(Reference)+sizeof(HeapObjHead));
		((HeapObjHead *)(plit->GetData()+sizeof(Reference)))->refcount = 1;
		((HeapObjHead *)(plit->GetData()+sizeof(Reference)))->mutex = NULL;
		((HeapObjHead *)(plit->GetData()+sizeof(Reference)))->datasize = plit->GetLength() - (sizeof(Reference)+sizeof(HeapObjHead));
		tk += CONST_TOKEN;
		tk += REF_TOKEN;
		tk += type;
		tk += literaltotal;
		literaltotal += plit->GetLength();
		return true;
	}
	bool ConstMojiretsu(const PWCArray<wchar_t> & str, PWCArray<intptr_t> & tk)
	{
		PWCArray<int8_t> * plit;
		plit = &literallist[literallist.GetLength()];
		plit->SetLength(sizeof(Reference)+sizeof(HeapObjHead));
		plit->AddTail((int8_t *)str.GetConst(), str.GetLength()*sizeof(wchar_t));
		((Reference *)plit->GetData())->position = 0;
		((Reference *)plit->GetData())->length = plit->GetLength() - (sizeof(Reference)+sizeof(HeapObjHead));
		((HeapObjHead *)(plit->GetData()+sizeof(Reference)))->refcount = 1;
		((HeapObjHead *)(plit->GetData()+sizeof(Reference)))->mutex = NULL;
		((HeapObjHead *)(plit->GetData()+sizeof(Reference)))->datasize = plit->GetLength() - (sizeof(Reference)+sizeof(HeapObjHead));
		tk += CONST_TOKEN;
		tk += REF_TOKEN;
		tk += CONST_TOKEN;
		tk += CHAR_TOKEN;
		tk += literaltotal;
		literaltotal += plit->GetLength();
		return true;
	}
	bool ConstNanika(Source & src, int & t, const TokenKind kin, PWCArray<intptr_t> & last, SourceTree & hkishiki)
	{
		Hensuu<SourceTree> * phs;
		PWCArray<wchar_t> name, tmp;
		PWCArray<intptr_t> type;
		TokenKind ki;
		wchar_t wc;
		int oi, ot, ogy, ii;
		int32_t fi;
		intptr_t tmpi, size;
		switch(kin){
		case MBR_TOKEN:
			if(frp == root || frp->parent == root || frp->selftype == CLASS_BLOCK){
				ErrorMessage.Add(src.filename, src.gyousuu, L"mbr͎g܂B");
				return false;
			}
			switch(src.GetToken(t)){
			case POINT_TOKEN:
				if(src.GetToken(t) != OTHERKIND_TOKEN){
					ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
					return false;
				}
				if(L'0' <= src.source.GetConst()[t] && src.source.GetConst()[t] <= L'9'){
					ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
					return false;
				}
				if(!frp->parent->ConstNanika(src, t, OTHERKIND_TOKEN, last, hkishiki)) return false;
				break;
			default:
				ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
				return false;
			}
			return true;
		case GBL_TOKEN:
			switch(src.GetToken(t)){
			case POINT_TOKEN:
				if(src.GetToken(t) != OTHERKIND_TOKEN){
					ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
					return false;
				}
				if(L'0' <= src.source.GetConst()[t] && src.source.GetConst()[t] <= L'9'){
					ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
					return false;
				}
				if(!root->ConstNanika(src, t, OTHERKIND_TOKEN, last, hkishiki)) return false;
				break;
			default:
				ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
				return false;
			}
			return true;
		case COLOCOLO_TOKEN:
		case TENTEN_TOKEN:
			src.idx = t;
			return ConstNanikaPath(src, last, hkishiki);
		case OTHERKIND_TOKEN:
			if(L'0' <= src.source.GetConst()[t] && src.source.GetConst()[t] <= L'9'){
				last.Clear();
				if(!Suuji(last, src, t)) return false;
			}else{
				name.Clear();
				name.AddTail(src.source.GetConst()+t, src.idx-t);
				oi = src.idx;
				ot = t;
				ogy = src.gyousuu;
				switch(src.GetToken(t)){
				case SHOUKAKKOOPEN_TOKEN:
				case BRACOLOOPEN_TOKEN:
				case COLOYAJIRUSHI_TOKEN:
				case COLOCOLO_TOKEN:
					src.idx = ot;
					src.gyousuu = ogy;
					if(!ConstNanikaPath(src, last, hkishiki)) return false;
					break;
				default:
					src.idx = oi;
					t = ot;
					src.gyousuu = ogy;
					if((phs = GetHensuu(name, ii, false)) == NULL){
						if((fi = GetFuncId(name, false)) < 0 ){
							tmp = L'\'';
							tmp += name;
							tmp += L"' ͒`Ă܂B";
							tmp += L'\0';
							ErrorMessage.Add(src.filename, src.gyousuu, tmp.GetConst());
							return false;
						}else if(funclist.Get(fi)->selftype != FUNC_BLOCK){
							tmp = L'\'';
							tmp += name;
							tmp += L"' class܂enumłB";
							tmp += L'\0';
							ErrorMessage.Add(src.filename, src.gyousuu, tmp.GetConst());
							return false;
						}else if(!funclist.Get(fi)->kakutei){
							tmp = L'\'';
							tmp += name;
							tmp += L"' ͊m肵ĂȂߊ֐|C^ł܂B";
							tmp += L'\0';
							ErrorMessage.Add(src.filename, src.gyousuu, tmp.GetConst());
							return false;
						}
						if(funclist.Get(fi)->parent == funclist.Get(fi)->root){
							last = CONST_TOKEN;
							last += FUNC_TOKEN;
							funclist.Get(fi)->FuncTypeGet(last, true, hkishiki);
						}else if(funclist.Get(fi)->parent->selftype == CLASS_BLOCK){
							last = CONST_TOKEN;
							last += METHOD_TOKEN;
							last += funclist.Get(fi)->parent->funcid;
							funclist.Get(fi)->FuncTypeGet(last, true, hkishiki);
						}else{
							ErrorMessage.Add(src.filename, src.gyousuu, L"֐֐͊֐|C^ł܂B");
							return false;
						}
						break;
					}
					switch(phs->type.GetConst()[0]){
					case LIB_TOKEN:
						if(src.GetToken(t) != POINT_TOKEN){
							ErrorMessage.Add(src.filename, src.gyousuu, L"lib^͒l܂B");
							return false;
						}
						if(src.GetToken(t) != OTHERKIND_TOKEN){
							ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
							return false;
						}
						if(L'0' <= src.source.GetConst()[t] && src.source.GetConst()[t] <= L'9'){
							ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
							return false;
						}
						if(!((SourceTree *)phs->type.GetConst()[1])->ConstNanika(src, t, OTHERKIND_TOKEN, last, hkishiki)) return false;
						break;
					case CONST_TOKEN:
						last = phs->type;
						break;
					default:
						ErrorMessage.Add(src.filename, src.gyousuu, L"萔ɒ萔ȊOgƂĂ܂B");
						return false;
					}
					break;
				}
			}
			return true;
		case DQUOT_TOKEN:
		case BACKSLA_TOKEN:
			name.Clear();
			src.idx = t;
			if(!MjiretuLiteral(name, src)) return false;
			last.Clear();
			if(!ConstMojiretsu(name, last)) return false;
			return true;
		case SQUOT_TOKEN:
			last = CONST_TOKEN;
			last += CHAR_TOKEN;
			if(!Moji(wc, src)) return false;
			last += wc;
			return true;
		case FALSE_TOKEN:
			last = CONST_TOKEN;
			last += BOOL_TOKEN;
			last += (intptr_t)false;
			return true;
		case TRUE_TOKEN:
			last = CONST_TOKEN;
			last += BOOL_TOKEN;
			last += (intptr_t)true;
			return true;
		case SIZEOF_TOKEN:
			if(src.GetToken(t) != SHOUKAKKOOPEN_TOKEN){
				ErrorMessage.Add(src.filename, src.gyousuu, L"'(' ܂B");
				return false;
			}
			type.Clear();
			if(!TypeNanika(type, src, false, false, hkishiki)) return false;
			if(src.GetToken(t) != SHOUKAKKOCLOSE_TOKEN){
				ErrorMessage.Add(src.filename, src.gyousuu, L"')' ܂B");
				return false;
			}
			if((size = GetTypeSize(type)) < 0){
				ErrorMessage.Add(src.filename, src.gyousuu, L"TCY߂܂B");
				return false;
			}
			last = CONST_TOKEN;
			last += INDEX_TOKEN;
			last.SetLength(last.GetLength()+(sizeof(intptr_t)+sizeof(intptr_t)-1)/sizeof(intptr_t));
			*(intptr_t *)(last.GetConst()+last.GetLength()-(sizeof(intptr_t)+sizeof(intptr_t)-1)/sizeof(intptr_t)) = size;
			return true;
		case TYPEIDOF_TOKEN:
			if(src.GetToken(t) != SHOUKAKKOOPEN_TOKEN){
				ErrorMessage.Add(src.filename, src.gyousuu, L"'(' ܂BB");
				return false;
			}
			type.Clear();
			if(!TypeNanika(type, src, false, false, hkishiki)) return false;
			if(src.GetToken(t) != SHOUKAKKOCLOSE_TOKEN){
				ErrorMessage.Add(src.filename, src.gyousuu, L"')' ܂B");
				return false;
			}
			if((fi = GetTypeId(type)) == UNKNOWN_TYPEID){
				ErrorMessage.Add(src.filename, src.gyousuu, L"^CvID߂܂B");
				return false;
			}
			last = CONST_TOKEN;
			last += INT_TOKEN;
			last.SetLength(last.GetLength()+(sizeof(int32_t)+sizeof(intptr_t)-1)/sizeof(intptr_t));
			*(int32_t *)(last.GetConst()+last.GetLength()-(sizeof(int32_t)+sizeof(intptr_t)-1)/sizeof(intptr_t)) = fi;
			return true;
		case SHOUKAKKOOPEN_TOKEN:
			ki = src.GetToken(t);
			switch(ki){
			case BOOL_TOKEN:
			case BYTE_TOKEN:
			case CHAR_TOKEN:
			case DOUBLE_TOKEN:
			case FLOAT_TOKEN:
			case INT_TOKEN:
			case LONG_TOKEN:
			case SHORT_TOKEN:
			case UBYTE_TOKEN:
			case UINT_TOKEN:
			case ULONG_TOKEN:
			case USHORT_TOKEN:
			case INDEX_TOKEN:
				if(src.GetToken(t) != SHOUKAKKOCLOSE_TOKEN){
					ErrorMessage.Add(src.filename, src.gyousuu, L"')' ܂B");
					return false;
				}
				type = CONST_TOKEN;
				type += ki;
				ki = src.GetToken(t);
				if(ki == DAIKAKKOOPEN_TOKEN){
					last.Clear();
					if(!Literal(src, type, last, hkishiki)) return false;
				}else{
					if(!ConstNanika(src, t, ki, last, hkishiki)) return false;
					if(!ConstCaster(last, type)){
						ErrorMessage.Add(src.filename, src.gyousuu, L"sȃLXgłB");
						return false;
					}
				}
				break;
			case SHOUKAKKOCLOSE_TOKEN:
				ErrorMessage.Add(src.filename, src.gyousuu, L"̏ʂłB");
				return false;
			default:
				if(!hkishiki.ConstShiki(src, t, NULL_TOKEN, ki, last, SHOUKAKKOCLOSE_TOKEN, hkishiki)) return false;
				break;
			}
			return true;
		case PULUS_TOKEN:
		case MINUS_TOKEN:
		case EXCLAMATION_TOKEN:
			if(!ConstNanika(src, t, src.GetToken(t), last, hkishiki)) return false;
			tmpi = 0;
			if(last.GetConst()[tmpi] != CONST_TOKEN) return false;
			tmpi++;
			switch(last.GetConst()[tmpi++]){
			case BYTE_TOKEN:
				TankouConst(kin, *(int8_t *)(last.GetConst()+tmpi));
				break;
			case SHORT_TOKEN:
				TankouConst(kin, *(int16_t *)(last.GetConst()+tmpi));
				break;
			case INT_TOKEN:
				TankouConst(kin, *(int32_t *)(last.GetConst()+tmpi));
				break;
			case LONG_TOKEN:
				TankouConst(kin, *(int64_t *)(last.GetConst()+tmpi));
				break;
			case UBYTE_TOKEN:
				TankouConst(kin, *(uint8_t *)(last.GetConst()+tmpi));
				break;
			case USHORT_TOKEN:
				TankouConst(kin, *(uint16_t *)(last.GetConst()+tmpi));
				break;
			case UINT_TOKEN:
				TankouConst(kin, *(uint32_t *)(last.GetConst()+tmpi));
				break;
			case ULONG_TOKEN:
				TankouConst(kin, *(uint64_t *)(last.GetConst()+tmpi));
				break;
			case INDEX_TOKEN:
				TankouConst(kin, *(intptr_t *)(last.GetConst()+tmpi));
				break;
			case FLOAT_TOKEN:
				if(kin == EXCLAMATION_TOKEN){
					ErrorMessage.Add(src.filename, src.gyousuu, L"'!' ͕_^ɂ͎g܂B");
					return false;
				}
				TankouConstReal(kin, *(float *)(last.GetConst()+tmpi));
				break;
			case DOUBLE_TOKEN:
				if(kin == EXCLAMATION_TOKEN){
					ErrorMessage.Add(src.filename, src.gyousuu, L"'!' ͕_^ɂ͎g܂B");
					return false;
				}
				TankouConstReal(kin, *(double *)(last.GetConst()+tmpi));
				break;
			case CHAR_TOKEN:
				TankouConst(kin, *(wchar_t *)(last.GetConst()+tmpi));
				break;
			case BOOL_TOKEN:
				if(kin != EXCLAMATION_TOKEN){
					ErrorMessage.Add(src.filename, src.gyousuu, L"bool^ɕ͂܂B");
					return false;
				}
				*(bool *)(last.GetConst()+tmpi) = !*(bool *)(last.GetConst()+tmpi);
				break;
			default:
				ErrorMessage.Add(src.filename, src.gyousuu, L"^G[łB");
				return false;
			}
			return true;
		}
		ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
		return false;
	}
	template<typename TYPE> bool NikouConst(const TokenKind to, TYPE & x, PWCArray<intptr_t> & test, const TYPE y)
	{
		switch(to){
		case KAKERU_TOKEN:
			x *= y;
			break;
		case WARU_TOKEN:
			x /= y;
			break;
		case AMARI_TOKEN:
			x %= y;
			break;
		case PULUS_TOKEN:
			x += y;
			break;
		case MINUS_TOKEN:
			x -= y;
			break;
		case LSHIFT_TOKEN:
			x <<= y;
			break;
		case RSHIFT_TOKEN:
			x >>= y;
			break;
		case SHOU_TOKEN:
			test = CONST_TOKEN;
			test += BOOL_TOKEN;
			test += (intptr_t)(x < y);
			break;
		case SHOUOREQUAL_TOKEN:
			test = CONST_TOKEN;
			test += BOOL_TOKEN;
			test += (intptr_t)(x <= y);
			break;
		case DAI_TOKEN:
			test = CONST_TOKEN;
			test += BOOL_TOKEN;
			test += (intptr_t)(x > y);
			break;
		case DAIOREQUAL_TOKEN:
			test = CONST_TOKEN;
			test += BOOL_TOKEN;
			test += (intptr_t)(x >= y);
			break;
		case EQUAL_TOKEN:
			test = CONST_TOKEN;
			test += BOOL_TOKEN;
			test += (intptr_t)(x == y);
			break;
		case NOTEQUAL_TOKEN:
			test = CONST_TOKEN;
			test += BOOL_TOKEN;
			test += (intptr_t)(x != y);
			break;
		case AND_TOKEN:
			x &= y;
			break;
		case XOR_TOKEN:
			x ^= y;
			break;
		case OR_TOKEN:
			x |= y;
			break;
		default:
			return false;
		}
		return true;
	}
	template<typename TYPE> bool NikouConstReal(const TokenKind to, TYPE & x, PWCArray<intptr_t> & test, const TYPE y)
	{
		switch(to){
		case KAKERU_TOKEN:
			x *= y;
			break;
		case WARU_TOKEN:
			x /= y;
			break;
		case PULUS_TOKEN:
			x += y;
			break;
		case MINUS_TOKEN:
			x -= y;
			break;
		case SHOU_TOKEN:
			test = CONST_TOKEN;
			test += BOOL_TOKEN;
			test += (intptr_t)(x < y);
			break;
		case SHOUOREQUAL_TOKEN:
			test = CONST_TOKEN;
			test += BOOL_TOKEN;
			test += (intptr_t)(x <= y);
			break;
		case DAI_TOKEN:
			test = CONST_TOKEN;
			test += BOOL_TOKEN;
			test += (intptr_t)(x > y);
			break;
		case DAIOREQUAL_TOKEN:
			test = CONST_TOKEN;
			test += BOOL_TOKEN;
			test += (intptr_t)(x >= y);
			break;
		case EQUAL_TOKEN:
			test = CONST_TOKEN;
			test += BOOL_TOKEN;
			test += (intptr_t)(x == y);
			break;
		case NOTEQUAL_TOKEN:
			test = CONST_TOKEN;
			test += BOOL_TOKEN;
			test += (intptr_t)(x != y);
			break;
		default:
			return false;
		}
		return true;
	}
	bool NikouConstBool(const TokenKind to, bool & x, const bool y)
	{
		switch(to){
		case EQUAL_TOKEN:
			x = x == y;
			break;
		case NOTEQUAL_TOKEN:
			x = x != y;
			break;
		case AND_TOKEN:
			x = x && y;
			break;
		case XOR_TOKEN:
			x = x != y;
			break;
		case OR_TOKEN:
			x = x || y;
			break;
		case ANDAND_TOKEN:
			x = x && y;
			break;
		case OROR_TOKEN:
			x = x || y;
			break;
		default:
			return false;
		}
		return true;
	}
	bool NikouConstEnum(const TokenKind to, const int32_t x, PWCArray<intptr_t> & test, const int32_t y)
	{
		switch(to){
		case SHOU_TOKEN:
			test = CONST_TOKEN;
			test += BOOL_TOKEN;
			test += (intptr_t)(x < y);
			break;
		case SHOUOREQUAL_TOKEN:
			test = CONST_TOKEN;
			test += BOOL_TOKEN;
			test += (intptr_t)(x <= y);
			break;
		case DAI_TOKEN:
			test = CONST_TOKEN;
			test += BOOL_TOKEN;
			test += (intptr_t)(x > y);
			break;
		case DAIOREQUAL_TOKEN:
			test = CONST_TOKEN;
			test += BOOL_TOKEN;
			test += (intptr_t)(x >= y);
			break;
		case EQUAL_TOKEN:
			test = CONST_TOKEN;
			test += BOOL_TOKEN;
			test += (intptr_t)(x == y);
			break;
		case NOTEQUAL_TOKEN:
			test = CONST_TOKEN;
			test += BOOL_TOKEN;
			test += (intptr_t)(x != y);
			break;
		default:
			return false;
		}
		return true;
	}
	bool NikouConstFunc(const TokenKind to, const intptr_t x, PWCArray<intptr_t> & test, const intptr_t y)
	{
		switch(to){
		case EQUAL_TOKEN:
			test = CONST_TOKEN;
			test += BOOL_TOKEN;
			test += (intptr_t)(x == y);
			break;
		case NOTEQUAL_TOKEN:
			test = CONST_TOKEN;
			test += BOOL_TOKEN;
			test += (intptr_t)(x != y);
			break;
		default:
			return false;
		}
		return true;
	}
	bool EnzanConst(const TokenKind kin, PWCArray<intptr_t> & test, PWCArray<intptr_t> & last)
	{
		intptr_t tmpi;
		if(!ConstCaster(last, test)) return false;
		tmpi = 0;
		if(test.GetConst()[tmpi] != CONST_TOKEN) return false;
		tmpi++;
		switch(test.GetConst()[tmpi++]){
		case BYTE_TOKEN:
			if(!NikouConst(kin, *(int8_t *)(test.GetConst()+tmpi), test, *(int8_t *)(last.GetConst()+tmpi))) return false;
			break;
		case SHORT_TOKEN:
			if(!NikouConst(kin, *(int16_t *)(test.GetConst()+tmpi), test, *(int16_t *)(last.GetConst()+tmpi))) return false;
			break;
		case INT_TOKEN:
			if(!NikouConst(kin, *(int32_t *)(test.GetConst()+tmpi), test, *(int32_t *)(last.GetConst()+tmpi))) return false;
			break;
		case LONG_TOKEN:
			if(!NikouConst(kin, *(int64_t *)(test.GetConst()+tmpi), test, *(int64_t *)(last.GetConst()+tmpi))) return false;
			break;
		case UBYTE_TOKEN:
			if(!NikouConst(kin, *(uint8_t *)(test.GetConst()+tmpi), test, *(uint8_t *)(last.GetConst()+tmpi))) return false;
			break;
		case USHORT_TOKEN:
			if(!NikouConst(kin, *(uint16_t *)(test.GetConst()+tmpi), test, *(uint16_t *)(last.GetConst()+tmpi))) return false;
			break;
		case UINT_TOKEN:
			if(!NikouConst(kin, *(uint32_t *)(test.GetConst()+tmpi), test, *(uint32_t *)(last.GetConst()+tmpi))) return false;
			break;
		case ULONG_TOKEN:
			if(!NikouConst(kin, *(uint64_t *)(test.GetConst()+tmpi), test, *(uint64_t *)(last.GetConst()+tmpi))) return false;
			break;
		case INDEX_TOKEN:
			if(!NikouConst(kin, *(intptr_t *)(test.GetConst()+tmpi), test, *(intptr_t *)(last.GetConst()+tmpi))) return false;
			break;
		case FLOAT_TOKEN:
			if(!NikouConstReal(kin, *(float *)(test.GetConst()+tmpi), test, *(float *)(last.GetConst()+tmpi))) return false;
			break;
		case DOUBLE_TOKEN:
			if(!NikouConstReal(kin, *(double *)(test.GetConst()+tmpi), test, *(double *)(last.GetConst()+tmpi))) return false;
			break;
		case CHAR_TOKEN:
			if(!NikouConst(kin, *(wchar_t *)(test.GetConst()+tmpi), test, *(wchar_t *)(last.GetConst()+tmpi))) return false;
			break;
		case BOOL_TOKEN:
			if(!NikouConstBool(kin, *(bool *)(test.GetConst()+tmpi), *(bool *)(last.GetConst()+tmpi))) return false;
			break;
		case ENUM_TOKEN:
			if(!NikouConstEnum(kin, *(int32_t *)(test.GetConst()+test.GetLength()-1), test, *(int32_t *)(last.GetConst()+last.GetLength()-1))) return false;
			break;
		case FUNC_TOKEN:
			if(!NikouConstFunc(kin, *(intptr_t *)(test.GetConst()+test.GetLength()-1), test, *(intptr_t *)(last.GetConst()+last.GetLength()-1))) return false;
			break;
		case METHOD_TOKEN:
			if(!NikouConstFunc(kin, *(intptr_t *)(test.GetConst()+test.GetLength()-1), test, *(intptr_t *)(last.GetConst()+last.GetLength()-1))) return false;
			break;
		default:
			return false;
		}
		return true;
	}
	bool ConstShiki(Source & src, int & t, const TokenKind enzansi, const TokenKind oskin, PWCArray<intptr_t> & last, const TokenKind end, SourceTree & hkishiki)
	{
		PWCArray<intptr_t> type;
		TokenKind kin;
		kin = oskin;
		PWCArray<intptr_t> test;
		if(kin != end){
			if(!ConstNanika(src, t, kin, last, hkishiki)) return false;
			test = last;
			while(KAKERU_TOKEN <= (kin = src.GetToken(t)) && kin <= QUESTION_TOKEN){
				switch(enzansi){
				case NULL_TOKEN:
					break;
				case KAKERU_TOKEN:case WARU_TOKEN:case AMARI_TOKEN:
					src.idx = t;
					return true;
				case PULUS_TOKEN:case MINUS_TOKEN:
					if(kin >= PULUS_TOKEN){
						src.idx = t;
						return true;
					}
					break;
				case LSHIFT_TOKEN:case RSHIFT_TOKEN:
					if(kin >= LSHIFT_TOKEN){
						src.idx = t;
						return true;
					}
					break;
				case SHOU_TOKEN:case SHOUOREQUAL_TOKEN:case DAI_TOKEN:case DAIOREQUAL_TOKEN:
					if(kin >= SHOU_TOKEN){
						src.idx = t;
						return true;
					}
					break;
				case EQUAL_TOKEN:case NOTEQUAL_TOKEN:
					if(kin >= EQUAL_TOKEN){
						src.idx = t;
						return true;
					}
					break;
				case AND_TOKEN:
					if(kin >= AND_TOKEN){
						src.idx = t;
						return true;
					}
					break;
				case XOR_TOKEN:
					if(kin >= XOR_TOKEN){
						src.idx = t;
						return true;
					}
					break;
				case OR_TOKEN:
					if(kin >= OR_TOKEN){
						src.idx = t;
						return true;
					}
					break;
				case ANDAND_TOKEN://E
					if(kin >= OROR_TOKEN){
						src.idx = t;
						return true;
					}
					break;
				case OROR_TOKEN://E
					if(kin >= QUESTION_TOKEN){
						src.idx = t;
						return true;
					}
					break;
				case QUESTION_TOKEN://E
					break;
				default:
					ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
					return false;
				}
				if(src.GetToken(t) == end){
					ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
					return false;
				}
				src.idx = t;
				if(kin == QUESTION_TOKEN){
					type = CONST_TOKEN;
					type += BOOL_TOKEN;
					if(!ConstCaster(test, type)){
						ErrorMessage.Add(src.filename, src.gyousuu, L"^G[łB");
						return false;
					}
					if(*(bool *)(test.GetConst()+type.GetLength())){
						if(!ConstShiki(src, t, QUESTION_TOKEN, src.GetToken(t), last, COLON_TOKEN, hkishiki)) return false;
						if(src.source.GetConst()[t] != L':'){
							ErrorMessage.Add(src.filename, src.gyousuu, L"':' ܂B");
							return false;
						}
						if(!ConstShiki(src, t, QUESTION_TOKEN, src.GetToken(t), test, end, hkishiki)) return false;
					}else{
						if(!ConstShiki(src, t, QUESTION_TOKEN, src.GetToken(t), last, COLON_TOKEN, hkishiki)) return false;
						if(src.source.GetConst()[t] != L':'){
							ErrorMessage.Add(src.filename, src.gyousuu, L"':' ܂B");
							return false;
						}
						if(!ConstShiki(src, t, QUESTION_TOKEN, src.GetToken(t), last, end, hkishiki)) return false;
					}
				}else{
					if(!ConstShiki(src, t, kin, src.GetToken(t), last, end, hkishiki)) return false;
					if(!EnzanConst(kin, test, last)){
						ErrorMessage.Add(src.filename, src.gyousuu, L"^G[łB");
						return false;
					}
					last = test;
				}
			}
		}
		if(enzansi != NULL_TOKEN) src.idx = t;
		if(kin != end && (end != COLON_TOKEN || kin != COLOYAJIRUSHI_TOKEN)){
			if(end == SHOUKAKKOCLOSE_TOKEN){
				ErrorMessage.Add(src.filename, src.gyousuu, L"')' ܂B");
				return false;
			}
			if(kin != COMMA_TOKEN){
				ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
				return false;
			}
		}
		return true;
	}
	bool NanikaPath(PWCArray<intptr_t> & tk, Source & src, const bool pub, SourceTree & hkishiki)
	{
		int32_t tyki;
		SourceTree * pst;
		PWCArray<wchar_t> name, tmp;
		Hensuu<SourceTree> * phs;
		int t, ii;
		if((tyki = PathtoClassID(src, FUNC_BLOCK, true, pub, hkishiki)) < 0) return false;
		pst = funclist.Get(tyki);
		switch(pst->selftype){
		case FUNC_BLOCK:
			if(pst != pst->root){
				if(src.GetToken(t) != SHOUKAKKOOPEN_TOKEN){
					if(pst->parent == pst->root){
						src.idx = t;
						tk += CONST_TOKEN;
						tk += FUNC_TOKEN;
						pst->FuncTypeGet(tk, true, hkishiki);
					}else if(pst->parent->selftype == CLASS_BLOCK){
						src.idx = t;
						tk += CONST_TOKEN;
						tk += METHOD_TOKEN;
						tk += pst->parent->funcid;
						pst->FuncTypeGet(tk, true, hkishiki);
					}else{
						ErrorMessage.Add(src.filename, src.gyousuu, L"֐֐͊֐|C^ł܂B");
						return false;
					}
				}else{
					if(pst->parent == frp){
					}else{
						if(pst->parent == pst->root){
							tk += GBL_TOKEN;
						}else if(pst->parent == hkishiki.parent){
							tk += MBR_TOKEN;
						}else{
							ErrorMessage.Add(src.filename, src.gyousuu, L"̊֐͌Ăׂ܂B");
							return false;
						}
					}
					pst->GblhaniSet(hkishiki);
					if(pst->mbrhani == INT_MAX) pst->mbrhani = pst->parent->hensuidx.GetLength();
					tk += SHOUKAKKOOPEN_TOKEN;
					tk += ~tyki;
					if(!hkishiki.Shiki(tk, src, t, NULL_TOKEN, src.GetToken(t), SHOUKAKKOCLOSE_TOKEN, hkishiki)) return false;
					tk += SHOUKAKKOCLOSE_TOKEN;
				}
				break;
			}
		case CLASS_BLOCK:
			src.GetToken(t);
			src.GetToken(t);
			name.Clear();
			name.AddTail(src.source.GetConst()+t, src.idx-t);
			if((phs = pst->GetHensuu(name, ii, true)) == NULL){
				tmp = L'\'';
				tmp += name;
				tmp += L"' o萔Ɍ܂B";
				tmp += L'\0';
				ErrorMessage.Add(src.filename, src.gyousuu, tmp.GetConst());
				return false;
			}
			tk += phs->type;
			break;
		case ENUM_BLOCK:
			src.GetToken(t);
			if(src.GetToken(t) != OTHERKIND_TOKEN){
				ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
				return false;
			}
			name.Clear();
			name.AddTail(src.source.GetConst()+t, src.idx-t);
			if((phs = pst->GetHensuu(name, ii, true)) == NULL){
				tmp = L'\'';
				tmp += name;
				tmp += L"' ܂B";
				tmp += L'\0';
				ErrorMessage.Add(src.filename, src.gyousuu, tmp.GetConst());
				return false;
			}
			tk += phs->type;
			break;
		default:
			ErrorMessage.Add(src.filename, src.gyousuu, L"G[łB");
			return false;
		}
		return true;
	}
	bool RefNewNanika(PWCArray<intptr_t> & tk, Source & src, const intptr_t * const iap, SourceTree & hkishiki)
	{
		int t;
		int32_t ci;
		PWCArray<wchar_t> name;
		switch(src.GetToken(t)){
		case NEW_TOKEN:
			if(iap[0] == CLASS_TOKEN && !funclist.Get((int32_t)iap[1])->kakutei){
				name = L"default";
				if((ci = funclist.Get((int32_t)iap[1])->GetFuncId(name, true)) < 0){
					ErrorMessage.Add(src.filename, src.gyousuu, L"G[łB");
					return false;
				}
				name = L"new";
				if((ci = funclist.Get((int32_t)iap[1])->GetFuncId(name, true)) < 0){
					ErrorMessage.Add(src.filename, src.gyousuu, L"G[łB");
					return false;
				}
				funclist.Get(ci)->GblhaniSet(hkishiki);
				name = L"delete";
				if((ci = funclist.Get((int32_t)iap[1])->GetFuncId(name, true)) < 0){
					ErrorMessage.Add(src.filename, src.gyousuu, L"G[łB");
					return false;
				}
				funclist.Get(ci)->GblhaniSet(hkishiki);
				name = L"break";
				if((ci = funclist.Get((int32_t)iap[1])->GetFuncId(name, true)) < 0){
					ErrorMessage.Add(src.filename, src.gyousuu, L"G[łB");
					return false;
				}
				funclist.Get(ci)->GblhaniSet(hkishiki);
			}
			tk += NEW_TOKEN;
			switch(src.GetToken(t)){
			case SHOUKAKKOOPEN_TOKEN:
				tk += SHOUKAKKOOPEN_TOKEN;
				if(!hkishiki.Shiki(tk, src, t, NULL_TOKEN, src.GetToken(t), SHOUKAKKOCLOSE_TOKEN, hkishiki)) return false;
				tk += SHOUKAKKOCLOSE_TOKEN;
				break;
			case DAIKAKKOOPEN_TOKEN:
				tk += DAIKAKKOOPEN_TOKEN;
				if(!hkishiki.Shiki(tk, src, t, NULL_TOKEN, src.GetToken(t), DAIKAKKOCLOSE_TOKEN, hkishiki)) return false;
				tk += DAIKAKKOCLOSE_TOKEN;
				break;
			default:
				ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
				return false;
			}
			break;
		default:
			ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
			return false;
		}
		return true;
	}
	bool ClassNanika(PWCArray<intptr_t> & tk, Source & src, SourceTree & hkishiki, const PWCArray<intptr_t> & type, int & jj)
	{
		int t;
		int32_t tyki;
		tk += POINT_TOKEN;
		jj++;
		tyki = (int32_t)type.GetConst()[jj];
		if(src.GetToken(t) != OTHERKIND_TOKEN){
			ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
			return false;
		}
		if(L'0' <= src.source.GetConst()[t] && src.source.GetConst()[t] <= L'9'){
			ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
			return false;
		}
		if(!funclist.Get(tyki)->Nanika(tk, src, t, OTHERKIND_TOKEN, (parent==NULL||tyki!=parent->funcid), hkishiki)) return false;
		return true;
	}
	bool Moji(wchar_t & wc, Source & src)
	{
		wc = src.GetChar();
		switch(wc){
		case L'\'':
			ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
			return false;
		case L'\\':
			if(!TokushuMoji(wc, src)) return false;
			break;
		}
		if(src.GetChar() != L'\''){
			ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
			return false;
		}
		return true;
	}
	bool Nanika(PWCArray<intptr_t> & tk, Source & src, int & t, const TokenKind kin, const bool pub, SourceTree & hkishiki)
	{
		Hensuu<SourceTree> * phs;
		PWCArray<wchar_t> name, tmp;
		PWCArray<intptr_t> type;
		TokenKind ki;
		wchar_t wc;
		int32_t fi;
		intptr_t size;
		int oi, ot, ogy, ii, jj;
		switch(kin){
		case DQUOT_TOKEN:
		case BACKSLA_TOKEN:
			name.Clear();
			src.idx = t;
			if(!MjiretuLiteral(name, src)) return false;
			if(!ConstMojiretsu(name, tk)) return false;
			break;
		case SQUOT_TOKEN:
			tk += CONST_TOKEN;
			tk += CHAR_TOKEN;
			if(!Moji(wc, src)) return false;
			tk += wc;
			break;
		case MBR_TOKEN:
			if(hkishiki.frp == hkishiki.root || hkishiki.frp->parent == hkishiki.root || hkishiki.frp->selftype == CLASS_BLOCK){
				ErrorMessage.Add(src.filename, src.gyousuu, L"mbr͎g܂B");
				return false;
			}
			switch(src.GetToken(t)){
			case POINT_TOKEN:
				tk += MBR_TOKEN;
				if(src.GetToken(t) != OTHERKIND_TOKEN){
					ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
					return false;
				}
				if(L'0' <= src.source.GetConst()[t] && src.source.GetConst()[t] <= L'9'){
					ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
					return false;
				}
				if(!hkishiki.frp->parent->Nanika(tk, src, t, OTHERKIND_TOKEN, pub, hkishiki)) return false;
				break;
			default:
				if(hkishiki.frp->parent->selftype != CLASS_BLOCK){
					ErrorMessage.Add(src.filename, src.gyousuu, L"NXȊOmbr͎QƂł܂B");
					return false;
				}
				tk += NULL_TOKEN;
				tk += MBR_TOKEN;
				src.idx = t;
				break;
			}
			break;
		case GBL_TOKEN:
			switch(src.GetToken(t)){
			case POINT_TOKEN:
				if(src.GetToken(t) != OTHERKIND_TOKEN){
					ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
					return false;
				}
				if(L'0' <= src.source.GetConst()[t] && src.source.GetConst()[t] <= L'9'){
					ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
					return false;
				}
				if(!hkishiki.root->Nanika(tk, src, t, OTHERKIND_TOKEN, pub, hkishiki)) return false;
				break;
			default:
				ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
				return false;
			}
			break;
		case SIZEOF_TOKEN:
			if(src.GetToken(t) != SHOUKAKKOOPEN_TOKEN){
				ErrorMessage.Add(src.filename, src.gyousuu, L"'(' ܂B");
				return false;
			}
			type.Clear();
			if(!TypeNanika(type, src, false, false, hkishiki)) return false;
			if(src.GetToken(t) != SHOUKAKKOCLOSE_TOKEN){
				ErrorMessage.Add(src.filename, src.gyousuu, L"')' ܂B");
				return false;
			}
			if((size = GetTypeSize(type)) < 0){
				ErrorMessage.Add(src.filename, src.gyousuu, L"TCY߂܂B");
				return false;
			}
			tk += CONST_TOKEN;
			tk += INDEX_TOKEN;
			tk.SetLength(tk.GetLength()+(sizeof(intptr_t)+sizeof(intptr_t)-1)/sizeof(intptr_t));
			*(intptr_t *)(tk.GetConst()+tk.GetLength()-(sizeof(intptr_t)+sizeof(intptr_t)-1)/sizeof(intptr_t)) = size;
			break;
		case TYPEIDOF_TOKEN:
			if(src.GetToken(t) != SHOUKAKKOOPEN_TOKEN){
				ErrorMessage.Add(src.filename, src.gyousuu, L"'(' ܂B");
				return false;
			}
			type.Clear();
			if(!TypeNanika(type, src, false, false, hkishiki)) return false;
			if(src.GetToken(t) != SHOUKAKKOCLOSE_TOKEN){
				ErrorMessage.Add(src.filename, src.gyousuu, L"')' ܂B");
				return false;
			}
			if((fi = GetTypeId(type)) == UNKNOWN_TYPEID){
				ErrorMessage.Add(src.filename, src.gyousuu, L"^CvID߂܂B");
				return false;
			}
			tk += CONST_TOKEN;
			tk += INT_TOKEN;
			tk.SetLength(tk.GetLength()+(sizeof(int32_t)+sizeof(intptr_t)-1)/sizeof(intptr_t));
			*(int32_t *)(tk.GetConst()+tk.GetLength()-(sizeof(int32_t)+sizeof(intptr_t)-1)/sizeof(intptr_t)) = fi;
			break;
		case WAIT_TOKEN:
		case LEN_TOKEN:
			if(src.GetToken(t) != SHOUKAKKOOPEN_TOKEN){
				ErrorMessage.Add(src.filename, src.gyousuu, L"'(' ܂B");
				return false;
			}
			tk += kin;
			tk += SHOUKAKKOOPEN_TOKEN;
			if(!hkishiki.Shiki(tk, src, t, NULL_TOKEN, src.GetToken(t), SHOUKAKKOCLOSE_TOKEN, hkishiki)) return false;
			tk += SHOUKAKKOCLOSE_TOKEN;
			break;
		case SHOUKAKKOOPEN_TOKEN:
			ki = src.GetToken(t);
			switch(ki){
			case BOOL_TOKEN:
			case BYTE_TOKEN:
			case CHAR_TOKEN:
			case DOUBLE_TOKEN:
			case FLOAT_TOKEN:
			case INT_TOKEN:
			case LONG_TOKEN:
			case SHORT_TOKEN:
			case UBYTE_TOKEN:
			case UINT_TOKEN:
			case ULONG_TOKEN:
			case USHORT_TOKEN:
			case INDEX_TOKEN:
				if(src.GetToken(t) != SHOUKAKKOCLOSE_TOKEN){
					ErrorMessage.Add(src.filename, src.gyousuu, L"')' ܂B");
					return false;
				}
				type = CONST_TOKEN;
				type += ki;
				if(src.GetToken(t) == DAIKAKKOOPEN_TOKEN){
					if(!Literal(src, type, tk, hkishiki)) return false;
				}else{
					src.idx = t;
					if(!Nanika(tk, src, t, src.GetToken(t), pub, hkishiki)) return false;
					tk += SHOUKAKKOOPEN_TOKEN;
					tk += ki;
					tk += SHOUKAKKOCLOSE_TOKEN;
				}
				break;
			case SHOUKAKKOCLOSE_TOKEN:
				ErrorMessage.Add(src.filename, src.gyousuu, L"̏ʂłB");
				return false;
			default:
				if(!hkishiki.Shiki(tk, src, t, NULL_TOKEN, ki, SHOUKAKKOCLOSE_TOKEN, hkishiki)) return false;
				break;
			}
			break;
		case FALSE_TOKEN:
			tk += CONST_TOKEN;
			tk += BOOL_TOKEN;
			tk += (intptr_t)false;
			break;
		case TRUE_TOKEN:
			tk += CONST_TOKEN;
			tk += BOOL_TOKEN;
			tk += (intptr_t)true;
			break;
		case PULUS_TOKEN:
		case MINUS_TOKEN:
			if(!Nanika(tk, src, t, src.GetToken(t), pub, hkishiki)) return false;
			tk += NULL_TOKEN;
			tk += kin;
			break;
		case EXCLAMATION_TOKEN:
		case PLSPLS_TOKEN:
		case MNSMNS_TOKEN:
			if(!Nanika(tk, src, t, src.GetToken(t), pub, hkishiki)) return false;
			tk += kin;
			break;
		case SELF_TOKEN:
			if(root == frp || src.GetToken(t) != SHOUKAKKOOPEN_TOKEN){
				ErrorMessage.Add(src.filename, src.gyousuu, L"selfɂ钼ڂ̒`͂ł܂B");
				return false;
			}
			if(frp->parent == root){
				tk += GBL_TOKEN;
			}else{
				tk += MBR_TOKEN;
			}
			tk += SHOUKAKKOOPEN_TOKEN;
			tk += ~frp->funcid;
			if(!hkishiki.Shiki(tk, src, t, NULL_TOKEN, src.GetToken(t), SHOUKAKKOCLOSE_TOKEN, hkishiki)) return false;
			tk += SHOUKAKKOCLOSE_TOKEN;
			break;
		case OTHERKIND_TOKEN:
			if(L'0' <= src.source.GetConst()[t] && src.source.GetConst()[t] <= L'9'){
				if(!Suuji(tk, src, t)) return false;
			}else{
				oi = src.idx;
				ot = t;
				ogy = src.gyousuu;
				if(frp == root) tk += GBL_TOKEN;
				switch(ki = src.GetToken(t)){
				case SHOUKAKKOOPEN_TOKEN:
				case BRACOLOOPEN_TOKEN:
				case COLOYAJIRUSHI_TOKEN:
				case COLOCOLO_TOKEN:
					src.idx = ot;
					src.gyousuu = ogy;
					if(!NanikaPath(tk, src, pub, hkishiki)) return false;
					break;
				case DAIKAKKOOPEN_TOKEN:
				case DIA_TOKEN:
				case POINT_TOKEN:
				default:
					name.Clear();
					name.AddTail(src.source.GetConst()+ot, oi-ot);
					if((phs = GetHensuu(name, ii, false)) == NULL){
						if((fi = GetFuncId(name, false)) < 0){
							tmp = L'\'';
							tmp += name;
							tmp += L"' ͒`Ă܂B";
							tmp += L'\0';
							ErrorMessage.Add(src.filename, src.gyousuu, tmp.GetConst());
							return false;
						}else if(funclist.Get(fi)->selftype != FUNC_BLOCK){
							tmp = L'\'';
							tmp += name;
							tmp += L"' class܂enumłB";
							tmp += L'\0';
							ErrorMessage.Add(src.filename, src.gyousuu, tmp.GetConst());
							return false;
						}else if(!funclist.Get(fi)->kakutei){
							tmp = L'\'';
							tmp += name;
							tmp += L"' ͊m肵ĂȂߊ֐|C^ł܂B";
							tmp += L'\0';
							ErrorMessage.Add(src.filename, src.gyousuu, tmp.GetConst());
							return false;
						}
						if(funclist.Get(fi)->parent == funclist.Get(fi)->root){
							src.idx = t;
							tk += CONST_TOKEN;
							tk += FUNC_TOKEN;
							funclist.Get(fi)->FuncTypeGet(tk, true, hkishiki);
						}else if(funclist.Get(fi)->parent->selftype == CLASS_BLOCK){
							src.idx = t;
							tk += CONST_TOKEN;
							tk += METHOD_TOKEN;
							tk += funclist.Get(fi)->parent->funcid;
							funclist.Get(fi)->FuncTypeGet(tk, true, hkishiki);
						}else{
							tmp = L'\'';
							tmp += name;
							tmp += L"' ͊֐֐Ȃ̂Ŋ֐|C^ł܂B";
							tmp += L'\0';
							ErrorMessage.Add(src.filename, src.gyousuu, tmp.GetConst());
							return false;
						}
						break;
					}
					tk += ~ii;
					jj = 0;
					if(phs->type.GetConst()[jj] == CONST_TOKEN){
						jj++;
					}else{
						if(hkishiki.root == frp && ii >= hkishiki.frp->gblhani){
							ErrorMessage.Add(src.filename, src.gyousuu, L"ÕO[oϐg\܂B");
							return false;
						}
						if(hkishiki.frp->parent == frp && ii >= hkishiki.frp->mbrhani){
							ErrorMessage.Add(src.filename, src.gyousuu, L"Õo[ϐg\܂B");
							return false;
						}
						if(IsPublicToken((TokenKind)phs->type.GetConst()[jj])){
							jj++;
						}else if(pub){
							tmp = L'\'';
							tmp += name;
							tmp += L"' ̓vCx[głB";
							tmp += L'\0';
							ErrorMessage.Add(src.filename, src.gyousuu, tmp.GetConst());
							return false;
						}else if(phs->type.GetConst()[jj] == CORE_TOKEN){
							jj++;
						}
					}
					if(phs->type.GetConst()[jj] == REF_TOKEN || phs->type.GetConst()[jj] == LIST_TOKEN) switch(ki){
					case DAIKAKKOOPEN_TOKEN:
					case DIA_TOKEN:
						while(true){
							tk += ki;
							if(ki == DAIKAKKOOPEN_TOKEN){
								if(!hkishiki.Shiki(tk, src, t, NULL_TOKEN, src.GetToken(t), DAIKAKKOCLOSE_TOKEN, hkishiki)) return false;
								tk += DAIKAKKOCLOSE_TOKEN;
								if(tk.GetConst()[tk.GetLength()-2] == TENTEN_TOKEN) jj--;
							}
							switch(ki = src.GetToken(t)){
							case POINT_TOKEN:
								jj++;
								if(IsPublicToken((TokenKind)phs->type.GetConst()[jj])) jj++;
								if(phs->type.GetConst()[jj] == CLASS_TOKEN || phs->type.GetConst()[jj] == ENUM_TOKEN){
									if(!ClassNanika(tk, src, hkishiki, phs->type, jj)) return false;
								}else if(phs->type.GetConst()[jj] == REF_TOKEN || phs->type.GetConst()[jj] == LIST_TOKEN){
									if(!RefNewNanika(tk, src, phs->type.GetConst()+jj+1, hkishiki)) return false;
								}else{
									ErrorMessage.Add(src.filename, src.gyousuu, L"炩̃G[łB");
									return false;
								}
								break;
							case DAIKAKKOOPEN_TOKEN:
							case DIA_TOKEN:
								jj++;
								if(IsPublicToken((TokenKind)phs->type.GetConst()[jj])) jj++;
								if(phs->type.GetConst()[jj] != REF_TOKEN && phs->type.GetConst()[jj] != LIST_TOKEN){
									ErrorMessage.Add(src.filename, src.gyousuu, L"炩̃G[łB");
									return false;
								}
								continue;
								break;
							default:
								src.idx = t;
								break;
							}
							break;
						}
						break;
					case POINT_TOKEN:
						if(!RefNewNanika(tk, src, phs->type.GetConst()+jj+1, hkishiki)) return false;
						break;
					default:
						src.idx = t;
						break;
					}else if(phs->type.GetConst()[jj] == THREAD_TOKEN) switch(ki){
					case TENTEN_TOKEN:
						if(src.GetToken(t) != SHOUKAKKOOPEN_TOKEN){
							ErrorMessage.Add(src.filename, src.gyousuu, L"'(' ܂B");
							return false;
						}
						fi = phs->type.GetConst()[jj+1];
						funclist.Get(fi)->GblhaniSet(hkishiki);
						if(funclist.Get(fi)->mbrhani == INT_MAX) funclist.Get(fi)->mbrhani = funclist.Get(fi)->parent->hensuidx.GetLength();
						tk += SHOUKAKKOOPEN_TOKEN;
						tk += TENTEN_TOKEN;
						if(!hkishiki.Shiki(tk, src, t, NULL_TOKEN, src.GetToken(t), SHOUKAKKOCLOSE_TOKEN, hkishiki)) return false;
						tk += SHOUKAKKOCLOSE_TOKEN;
						break;
					default:
						src.idx = t;
						break;
					}else switch(ki){
					case POINT_TOKEN:
						if(phs->type.GetConst()[0] == LIB_TOKEN){
							if(src.GetToken(t) != OTHERKIND_TOKEN){
								ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
								return false;
							}
							if(L'0' <= src.source.GetConst()[t] && src.source.GetConst()[t] <= L'9'){
								ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
								return false;
							}
							tk.SetLength(tk.GetLength()-1);
							tk += phs->type;
							if(!((SourceTree *)phs->type.GetConst()[1])->Nanika(tk, src, t, OTHERKIND_TOKEN, true, hkishiki)) return false;
						}else{
							if(phs->type.GetConst()[jj] != CLASS_TOKEN && phs->type.GetConst()[jj] != ENUM_TOKEN){
								ErrorMessage.Add(src.filename, src.gyousuu, L"'.' słB");
								return false;
							}
							if(!ClassNanika(tk, src, hkishiki, phs->type, jj)) return false;
						}
						break;
					default:
						src.idx = t;
						break;
					}
					break;
				}
			}
			break;
		default:
			ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
			return false;
		}
		while(true){
			ki = src.GetToken(t);
			switch(ki){
			case KAKKOCOLOOPEN_TOKEN:
				tk += KAKKOCOLOOPEN_TOKEN;
				if(!hkishiki.Shiki(tk, src, t, NULL_TOKEN, src.GetToken(t), KAKKOCOLOCLOSE_TOKEN, hkishiki)) return false;
				tk += KAKKOCOLOCLOSE_TOKEN;
				continue;
			case PLSPLS_TOKEN:
			case MNSMNS_TOKEN:
				tk += NULL_TOKEN;
				tk += ki;
				continue;
			}
			src.idx = t;
			break;
		}
		return true;
	}
	bool Shiki(PWCArray<intptr_t> & tk, Source & src, int & t, const TokenKind enzansi, const TokenKind oskin, const TokenKind end, SourceTree & hkishiki)
	{
		TokenKind kin, ki;
		kin = oskin;
		if(kin != end){
			if(!Nanika(tk, src, t, kin, false, hkishiki)) return false;
			while(KAKERU_TOKEN <= (kin = src.GetToken(t)) && kin <= (end == SEMICOLON_TOKEN ? SHARP_TOKEN :  COMMA_TOKEN)){
				switch(enzansi){
				case NULL_TOKEN:
					break;
				case KAKERU_TOKEN:case WARU_TOKEN:case AMARI_TOKEN:
					src.idx = t;
					return true;
				case PULUS_TOKEN:case MINUS_TOKEN:
					if(kin >= PULUS_TOKEN){
						src.idx = t;
						return true;
					}
					break;
				case LSHIFT_TOKEN:case RSHIFT_TOKEN:
					if(kin >= LSHIFT_TOKEN){
						src.idx = t;
						return true;
					}
					break;
				case SHOU_TOKEN:case SHOUOREQUAL_TOKEN:case DAI_TOKEN:case DAIOREQUAL_TOKEN:
					if(kin >= SHOU_TOKEN){
						src.idx = t;
						return true;
					}
					break;
				case EQUAL_TOKEN:case NOTEQUAL_TOKEN:
					if(kin >= EQUAL_TOKEN){
						src.idx = t;
						return true;
					}
					break;
				case AND_TOKEN:
					if(kin >= AND_TOKEN){
						src.idx = t;
						return true;
					}
					break;
				case XOR_TOKEN:
					if(kin >= XOR_TOKEN){
						src.idx = t;
						return true;
					}
					break;
				case OR_TOKEN:
					if(kin >= OR_TOKEN){
						src.idx = t;
						return true;
					}
					break;
				case ANDAND_TOKEN://E
					if(kin >= OROR_TOKEN){
						src.idx = t;
						return true;
					}
					break;
				case OROR_TOKEN://E
					if(kin >= QUESTION_TOKEN){
						src.idx = t;
						return true;
					}
					break;
				case QUESTION_TOKEN://E
					if(kin >= DAINYUU_TOKEN){
						src.idx = t;
						return true;
					}
					break;
				case DAINYUU_TOKEN:case PULUSDAINYUU_TOKEN:case MINUSDAINYUU_TOKEN:case KAKERUDAINYUU_TOKEN:case WARUDAINYUU_TOKEN:case AMARIDAINYUU_TOKEN:
				case ANDDAINYUU_TOKEN:case XORDAINYUU_TOKEN:case ORDAINYUU_TOKEN:case LSHIFTDAINYUU_TOKEN:case RSHIFTDAINYUU_TOKEN:
				case TENDAINYUU_TOKEN:
				case YAJIRUSHI_TOKEN:case SHIROYAJIRUSHI_TOKEN://E
				case SHARP_TOKEN:
					if(kin >= SHARP_TOKEN){
						src.idx = t;
						return true;
					}
					break;
				case TENTEN_TOKEN:
					if(end != DAIKAKKOCLOSE_TOKEN){
						ErrorMessage.Add(src.filename, src.gyousuu, L"'..' ̉Zq '[ ]' łB");
						return false;
					}
				case COMMA_TOKEN:
					if(kin >= TENTEN_TOKEN){
						src.idx = t;
						return true;
					}
					break;
				default:
					ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
					return false;
				}
				ki = src.GetToken(t);
				if(
					(enzansi == NULL_TOKEN || enzansi == COMMA_TOKEN) && (end == SHOUKAKKOCLOSE_TOKEN || end == KAKKOCOLOCLOSE_TOKEN)
					&& kin == DAINYUU_TOKEN && (ki == end || ki == COMMA_TOKEN))
				{
					tk += NULL_TOKEN;
					tk += DAINYUU_TOKEN;
					tk += COMMA_TOKEN;
					if(ki == end){
						if(enzansi != NULL_TOKEN) src.idx = t;
						return true;
					}
					kin = ki;
					ki = src.GetToken(t);
				}
				if(ki == end){
					ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
					return false;
				}
				if(kin == SHARP_TOKEN || kin == COMMA_TOKEN){
					tk += kin;
				}else if((ANDAND_TOKEN <= kin && kin <= QUESTION_TOKEN)
					|| (DAINYUU_TOKEN <= kin && kin <= SHIROYAJIRUSHI_TOKEN) || kin == TENTEN_TOKEN)
				{
					tk += NULL_TOKEN;
					tk += kin;
					if(kin == QUESTION_TOKEN){
						if(!Shiki(tk, src, t, QUESTION_TOKEN, ki, COLON_TOKEN, hkishiki)) return false;
						if(src.source.GetConst()[t] != L':'){
							ErrorMessage.Add(src.filename, src.gyousuu, L"':' ܂B");
							return false;
						}
						tk += COLON_TOKEN;
						src.GetToken(t);
						ki = src.GetToken(t);
					}
				}
				if(!Shiki(tk, src, t, kin, ki, end, hkishiki)) return false;
				if(kin != SHARP_TOKEN && kin != COMMA_TOKEN) tk += kin;
			}
		}
		if(enzansi != NULL_TOKEN) src.idx = t;
		if(kin != end){
			if(end != SEMICOLON_TOKEN){
				ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
				return false;
			}
			if(kin != COMMA_TOKEN){
				ErrorMessage.Add(src.filename, src.gyousuu, L"';' ܂B");
				return false;
			}
		}
		return true;
	}
	bool TypeNanikaPath(PWCArray<intptr_t> & type, Source & src, const bool conf, SourceTree & hkishiki)
	{
		int t;
		int32_t tyki;
		PWCArray<wchar_t> name;
		Hensuu<SourceTree> * phs;
		int ii;
		if((tyki = PathtoClassID(src, FUNC_BLOCK, true, false, hkishiki)) < 0) return false;
		switch(funclist.Get(tyki)->selftype){
		case FUNC_BLOCK:
			if(funclist.Get(tyki) != funclist.Get(tyki)->root){
				if(src.GetToken(t) == SHOUKAKKOOPEN_TOKEN){
					ErrorMessage.Add(src.filename, src.gyousuu, L"^ł͂Ȃ֐ĂяołB");
					return false;
				}
				src.idx = t;
				type += NULL_TOKEN;
				type += tyki;
				break;
			}
		case CLASS_BLOCK:
			src.GetToken(t);
			src.GetToken(t);
			name.Clear();
			name.AddTail(src.source.GetConst()+t, src.idx-t);
			phs = funclist.Get(tyki)->GetHensuu(name, ii, false);
			if(phs->type.GetConst()[0] != TYPE_TOKEN){
				ErrorMessage.Add(src.filename, src.gyousuu, L"type^ł܂B");
				return false;
			}
			type.AddTail(phs->type.GetConst()+1, phs->type.GetLength()-1);
			break;
		default:
			ErrorMessage.Add(src.filename, src.gyousuu, L"G[łB");
			return false;
		}
		return true;
	}
	bool TypeNanika(PWCArray<intptr_t> & type, Source & src, const bool conf, const bool corf, SourceTree & hkishiki)
	{
		Hensuu<SourceTree> * phs;
		PWCArray<wchar_t> name;
		int t, ci, kmfs, oi, ot, ogy;
		int32_t tyki;
		TokenKind kin;
		kin = src.GetToken(t);
		switch(kin){
		case MBR_TOKEN:
			if(frp == root || frp->parent == root || frp->selftype == CLASS_BLOCK){
				ErrorMessage.Add(src.filename, src.gyousuu, L"mbr͎g܂B");
				return false;
			}
			switch(src.GetToken(t)){
			case POINT_TOKEN:
				if((kin = src.GetToken(t)) != OTHERKIND_TOKEN && kin != SELF_TOKEN){
					ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
					return false;
				}
				src.idx = t;
				if(!frp->parent->TypeNanika(type, src, conf, corf, hkishiki)) return false;
				break;
			default:
				ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
				return false;
			}
			return true;
		case GBL_TOKEN:
			switch(src.GetToken(t)){
			case POINT_TOKEN:
				if((kin = src.GetToken(t)) != OTHERKIND_TOKEN && kin != SELF_TOKEN){
					ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
					return false;
				}
				src.idx = t;
				if(!root->TypeNanika(type, src, conf, corf, hkishiki)) return false;
				break;
			default:
				ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
				return false;
			}
			return true;
		case SELF_TOKEN:
			if(selftype == CLASS_BLOCK){
				type += CLASS_TOKEN;
			}else{
				if(corf){
					ErrorMessage.Add(src.filename, src.gyousuu, L"NXł܂B");
					return false;
				}
				if(selftype == ENUM_BLOCK){
					type += ENUM_TOKEN;
				}else{
					type += NULL_TOKEN;
				}
			}
			type += funcid;
			return true;
		case BOOL_TOKEN:
		case BYTE_TOKEN:
		case CHAR_TOKEN:
		case DOUBLE_TOKEN:
		case FLOAT_TOKEN:
		case INT_TOKEN:
		case LONG_TOKEN:
		case SHORT_TOKEN:
		case UBYTE_TOKEN:
		case UINT_TOKEN:
		case ULONG_TOKEN:
		case USHORT_TOKEN:
		case INDEX_TOKEN:
		case VOID_TOKEN:
			if(corf){
				ErrorMessage.Add(src.filename, src.gyousuu, L"NXł܂B");
				return false;
			}
			type += kin;
			return true;
		case LIST_TOKEN:
			if(conf){
				ErrorMessage.Add(src.filename, src.gyousuu, L"萔list^͂܂B");
				return false;
			}
		case REF_TOKEN:
			if(corf){
				ErrorMessage.Add(src.filename, src.gyousuu, L"NXł܂B");
				return false;
			}
			type += kin;
			if(src.GetToken(t) != BRACOLOOPEN_TOKEN){
				ErrorMessage.Add(src.filename, src.gyousuu, L"'<:' ܂B");
				return false;
			}
			kin = src.GetToken(t);
			if(kin == CONST_TOKEN){
				type += CONST_TOKEN;
				if(!TypeNanika(type, src, true, false, hkishiki)) return false;
			}else if(kin == FUNC_TOKEN || kin == METHOD_TOKEN){
				ErrorMessage.Add(src.filename, src.gyousuu, L"֐|C^͒newł܂B");
				return false;
			}else{
				src.idx = t;
				if(!TypeNanika(type, src, false, false, hkishiki)) return false;
			}
			if(src.GetToken(t) != BRACOLOCLOSE_TOKEN){
				ErrorMessage.Add(src.filename, src.gyousuu, L"':>' ܂B");
				return false;
			}
			return true;
		case ENUM_TOKEN:
			if(corf){
				ErrorMessage.Add(src.filename, src.gyousuu, L"NXł܂B");
				return false;
			}
		case CLASS_TOKEN:
			type += kin;
			if((ci = PathtoClassID(src, (kin==CLASS_TOKEN?CLASS_BLOCK:ENUM_BLOCK), false, false, hkishiki)) < 0) return false;
			if(src.source.GetConst()[src.idx-1] == L'>' && src.source.GetConst()[src.idx-2] != L':'){
				ErrorMessage.Add(src.filename, src.gyousuu, L"̓G[łB");
				return false;
			}
			type += ci;
			return true;
		case FUNC_TOKEN:
			if(corf){
				ErrorMessage.Add(src.filename, src.gyousuu, L"NXł܂B");
				return false;
			}
			type += FUNC_TOKEN;
			FuncType(type, src, hkishiki);
			return true;
		case THREAD_TOKEN:
			if(conf){
				ErrorMessage.Add(src.filename, src.gyousuu, L"萔thread^͂܂B");
				return false;
			}
			if(corf){
				ErrorMessage.Add(src.filename, src.gyousuu, L"NXł܂B");
				return false;
			}
			type += THREAD_TOKEN;
			if(src.GetToken(t) != BRACOLOOPEN_TOKEN){
				ErrorMessage.Add(src.filename, src.gyousuu, L"<:' ܂B");
				return false;
			}
			if((ci = PathtoClassID(src, FUNC_BLOCK, false, false, hkishiki)) < 0) return false;
			if(funclist.Get(ci)->parent != funclist.Get(ci)->root
				|| (src.source.GetConst()[src.idx-1] == L'>' && src.source.GetConst()[src.idx-2] != L':'))
			{
				ErrorMessage.Add(src.filename, src.gyousuu, L"̓G[łB");
				return false;
			}
			type += ci;
			if(src.GetToken(t) != BRACOLOCLOSE_TOKEN){
				ErrorMessage.Add(src.filename, src.gyousuu, L"':>' ܂B");
				return false;
			}
			return true;
		case OTHERKIND_TOKEN:
			oi = src.idx;
			ot = t;
			ogy = src.gyousuu;
			switch(src.GetToken(t)){
			case SHOUKAKKOOPEN_TOKEN:
			case BRACOLOOPEN_TOKEN:
			case COLOYAJIRUSHI_TOKEN:
			case COLOCOLO_TOKEN:
				src.idx = ot;
				src.gyousuu = ogy;
				if(!TypeNanikaPath(type, src, conf, hkishiki)) return false;
				break;
			default:
				src.idx = t;
				name.Clear();
				name.AddTail(src.source.GetConst()+ot, oi-ot);
				if((phs = GetHensuu(name, kmfs, false)) == NULL){
					if((tyki = GetFuncId(name, false)) < 0 || funclist.Get(tyki)->selftype != FUNC_BLOCK){
						ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
						return false;
					}
					src.idx = t;
					type += NULL_TOKEN;
					type += tyki;
					break;
				}
				kmfs = 0;
				while(true){
					if(phs->type.GetConst()[kmfs] == TYPE_TOKEN){
						kmfs++;
						if(conf){
							switch(phs->type.GetConst()[kmfs]){
							case LIST_TOKEN:
							case METHOD_TOKEN:
							case THREAD_TOKEN:
								ErrorMessage.Add(src.filename, src.gyousuu, L"萔Œ`ł܂B");
								return false;
							}
						}
						if(corf && phs->type.GetConst()[kmfs] != CLASS_TOKEN){
							ErrorMessage.Add(src.filename, src.gyousuu, L"NXł܂B");
							return false;
						}
						type.AddTail(phs->type.GetConst()+kmfs, phs->type.GetLength()-kmfs);
					}else if((phs->type.GetConst()[kmfs] == CLASS_TOKEN && (kmfs++, true))
						|| ((IsSoushokuToken((TokenKind)phs->type.GetConst()[kmfs]) && phs->type.GetConst()[kmfs+1] == CLASS_TOKEN) && (kmfs += 2, true))
					){
						if(src.GetToken(t) != POINT_TOKEN){
							ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
							return false;
						}
						kin = src.GetToken(t);
						if(kin != SELF_TOKEN && kin != OTHERKIND_TOKEN){
							ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
							return false;
						}
						tyki = (int32_t)phs->type.GetConst()[kmfs];
						src.idx = t;
						if(!funclist.Get(tyki)->TypeNanika(type, src, conf, corf, hkishiki)) return false;
					}else if((phs->type.GetConst()[kmfs] == REF_TOKEN || phs->type.GetConst()[kmfs] == LIST_TOKEN)
						|| ((IsSoushokuToken((TokenKind)phs->type.GetConst()[kmfs]) && (phs->type.GetConst()[kmfs+1] == REF_TOKEN
						|| phs->type.GetConst()[kmfs+1] == LIST_TOKEN)) && (kmfs++, true))
						|| ((phs->type.GetConst()[kmfs] == CONST_TOKEN && phs->type.GetConst()[kmfs+1] == REF_TOKEN) && (kmfs++, true)))
					{
						if(corf){
							ErrorMessage.Add(src.filename, src.gyousuu, L"NXł܂B");
							return false;
						}
						switch(src.GetToken(t)){
						case POINT_TOKEN:
							if(conf && phs->type.GetConst()[kmfs] == LIST_TOKEN){
								ErrorMessage.Add(src.filename, src.gyousuu, L"萔list^͂܂B");
								return false;
							}
							if(src.GetToken(t) != SELF_TOKEN){
								ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
								return false;
							}
							if(kmfs >= 1 && phs->type.GetConst()[kmfs-1] == CONST_TOKEN){
								type.AddTail(phs->type.GetConst()+kmfs, phs->type.GetLength()-kmfs-1);
							}else{
								type.AddTail(phs->type.GetConst()+kmfs, phs->type.GetLength()-kmfs);
							}
							break;
						case DIA_TOKEN:
							kmfs++;
							continue;
						default:
							ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
							return false;
						}
					}else if(phs->type.GetConst()[kmfs] == LIB_TOKEN){
						if(corf){
							ErrorMessage.Add(src.filename, src.gyousuu, L"NXł܂B");
							return false;
						}
						if(src.GetToken(t) != POINT_TOKEN){
							ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
							return false;
						}
						kin = src.GetToken(t);
						switch(kin){
						case SELF_TOKEN:
							type += NULL_TOKEN;
							type += ((SourceTree *)phs->type.GetConst()[kmfs+1])->funcid;
							break;
						case OTHERKIND_TOKEN:
							if(L'0' <= src.source.GetConst()[t] && src.source.GetConst()[t] <= L'9'){
								ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
								return false;
							}
							src.idx = t;
							if(!((SourceTree *)phs->type.GetConst()[1])->TypeNanika(type, src, conf, corf, hkishiki)) return false;
							break;
						default:
							ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
							return false;
						}
					}else if((phs->type.GetConst()[kmfs] == FUNC_TOKEN || phs->type.GetConst()[kmfs] == METHOD_TOKEN)
						|| ((IsSoushokuToken((TokenKind)phs->type.GetConst()[kmfs]) && (phs->type.GetConst()[kmfs+1] == FUNC_TOKEN
						|| phs->type.GetConst()[kmfs+1] == METHOD_TOKEN)) && (kmfs++, true))
						|| ((phs->type.GetConst()[kmfs] == CONST_TOKEN && phs->type.GetConst()[kmfs+1] == FUNC_TOKEN) && (kmfs++, true)))
					{
						if(conf && phs->type.GetConst()[kmfs] == METHOD_TOKEN){
							ErrorMessage.Add(src.filename, src.gyousuu, L"萔method^͂܂B");
							return false;
						}
						if(corf){
							ErrorMessage.Add(src.filename, src.gyousuu, L"NXł܂B");
							return false;
						}
						if(src.GetToken(t) != POINT_TOKEN){
							ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
							return false;
						}
						if(src.GetToken(t) != SELF_TOKEN){
							ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
							return false;
						}
						if(kmfs >= 1 && phs->type.GetConst()[kmfs-1] == CONST_TOKEN){
							type.AddTail(phs->type.GetConst()+kmfs, phs->type.GetLength()-kmfs-1);
						}else{
							type.AddTail(phs->type.GetConst()+kmfs, phs->type.GetLength()-kmfs);
						}
					}else{
						if(IsSoushokuToken((TokenKind)phs->type.GetConst()[kmfs])) kmfs++;
						if(conf && phs->type.GetConst()[kmfs] == THREAD_TOKEN){
							ErrorMessage.Add(src.filename, src.gyousuu, L"萔thread^͂܂B");
							return false;
						}
						if(corf){
							ErrorMessage.Add(src.filename, src.gyousuu, L"NXł܂B");
							return false;
						}
						if(src.GetToken(t) != POINT_TOKEN){
							ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
							return false;
						}
						if(src.GetToken(t) != SELF_TOKEN){
							ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
							return false;
						}
						if(phs->type.GetConst()[kmfs] == ENUM_TOKEN || phs->type.GetConst()[kmfs] == THREAD_TOKEN){
							type.AddTail(phs->type.GetConst()+kmfs, 2);
						}else{
							type += phs->type.GetConst()[kmfs];
						}
					}
					break;
				}
				break;
			}
			return true;
		}
		ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
		return false;
	}
	bool LibNanikaPath(PWCArray<intptr_t> & type, Source & src, SourceTree & hkishiki)
	{
		int t;
		int32_t tyki;
		PWCArray<wchar_t> name;
		Hensuu<SourceTree> * phs;
		int ii;
		if((tyki = PathtoClassID(src, FUNC_BLOCK, true, false, hkishiki)) < 0) return false;
		switch(funclist.Get(tyki)->selftype){
		case FUNC_BLOCK:
			if(funclist.Get(tyki) != funclist.Get(tyki)->root){
				ErrorMessage.Add(src.filename, src.gyousuu, L"G[łB");
				return false;
			}
		case CLASS_BLOCK:
			src.GetToken(t);
			src.GetToken(t);
			name.Clear();
			name.AddTail(src.source.GetConst()+t, src.idx-t);
			phs = funclist.Get(tyki)->GetHensuu(name, ii, false);
			if(phs->type.GetConst()[0] != LIB_TOKEN){
				ErrorMessage.Add(src.filename, src.gyousuu, L"lib^ł܂B");
				return false;
			}
			type.AddTail(phs->type.GetConst()+1, phs->type.GetLength()-1);
			break;
		default:
			ErrorMessage.Add(src.filename, src.gyousuu, L"G[łB");
			return false;
		}
		return true;
	}
	bool LibNanika(PWCArray<intptr_t> & type, Source & src, SourceTree & hkishiki)
	{
		SourceTree * pst;
		Hensuu<SourceTree> * phs;
		int t, kmfs, oi, ot, ogy;
		PWCArray<wchar_t> name, tmp, path;
		TokenKind kin;
		kin = src.GetToken(t);
		switch(kin){
		case DQUOT_TOKEN:
		case BACKSLA_TOKEN:
		case SHOU_TOKEN:
			name.Clear();
			if(kin == SHOU_TOKEN){
				src.Find(L'>', t);
				name.AddTail(src.source.GetConst()+t, src.idx-t);
				src.idx++;
			}else{
				src.idx = t;
				if(!MjiretuLiteral(name, src)) return false;
			}
			if(name.GetLength() <= 0){
				ErrorMessage.Add(src.filename, src.gyousuu, L"t@CłB");
				return false;
			}
			if(!KanzenPath(name, (kin==SHOU_TOKEN ? (path=_exedir, path+=L"lib/") : src.filename))){
				ErrorMessage.Add(src.filename, src.gyousuu, L"΃pXւ̕ϊɎs܂B");
				return false;
			}
			name += L'\0';
			if(srclist.Exist(name.GetConst())){
				pst = srclist[name.GetConst()].get();
				do{
					if(pst == root){
						ErrorMessage.Add(src.filename, src.gyousuu, L"CȕzQƂ͂ł܂B");
						return false;
					}
					pst = pst->subsrc;
				}while(pst != NULL);
				type += (intptr_t)srclist[name.GetConst()].get();
			}else{
				pst = subsrc;
				subsrc = new SourceTree;
				subsrc->parent = root;
				if(pst != NULL){
					pst->parent = subsrc;
					subsrc->subsrc = pst;
				}
				if(!subsrc->FileRead(name.GetConst())){
					ErrorMessage.Add(src.filename, src.gyousuu, L"");
					delete subsrc;
					subsrc = NULL;
					return false;
				}
				type += (intptr_t)subsrc;
			}
			return true;
		case MBR_TOKEN:
			if(frp == root || frp->parent == root || frp->selftype == CLASS_BLOCK){
				ErrorMessage.Add(src.filename, src.gyousuu, L"mbr͎g܂B");
				return false;
			}
			switch(src.GetToken(t)){
			case POINT_TOKEN:
				if(src.GetToken(t) != OTHERKIND_TOKEN){
					ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
					return false;
				}
				src.idx = t;
				if(!frp->parent->LibNanika(type, src, hkishiki)) return false;
				break;
			default:
				ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
				return false;
			}
			return true;
		case GBL_TOKEN:
			switch(src.GetToken(t)){
			case POINT_TOKEN:
				if(src.GetToken(t) != OTHERKIND_TOKEN){
					ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
					return false;
				}
				src.idx = t;
				if(!root->LibNanika(type, src, hkishiki)) return false;
				break;
			default:
				ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
				return false;
			}
			return true;
		case OTHERKIND_TOKEN:
			oi = src.idx;
			ot = t;
			ogy = src.gyousuu;
			switch(src.GetToken(t)){
			case SHOUKAKKOOPEN_TOKEN:
			case BRACOLOOPEN_TOKEN:
			case COLOYAJIRUSHI_TOKEN:
			case COLOCOLO_TOKEN:
				src.idx = ot;
				src.gyousuu = ogy;
				if(!LibNanikaPath(type, src, hkishiki)) return false;
				break;
			default:
				src.idx = t;
				name.Clear();
				name.AddTail(src.source.GetConst()+ot, oi-ot);
				if((phs = GetHensuu(name, kmfs, false)) == NULL){
					tmp = L'\'';
					tmp += name;
					tmp += L"' ܂B";
					tmp += L'\0';
					ErrorMessage.Add(src.filename, src.gyousuu, tmp.GetConst());
					return false;
				}
				if(phs->type.GetConst()[0] != LIB_TOKEN){
					tmp = L'\'';
					tmp += name;
					tmp += L"' ̓Cuł܂B";
					tmp += L'\0';
					ErrorMessage.Add(src.filename, src.gyousuu, tmp.GetConst());
					return false;
				}
				if(src.GetToken(t) == POINT_TOKEN){
					if(src.GetToken(t) != OTHERKIND_TOKEN){
						ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
						return false;
					}
					src.idx = t;
					if(!((SourceTree *)phs->type.GetConst()[1])->LibNanika(type, src, hkishiki)) return false;
				}else{
					src.idx = t;
					type += phs->type.GetConst()[1];
				}
				break;
			}
			return true;
		}
		ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
		return false;
	}
	bool KanzenPath(PWCArray<wchar_t> & name, const PWCArray<wchar_t> & karento)
	{
		int i;
		wchar_t * pwc;
		PWCArray<wchar_t> tmp;
		if(name.GetLength() > 0 && name.GetConst()[0] != L'/' && (name.GetLength() < 4 || name.GetConst()[1] != L':')){
			tmp = name;
			name = karento;
			for(i = name.GetLength()-1; i >= 0; i--){
				if(name.GetConst()[i] == L'/' || name.GetConst()[i] == L'\\') break;
			}
			name.SetLength(i+1);
			name += tmp;
		}
		tmp = name;
		tmp += L'\0';
		pwc = _wfullpath(NULL, tmp.GetConst(), 0);
		if(pwc == NULL) return false;
		name = pwc;
		free(pwc);
		for(i = 0; i < name.GetLength(); i++) name.GetData()[i] = tolower(name.GetData()[i]);
		return true;
	}
	bool MjiretuLiteral(PWCArray<wchar_t> & str, Source & src)
	{
		wchar_t wc;
		int t;
		while(true){
			switch(src.GetToken(t)){
			case DQUOT_TOKEN:
				src.Find(L'"', t);
				str.AddTail(src.source.GetConst()+t, src.idx-t);
				src.idx++;
				continue;
			case BACKSLA_TOKEN:
				if(!TokushuMoji(wc, src)) return false;
				str += wc;
				continue;
			default:
				src.idx = t;
				break;
			}
			break;
		}
		return true;
	}
	bool TokushuMoji(wchar_t & wc, Source & src)
	{
		uint64_t ui64;
		int t;
		switch(src.GetChar()){
		case L'0':
			wc = L'\0';
			return true;
		case L't':
			wc =  L'\t';
			return true;
		case L'r':
			wc = L'\r';
			return true;
		case L'n':
			wc = L'\n';
			return true;
		case L'\\':
			wc = L'\\';
			return true;
		case L'\'':
			wc = L'\'';
			return true;
		case L'"':
			wc = L'"';
			return true;
		case L'b':
		case L'd':
		case L'o':
		case L'x':
			src.idx--;
			src.GetToken(t);
			if(!ZeroHajimari(ui64, src.source.GetConst()+t, src.idx-t)){
				ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
				return false;
			}
			wc = (wchar_t)ui64;
			return true;
		}
		ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
		return false;
	}
	int32_t PathtoClassID(Source & src, const BlockType blty, const bool toka, const bool publ, SourceTree & hkishiki)
	{
		TokenKind kin;
		SourceTree * pst, * opst;
		Hensuu<SourceTree> * phs;
		bool pub, kalono, moou;
		BlockType bt;
		int t, oi, ogy, kmfs;
		int32_t fi;
		intptr_t size;
		PWCArray<wchar_t> name, tmp;
		PWCArray<intptr_t> type;
		fi = -1;
		oi = src.idx;
		ogy = src.gyousuu;
		moou = false;
		pst = this;
		pub = publ;
		while(true){
TOPLOOP:
			kin = src.GetToken(t);
			switch(kin){
			case GBL_TOKEN:
				if(toka || moou){
					ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
					return -1;
				}
				pst = root;
				switch(src.GetToken(t)){
				case POINT_TOKEN:
					pst = root;
					moou = true;
					break;
				default:
					ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
					return -1;
				}
				break;
			case MBR_TOKEN:
				if(toka || moou || frp == root || frp->parent == root){
					ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
					return -1;
				}
				switch(src.GetToken(t)){
				case POINT_TOKEN:
					pst = frp->parent;
					moou = true;
					break;
				default:
					ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
					return -1;
				}
				break;
			case OTHERKIND_TOKEN:
				name.Clear();
				name.AddTail(src.source.GetConst()+t, src.idx-t);
				if((fi = pst->GetFuncId(name, true)) < 0){
					if((phs = pst->GetHensuu(name, kmfs, false)) == NULL){
						tmp = L'\'';
						tmp += name;
						tmp += L"' ͒`Ă܂B";
						tmp += L'\0';
						ErrorMessage.Add(src.filename, src.gyousuu, tmp.GetConst());
						return -1;
					}
					switch(phs->type.GetConst()[0]){
					case TYPE_TOKEN:
						if(toka){
							kin = src.GetToken(t);
							if(kin == COLOCOLO_TOKEN){
								src.idx = t;
							}else if(kin == SHOUKAKKOOPEN_TOKEN){
								if(phs->type.GetConst()[1] != NULL_TOKEN){
									ErrorMessage.Add(src.filename, src.gyousuu, L"֐ł܂B");
									return -1;
								}
								src.idx = t;
								return (int32_t)phs->type.GetConst()[2];
							}else{
								src.idx = oi;
								src.gyousuu = ogy;
								return pst->funcid;
							}
						}
						if(phs->type.GetConst()[1] != CLASS_TOKEN
							&& phs->type.GetConst()[1] != ENUM_TOKEN && phs->type.GetConst()[1] != NULL_TOKEN)
						{
							ErrorMessage.Add(src.filename, src.gyousuu, L"G[łB");
							return -1;
						}
						fi = (int32_t)phs->type.GetConst()[2];
						break;
					case LIB_TOKEN:
						switch(src.GetToken(t)){
						case POINT_TOKEN:
							pst = (SourceTree *)phs->type.GetConst()[1];
							pub = true;
							continue;
						default:
							if(toka){
								src.idx = oi;
								src.gyousuu = ogy;
								return pst->funcid;
							}
							ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
							return -1;
						}
						break;
					default:
						ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
						return -1;
					}
				}else if(pst->touka){
					funclist.Get(fi)->parent = pst->parent;
				}
				kalono = false;
				while(true){
					kin = src.GetToken(t);
					switch(kin){
					case BRACOLOOPEN_TOKEN:
						if(kalono){
							ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
							return -1;
						}
						oi = src.idx;
						ogy = src.gyousuu;
						for(kmfs = 1; kmfs != 0 && kin != NULL_TOKEN; ){
							kin = src.GetToken(t);
							switch(kin){
							case BRACOLOOPEN_TOKEN:
								kmfs++;
								break;
							case BRACOLOCLOSE_TOKEN:
								kmfs--;
								break;
							case CHUUKAKKOOPEN_TOKEN:
							case CHUUKAKKOCLOSE_TOKEN:
							case SEMICOLON_TOKEN:
								ErrorMessage.Add(src.filename, src.gyousuu, L"':>' ܂B");
								return -1;
							}
						}
						if(kin == NULL_TOKEN){
							ErrorMessage.Add(src.filename, src.gyousuu, L"':>' ܂B");
							return -1;
						}
						switch(src.GetToken(t)){
						case COLOYAJIRUSHI_TOKEN:
							bt = FUNC_BLOCK;
							break;
						case POINT_TOKEN:
						case COLOCOLO_TOKEN:
							bt = CLASS_BLOCK;
							break;
						default:
							if(blty == ENUM_BLOCK){
								ErrorMessage.Add(src.filename, src.gyousuu, L"enumłB");
								return -1;
							}
							bt = blty;
							break;
						}
						src.idx = oi;
						src.gyousuu = ogy;
						if(!funclist.Get(fi)->kakutei){
							if(funclist.Get(fi)->selftype == UNKNOWN_BLOCK){
								funclist.Get(fi)->selftype = bt;
								funclist.Get(fi)->srce = &src;
								funclist.Get(fi)->topsrcgyo = src.gyousuu;
							}
						}
						if(funclist.Get(fi)->selftype != bt){
							ErrorMessage.Add(src.filename, src.gyousuu, L"^G[łB");
							return -1;
						}
						oi = 0;
						opst = funclist.Get(fi);
						while(true){
							if(opst->tpcount > 0 && oi >= opst->tpcount){
								ErrorMessage.Add(src.filename, src.gyousuu, L"ev[g܂B");
								return -1;
							}
							type.Clear();
							if(!hkishiki.TypeNanika(type, src, false, false, hkishiki)) return -1;
							name.SetLength((sizeof(intptr_t)*type.GetLength()+sizeof(wchar_t)-1)/sizeof(wchar_t));
							memcpy(name.GetData(), type.GetConst(), sizeof(intptr_t)*type.GetLength());
							if((pst = opst->BlockOpen(&name, bt)) == NULL){
								tmp = L'\'';
								tmp += name;
								tmp += L"' ͖OdĂ邩AsłB";
								tmp += L'\0';
								ErrorMessage.Add(src.filename, src.gyousuu, tmp.GetConst());
								return -1;
							}
							if(pst->selftype != opst->selftype){
								ErrorMessage.Add(src.filename, src.gyousuu, L"^G[łB");
								return -1;
							}
							if(!pst->kakutei && funclist.Get(fi)->kakutei){
								pst->parent = opst->parent;
								pst->rettype = opst->rettype;
								pst->tpcount = opst->tpcount;
								pst->funchensuu = opst->funchensuu;
								pst->hensuname = opst->hensuname;
								pst->hensuidx = opst->hensuidx;
								pst->srce = opst->srce;
								pst->topsrcidx = opst->topsrcidx;
								pst->topsrcgyo = opst->topsrcgyo;
								pst->funchensuu.GetData()[oi].type += type;
							}
							opst = pst;
							kin = src.GetToken(t);
							switch(kin){
							case BRACOLOCLOSE_TOKEN:
								oi++;
								break;
							case COMMA_TOKEN:
								oi++;
								pst->kakutei = funclist.Get(fi)->kakutei;
								continue;
							default:
								ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
								return -1;
							}
							break;
						}
						if(pst->tpcount > 0 && oi != pst->tpcount){
							ErrorMessage.Add(src.filename, src.gyousuu, L"ev[g܂B");
							return -1;
						}
						if(!pst->kakutei && funclist.Get(fi)->kakutei){
							oi = pst->srce->idx;
							ogy = pst->srce->gyousuu;
							pst->srce->idx = pst->topsrcidx;
							pst->srce->gyousuu = pst->topsrcgyo;
							if((pst->selftype == FUNC_BLOCK && !pst->KariHikisuu()) || !pst->MakeTree()){
								tokubetuerr = true;
								return -1;
							}
							pst->srce->idx = oi;
							pst->srce->gyousuu = ogy;
							if(pst->selftype == CLASS_BLOCK) pst->ClassShokika();
							pst->kakutei = true;
							size = pst->GetMemberSize();
							for(kmfs = 0; kmfs < pst->backpatch.GetLength(); kmfs++){
								((SourceTree *)pst->backpatch.GetConst()[kmfs])->funchensuu.GetData()[pst->breakpatch.GetConst()[kmfs]].size = size;
							}
							pst->backpatch.Clear();
							pst->breakpatch.Clear();
						}else if(funclist.Get(fi)->tpcount <= 0){
							funclist.Get(fi)->tpcount = oi;
						}
						fi = pst->funcid;
						kalono = true;
						continue;
					case SHOU_TOKEN:
						if(kalono){
							ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
							return -1;
						}
						if(blty == ENUM_BLOCK){
							ErrorMessage.Add(src.filename, src.gyousuu, L"enumłB");
							return -1;
						}
						if(toka){
							ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
							return -1;
						}
						bt = blty;
						oi = -1;
						if(funclist.Get(fi)->selftype == UNKNOWN_BLOCK){
							funclist.Get(fi)->selftype = bt;
							funclist.Get(fi)->srce = &src;
							funclist.Get(fi)->topsrcgyo = src.gyousuu;
						}else{
							oi = funclist.Get(fi)->tpcount;
							funclist.Get(fi)->tpcount = 0;
						}
						if(funclist.Get(fi)->selftype != bt){
							ErrorMessage.Add(src.filename, src.gyousuu, L"^G[łB");
							return -1;
						}
						if((toka || blty == CLASS_BLOCK) && pub){
							if(funclist.Get(fi)->rettype.GetLength() > 0){
								if(!IsPublicToken((TokenKind)funclist.Get(fi)->rettype.GetConst()[0])){
									ErrorMessage.Add(src.filename, src.gyousuu, L"vCx[głB");
									return -1;
								}
							}else{
								funclist.Get(fi)->rettype = PUBLIC_TOKEN;
							}
						}
						kin = src.GetToken(t);
						switch(kin){
						case OTHERKIND_TOKEN:
							while(true){
								if(src.idx-t < 2 || src.source.GetConst()[src.idx-2] != L'_' || src.source.GetConst()[src.idx-1] != L't'){
									ErrorMessage.Add(src.filename, src.gyousuu, L"type^̎ʎq '_t' ŏIȂ΂܂B");
									return -1;
								}
								name.Clear();
								name.AddTail(src.source.GetConst()+t, src.idx-t);
								type = TYPE_TOKEN;
								if(funclist.Get(fi)->GetHensuu(name, kmfs, false) == NULL && !funclist.Get(fi)->AddHensuu(type, name, 0)){
									tmp = L'\'';
									tmp += name;
									tmp += L"' ͂łɒ`Ă܂B";
									tmp += L'\0';
									ErrorMessage.Add(src.filename, src.gyousuu, tmp.GetConst());
									return -1;
								}
								funclist.Get(fi)->tpcount++;
								kin = src.GetToken(t);
								switch(kin){
								case DAI_TOKEN:
									break;
								case COMMA_TOKEN:
									kin = src.GetToken(t);
									switch(kin){
									case OTHERKIND_TOKEN:
										break;
									default:
										ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
										return -1;
									}
									continue;
								default:
									ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
									return -1;
								}
								break;
							}
							if(oi >= 0 && funclist.Get(fi)->tpcount != oi){
								ErrorMessage.Add(src.filename, src.gyousuu, L"ev[g̐܂B");
								return -1;
							}
							return fi;
						default:
							ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
							return -1;
						}
						break;
					case COLOYAJIRUSHI_TOKEN:
						if(funclist.Get(fi)->tpcount > 0
							&& funclist.Get(fi)->funchensuu.GetConst()[funclist.Get(fi)->tpcount-1].type.GetLength() <= 1)
						{
							ErrorMessage.Add(src.filename, src.gyousuu, L"ev[g܂B");
							return -1;
						}
						if(!funclist.Get(fi)->kakutei){
							if(funclist.Get(fi)->selftype == UNKNOWN_BLOCK){
								funclist.Get(fi)->selftype = FUNC_BLOCK;
								funclist.Get(fi)->touka = true;
								funclist.Get(fi)->srce = &src;
								funclist.Get(fi)->topsrcgyo = src.gyousuu;
							}
						}
						if(funclist.Get(fi)->selftype != FUNC_BLOCK || !funclist.Get(fi)->touka){
							ErrorMessage.Add(src.filename, src.gyousuu, L"ߊ֐ł͂܂B");
							return -1;
						}
						if((toka || blty == CLASS_BLOCK) && pub){
							if(funclist.Get(fi)->rettype.GetLength() > 0){
								if(!IsPublicToken((TokenKind)funclist.Get(fi)->rettype.GetConst()[0])){
									ErrorMessage.Add(src.filename, src.gyousuu, L"vCx[głB");
									return -1;
								}
							}else{
								funclist.Get(fi)->rettype = PUBLIC_TOKEN;
							}
						}
						pst = funclist.Get(fi);
						pub = true;
						break;
					case COLOCOLO_TOKEN:
						if(funclist.Get(fi)->tpcount > 0
							&& funclist.Get(fi)->funchensuu.GetConst()[funclist.Get(fi)->tpcount-1].type.GetLength() <= 1)
						{
							ErrorMessage.Add(src.filename, src.gyousuu, L"ev[g܂B");
							return -1;
						}
						while(true){
							if(funclist.Get(fi)->selftype == ENUM_BLOCK){
								if(!toka){
									ErrorMessage.Add(src.filename, src.gyousuu, L"enumłB");
									return -1;
								}
								src.idx = t;
								return fi;
							}
							if(!funclist.Get(fi)->kakutei){
								if(funclist.Get(fi)->selftype == UNKNOWN_BLOCK){
									funclist.Get(fi)->selftype = CLASS_BLOCK;
									funclist.Get(fi)->srce = &src;
									funclist.Get(fi)->topsrcgyo = src.gyousuu;
								}
							}
							if(funclist.Get(fi)->selftype != CLASS_BLOCK){
								ErrorMessage.Add(src.filename, src.gyousuu, L"NXł͂܂B");
								return -1;
							}
							if((toka || blty == CLASS_BLOCK) && pub){
								if(funclist.Get(fi)->rettype.GetLength() > 0){
									if(!IsPublicToken((TokenKind)funclist.Get(fi)->rettype.GetConst()[0])){
										ErrorMessage.Add(src.filename, src.gyousuu, L"vCx[głB");
										return -1;
									}
								}else{
									funclist.Get(fi)->rettype = PUBLIC_TOKEN;
								}
							}
							if(toka){
								oi = t;
								ogy = src.gyousuu;
								if(src.GetToken(t) == OTHERKIND_TOKEN){
									name.Clear();
									name.AddTail(src.source.GetConst()+t, src.idx-t);
									if((phs = funclist.Get(fi)->GetHensuu(name, kmfs, false)) != NULL){
										switch(phs->type.GetConst()[0]){
										case TYPE_TOKEN:
											if(
												(phs->type.GetConst()[1] == CLASS_TOKEN || phs->type.GetConst()[1] == ENUM_TOKEN)
												&& src.GetToken(t) == COLOCOLO_TOKEN)
											{
												fi = (int32_t)phs->type.GetConst()[2];
												pst = funclist.Get(fi);
												pub = true;
												continue;
											}
											break;
										case LIB_TOKEN:
											if(src.GetToken(t) == POINT_TOKEN){
												pst = (SourceTree *)phs->type.GetConst()[1];
												pub = true;
												oi = t;
												ogy = src.gyousuu;
												goto TOPLOOP;
											}
											break;
										}
										src.idx = oi;
										src.gyousuu = ogy;
										return fi;
									}
								}
								ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
								return -1;
							}
							pst = funclist.Get(fi);
							pub = true;
							break;
						}
						break;
					default:
						if(funclist.Get(fi)->tpcount > 0
							&& funclist.Get(fi)->funchensuu.GetConst()[funclist.Get(fi)->tpcount-1].type.GetLength() <= 1)
						{
							ErrorMessage.Add(src.filename, src.gyousuu, L"ev[g܂B");
							return -1;
						}
						if(!funclist.Get(fi)->kakutei){
							if(funclist.Get(fi)->selftype == UNKNOWN_BLOCK){
								funclist.Get(fi)->selftype = blty;
								funclist.Get(fi)->srce = &src;
								funclist.Get(fi)->topsrcgyo = src.gyousuu;
							}
						}
						if(funclist.Get(fi)->selftype != blty){
							ErrorMessage.Add(src.filename, src.gyousuu, L"^G[łB");
							return -1;
						}
						if((toka || blty == CLASS_BLOCK) && pub){
							if(funclist.Get(fi)->rettype.GetLength() > 0){
								if(
									!IsPublicToken((TokenKind)funclist.Get(fi)->rettype.GetConst()[0])
									&& funclist.Get(fi)->selftype != ENUM_BLOCK)
								{
									ErrorMessage.Add(src.filename, src.gyousuu, L"pubNł܂B");
									return -1;
								}
							}else{
								funclist.Get(fi)->rettype = PUBLIC_TOKEN;
							}
						}
						src.idx = t;
						return fi;
					}
					break;
				}
				break;
			default:
				ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
				return -1;
			}
		}
		return fi;
	}
	void ClassShokika()
	{
		PWCArray<wchar_t> name;
		PWCArray<intptr_t> meniya;
		int32_t fi;
		MemberNew(meniya);
		if(meniya.GetLength() > 0){
			name = L"default";
			fi = GetFuncId(name, true);
			funclist.Get(fi)->GblhaniSet(*this);
			funclist.Get(fi)->selftype = FUNC_BLOCK;
			funclist.Get(fi)->rettype = VOID_TOKEN;
			funclist.Get(fi)->token[0] = meniya;
			funclist.Get(fi)->kakutei = true;
		}
		MemberDel(meniya);
		if(meniya.GetLength() > 0){
			name = L"break";
			fi = GetFuncId(name, true);
			funclist.Get(fi)->GblhaniSet(*this);
			funclist.Get(fi)->selftype = FUNC_BLOCK;
			funclist.Get(fi)->rettype = VOID_TOKEN;
			funclist.Get(fi)->token[0] = meniya;
			funclist.Get(fi)->kakutei = true;
		}
	}
	bool BackTemplate(const int ato)
	{
		int i, oi, ogy;
		intptr_t size;
		if(ato <= 0){
			oi = srce->idx;
			ogy = srce->gyousuu;
			srce->idx = topsrcidx;
			srce->gyousuu = topsrcgyo;
			if(selftype == FUNC_BLOCK && !KariHikisuu()) return false;
			if(!MakeTree()) return false;
			srce->idx = oi;
			srce->gyousuu = ogy;
			if(selftype == CLASS_BLOCK) ClassShokika();
			kakutei = true;
			size = GetMemberSize();
			for(i = 0; i < backpatch.GetLength(); i++){
				((SourceTree *)backpatch.GetConst()[i])->funchensuu.GetData()[breakpatch.GetConst()[i]].size = size;
			}
			backpatch.Clear();
			breakpatch.Clear();
			return true;
		}
		if(children.GetLength() <= 0){
			ErrorMessage.Add(srce->filename, topsrcgyo, L"G[łB");
			return false;
		}
		for(i=0; i < children.GetLength(); i++){
			children.GetData()[i]->parent = parent;
			children.GetData()[i]->rettype = rettype;
			children.GetData()[i]->tpcount = tpcount;
			children.GetData()[i]->funchensuu = funchensuu;
			children.GetData()[i]->hensuname = hensuname;
			children.GetData()[i]->hensuidx = hensuidx;
			children.GetData()[i]->srce = srce;
			children.GetData()[i]->topsrcidx = topsrcidx;
			children.GetData()[i]->topsrcgyo = topsrcgyo;
			children.GetData()[i]->funchensuu.GetData()[tpcount-ato].type.AddTail(
				(intptr_t *)subfunc.GetConst()[i]->myname.GetConst(),
				(subfunc.GetConst()[i]->myname.GetLength()*sizeof(wchar_t)+sizeof(intptr_t)-1)/sizeof(intptr_t)
			);
			if(!children.GetData()[i]->BackTemplate(ato-1)) return false;
		}
		kakutei = true;
		return true;
	}
	bool RefTouroku(const PWCArray<intptr_t> & type, int & t, PWCArray<intptr_t> * const ptk)
	{
		PWCArray<wchar_t> name, tmp;
		if(srce->GetToken(t) != OTHERKIND_TOKEN){
			ErrorMessage.Add(srce->filename, srce->gyousuu, L"\G[łB");
			return false;
		}
		name.Clear();
		name.AddTail(srce->source.GetConst()+t, srce->idx-t);
		if(type.GetConst()[0] == CONST_TOKEN){
			if(!AddHensuu(type, name, 0)){
				tmp = L'\'';
				tmp += name;
				tmp += L"' ͖OdĂ邩AsłB";
				tmp += L'\0';
				ErrorMessage.Add(srce->filename, srce->gyousuu, tmp.GetConst());
				return false;
			}
		}else{
			if(!AddHensuu(type, name, sizeof(Reference))){
				tmp = L'\'';
				tmp += name;
				tmp += L"' ͖OdĂ邩AsłB";
				tmp += L'\0';
				ErrorMessage.Add(srce->filename, srce->gyousuu, tmp.GetConst());
				return false;
			}
			if(ptk != NULL){
				if(frp == root) *ptk += GBL_TOKEN;
				*ptk += ~(frp->funchensuu.GetLength()-1);
				*ptk += VOID_TOKEN;
				*ptk += SEMICOLON_TOKEN;
			}
		}
		return true;
	}
	bool ListTouroku(const PWCArray<intptr_t> & type, int & t, PWCArray<intptr_t> * const ptk)
	{
		PWCArray<wchar_t> name, tmp;
		if(srce->GetToken(t) != OTHERKIND_TOKEN){
			ErrorMessage.Add(srce->filename, srce->gyousuu, L"\G[łB");
			return false;
		}
		name.Clear();
		name.AddTail(srce->source.GetConst()+t, srce->idx-t);
		if(!AddHensuu(type, name, sizeof(Reference))){
			tmp = L'\'';
			tmp += name;
			tmp += L"' ͖OdĂ邩AsłB";
			tmp += L'\0';
			ErrorMessage.Add(srce->filename, srce->gyousuu, tmp.GetConst());
			return false;
		}
		if(ptk != NULL){
			if(frp == root) *ptk += GBL_TOKEN;
			*ptk += ~(frp->funchensuu.GetLength()-1);
			*ptk += VOID_TOKEN;
			*ptk += SEMICOLON_TOKEN;
		}
		return true;
	}
	bool ThreadTouroku(const PWCArray<intptr_t> & type, PWCArray<intptr_t> * const ptk)
	{
		int t;
		PWCArray<wchar_t> name, tmp;
		if(srce->GetToken(t) != OTHERKIND_TOKEN){
			ErrorMessage.Add(srce->filename, srce->gyousuu, L"\G[łB");
			return false;
		}
		name.Clear();
		name.AddTail(srce->source.GetConst()+t, srce->idx-t);
		if(!AddHensuu(type, name, sizeof(Thread))){
			tmp = L'\'';
			tmp += name;
			tmp += L"' ͖OdĂ邩AsłB";
			tmp += L'\0';
			ErrorMessage.Add(srce->filename, srce->gyousuu, tmp.GetConst());
			return false;
		}
		if(ptk != NULL){
			if(frp == root) *ptk += GBL_TOKEN;
			*ptk += ~(frp->funchensuu.GetLength()-1);
			*ptk += VOID_TOKEN;
			*ptk += SEMICOLON_TOKEN;
		}
		return true;
	}
	void CallNew(PWCArray<intptr_t> & tk, PWCArray<intptr_t> & meniya)
	{
		PWCArray<wchar_t> name;
		int32_t fi;
		name = L"default";
		if((fi = GetFuncId(name, false)) >= 0){
			tk += meniya;
			tk += SHOUKAKKOOPEN_TOKEN;
			tk += ~fi;
			tk += SHOUKAKKOCLOSE_TOKEN;
			tk += SEMICOLON_TOKEN;
		}
	}
	void MemberNew(PWCArray<intptr_t> & meniya)
	{
		PWCArray<wchar_t> name;
		int32_t fi;
		int ii, il;
		meniya.Clear();
		for(ii = tpcount+hikisuucount; ii < funchensuu.GetLength(); ii++){
			if(funchensuu.GetConst()[ii].type.GetConst()[0] == CONST_TOKEN) continue;
			fi = TokenTtoTypeId(funchensuu.GetConst()[ii].type.GetConst(), il=0);
			if(fi > ENDCLASS_TYPEID) continue;
			if(fi < 0){
				if(fi != REF_TYPEID && fi != LIST_TYPEID && fi < ENDTHREAD_TYPEID) continue;
				meniya += MBR_TOKEN;
				meniya += ~ii;
				meniya += VOID_TOKEN;
				meniya += SEMICOLON_TOKEN;
			}else if(funclist.Get(fi)->selftype == CLASS_BLOCK){
				name = L"default";
				if((fi = funclist.Get(fi)->GetFuncId(name, false)) >= 0){
					meniya += MBR_TOKEN;
					meniya += ~ii;
					meniya += POINT_TOKEN;
					meniya += SHOUKAKKOOPEN_TOKEN;
					meniya += ~fi;
					meniya += SHOUKAKKOCLOSE_TOKEN;
					meniya += SEMICOLON_TOKEN;
				}
			}
		}
		name = L"new";
		if((fi = GetFuncId(name, false)) >= 0){
			if(funclist.Get(fi)->kakutei){
				funclist.Get(fi)->GblhaniSet(*this);
				meniya += MBR_TOKEN;
				meniya += SHOUKAKKOOPEN_TOKEN;
				meniya += ~fi;
				meniya += SHOUKAKKOCLOSE_TOKEN;
				meniya += SEMICOLON_TOKEN;
			}else{
				funclist.Get(fi)->kakutei = true;
				funclist.Get(fi)->gblhani = INT_MAX;
			}
		}
	}
	void CallDel(PWCArray<intptr_t> & tk, PWCArray<intptr_t> & meniya)
	{
		PWCArray<wchar_t> name;
		int32_t fi;
		name = L"break";
		if((fi = GetFuncId(name, false)) >= 0){
			tk += meniya;
			tk += SHOUKAKKOOPEN_TOKEN;
			tk += ~fi;
			tk += SHOUKAKKOCLOSE_TOKEN;
			tk += SEMICOLON_TOKEN;
		}
	}
	void MemberDel(PWCArray<intptr_t> & meniya)
	{
		PWCArray<wchar_t> name;
		int32_t fi;
		int ii, il;
		meniya.Clear();
		name = L"delete";
		if((fi = GetFuncId(name, false)) >= 0){
			if(funclist.Get(fi)->kakutei){
				funclist.Get(fi)->GblhaniSet(*this);
				meniya += MBR_TOKEN;
				meniya += SHOUKAKKOOPEN_TOKEN;
				meniya += ~fi;
				meniya += SHOUKAKKOCLOSE_TOKEN;
				meniya += SEMICOLON_TOKEN;
			}else{
				funclist.Get(fi)->kakutei = true;
				funclist.Get(fi)->gblhani = INT_MAX;
			}
		}
		for(ii = funchensuu.GetLength()-1; ii >= tpcount+hikisuucount; ii--){
			if(funchensuu.GetConst()[ii].type.GetConst()[0] == CONST_TOKEN) continue;
			fi = TokenTtoTypeId(funchensuu.GetConst()[ii].type.GetConst(), il=0);
			if(fi > ENDCLASS_TYPEID) continue;
			if(fi < 0){
				if(fi != REF_TYPEID && fi != LIST_TYPEID && fi < ENDTHREAD_TYPEID) continue;
				meniya += MBR_TOKEN;
				meniya += ~ii;
				meniya += DELETE_TOKEN;
				meniya += SEMICOLON_TOKEN;
			}else if(funclist.Get(fi)->selftype == CLASS_BLOCK){
				name = L"break";
				if((fi = funclist.Get(fi)->GetFuncId(name, false)) >= 0){
					meniya += MBR_TOKEN;
					meniya += ~ii;
					meniya += POINT_TOKEN;
					meniya += SHOUKAKKOOPEN_TOKEN;
					meniya += ~fi;
					meniya += SHOUKAKKOCLOSE_TOKEN;
					meniya += SEMICOLON_TOKEN;
				}
			}
		}
	}
	bool ClassObjToroku(const PWCArray<intptr_t> & type, const int32_t ci, PWCArray<intptr_t> * const ptk)
	{
		PWCArray<wchar_t> name, tmp;
		PWCArray<intptr_t> meniya;
		int t;
		if(srce->GetToken(t) != OTHERKIND_TOKEN){
			ErrorMessage.Add(srce->filename, srce->gyousuu, L"\G[łB");
			return false;
		}
		name.Clear();
		name.AddTail(srce->source.GetConst()+t, srce->idx-t);
		if(!AddHensuu(type, name, funclist.Get(ci)->GetMemberSize())){
			tmp = L'\'';
			tmp += name;
			tmp += L"' ͖OdĂ邩AsłB";
			tmp += L'\0';
			ErrorMessage.Add(srce->filename, srce->gyousuu, tmp.GetConst());
			return false;
		}
		if(ptk != NULL){
			if(frp == root){
				meniya = GBL_TOKEN;
			}else{
				meniya.Clear();
			}
			meniya += ~(frp->funchensuu.GetLength()-1);
			meniya += POINT_TOKEN;
			funclist.Get(ci)->CallNew(*ptk, meniya);
		}
		return true;
	}
	bool KariHikisuu()
	{
		TokenKind kin;
		PWCArray<wchar_t> name, tmp;
		int t;
		intptr_t size;
		PWCArray<intptr_t> type;
		if(srce->GetToken(t) != SHOUKAKKOOPEN_TOKEN){
			ErrorMessage.Add(srce->filename, srce->gyousuu, L"'(' ܂B");
			return false;
		}
		hikisuucount = 0;
		kin = srce->GetToken(t);
		while(kin != SHOUKAKKOCLOSE_TOKEN){
			srce->idx = t;
			type.Clear();
			if(!TypeNanika(type, *srce, false, false, *this)) return false;
			switch(type.GetConst()[0]){
			case REF_TOKEN:
				if(!RefTouroku(type, t, NULL)) return false;
				break;
			case LIST_TOKEN:
				if(!ListTouroku(type, t, NULL)) return false;
				break;
			case THREAD_TOKEN:
				if(!ThreadTouroku(type, NULL)) return false;
				break;
			case CLASS_TOKEN:
				if(!ClassObjToroku(type, (int32_t)type.GetConst()[1], NULL)) return false;
				break;
			default:
				if(srce->GetToken(t) != OTHERKIND_TOKEN){
					ErrorMessage.Add(srce->filename, srce->gyousuu, L"\G[łB");
					return false;
				}
				name.Clear();
				name.AddTail(srce->source.GetConst()+t, srce->idx-t);
				if((size = GetTypeSize(type)) < 0){
					ErrorMessage.Add(srce->filename, srce->gyousuu, L"G[łB");
					return false;
				}
				if(!AddHensuu(type, name, size)){
					tmp = L'\'';
					tmp += name;
					tmp += L"' ͖OdĂ邩AsłB";
					tmp += L'\0';
					ErrorMessage.Add(srce->filename, srce->gyousuu, tmp.GetConst());
					return false;
				}
				break;
			}
			hikisuucount++;
			kin = srce->GetToken(t);
			if(kin == DAINYUU_TOKEN){
				funchensuu.GetData()[funchensuu.GetLength()-1].type += ~DAINYUU_TOKEN;
				funchensuu.GetData()[funchensuu.GetLength()-1].size = sizeof(intptr_t);
				kin = srce->GetToken(t);
			}else{
				if(type.GetConst()[0] == THREAD_TOKEN){
					ErrorMessage.Add(srce->filename, srce->gyousuu, L"thread^͒lnł܂B");
					return false;
				}
				if(type.GetConst()[0] == CLASS_TOKEN && !funclist.Get((int32_t)type.GetConst()[1])->kakutei){
					funclist.Get((int32_t)type.GetConst()[1])->backpatch += (intptr_t)this;
					funclist.Get((int32_t)type.GetConst()[1])->breakpatch += funchensuu.GetLength()-1;
				}
			}
			switch(kin){
			case COMMA_TOKEN:
				srce->GetToken(t);
				break;
			case SHOUKAKKOCLOSE_TOKEN:
				break;
			default:
				return false;
			}
		}
		if(srce->GetToken(t) != CHUUKAKKOOPEN_TOKEN){
			ErrorMessage.Add(srce->filename, srce->gyousuu, L"'{' ܂B");
			return false;
		}
		if(srce->GetToken(t) == COLOYAJIRUSHI_TOKEN){
			touka = true;
		}else{
			if(touka){
				ErrorMessage.Add(srce->filename, srce->gyousuu, L"łɓߊ֐ƂĎgĂ܂B");
				return false;
			}
			srce->idx = t;
		}
		return true;
	}
	bool ReturnType(PWCArray<intptr_t> & type, Source & src, SourceTree & hkishiki)
	{
		TokenKind kin;
		int t;
		int32_t ci;
		kin = src.GetToken(t);
		if(IsReadOnlyToken(kin)){
			type += kin;
			kin = src.GetToken(t);
		}
		switch(kin){
		case BOOL_TOKEN:
		case CHAR_TOKEN:
		case DOUBLE_TOKEN:
		case FLOAT_TOKEN:
		case BYTE_TOKEN:
		case INT_TOKEN:
		case LONG_TOKEN:
		case SHORT_TOKEN:
		case UBYTE_TOKEN:
		case UINT_TOKEN:
		case ULONG_TOKEN:
		case USHORT_TOKEN:
		case INDEX_TOKEN:
		case VOID_TOKEN:
			type += kin;
			break;
		case ENUM_TOKEN:
			type += kin;
			if((ci = PathtoClassID(src, ENUM_BLOCK, false, false, hkishiki)) < 0) return false;
			type += ci;
			break;
		case FUNC_TOKEN:
			type += kin;
			if(!FuncType(type, src, hkishiki)) return false;
			break;
		default:
			ErrorMessage.Add(src.filename, src.gyousuu, L"߂ľ^słB");
			return false;
		}
		return true;
	}
	bool FuncType(PWCArray<intptr_t> & type, Source & src, SourceTree & hkishiki)
	{
		TokenKind kin;
		int t;
		if(!ReturnType(type, src, hkishiki)) return false;
		if(src.GetToken(t) != KAKKOCOLOOPEN_TOKEN){
			ErrorMessage.Add(src.filename, src.gyousuu, L"'(:' ܂B");
			return false;
		}
		type += KAKKOCOLOOPEN_TOKEN;
		if(src.GetToken(t) != KAKKOCOLOCLOSE_TOKEN){
			src.idx = t;
			while(true){
				if(!TypeNanika(type, src, false, false, hkishiki)) return false;
				kin = src.GetToken(t);
				if(kin == DAINYUU_TOKEN){
					type += ~DAINYUU_TOKEN;
					kin = src.GetToken(t);
				}
				switch(kin){
				case COMMA_TOKEN:
					type += COMMA_TOKEN;
					continue;
				case KAKKOCOLOCLOSE_TOKEN:
					break;
				default:
					ErrorMessage.Add(src.filename, src.gyousuu, L"\G[łB");
					return false;
				}
				break;
			}
		}
		type += KAKKOCOLOCLOSE_TOKEN;
		return true;
	}
	bool PluginType(PWCArray<intptr_t> & type, PWCArray<wchar_t> & name)
	{
		TokenKind kin;
		int t;
		if(!ReturnType(type, *srce, *this)) return false;
		if(srce->GetToken(t) != OTHERKIND_TOKEN){
			ErrorMessage.Add(srce->filename, srce->gyousuu, L"\G[łB");
			return false;
		}
		name.Clear();
		name.AddTail(srce->source.GetConst()+t, srce->idx-t);
		if(srce->GetToken(t) != KAKKOCOLOOPEN_TOKEN){
			ErrorMessage.Add(srce->filename, srce->gyousuu, L"'(:' ܂B");
			return false;
		}
		type += KAKKOCOLOOPEN_TOKEN;
		if(srce->GetToken(t) != KAKKOCOLOCLOSE_TOKEN){
			srce->idx = t;
			while(true){
				if(!TypeNanika(type, *srce, false, false, *this)) return false;
				kin = srce->GetToken(t);
				if(kin == DAINYUU_TOKEN){
					type += ~DAINYUU_TOKEN;
					kin = srce->GetToken(t);
				}
				switch(kin){
				case COMMA_TOKEN:
					type += COMMA_TOKEN;
					continue;
				case KAKKOCOLOCLOSE_TOKEN:
					break;
				default:
					ErrorMessage.Add(srce->filename, srce->gyousuu, L"\G[łB");
					return false;
				}
				break;
			}
		}
		type += KAKKOCOLOCLOSE_TOKEN;
		return true;
	}
	bool ClassnoTeisuuDainyuu(const PWCArray<intptr_t> & type, int & t)
	{
		PWCArray<intptr_t> last, tkty;
		PWCArray<wchar_t> name;
		int32_t ci;
		SourceTree * pst;
		PWCArrayQuad< PWCArray<intptr_t> > tmptk;
		if(!ConstShiki(*srce, t, NULL_TOKEN, srce->GetToken(t), last, SEMICOLON_TOKEN, *this)) return false;
		tkty = CONST_TOKEN;
		if(IsSoushokuToken((TokenKind)type.GetConst()[0])){
			tkty.AddTail(type.GetConst()+1, type.GetLength()-1);
		}else{
			tkty += type;
		}
		if(!ConstCaster(last, tkty)){
			ErrorMessage.Add(srce->filename, srce->gyousuu, L"^G[łB");
			return false;
		}
		name = L"new";
		if((ci = GetFuncId(name, true)) < 0){
			ErrorMessage.Add(srce->filename, srce->gyousuu, L"svcȃG[łB");
			return false;
		}
		pst = funclist.Get(ci);
		pst->selftype = FUNC_BLOCK;
		pst->rettype = VOID_TOKEN;
		tmptk = pst->token;
		pst->token.SetLength(1);
		pst->token.GetData()[0] = MBR_TOKEN;
		pst->token.GetData()[0] += ~(funchensuu.GetLength()-1);
		pst->token.GetData()[0] += NULL_TOKEN;
		pst->token.GetData()[0] += DAINYUU_TOKEN;
		pst->token.GetData()[0] += last;
		pst->token.GetData()[0] += DAINYUU_TOKEN;
		pst->token.GetData()[0] += SEMICOLON_TOKEN;
		pst->token += tmptk;
		pst->kakutei = true;
		return true;
	}
	bool HenFuTouroku(PWCArray<intptr_t> & tk, PWCArray<intptr_t> & type)
	{
		TokenKind kin, okin;
		int t, oi, ot, ogy, kmfs;
		int32_t ci, t32;
		intptr_t size;
		bool cst, flu, funcfg;
		SourceTree * pst;
		PWCArray<wchar_t> name, tmp, path;
		PWCArray<intptr_t> last, inty;
		if(type.GetConst()[0] == CORE_TOKEN && selftype != CLASS_BLOCK && root != this){
			ErrorMessage.Add(srce->filename, srce->gyousuu, L"core͒`ł܂B");
			return false;
		}
		if(teigikinshi){
			ErrorMessage.Add(srce->filename, srce->gyousuu, L"ł͒`ł܂B");
			return false;
		}
		cst = type.GetConst()[0] == CONST_TOKEN;
		funcfg = false;
		kmfs = 0;
		if(IsSoushokuToken((TokenKind)type.GetConst()[kmfs])) kmfs++;
		switch(type.GetConst()[kmfs]){
		case REF_TOKEN:
			if(root == this){
				if(returnshita && IsKoukaiHensuuToken((TokenKind)type.GetConst()[0])){
					ErrorMessage.Add(srce->filename, srce->gyousuu, L"O[oreturnoAJO[oϐ`邱Ƃ͂ł܂B");
					return false;
				}
			}
			if(kmfs == type.GetLength()-1){
				if(srce->GetToken(t) != BRACOLOOPEN_TOKEN){
					ErrorMessage.Add(srce->filename, srce->gyousuu, L"'<:' ܂B");
					return false;
				}
				kin = srce->GetToken(t);
				if(kin == CONST_TOKEN){
					type += CONST_TOKEN;
					if(!TypeNanika(type, *srce, true, false, *this)) return false;
				}else if(kin == FUNC_TOKEN || kin == METHOD_TOKEN){
					ErrorMessage.Add(srce->filename, srce->gyousuu, L"֐|C^͒newł܂B");
					return false;
				}else{
					srce->idx = t;
					if(!TypeNanika(type, *srce, false, false, *this)) return false;
				}
				if(srce->GetToken(t) != BRACOLOCLOSE_TOKEN){
					ErrorMessage.Add(srce->filename, srce->gyousuu, L"':>' ܂B");
					return false;
				}
			}
			while(true){
				if(!RefTouroku(type, t, &tk)) return false;
				oi = srce->idx;
				ot = t;
				ogy = srce->gyousuu;
				switch(srce->GetToken(t)){
				case DAINYUU_TOKEN:
					if(cst){
						if(!ConstShiki(*srce, t, NULL_TOKEN, srce->GetToken(t), last, SEMICOLON_TOKEN, *this)) return false;
						if(!ConstCaster(last, type)){
							ErrorMessage.Add(srce->filename, srce->gyousuu, L"^G[łB");
							return false;
						}
						frp->funchensuu.GetData()[frp->funchensuu.GetLength()-1].type = last;
						frp->funchensuu.GetData()[frp->funchensuu.GetLength()-1].size = 0;
						if(srce->source.GetConst()[t] == L',') continue;
					}else if(selftype == CLASS_BLOCK){
						if(!ClassnoTeisuuDainyuu(type, t)) return false;
						if(srce->source.GetConst()[t] == L',') continue;
					}else{
						srce->idx = oi;
						t = ot;
						srce->gyousuu = ogy;
						if(!Shiki(tk, *srce, t, NULL_TOKEN, OTHERKIND_TOKEN, SEMICOLON_TOKEN, *this)) return false;
						tk += SEMICOLON_TOKEN;
						if(srce->source.GetConst()[t] == L',') continue;
					}
					break;
				case COMMA_TOKEN:
					if(cst){
						ErrorMessage.Add(srce->filename, srce->gyousuu, L"萔̒lw肳Ă܂B");
						return false;
					}
					continue;
				case SEMICOLON_TOKEN:
					if(cst){
						ErrorMessage.Add(srce->filename, srce->gyousuu, L"萔̒lw肳Ă܂B");
						return false;
					}
					break;
				default:
					ErrorMessage.Add(srce->filename, srce->gyousuu, L"';' ܂B");
					return false;
				}
				break;
			}
			return true;
		case LIST_TOKEN:
			if(root == this){
				if(returnshita && IsKoukaiHensuuToken((TokenKind)type.GetConst()[0])){
					ErrorMessage.Add(srce->filename, srce->gyousuu, L"O[oreturnoAJO[oϐ`邱Ƃ͂ł܂B");
					return false;
				}
			}
			if(kmfs == type.GetLength()-1){
				if(srce->GetToken(t) != BRACOLOOPEN_TOKEN){
					ErrorMessage.Add(srce->filename, srce->gyousuu, L"'<:' ܂B");
					return false;
				}
				kin = srce->GetToken(t);
				if(kin == CONST_TOKEN){
					type += CONST_TOKEN;
					if(!TypeNanika(type, *srce, true, false, *this)) return false;
				}else if(kin == FUNC_TOKEN || kin == METHOD_TOKEN){
					ErrorMessage.Add(srce->filename, srce->gyousuu, L"֐|C^͒newł܂B");
					return false;
				}else{
					srce->idx = t;
					if(!TypeNanika(type, *srce, false, false, *this)) return false;
				}
				if(srce->GetToken(t) != BRACOLOCLOSE_TOKEN){
					ErrorMessage.Add(srce->filename, srce->gyousuu, L"':>' ܂B");
					return false;
				}
			}
			while(true){
				if(!ListTouroku(type, t, &tk)) return false;
				oi = srce->idx;
				ot = t;
				ogy = srce->gyousuu;
				switch(srce->GetToken(t)){
				case DAINYUU_TOKEN:
					if(!ClassnaiKinsoku()) return false;
					srce->idx = oi;
					t = ot;
					srce->gyousuu = ogy;
					if(!Shiki(tk, *srce, t, NULL_TOKEN, OTHERKIND_TOKEN, SEMICOLON_TOKEN, *this)) return false;
					tk += SEMICOLON_TOKEN;
					if(srce->source.GetConst()[t] == L',') continue;
					break;
				case COMMA_TOKEN:
					continue;
				case SEMICOLON_TOKEN:
					break;
				default:
					ErrorMessage.Add(srce->filename, srce->gyousuu, L"';' ܂B");
					return false;
				}
				break;
			}
			return true;
		case THREAD_TOKEN:
			if(root == this){
				if(returnshita && IsKoukaiHensuuToken((TokenKind)type.GetConst()[0])){
					ErrorMessage.Add(srce->filename, srce->gyousuu, L"O[oreturnoAJO[oϐ`邱Ƃ͂ł܂B");
					return false;
				}
			}
			if(kmfs == type.GetLength()-1){
				if(srce->GetToken(t) != BRACOLOOPEN_TOKEN){
					ErrorMessage.Add(srce->filename, srce->gyousuu, L"'<:' ܂B");
					return false;
				}
				if((ci = PathtoClassID(*srce, FUNC_BLOCK, false, false, *this)) < 0) return false;
				if(funclist.Get(ci)->parent != funclist.Get(ci)->root
					|| (srce->source.GetConst()[srce->idx-1] == L'>' && srce->source.GetConst()[srce->idx-2] != L':'))
				{
					ErrorMessage.Add(srce->filename, srce->gyousuu, L"̓G[łB");
					return false;
				}
				type += ci;
				if(srce->GetToken(t) != BRACOLOCLOSE_TOKEN){
					ErrorMessage.Add(srce->filename, srce->gyousuu, L"':>' ܂B");
					return false;
				}
			}
			while(true){
				if(!ThreadTouroku(type, &tk)) return false;
				switch(srce->GetToken(t)){
				case COMMA_TOKEN:
					continue;
				case SEMICOLON_TOKEN:
					break;
				default:
					ErrorMessage.Add(srce->filename, srce->gyousuu, L"';' ܂B");
					return false;
				}
				break;
			}
			return true;
		case FUNC_TOKEN:
			if(kmfs == type.GetLength()-1 && !FuncType(type, *srce, *this)) return false;
			funcfg = true;
			break;
		case METHOD_TOKEN:
			if(kmfs < type.GetLength()-1){
				ErrorMessage.Add(srce->filename, srce->gyousuu, L"\bhselfŒ`ł܂B");
				return false;
			}
			if(selftype != CLASS_BLOCK){
				ErrorMessage.Add(srce->filename, srce->gyousuu, L"\bh̓NXpłB");
				return false;
			}
			type += funcid;
			if(!FuncType(type, *srce, *this)) return false;
			funcfg = true;
			break;
		case PLUGIN_TOKEN:
			type = CONST_TOKEN;
			type += FUNC_TOKEN;
			if(!PluginType(type, name)) return false;
			if(srce->GetToken(t) != DAINYUU_TOKEN){
				ErrorMessage.Add(srce->filename, srce->gyousuu, L"vOC̃t@Cw肳Ă܂B");
				return false;
			}
			switch(srce->GetToken(t)){
			case DQUOT_TOKEN:
			case BACKSLA_TOKEN:
				path.Clear();
				srce->idx = t;
				if(!MjiretuLiteral(path, *srce)) return false;
				if(path.GetLength() <= 0){
					ErrorMessage.Add(srce->filename, srce->gyousuu, L"t@CłB");
					return false;
				}
				if(!KanzenPath(path, srce->filename)){
					ErrorMessage.Add(srce->filename, srce->gyousuu, L"Ȑ΃pXւ̕ϊɎs܂B");
					return false;
				}
				break;
			default:
				ErrorMessage.Add(srce->filename, srce->gyousuu, L"\G[łB");
				return false;
			}
			if(srce->GetToken(t) != SEMICOLON_TOKEN){
				ErrorMessage.Add(srce->filename, srce->gyousuu, L"';' ܂B");
				return false;
			}
			path += L'\0';
			name += L'\0';
			type += (intptr_t)dlllist[path.GetConst()].getfunc(name.GetConst());
			name.SetLength(name.GetLength()-1);
			if(type.GetConst()[type.GetLength()-1] == NULL){
				ErrorMessage.Add(srce->filename, srce->gyousuu, L"vOCǂݍ߂܂łB");
				return false;
			}
			type.GetData()[type.GetLength()-1] |= INTPTR_MIN;
			if(!AddHensuu(type, name, 0)){
				tmp = L'\'';
				tmp += name;
				tmp += L"' ͖OdĂ邩AsłB";
				tmp += L'\0';
				ErrorMessage.Add(srce->filename, srce->gyousuu, tmp.GetConst());
				return false;
			}
			return true;
		case ENUM_TOKEN:
			if(kmfs < type.GetLength()-1){
				ci = (int32_t)type.GetConst()[++kmfs];
			}else{
				if((ci = PathtoClassID(*srce, ENUM_BLOCK, false, false, *this)) < 0) return false;
				type += ci;
			}
			oi = srce->idx;
			ogy = srce->gyousuu;
			if(!funclist.Get(ci)->kakutei){
				if(frp != this){
					ErrorMessage.Add(srce->filename, srce->gyousuu, L"enum̓TuubNŒ`ł܂B");
					return false;
				}
				if(IsSoushokuToken((TokenKind)type.GetConst()[0])){
					ErrorMessage.Add(srce->filename, srce->gyousuu, L"enumɑq͂܂B");
					return false;
				}
				pst = funclist.Get(ci);
				pst->rettype = type;
				pst->glbconstant = true;
				if(srce->GetToken(t) != CHUUKAKKOOPEN_TOKEN){
					ErrorMessage.Add(srce->filename, srce->gyousuu, L"'{' ܂B");
					return false;
				}
				t32 = 0;
				type = CONST_TOKEN;
				type += ENUM_TOKEN;
				type += ci;
				type.SetLength(type.GetLength()+(sizeof(int32_t)+sizeof(intptr_t)-1)/sizeof(intptr_t));
				inty = CONST_TOKEN;
				inty += INT_TOKEN;
				kin = srce->GetToken(t);
				while(kin != CHUUKAKKOCLOSE_TOKEN){
					if(kin != OTHERKIND_TOKEN){
						ErrorMessage.Add(srce->filename, srce->gyousuu, L"\G[łB");
						return false;
					}
					name.Clear();
					name.AddTail(srce->source.GetConst()+t, srce->idx-t);
					kin = srce->GetToken(t);
					if(kin == DAINYUU_TOKEN){
						if(!ConstShiki(*srce, t, NULL_TOKEN, srce->GetToken(t), last, CHUUKAKKOCLOSE_TOKEN, *this)) return false;
						if(!ConstCaster(last, inty)){
							ErrorMessage.Add(srce->filename, srce->gyousuu, L"^G[łB");
							return false;
						}
						t32 = *(int32_t *)(last.GetConst()+2);
						srce->idx = t;
						kin = srce->GetToken(t);
					}
					switch(kin){
					case COMMA_TOKEN:
						kin = srce->GetToken(t);
						break;
					case OTHERKIND_TOKEN:
						ErrorMessage.Add(srce->filename, srce->gyousuu, L"\G[łB");
						return false;
					}
					*(int32_t *)(type.GetConst()+3) = t32++;
					if(!pst->AddHensuu(type, name, 0)){
						tmp = L'\'';
						tmp += name;
						tmp += L"' ͖OdĂ邩AsłB";
						tmp += L'\0';
						ErrorMessage.Add(srce->filename, srce->gyousuu, tmp.GetConst());
						return false;
					}
				}
				pst->selftype = ENUM_BLOCK;
				pst->kakutei = true;
				return true;
			}
			break;
		case CLASS_TOKEN:
			if(kmfs < type.GetLength()-1){
				ci = (int32_t)type.GetConst()[++kmfs];
				type.SetLength(kmfs);
			}else{
				if((ci = PathtoClassID(*srce, CLASS_BLOCK, false, false, *this)) < 0) return false;
			}
			oi = srce->idx;
			ogy = srce->gyousuu;
			if(!funclist.Get(ci)->kakutei){
				if(frp != this){
					ErrorMessage.Add(srce->filename, srce->gyousuu, L"TuubN̒ł̓NX`ł܂B");
					return false;
				}
				if(type.GetConst()[0] == PROPERTY_TOKEN){
					ErrorMessage.Add(srce->filename, srce->gyousuu, L"propertyŃNX`ł܂B");
					return false;
				}
				if(type.GetConst()[0] == CORE_TOKEN){
					ErrorMessage.Add(srce->filename, srce->gyousuu, L"coreŃNX`ł܂B");
					return false;
				}
				pst = funclist.Get(ci);
				if(srce->source.GetConst()[srce->idx-1] == L'>' && srce->source.GetConst()[srce->idx-2] == L':'){
					ErrorMessage.Add(srce->filename, srce->gyousuu, L"̓G[łB");
					return false;
				}
				if(pst->rettype.GetLength() > 0 && !IsPublicToken((TokenKind)type.GetConst()[0])){
					ErrorMessage.Add(srce->filename, srce->gyousuu, L"łɃpubNƂĎgĂ܂B");
					return false;
				}
				pst->rettype = type;
				if(cst) pst->glbconstant = true;
				if(srce->source.GetConst()[srce->idx-1] == L'>'){
					if((kin = srce->GetToken(t)) != CHUUKAKKOOPEN_TOKEN){
						ErrorMessage.Add(srce->filename, srce->gyousuu, L"'{' ܂B");
						return false;
					}
					pst->topsrcidx = srce->idx;
					pst->topsrcgyo = srce->gyousuu;
					for(kmfs = 1; kmfs != 0 && kin != NULL_TOKEN; ){
						kin = srce->GetToken(t);
						switch(kin){
						case CHUUKAKKOOPEN_TOKEN:
							kmfs++;
							break;
						case CHUUKAKKOCLOSE_TOKEN:
							kmfs--;
							break;
						}
					}
					if(kin == NULL_TOKEN){
						ErrorMessage.Add(srce->filename, pst->topsrcgyo, L"'}' ܂B");
						return false;
					}
					if(pst->children.GetLength() > 0 && !pst->BackTemplate(pst->tpcount)) return false;
				}else{
					if(srce->GetToken(t) != CHUUKAKKOOPEN_TOKEN){
						ErrorMessage.Add(srce->filename, srce->gyousuu, L"`ĂȂNXgƂA '{' ܂B");
						return false;
					}
					if(!pst->MakeTree()) return false;
					pst->ClassShokika();
				}
				pst->kakutei = true;
				size = pst->GetMemberSize();
				for(kmfs = 0; kmfs < pst->backpatch.GetLength(); kmfs++){
					((SourceTree *)pst->backpatch.GetConst()[kmfs])->funchensuu.GetData()[pst->breakpatch.GetConst()[kmfs]].size = size;
				}
				pst->backpatch.Clear();
				pst->breakpatch.Clear();
			}else{
				if(root == this){
					if(returnshita && IsKoukaiHensuuToken((TokenKind)type.GetConst()[0])){
						ErrorMessage.Add(srce->filename, srce->gyousuu, L"O[oreturnoAJO[oϐ`邱Ƃ͂ł܂B");
						return false;
					}
				}
				if(cst){
					ErrorMessage.Add(srce->filename, srce->gyousuu, L"萔̃NXIuWFNg͂܂B");
					return false;
				}
				if(srce->source.GetConst()[srce->idx-1] == L'>' && srce->source.GetConst()[srce->idx-2] != L':'){
					ErrorMessage.Add(srce->filename, srce->gyousuu, L"̓G[łB");
					return false;
				}
				type += ci;
				while(true){
					if(!ClassObjToroku(type, ci, &tk)) return false;
					switch(srce->GetToken(t)){
					case COMMA_TOKEN:
						continue;
					case SEMICOLON_TOKEN:
						break;
					default:
						ErrorMessage.Add(srce->filename, srce->gyousuu, L"';' ܂B");
						return false;
					}
					break;
				}
			}
			return true;
		case TYPE_TOKEN:
			while(true){
				if(srce->GetToken(t) != OTHERKIND_TOKEN){
					ErrorMessage.Add(srce->filename, srce->gyousuu, L"\G[łB");
					return false;
				}
				name.Clear();
				name.AddTail(srce->source.GetConst()+t, srce->idx-t);
				if(srce->GetToken(t) != DAINYUU_TOKEN){
					ErrorMessage.Add(srce->filename, srce->gyousuu, L"^w肵Ă܂B");
					return false;
				}
				if(!TypeNanika(type, *srce, false, false, *this)) return false;
				switch(srce->GetToken(t)){
				case COMMA_TOKEN:
					if(!AddHensuu(type, name, 0)){
						tmp = L'\'';
						tmp += name;
						tmp += L"' ͖OdĂ邩AsłB";
						tmp += L'\0';
						ErrorMessage.Add(srce->filename, srce->gyousuu, tmp.GetConst());
						return false;
					}
					type.SetLength(1);
					continue;
				case SEMICOLON_TOKEN:
					if(!AddHensuu(type, name, 0)){
						tmp = L'\'';
						tmp += name;
						tmp += L"' ͖OdĂ邩AsłB";
						tmp += L'\0';
						ErrorMessage.Add(srce->filename, srce->gyousuu, tmp.GetConst());
						return false;
					}
					break;
				default:
					ErrorMessage.Add(srce->filename, srce->gyousuu, L"';' ܂B");
					return false;
				}
				break;
			}
			return true;
		case LIB_TOKEN:
			while(true){
				if(srce->GetToken(t) != OTHERKIND_TOKEN){
					ErrorMessage.Add(srce->filename, srce->gyousuu, L"\G[łB");
					return false;
				}
				name.Clear();
				name.AddTail(srce->source.GetConst()+t, srce->idx-t);
				if(srce->GetToken(t) != DAINYUU_TOKEN){
					ErrorMessage.Add(srce->filename, srce->gyousuu, L"Cuw肵Ă܂B");
					return false;
				}
				if(!LibNanika(type, *srce, *this)) return false;
				switch(srce->GetToken(t)){
				case COMMA_TOKEN:
					if(!AddHensuu(type, name, 0)){
						tmp = L'\'';
						tmp += name;
						tmp += L"' ͖OdĂ邩AsłB";
						tmp += L'\0';
						ErrorMessage.Add(srce->filename, srce->gyousuu, tmp.GetConst());
						return false;
					}
					type.SetLength(1);
					continue;
				case SEMICOLON_TOKEN:
					if(!AddHensuu(type, name, 0)){
						tmp = L'\'';
						tmp += name;
						tmp += L"' ͖OdĂ邩AsłB";
						tmp += L'\0';
						ErrorMessage.Add(srce->filename, srce->gyousuu, tmp.GetConst());
						return false;
					}
					break;
				default:
					ErrorMessage.Add(srce->filename, srce->gyousuu, L"';' ܂B");
					return false;
				}
				break;
			}
			return true;
		}
		if((size = GetTypeSize(type)) < 0){
			ErrorMessage.Add(srce->filename, srce->gyousuu, L"֐̈XgȂA֐^ƂĈƂ܂B");
			return false;
		}
		kin = srce->GetToken(t);
		okin = kin;
		oi = srce->idx;
		ot = t;
		ogy = srce->gyousuu;
		flu = false;
		switch(kin){
		case OTHERKIND_TOKEN:
			kin = srce->GetToken(t);
			switch(kin){
			case SHOUKAKKOOPEN_TOKEN:
			case BRACOLOOPEN_TOKEN:
			case SHOU_TOKEN:
			case COLOCOLO_TOKEN:
			case COLOYAJIRUSHI_TOKEN:
			case POINT_TOKEN:
				flu = true;
				break;
			}
			kin = okin;
			srce->idx = oi;
			t = ot;
			srce->gyousuu = ogy;
			break;
		case GBL_TOKEN:
		case MBR_TOKEN:
			flu = true;
			break;
		}
		if(flu){
			if(frp != this){
				ErrorMessage.Add(srce->filename, srce->gyousuu, L"TuubN̒ł͊֐`ł܂B");
				return false;
			}
			srce->idx = t;
			if((ci = PathtoClassID(*srce, FUNC_BLOCK, false, false, *this)) < 0) return false;
			pst = funclist.Get(ci);
			if(pst->kakutei){
				ErrorMessage.Add(srce->filename, srce->gyousuu, L"łɒ`Ă܂B");
				return false;
			}
			if(srce->source.GetConst()[srce->idx-1] == L'>' && srce->source.GetConst()[srce->idx-2] == L':'){
				ErrorMessage.Add(srce->filename, srce->gyousuu, L"̓G[łB");
				return false;
			}
			if(pst->rettype.GetLength() > 0 && !IsPublicToken((TokenKind)type.GetConst()[0])){
				ErrorMessage.Add(srce->filename, srce->gyousuu, L"łɃpubNƂĎgĂ܂B");
				return false;
			}
			if(pst->parent == pst->root){
				if(type.GetConst()[0] == PROPERTY_TOKEN){
					ErrorMessage.Add(srce->filename, srce->gyousuu, L"O[oproperty֐͒`ł܂B");
					return false;
				}else if(pst->root->returnshita && IsPublicToken((TokenKind)type.GetConst()[0])){
					for(kmfs = 0; kmfs < pst->root->children.GetLength(); kmfs++){
						if(pst->root->children.GetConst()[kmfs] == pst) break;
					}
					if(kmfs < pst->root->children.GetLength()){
						ErrorMessage.Add(srce->filename, srce->gyousuu, L"O[oreturnoAconstłȂJO[o֐`邱Ƃ͂ł܂B");
						return false;
					}
				}
			}
			pst->srce = srce;
			pst->rettype = type;
			if(cst) pst->glbconstant = true;
			if(srce->source.GetConst()[srce->idx-1] == L'>' && srce->source.GetConst()[srce->idx-2] != L':'){
				pst->topsrcidx = srce->idx;
				pst->topsrcgyo = srce->gyousuu;
				if(srce->GetToken(t) != SHOUKAKKOOPEN_TOKEN){
					ErrorMessage.Add(srce->filename, srce->gyousuu, L"'(' ܂B");
					return false;
				}
				for(kmfs = 1; kmfs != 0 && kin != NULL_TOKEN; ){
					kin = srce->GetToken(t);
					switch(kin){
					case SHOUKAKKOOPEN_TOKEN:
						kmfs++;
						break;
					case SHOUKAKKOCLOSE_TOKEN:
						kmfs--;
						break;
					case CHUUKAKKOOPEN_TOKEN:
					case CHUUKAKKOCLOSE_TOKEN:
					case SEMICOLON_TOKEN:
						ErrorMessage.Add(srce->filename, srce->gyousuu, L"')' ܂B");
						return false;
					}
				}
				if(kin == NULL_TOKEN){
					ErrorMessage.Add(srce->filename, srce->gyousuu, L"')' ܂B");
					return false;
				}
				if(srce->GetToken(t) != CHUUKAKKOOPEN_TOKEN){
					ErrorMessage.Add(srce->filename, srce->gyousuu, L"'{' ܂B");
					return false;
				}
				for(kmfs = 1; kmfs != 0 && kin != NULL_TOKEN; ){
					kin = srce->GetToken(t);
					switch(kin){
					case CHUUKAKKOOPEN_TOKEN:
						kmfs++;
						break;
					case CHUUKAKKOCLOSE_TOKEN:
						kmfs--;
						break;
					}
				}
				if(kin == NULL_TOKEN){
					ErrorMessage.Add(srce->filename, pst->topsrcgyo, L"'}' ܂B");
					return false;
				}
				if(pst->children.GetLength() > 0 && !pst->BackTemplate(pst->tpcount)) return false;
			}else{
				if(!pst->KariHikisuu()) return false;
				if(!pst->MakeTree()) return false;
			}
			pst->kakutei = true;
			return true;
		}
		if(kin != OTHERKIND_TOKEN){
			ErrorMessage.Add(srce->filename, srce->gyousuu, L"\G[łB");
			return false;
		}
		if(root == this){
			if(returnshita && IsKoukaiHensuuToken((TokenKind)type.GetConst()[0])){
				ErrorMessage.Add(srce->filename, srce->gyousuu, L"O[oreturnoAJO[oϐ`邱Ƃ͂ł܂B");
				return false;
			}
		}
		name.Clear();
		name.AddTail(srce->source.GetConst()+t, srce->idx-t);
		kin = srce->GetToken(t);
		switch(kin){
		case DAINYUU_TOKEN:
			if(cst){
				if(!ConstShiki(*srce, t, NULL_TOKEN, srce->GetToken(t), last, SEMICOLON_TOKEN, *this)) return false;
				if(!ConstCaster(last, type)){
					ErrorMessage.Add(srce->filename, srce->gyousuu, L"^G[łB");
					return false;
				}
				if(!AddHensuu(last, name, 0)){
					tmp = L'\'';
					tmp += name;
					tmp += L"' ͖OdĂ邩AsłB";
					tmp += L'\0';
					ErrorMessage.Add(srce->filename, srce->gyousuu, tmp.GetConst());
					return false;
				}
				if(srce->source.GetConst()[t] == L','){
					if(!HenFuTouroku(tk, type)) return false;
				}
			}else if(selftype == CLASS_BLOCK){
				if(!AddHensuu(type, name, size)){
					tmp = L'\'';
					tmp += name;
					tmp += L"' ͖OdĂ邩AsłB";
					tmp += L'\0';
					ErrorMessage.Add(srce->filename, srce->gyousuu, tmp.GetConst());
					return false;
				}
				if(!ClassnoTeisuuDainyuu(type, t)) return false;
				if(srce->source.GetConst()[t] == L','){
					if(!HenFuTouroku(tk, type)) return false;
				}
			}else{
				if(!AddHensuu(type, name, size)){
					tmp = L'\'';
					tmp += name;
					tmp += L"' ͖OdĂ邩AsłB";
					tmp += L'\0';
					ErrorMessage.Add(srce->filename, srce->gyousuu, tmp.GetConst());
					return false;
				}
				srce->idx = oi;
				t = ot;
				srce->gyousuu = ogy;
				if(!Shiki(tk, *srce, t, NULL_TOKEN, OTHERKIND_TOKEN, SEMICOLON_TOKEN, *this)) return false;
				tk += SEMICOLON_TOKEN;
				if(srce->source.GetConst()[t] == L','){
					if(!HenFuTouroku(tk, type)) return false;
				}
			}
			break;
		case COMMA_TOKEN:
			if(cst || funcfg){
				ErrorMessage.Add(srce->filename, srce->gyousuu, L"lw肳Ă܂B");
				return false;
			}
			if(!AddHensuu(type, name, size)){
				tmp = L'\'';
				tmp += name;
				tmp += L"' ͖OdĂ邩AsłB";
				tmp += L'\0';
				ErrorMessage.Add(srce->filename, srce->gyousuu, tmp.GetConst());
				return false;
			}
			if(!HenFuTouroku(tk, type)) return false;
			break;
		case SEMICOLON_TOKEN:
			if(cst || funcfg){
				ErrorMessage.Add(srce->filename, srce->gyousuu, L"lw肳Ă܂B");
				return false;
			}
			if(!AddHensuu(type, name, size)){
				tmp = L'\'';
				tmp += name;
				tmp += L"' ͖OdĂ邩AsłB";
				tmp += L'\0';
				ErrorMessage.Add(srce->filename, srce->gyousuu, tmp.GetConst());
				return false;
			}
			break;
		default:
			ErrorMessage.Add(srce->filename, srce->gyousuu, L"';' ܂B");
			return false;
		}
		return true;
	}
	bool SetType(PWCArray<intptr_t> & type, const TokenKind oskin)
	{
		TokenKind kin;
		bool pubdsk, constdsk, propdsk, coredsk;
		int t;
		kin = oskin;
		pubdsk = constdsk = propdsk = coredsk = false;
		type.Clear();
		while(kin != NULL_TOKEN){
			type += kin;
			switch(kin){
			case PUBLIC_TOKEN:
			case CONST_TOKEN:
			case PROPERTY_TOKEN:
			case CORE_TOKEN:
				if(pubdsk || constdsk || propdsk || coredsk){
					ErrorMessage.Add(srce->filename, srce->gyousuu, L"qȏd˂邱Ƃ͂ł܂B");
					return false;
				}
				pubdsk = kin == PUBLIC_TOKEN;
				constdsk = kin == CONST_TOKEN;
				propdsk = kin == PROPERTY_TOKEN;
				coredsk = kin == CORE_TOKEN;
				kin = srce->GetToken(t);
				continue;
			case BOOL_TOKEN:
			case CHAR_TOKEN:
			case DOUBLE_TOKEN:
			case FLOAT_TOKEN:
			case BYTE_TOKEN:
			case INT_TOKEN:
			case LONG_TOKEN:
			case SHORT_TOKEN:
			case UBYTE_TOKEN:
			case UINT_TOKEN:
			case ULONG_TOKEN:
			case USHORT_TOKEN:
			case INDEX_TOKEN:
			case VOID_TOKEN:
			case ENUM_TOKEN:
			case REF_TOKEN:
			case FUNC_TOKEN:
				if(coredsk){
					ErrorMessage.Add(srce->filename, srce->gyousuu, L"core̓NXłB");
					return false;
				}
				break;
			case CLASS_TOKEN:
				break;
			case LIST_TOKEN:
			case METHOD_TOKEN:
			case THREAD_TOKEN:
				if(constdsk){
					ErrorMessage.Add(srce->filename, srce->gyousuu, L"萔ɂȂ܂B");
					return false;
				}
				if(coredsk){
					ErrorMessage.Add(srce->filename, srce->gyousuu, L"core̓NXłB");
					return false;
				}
				break;
			case TYPE_TOKEN:
			case LIB_TOKEN:
			case PLUGIN_TOKEN:
				if(pubdsk || constdsk || propdsk || coredsk){
					ErrorMessage.Add(srce->filename, srce->gyousuu, L"q͂܂B");
					return false;
				}
				break;
			default:
				ErrorMessage.Add(srce->filename, srce->gyousuu, L"\G[łB");
				return false;
			}
			break;
		}
		if(kin == NULL_TOKEN){
			ErrorMessage.Add(srce->filename, srce->gyousuu, L"G[łB");
			return false;
		}
		return true;
	}
	bool Teigi(PWCArray<intptr_t> & tk, const TokenKind oskin)
	{
		PWCArray<intptr_t> type;
		if(!SetType(type, oskin)) return false;
		if(!HenFuTouroku(tk, type)) return false;
		return true;
	}
	Hensuu<SourceTree> * GetHensuu(const PWCArray<wchar_t> & name, int & iii, bool cst)
	{
		SourceTree * pst;
		pst = this;
		int ii;
		while(true){
			for(ii = 0; ii < (!pst->breakin||pst->breaknaihani<0 ? pst->hensuname.GetLength() : breaknaihani); ii++){
				if(name == pst->hensuname.GetConst()[ii]){
					if(cst && frp->funchensuu.GetConst()[pst->hensuidx.GetConst()[ii]].type.GetConst()[0] != CONST_TOKEN) return NULL;
					iii = pst->hensuidx.GetConst()[ii];
					return frp->funchensuu.GetData() + pst->hensuidx.GetConst()[ii];
				}
			}
			if(ii < pst->hensuname.GetLength()) break;
			if(pst == frp) return NULL;
			ii = 0;
			pst = pst->parent;
		}
		return NULL;
	}
	bool TeigitoIfKinshi()
	{
		TokenKind ki;
		int t, oi, ot, ogy;
		PWCArray<intptr_t> type;
		switch(srce->GetToken(t)){
		case CONST_TOKEN:
		case PUBLIC_TOKEN:
		case PROPERTY_TOKEN:
		case CORE_TOKEN:
		case BOOL_TOKEN:
		case BYTE_TOKEN:
		case CHAR_TOKEN:
		case CLASS_TOKEN:
		case DOUBLE_TOKEN:
		case ENUM_TOKEN:
		case FLOAT_TOKEN:
		case INT_TOKEN:
		case LONG_TOKEN:
		case LIST_TOKEN:
		case REF_TOKEN:
		case SHORT_TOKEN:
		case TYPE_TOKEN:
		case UBYTE_TOKEN:
		case UINT_TOKEN:
		case ULONG_TOKEN:
		case USHORT_TOKEN:
		case INDEX_TOKEN:
		case VOID_TOKEN:
		case LIB_TOKEN:
		case FUNC_TOKEN:
		case PLUGIN_TOKEN:
		case METHOD_TOKEN:
		case THREAD_TOKEN:
		case NEW_TOKEN:
		case DELETE_TOKEN:
			ErrorMessage.Add(srce->filename, srce->gyousuu, L"Œ`͂ł܂B");
			return false;
		case CHUUKAKKOCLOSE_TOKEN:
		case NULL_TOKEN:
			ErrorMessage.Add(srce->filename, srce->gyousuu, L"G[łB");
			return false;
		case IF_TOKEN:
			ErrorMessage.Add(srce->filename, srce->gyousuu, L"if͏܂B");
			return false;
		case CASE_TOKEN:
		case COND_TOKEN:
		case DIFF_TOKEN:
		case COMM_TOKEN:
			ErrorMessage.Add(srce->filename, srce->gyousuu, L"Ƀx͏܂B");
			return false;
		case BREAK_TOKEN:
		case WHILE_TOKEN:
		case DEFAULT_TOKEN:
		case DO_TOKEN:
		case ELSE_TOKEN:
		case CONTINUE_TOKEN:
			oi = srce->idx;
			ot = t;
			ogy = srce->gyousuu;
			ki = srce->GetToken(t);
			if(ki != SEMICOLON_TOKEN && ki != COMMA_TOKEN){
				ErrorMessage.Add(srce->filename, srce->gyousuu, L"Ƀx͏܂B");
				return false;
			}
			srce->idx = oi;
			t = ot;
			srce->gyousuu = ogy;
			break;
		case MBR_TOKEN:
		case GBL_TOKEN:
		case COLOCOLO_TOKEN:
		case TENTEN_TOKEN:
		case OTHERKIND_TOKEN:
			oi = srce->idx;
			ot = t;
			ogy = srce->gyousuu;
			srce->idx = t;
			type.Clear();
			if(TypeNanika(type, *srce, false, false, *this)){
				ErrorMessage.Add(srce->filename, srce->gyousuu, L"Œ`͂ł܂B");
				return false;
			}
			if(tokubetuerr) return false;
			ErrorMessage.Clear();
			srce->idx = oi;
			t = ot;
			srce->gyousuu = ogy;
			break;
		}
		srce->idx = t;
		return true;
	}
	bool BlockOpenKinshi()
	{
		int t;
		switch(srce->GetToken(t)){
		case CHUUKAKKOOPEN_TOKEN:
		case SWITCH_TOKEN:
		case BRANCH_TOKEN:
		case LOOP_TOKEN:
		case LOCK_TOKEN:
			ErrorMessage.Add(srce->filename, srce->gyousuu, L"ɃubN͏܂B");
			return false;
		}
		srce->idx = t;
		return true;
	}
	bool ClassnaiKinsoku()
	{
		if(selftype == CLASS_BLOCK){
			ErrorMessage.Add(srce->filename, srce->gyousuu, L"NXɏ̂͒`łB");
			return false;
		}
		return true;
	}
	bool KoubunKanouJoutai(const BlockType bt)
	{
		if((selftype != bt && bt != NORMAL_BLOCK) || frp == this || breakin){
			ErrorMessage.Add(srce->filename, srce->gyousuu, L"ł͂ł܂B");
			return false;
		}
		return true;
	}
	bool Bun(PWCArray<intptr_t> & tk, int & t, const TokenKind kin)
	{
		if(!Shiki(tk, *srce, t, NULL_TOKEN, kin, SEMICOLON_TOKEN, *this)) return false;
		if(srce->source.GetConst()[t] == L','){
			ErrorMessage.Add(srce->filename, srce->gyousuu, L"',' słB");
			return false;
		}
		return true;
	}
	bool MakeTreeSwitch(PWCArray<intptr_t> & tk, int & t, const TokenKind kin)
	{
		PWCArray<intptr_t> type;
		int oi, ot, ogy, ii;
		TokenKind ki;
		SourceTree * pst;
		int32_t fi, ipr;
		PWCArray<wchar_t> name;
		switch(kin){
		case CONST_TOKEN:
		case PUBLIC_TOKEN:
		case PROPERTY_TOKEN:
		case CORE_TOKEN:
			oi = srce->idx;
			ot = t;
			ogy = srce->gyousuu;
			type = kin;
			if(TypeNanika(type, *srce, kin == CONST_TOKEN, kin == CORE_TOKEN, *this)){
				if(!HenFuTouroku(tk, type)) return false;
				break;
			}
			if(tokubetuerr) return false;
			ErrorMessage.Clear();
			srce->idx = oi;
			t = ot;
			srce->gyousuu = ogy;
		case BOOL_TOKEN:
		case BYTE_TOKEN:
		case CHAR_TOKEN:
		case CLASS_TOKEN:
		case DOUBLE_TOKEN:
		case ENUM_TOKEN:
		case FLOAT_TOKEN:
		case INT_TOKEN:
		case LONG_TOKEN:
		case LIST_TOKEN:
		case REF_TOKEN:
		case SHORT_TOKEN:
		case TYPE_TOKEN:
		case UBYTE_TOKEN:
		case UINT_TOKEN:
		case ULONG_TOKEN:
		case USHORT_TOKEN:
		case INDEX_TOKEN:
		case VOID_TOKEN:
		case LIB_TOKEN:
		case FUNC_TOKEN:
		case PLUGIN_TOKEN:
		case METHOD_TOKEN:
		case THREAD_TOKEN:
			if(!Teigi(tk, kin)) return false;
			break;
		case NEW_TOKEN:
		case DELETE_TOKEN:
			if(selftype != CLASS_BLOCK){
				ErrorMessage.Add(srce->filename, srce->gyousuu, L"NXłȂƂ܂B");
				return false;
			}
			name.Clear();
			name.AddTail(srce->source.GetConst()+t, srce->idx-t);
			if((fi = GetFuncId(name, true)) < 0){
				ErrorMessage.Add(srce->filename, srce->gyousuu, L"svcȃG[łB");
				return false;
			}
			if(funclist.Get(fi)->mbrhani != INT_MAX){
				ErrorMessage.Add(srce->filename, srce->gyousuu, L"łɒ`Ă܂B");
				return false;
			}
			funclist.Get(fi)->mbrhani = funclist.Get(fi)->parent->hensuidx.GetLength();
			funclist.Get(fi)->selftype = FUNC_BLOCK;
			funclist.Get(fi)->rettype = VOID_TOKEN;
			if(srce->GetToken(t) != SHOUKAKKOOPEN_TOKEN
				|| srce->GetToken(t) != SHOUKAKKOCLOSE_TOKEN || srce->GetToken(t) != CHUUKAKKOOPEN_TOKEN)
			{
				ErrorMessage.Add(srce->filename, srce->gyousuu, L"\G[łB");
				return false;
			}
			if(srce->GetToken(t) == COLOYAJIRUSHI_TOKEN){
				funclist.Get(fi)->touka = true;
			}else{
				srce->idx = t;
			}
			if(!funclist.Get(fi)->MakeTree()) return false;
			funclist.Get(fi)->kakutei = true;
			break;
		case OTHERKIND_TOKEN:
			oi = srce->idx;
			ot = t;
			ogy = srce->gyousuu;
			srce->idx = t;
			type.Clear();
			if(TypeNanika(type, *srce, false, false, *this) && srce->GetToken(t) != SHOUKAKKOOPEN_TOKEN){
				srce->idx = t;
				if(!HenFuTouroku(tk, type)) return false;
				break;
			}
			if(tokubetuerr) return false;
			ErrorMessage.Clear();
			srce->idx = oi;
			t = ot;
			srce->gyousuu = ogy;
			if(!ClassnaiKinsoku()) return false;
			if(!Bun(tk, t, kin)) return false;
			tk += SEMICOLON_TOKEN;
			break;
		case MBR_TOKEN:
		case GBL_TOKEN:
			oi = srce->idx;
			ot = t;
			ogy = srce->gyousuu;
			srce->idx = t;
			type.Clear();
			if(TypeNanika(type, *srce, false, false, *this) && srce->GetToken(t) != SHOUKAKKOOPEN_TOKEN){
				srce->idx = t;
				if(!HenFuTouroku(tk, type)) return false;
				break;
			}
			if(tokubetuerr) return false;
			ErrorMessage.Clear();
			srce->idx = oi;
			t = ot;
			srce->gyousuu = ogy;
		case PULUS_TOKEN:
		case MINUS_TOKEN:
		case EXCLAMATION_TOKEN:
		case SHOUKAKKOOPEN_TOKEN:
		case SQUOT_TOKEN:
		case DQUOT_TOKEN:
		case FALSE_TOKEN:
		case TRUE_TOKEN:
		case SELF_TOKEN:
		case WAIT_TOKEN:
		case LEN_TOKEN:
			if(!ClassnaiKinsoku()) return false;
			if(!Bun(tk, t, kin)) return false;
			tk += SEMICOLON_TOKEN;
			break;
		case RETURN_TOKEN:
			if(!ClassnaiKinsoku()) return false;
			if(breakinnest){
				ErrorMessage.Add(srce->filename, srce->gyousuu, L"breakłreturnł܂B");
				return false;
			}
			if(!Bun(tk, t, srce->GetToken(t))) return false;
			tk += NULL_TOKEN;
			tk += RETURN_TOKEN;
			pst = this;
			while(pst != pst->frp){
				tk += BREAK_TOKEN;
				breaknaihani = pst->hensuname.GetLength();
				for(ii = pst->hensuidx.GetLength()-1; ii >= 0; ii--){
					if(frp->funchensuu.GetConst()[pst->hensuidx.GetConst()[ii]].type.GetConst()[0] == CONST_TOKEN) continue;
					fi = TokenTtoTypeId(frp->funchensuu.GetConst()[pst->hensuidx.GetConst()[ii]].type.GetConst(), oi=0);
					if(fi > ENDCLASS_TYPEID) continue;
					if(fi < 0){
						if(fi != REF_TYPEID && fi != LIST_TYPEID && fi < ENDTHREAD_TYPEID) continue;
						if(frp == root) tk += GBL_TOKEN;
						tk += ~pst->hensuidx.GetConst()[ii];
						tk += DELETE_TOKEN;
						tk += SEMICOLON_TOKEN;
					}else if(funclist.Get(fi)->selftype == CLASS_BLOCK){
						if(frp == root){
							type = GBL_TOKEN;
						}else{
							type.Clear();
						}
						type += ~pst->hensuidx.GetConst()[ii];
						type += POINT_TOKEN;
						funclist.Get(fi)->CallDel(tk, type);
					}
				}
				tk += COMMA_TOKEN;
				pst = pst->parent;
			}
			for(ii = hensuidx.GetLength()-1; ii >= tpcount+hikisuucount; ii--){
				if(frp->funchensuu.GetConst()[hensuidx.GetConst()[ii]].type.GetConst()[0] == CONST_TOKEN) continue;
				fi = TokenTtoTypeId(frp->funchensuu.GetConst()[hensuidx.GetConst()[ii]].type.GetConst(), oi=0);
				if(fi > ENDCLASS_TYPEID) continue;
				if(fi < 0){
					if(fi != REF_TYPEID && fi != LIST_TYPEID && fi < ENDTHREAD_TYPEID) continue;
					if(frp == root) tk += GBL_TOKEN;
					tk += ~hensuidx.GetConst()[ii];
					tk += DELETE_TOKEN;
					tk += SEMICOLON_TOKEN;
				}else if(funclist.Get(fi)->selftype == CLASS_BLOCK){
					if(frp == root){
						type = GBL_TOKEN;
					}else{
						type.Clear();
					}
					type += ~hensuidx.GetConst()[ii];
					type += POINT_TOKEN;
					funclist.Get(fi)->CallDel(tk, type);
				}
			}
			tk += RETURN_TOKEN;
			returnshita = true;
			break;
		case BRANCH_TOKEN:
		case LOOP_TOKEN:
			if(!ClassnaiKinsoku()) return false;
			if(srce->GetToken(t) != CHUUKAKKOOPEN_TOKEN){
				ErrorMessage.Add(srce->filename, srce->gyousuu, L"'{' ܂B");
				return false;
			}
			tk += CHUUKAKKOOPEN_TOKEN;
			tk += children.GetLength();
			if((pst = BlockOpen(NULL, (kin==BRANCH_TOKEN ? BRANCH_BLOCK : LOOP_BLOCK))) == NULL){
				ErrorMessage.Add(srce->filename, srce->gyousuu, L"svcȃG[łB");
				return false;
			}
			if(!pst->MakeTree()) return false;
			tk += CHUUKAKKOCLOSE_TOKEN;
			break;
		case SWITCH_TOKEN:
		case LOCK_TOKEN:
			if(!ClassnaiKinsoku()) return false;
			tk += CHUUKAKKOOPEN_TOKEN;
			tk += children.GetLength();
			if((pst = BlockOpen(NULL, (kin==SWITCH_TOKEN ? SWITCH_BLOCK : LOCK_BLOCK))) == NULL){
				ErrorMessage.Add(srce->filename, srce->gyousuu, L"svcȃG[łB");
				return false;
			}
			if(srce->GetToken(t) != SHOUKAKKOOPEN_TOKEN){
				ErrorMessage.Add(srce->filename, srce->gyousuu, L"'(' ܂B");
				return false;
			}
			tk += SHOUKAKKOOPEN_TOKEN;
			if(!Shiki(tk, *srce, t, NULL_TOKEN, srce->GetToken(t), SHOUKAKKOCLOSE_TOKEN, *this)) return false;
			tk += SHOUKAKKOCLOSE_TOKEN;
			if(srce->GetToken(t) != CHUUKAKKOOPEN_TOKEN){
				ErrorMessage.Add(srce->filename, srce->gyousuu, L"'{' ܂B");
				return false;
			}
			if(!pst->MakeTree()) return false;
			tk += CHUUKAKKOCLOSE_TOKEN;
			break;
		case DO_TOKEN:
			if(!KoubunKanouJoutai(LOOP_BLOCK)) return false;
			teigikinshi = true;
			tk += DO_TOKEN;
			ki = srce->GetToken(t);
			switch(ki){
			case COLON_TOKEN:
				if(extloop->mode != 0){
					ErrorMessage.Add(srce->filename, srce->gyousuu, L"\G[łB");
					return false;
				}
				extloop->mode = 1;
				break;
			case SEMICOLON_TOKEN:
				break;
			default:
				ErrorMessage.Add(srce->filename, srce->gyousuu, L"\G[łB");
				return false;
			}
			tk += ki;
			break;
		case CONTINUE_TOKEN:
			if(!KoubunKanouJoutai(LOOP_BLOCK)) return false;
			teigikinshi = true;
			tk += CONTINUE_TOKEN;
			ki = srce->GetToken(t);
			switch(ki){
			case COLON_TOKEN:
				if(extloop->mode != 1){
					ErrorMessage.Add(srce->filename, srce->gyousuu, L"\G[łB");
					return false;
				}
				extloop->mode = 2;
				break;
			case SEMICOLON_TOKEN:
				break;
			default:
				ErrorMessage.Add(srce->filename, srce->gyousuu, L"\G[łB");
				return false;
			}
			tk += ki;
			break;
		case WHILE_TOKEN:
			if(!KoubunKanouJoutai(LOOP_BLOCK)) return false;
			teigikinshi = true;
			tk += WHILE_TOKEN;
			ki = srce->GetToken(t);
			switch(ki){
			case SEMICOLON_TOKEN:
				tk += SEMICOLON_TOKEN;
				break;
			default:
				if(extloop->mode < 1 || 2 < extloop->mode){
					ErrorMessage.Add(srce->filename, srce->gyousuu, L"\G[łB");
					return false;
				}
				extloop->mode = 3;
				if(!Shiki(tk, *srce, t, NULL_TOKEN, ki, COLON_TOKEN, *this)) return false;
				tk += COLON_TOKEN;
				break;
			}
			break;
		case COND_TOKEN:
			if(!KoubunKanouJoutai(BRANCH_BLOCK)) return false;
			teigikinshi = true;
			if((extbranch->mode < 0 ? -extbranch->mode : extbranch->mode) >= 2){
				ErrorMessage.Add(srce->filename, srce->gyousuu, L"\G[łB");
				return false;
			}
			tk += COND_TOKEN;
			if(srce->GetToken(t) == SHOU_TOKEN){
				if(extbranch->mode > 0){
					ErrorMessage.Add(srce->filename, srce->gyousuu, L"\G[łB");
					return false;
				}
				if(srce->GetToken(t) != OTHERKIND_TOKEN || !extbranch->addlabel(srce->source.GetConst()+t, srce->idx-t)){
					ErrorMessage.Add(srce->filename, srce->gyousuu, L"\G[łB");
					return false;
				}
				if(srce->GetToken(t) != DAI_TOKEN){
					ErrorMessage.Add(srce->filename, srce->gyousuu, L"'>' ܂B");
					return false;
				}
				tk += extbranch->label.GetLength()-1;
				extbranch->mode = -1;
			}else{
				if(extbranch->mode < 0){
					ErrorMessage.Add(srce->filename, srce->gyousuu, L"\G[łB");
					return false;
				}
				srce->idx = t;
				extbranch->mode = 1;
			}
			if(!Shiki(tk, *srce, t, NULL_TOKEN, srce->GetToken(t), COLON_TOKEN, *this)) return false;
			tk += COLON_TOKEN;
			break;
		case COMM_TOKEN:
			if(!KoubunKanouJoutai(BRANCH_BLOCK)) return false;
			if((extbranch->mode >= 0 && extbranch->mode != 2) || extbranch->mode == -4){
				ErrorMessage.Add(srce->filename, srce->gyousuu, L"\G[łB");
				return false;
			}
			tk += COMM_TOKEN;
			extbranch->dino = 0;
			extbranch->mode = (extbranch->mode < 0 ? -4 : 4);
			if(srce->GetToken(t) != COLON_TOKEN){
				ErrorMessage.Add(srce->filename, srce->gyousuu, L"':' ܂B");
				return false;
			}
			tk += COLON_TOKEN;
			break;
		case DIFF_TOKEN:
			if(!KoubunKanouJoutai(BRANCH_BLOCK)) return false;
			if(extbranch->mode >= 0 || extbranch->mode == -2){
				ErrorMessage.Add(srce->filename, srce->gyousuu, L"\G[łB");
				return false;
			}
			tk += DIFF_TOKEN;
			if(srce->GetToken(t) != SHOU_TOKEN){
				ErrorMessage.Add(srce->filename, srce->gyousuu, L"'<' ܂B");
				return false;
			}
			if(srce->GetToken(t) != OTHERKIND_TOKEN || ((ipr=extbranch->findlabel(srce->source.GetConst()+t, srce->idx-t)) < 0)){
				ErrorMessage.Add(srce->filename, srce->gyousuu, L"\G[łB");
				return false;
			}
			if(srce->GetToken(t) != DAI_TOKEN){
				ErrorMessage.Add(srce->filename, srce->gyousuu, L"'>' ܂B");
				return false;
			}
			if(ipr < extbranch->dino){
				ErrorMessage.Add(srce->filename, srce->gyousuu, L"\G[łB");
				return false;
			}
			tk += ipr;
			extbranch->dino = ipr+1;
			extbranch->mode = -3;
			if(srce->GetToken(t) != COLON_TOKEN){
				ErrorMessage.Add(srce->filename, srce->gyousuu, L"':' ܂B");
				return false;
			}
			tk += COLON_TOKEN;
			break;
		case ELSE_TOKEN:
			if(!KoubunKanouJoutai(BRANCH_BLOCK)) return false;
			teigikinshi = true;
			tk += ELSE_TOKEN;
			ki = srce->GetToken(t);
			switch(ki){
			case COLON_TOKEN:
				if(extbranch->mode % 2 == 0 && extbranch->mode != -4){
					ErrorMessage.Add(srce->filename, srce->gyousuu, L"\G[łB");
					return false;
				}
				if(extbranch->mode < 0){
					extbranch->mode = -2;
				}else{
					extbranch->mode = 2;
				}
				break;
			case SEMICOLON_TOKEN:
				break;
			default:
				ErrorMessage.Add(srce->filename, srce->gyousuu, L"\G[łB");
				return false;
			}
			tk += ki;
			break;
		case CASE_TOKEN:
			if(!KoubunKanouJoutai(SWITCH_BLOCK)) return false;
			teigikinshi = true;
			tk += CASE_TOKEN;
			do{
				if(!ConstShiki(*srce, t, NULL_TOKEN, srce->GetToken(t), type, COLON_TOKEN, *this)) return false;
				tk += type;
				tk += COMMA_TOKEN;
			}while(srce->source.GetConst()[t] == L',');
			tk.GetData()[tk.GetLength()-1] = (srce->idx-t == 1 ? COLON_TOKEN : COLOYAJIRUSHI_TOKEN);
			break;
		case DEFAULT_TOKEN:
			if(!KoubunKanouJoutai(SWITCH_BLOCK)) return false;
			teigikinshi = true;
			tk += DEFAULT_TOKEN;
			ki = srce->GetToken(t);
			if(ki != COLON_TOKEN && ki != COLOYAJIRUSHI_TOKEN && ki != SEMICOLON_TOKEN){
				ErrorMessage.Add(srce->filename, srce->gyousuu, L"\G[łB");
				return false;
			}
			tk += ki;
			break;
		case IF_TOKEN:
			if(!ClassnaiKinsoku()) return false;
			tk += IF_TOKEN;
			if(srce->GetToken(t) != SHOUKAKKOOPEN_TOKEN){
				ErrorMessage.Add(srce->filename, srce->gyousuu, L"'(' ܂B");
				return false;
			}
			tk += SHOUKAKKOOPEN_TOKEN;
			if(!Shiki(tk, *srce, t, NULL_TOKEN, srce->GetToken(t), SHOUKAKKOCLOSE_TOKEN, *this)) return false;
			tk += SHOUKAKKOCLOSE_TOKEN;
			if(!TeigitoIfKinshi()) return false;
			break;
		case BREAK_TOKEN:
			if(!KoubunKanouJoutai(NORMAL_BLOCK)) return false;
			tk += BREAK_TOKEN;
			ki = srce->GetToken(t);
			if(ki == COLON_TOKEN){
				tk += COLON_TOKEN;
				breakin = breakinnest = teigikinshi = true;
			}else{
				breaknaihani = hensuname.GetLength();
				for(ii = hensuidx.GetLength()-1; ii >= tpcount+hikisuucount; ii--){
					if(frp->funchensuu.GetConst()[hensuidx.GetConst()[ii]].type.GetConst()[0] == CONST_TOKEN) continue;
					fi = TokenTtoTypeId(frp->funchensuu.GetConst()[hensuidx.GetConst()[ii]].type.GetConst(), oi=0);
					if(fi > ENDCLASS_TYPEID) continue;
					if(fi < 0){
						if(fi != REF_TYPEID && fi != LIST_TYPEID && fi < ENDTHREAD_TYPEID) continue;
						if(frp == root) tk += GBL_TOKEN;
						tk += ~hensuidx.GetConst()[ii];
						tk += DELETE_TOKEN;
						tk += SEMICOLON_TOKEN;
					}else if(funclist.Get(fi)->selftype == CLASS_BLOCK){
						if(frp == root){
							type = GBL_TOKEN;
						}else{
							type.Clear();
						}
						type += ~hensuidx.GetConst()[ii];
						type += POINT_TOKEN;
						funclist.Get(fi)->CallDel(tk, type);
					}
				}
				if(ki == COMMA_TOKEN){
					tk += COMMA_TOKEN;
					if(!BlockOpenKinshi()) return false;
					if(!TeigitoIfKinshi()) return false;
					ki = srce->GetToken(t);
					if(!parent->MakeTreeSwitch(tk, t, ki)) return false;
				}else{
					if(ki != SEMICOLON_TOKEN){
						ErrorMessage.Add(srce->filename, srce->gyousuu, L"';' ܂B");
						return false;
					}
					tk += SEMICOLON_TOKEN;
				}
			}
			break;
		case CHUUKAKKOOPEN_TOKEN:
			if(!ClassnaiKinsoku()) return false;
			tk += CHUUKAKKOOPEN_TOKEN;
			tk += children.GetLength();
			if((pst = BlockOpen(NULL, NORMAL_BLOCK)) == NULL){
				ErrorMessage.Add(srce->filename, srce->gyousuu, L"svcȃG[łB");
				return false;
			}
			if(!pst->MakeTree()) return false;
			tk += CHUUKAKKOCLOSE_TOKEN;
			break;
		default:
			name = L'\'';
			name.AddTail(srce->source.GetConst()+t, srce->idx-t);
			name += L"' słB";
			name += L'\0';
			ErrorMessage.Add(srce->filename, srce->gyousuu, name.GetConst());
			return false;
		}
		return true;
	}
	bool MakeTree()
	{
		PWCArray<intptr_t> * ptk;
		PWCArray<intptr_t> meniya;
		TokenKind kin;
		int t, il, ii;
		int32_t fi;
		topsrcidx = srce->idx;
		topsrcgyo = srce->gyousuu;
		switch(selftype){
		case SWITCH_BLOCK:
			extswitch = new SwitchExtStruct;
			break;
		case BRANCH_BLOCK:
			extbranch = new BranchExtStruct;
			break;
		case LOOP_BLOCK:
			extloop = new LoopExtStruct;
			break;
		}
		while((kin = srce->GetToken(t)) != NULL_TOKEN && kin != CHUUKAKKOCLOSE_TOKEN){
			ptk = &token[token.GetLength()];
			ptk->Clear();
			gyo += srce->gyousuu;
			if(!MakeTreeSwitch(*ptk, t, kin)) return false;
			if(ptk->GetLength() == 0){
				token.SetLength(token.GetLength()-1);
				gyo.SetLength(gyo.GetLength()-1);
			}
		}
		if(root == this){
			if(kin != NULL_TOKEN || srce->idx != srce->source.GetLength()){
				ErrorMessage.Add(srce->filename, srce->gyousuu, L"\G[łB");
				return false;
			}
		}else{
			if(kin != CHUUKAKKOCLOSE_TOKEN){
				ErrorMessage.Add(srce->filename, srce->gyousuu, L"'}' ܂B");
				return false;
			}
		}
		if(frp != this || selftype == FUNC_BLOCK && rettype.GetConst()[rettype.GetLength()-1] == VOID_TOKEN){
			returnshita = true;
			for(ii = hensuidx.GetLength()-1; ii >= tpcount+hikisuucount; ii--){
				if(frp->funchensuu.GetConst()[hensuidx.GetConst()[ii]].type.GetConst()[0] == CONST_TOKEN) continue;
				fi = TokenTtoTypeId(frp->funchensuu.GetConst()[hensuidx.GetConst()[ii]].type.GetConst(), il=0);
				if(fi > ENDCLASS_TYPEID) continue;
				if(fi < 0){
					if(fi != REF_TYPEID && fi != LIST_TYPEID && fi < ENDTHREAD_TYPEID) continue;
					if(frp == root) defdel += GBL_TOKEN;
					defdel += ~hensuidx.GetConst()[ii];
					defdel += DELETE_TOKEN;
					defdel += SEMICOLON_TOKEN;
				}else if(funclist.Get(fi)->selftype == CLASS_BLOCK){
					if(frp == root){
						meniya = GBL_TOKEN;
					}else{
						meniya.Clear();
					}
					meniya += ~hensuidx.GetConst()[ii];
					meniya += POINT_TOKEN;
					funclist.Get(fi)->CallDel(defdel, meniya);
				}
			}
		}
		return true;
	}
	bool FileRead(const wchar_t * const fn)
	{
		if(!srce->Load(fn)) return false;
		srce->filename += L'\0';
		srclist[srce->filename.GetConst()].set(this);
		srce->filename.SetLength(srce->filename.GetLength()-1);
		if(!MakeTree()) return false;
		return true;
	}
	void FlgReset()
	{
		breakin = false;
		teigikinshi = false;
		returnshita = false;
		breaknaihani = -1;
		tpcount = 0;
		hikisuucount = 0;
		golbalgetahoka = 0;
		byteadress = 0;
		topsrcidx = 0;
		topsrcgyo = 0;
		touka = false;
		gblhani = INT_MAX;
		mbrhani = INT_MAX;
	}
	void ArrayReset()
	{
		myname.Clear();
		token.Clear();
		defdel.Clear();
		gyo.Clear();
		funchensuu.Clear();
		hensuname.Clear();
		hensuidx.Clear();
		subfunc.Clear();
		backpatch.Clear();
		breakpatch.Clear();
	}
	void Clear()
	{
		tokubetuerr = false;
		Del();
		funclist.Clear();
		funclist.Add(this);
		srclist.Clear();
		dlllist.Clear();
		literallist.Clear();
		literaltotal = 0;
		ArrayReset();
		FlgReset();
	}
};
Functions<SourceTree> SourceTree::funclist;
StrIdxArray< SIASTreeNodeItem<SourceTree> > SourceTree::srclist;
StrIdxArray<SIASDLLItem> SourceTree::dlllist;
PWCArrayQuad< PWCArray<int8_t> > SourceTree::literallist;
intptr_t SourceTree::literaltotal;
bool SourceTree::tokubetuerr;
